import globalConfig from '../src/js/config/config';

/**
 * @typedef AddonItem
 * @property {string} user_role - for what role tab shows
 * @see client/src/js/common/user-roles.js
 * @property {object} tabs
 * @property {string} tabs.page
 * @property {string} tabs.name
 * @property {string} tabs.systemName
 * @property {string} tabs.dataCy
 * @property {string} tabs.path
 * @property {function} component
 * @example {
 *      user_role: [USER_ROLES.PROJECT_OPERATIONS_ADMIN, USER_ROLES.PROJECT_SYSTEM_ADMIN],
 *      tabs: {
 *          page: '/admin',
 *          name: NAMES_OF_TABS.ZONE_MANAGEMENT,
 *          systemName: 'zone_manager',
 *          dataCy: 'nav_submenu_admin_zone_manager',
 *          path: '/admin/zone_manager',
 *      },
 *      component: () => (<App />),
 * }
 */

/**
 * @description Mapping configuration constants (_client_config.js) to addon `systemName` (features/*.js)
 * @desc globalConfig.FEATURES - configuration constants file `client_config.js`
 * @desc `vehicle_certification` is a value `default.tabs.systemName` in file `vehicle_certification.js`
 * @desc `zone_manager` is a value `default.tabs.systemName` in file `zone_manager.js`
 * @see client/features/vehicle_certification.js
 * @see client/features/zone_manager.js
 * @see client/public/_client_config.js
 * @type {{vehicle_certification: (boolean|*), zone_manager: (boolean|*)}}
 */
const mapping = {
    vehicle_certification: globalConfig?.FEATURES?.VEHICLE_CERTIFICATION,
    zone_manager: globalConfig?.FEATURES?.ZONE_MANAGEMENT,
};

/**
 * @description export addons from folder `client/features` exclude files `client/features/featuresList.js` and features that enabled in globalConfig
 * @returns {AddonItem[]}
 */
function getFeatures() {
    const context = require.context('./', false, /.*\.js$/);
    const keys = context.keys();
    if (keys.length > 0) {
        return context.keys().reduce((acc, key) => {
            if (mapping[context(key).default?.tabs?.systemName]) {
                acc.push(context(key).default);
            }
            return acc;
        }, []);
    } 
    return [];
}

export const modules_list = getFeatures();
