import React from 'react';
import Modal from 'react-modal';
import { useSelector, useDispatch } from 'react-redux';
import PropTypes from 'prop-types';
import { VEHICLE_CERTIFICATION } from 'common/ui-labels';
import { selectDeleteVMStatus, selectDeletedVMs } from '../store/selectors';
import { closeDeleteCertModal, removeVehicleModel } from '../store/actions';


function DeleteCertificationForm(props) {
    const { close, submit, className } = props;
    return (
        <form className={className}>
            <div
                className="col-md-12"
                style={{ overflowY: 'auto', overflowX: 'hidden' }}
            >
                <div className="Form-Buttons">
                    <button type="button" onClick={submit} data-id="cert-class-delete-ok">{VEHICLE_CERTIFICATION.BUTTON_OK}</button>
                    <button type="button" data-id="cert-class-delete-cancel" onClick={close}>{VEHICLE_CERTIFICATION.BUTTON_CANCEL}</button>
                </div>
            </div>
        </form>
    );
}

DeleteCertificationForm.defaultProps = {
    close: () => {},
    submit: () => {},
    className: '',
};

DeleteCertificationForm.propTypes = {
    close: PropTypes.func,
    submit: PropTypes.func,
    className: PropTypes.string,
};

export default function DeleteVehicleModel(props) {
    const dispatch = useDispatch();
    const open = useSelector(selectDeleteVMStatus);
    const vehicleModels = useSelector(selectDeletedVMs);
    const { style } = props;
    
    function submit() {
        dispatch(removeVehicleModel(vehicleModels));
        dispatch(closeDeleteCertModal());
    }
    function close() {
        dispatch(closeDeleteCertModal());
    }
    
    return (
        <Modal
            contentLabel="deleteVehicleModel"
            isOpen={open}
            style={style}
        >
            <div className="RPP-Modal">
                <span className="Modal-Header">
                    {VEHICLE_CERTIFICATION.DELETE_CERT_CLASS_MODAL_TITLE}
                </span>
                <DeleteCertificationForm
                    className="Modal-Form"
                    close={close}
                    submit={submit}
                />
            </div>
        </Modal>
    );
}

DeleteVehicleModel.propTypes = {
    style: PropTypes.shape({}),
};

DeleteVehicleModel.defaultProps = {
    style: {},
};
