import React from 'react';
import { Field, reduxForm } from 'redux-form';
import { connect } from 'react-redux';
import _IsEmpty from 'lodash/isEmpty';
import PropTypes from 'prop-types';
import { injectIntl } from 'react-intl';
import { VEHICLE_CERTIFICATION, COMPONENTS } from 'common/ui-labels';
import { FORMS_NAME } from '../../common/constants';
import { selectVehicles } from '../../store/selectors';
import MultiSelectComponent from '../../../../src/js/components/modals/MultiSelectComponent';
import SaveButtons from '../../../../src/js/components/modals/SaveButtons';
import { filterSelectBoxOptions } from '../../../../src/js/utils/utils';


const required = value => (_IsEmpty(value) ? 'Required' : undefined);

let EditVehicleCertForm = (props) => {
    const { close, className, vehicles, handleSubmit, invalid, intl } = props;

    return (
        <form className={className} onSubmit={handleSubmit}>
            <div className="Form-Line row">
                <div className="Form-Label col-md-4">{VEHICLE_CERTIFICATION.VEHICLES}*</div>
                <div className="col-md-8">
                    <Field
                        name="vehicles"
                        dataId="vehicle-cert-add"
                        component={MultiSelectComponent}
                        placeholder={COMPONENTS.SELECT_COMPONENT_PLACEHOLDER(intl)}
                        noResultsText={COMPONENTS.SELECT_COMPONENT_NO_RESULTS_TEXT}
                        options={vehicles}
                        filterOptions={filterSelectBoxOptions}
                        validate={[required]}
                    />
                </div>
            </div>
            <SaveButtons
                submit={handleSubmit}
                close={close}
                disabled={invalid}
                dataId="vehicle-cert-edit"
            />
        </form>
    );
};

EditVehicleCertForm.propTypes = {
    close: PropTypes.func,
    handleSubmit: PropTypes.func,
    intl: PropTypes.shape({ formatMessage: PropTypes.func }),
    className: PropTypes.string,
    vehicles: PropTypes.arrayOf(PropTypes.shape()),
    invalid: PropTypes.bool,
};

EditVehicleCertForm.defaultProps = {
    close: () => {},
    handleSubmit: () => {},
    intl: {
        formatMessage: () => {
        },
    },
    className: '',
    vehicles: [],
    invalid: false,
};

EditVehicleCertForm = reduxForm({
    form: FORMS_NAME.VEHICLE_CERT_EDIT_FORM,
})(EditVehicleCertForm);

const mapStateToForm = (state) => {
    const vehicles = selectVehicles(state);
    return ({
        vehicles: vehicles.reduce((memo, vehicle) => {
            if (!vehicle.vehicleModelName) memo.push({ ...vehicle, value: vehicle.obj_uid, label: vehicle.name });
            return memo;
        }, []),
    });
};

EditVehicleCertForm = connect(mapStateToForm)(injectIntl(EditVehicleCertForm));

export default EditVehicleCertForm;
