import React from 'react';
import Modal from 'react-modal';
import { useSelector, useDispatch } from 'react-redux';
import PropTypes from 'prop-types';
import { VEHICLE_CERTIFICATION } from 'common/ui-labels';
import { selectEditVehicleStatus, selectCheckedVMs } from '../../store/selectors';
import { closeEditVehicleModal, addVehicleCertification } from '../../store/actions';
import EditVehicleCertForm from './EditVehicleCertForm';


export default function EditVehicleCert(props) {
    const dispatch = useDispatch();
    const open = useSelector(selectEditVehicleStatus);
    const vehicleModels = useSelector(selectCheckedVMs);
    const { style } = props;
    
    function submit({ vehicles }) {
        dispatch(addVehicleCertification(vehicles, vehicleModels[0]));
        dispatch(closeEditVehicleModal());
    }
    function close() {
        dispatch(closeEditVehicleModal());
    }
    
    return (
        <Modal
            contentLabel="editVehicleCertification"
            isOpen={open}
            style={style}
        >
            <div className="RPP-Modal">
                <div className="Modal-Header capitalizedText">
                    {VEHICLE_CERTIFICATION.EDIT_VEHICLE_MODAL_TITLE}
                </div>
                <div className="Modal-Header-Subtitle">
                    {VEHICLE_CERTIFICATION.EDIT_VEHICLE_MODAL_MESSAGE}
                </div>
                <EditVehicleCertForm
                    className="Modal-Form"
                    close={close}
                    onSubmit={submit}
                />
            </div>
        </Modal>
    );
}

EditVehicleCert.propTypes = {
    style: PropTypes.shape({}),
};

EditVehicleCert.defaultProps = {
    style: {},
};
