import React from 'react';
import { Field, reduxForm, touch } from 'redux-form';
import { injectIntl } from 'react-intl';
import { connect } from 'react-redux';
import PropTypes from 'prop-types';
import { VEHICLE_CERTIFICATION, COMPONENTS, NAME_ALREADY_EXISTS } from 'common/ui-labels';
import { FORMS_NAME, CERT_DEFAULT_VALUES } from '../../common/constants';
import RenderField from '../../../../src/js/components/modals/RenderField';
import { selectEditedVehModel } from '../../store/selectors';


const renderField = RenderField(4, 8);

let EditVehicleModelForm = (props) => {
    const { close, submit, vehicleModel, className, invalid } = props;
    
    return (
        <form className={className} onSubmit={(e) => { e.preventDefault(); }}>
            <div
                className="col-md-12"
                style={{ overflowY: 'auto', overflowX: 'hidden' }}
            >
                <div className="Form-Line row">
                    <Field
                        autoFocus={!vehicleModel}
                        className="Form-Input"
                        name="name"
                        dataId="cert-class-edit-name"
                        component={renderField}
                        label={VEHICLE_CERTIFICATION.EDIT_CERT_CLASS_MODAL_FORM_NAME}
                        type="text"
                    />
                </div>
                <div className="Form-Line row" style={{ textAlign: 'center', marginTop: '15px' }}>
                    <div className="Form-Label col-md-4">
                        {VEHICLE_CERTIFICATION.CERTIFICATION}
                    </div>
                    <div className="col-md-8 text-left" data-id="vehicle-model-certification-required">
                        <Field
                            name="certification_required"
                            component="input"
                            type="checkbox"
                        />
                    </div>
                </div>
                <div className="Form-Buttons">
                    <button type="button" onClick={submit} disabled={invalid} data-id="cert-class-edit-save">{VEHICLE_CERTIFICATION.BUTTON_SAVE}</button>
                    <button type="button" data-id="cert-class-edit-cancel" onClick={close}>{VEHICLE_CERTIFICATION.BUTTON_CANCEL}</button>
                </div>
            </div>
        </form>
    );
};

EditVehicleModelForm.defaultProps = {
    close: () => {},
    submit: () => {},
    className: '',
    vehicleModel: null,
    isEditMode: false,
    allModels: [],
    dispatch: () => { },
    intl: {
        formatMessage: () => {
        },
    },
    invalid: true,
};

EditVehicleModelForm.propTypes = {
    close: PropTypes.func,
    submit: PropTypes.func,
    className: PropTypes.string,
    isEditMode: PropTypes.bool,
    vehicleModel: PropTypes.shape(),
    allModels: PropTypes.arrayOf(PropTypes.shape({})),
    dispatch: PropTypes.func,
    intl: PropTypes.shape({
        formatMessage: PropTypes.func,
    }),
    invalid: PropTypes.bool,
};

const validate = (values, props) => {
    const errors = {};

    if (!values.name) {
        errors.name = COMPONENTS.VALIDATION.REQUIRED;
    } else if (values.name.length > 255) {
        errors.name = COMPONENTS.VALIDATION.MAXIMUM_LENGTH_FUNC(255);
    } else if (!props.isEditMode && props.allModels.length >= CERT_DEFAULT_VALUES.MAX_MODELS) {
        errors.name = VEHICLE_CERTIFICATION.MAX_LIMIT(props.intl, CERT_DEFAULT_VALUES.MAX_MODELS);
    } else if (props.allModels && props.allModels.find(x => x.name === values.name && x.id !== values.id)) {
        errors.name = NAME_ALREADY_EXISTS;
        props.dispatch(touch(FORMS_NAME.CERTIFICATION_EDIT_FORM, 'name'));
    }
    return errors;
};

EditVehicleModelForm = reduxForm({
    form: FORMS_NAME.CERTIFICATION_EDIT_FORM,
    validate,
})(EditVehicleModelForm);
EditVehicleModelForm = connect(state => ({ initialValues: selectEditedVehModel(state) }))(EditVehicleModelForm);

export default injectIntl(EditVehicleModelForm);
