import * as api from '../../api';
import { ACTIONS } from '../../common/constants';
import { errorHandlerGetRequest } from '../../../../src/js/stores/actions/errorHandlerActions';


export const loadVehicleCertifications = () => async (dispatch) => {
    try {
        const vehiclesCertifications = await api.getVehicleCertifications();
        dispatch({
            type: ACTIONS.VEHICLE_CERTIFICATIONS_SET,
            params: vehiclesCertifications,
        });
    } catch (err) {
        errorHandlerGetRequest(err, dispatch);
    }
};

export const deleteVehicleCertification = params => async (dispatch) => {
    const promises = [];
    
    for (let i = 0; i < params.length; i += 1) {
        const requestData = { obj_uid: params[i].obj_uid, id: 0 };
        promises.push(api.updateVehicleCertification(requestData)
            .then(() => {
                dispatch({
                    type: ACTIONS.VEHICLE_CERTIFICATIONS_UPDATED,
                    params: requestData,
                });
            })
            .catch((err) => {
                errorHandlerGetRequest(err, dispatch);
            }));
    }
    return Promise.all(promises);
};

export const addVehicleCertification = (vehicles, vehicleModel) => async (dispatch) => {
    const promises = [];
    for (let i = 0; i < vehicles.length; i += 1) {
        const requestData = {
            obj_uid: vehicles[i].obj_uid,
            id: vehicleModel.id,
            certification_required: vehicleModel.certification_required,
        };
        promises.push(api.updateVehicleCertification(requestData)
            .then((result) => {
                dispatch({
                    type: ACTIONS.VEHICLE_CERTIFICATIONS_UPDATED,
                    params: result,
                });
            })
            .catch((err) => {
                errorHandlerGetRequest(err, dispatch);
            }));
    }
    return Promise.all(promises);
};

export const selectTableVehicle = params => ({
    type: ACTIONS.VEHICLE_CERTIFICATIONS_SINGLE_SELECT,
    params,
});

export const selectTableVehicles = params => ({
    type: ACTIONS.VEHICLE_CERTIFICATIONS_SELECT,
    params,
});

export const unselectTableVehicle = params => ({
    type: ACTIONS.VEHICLE_CERTIFICATIONS_UNSELECT,
    params,
});
