import { ACTIONS } from '../../common/constants';
import { bulkSelectReducerFunc, singleSelectReducerFunc, unselectReducerFunc } from '../../common/utils';

const initialState = { items: [], selected: [] };


const vehicleModels = (state = initialState, action) => {
    switch (action.type) {
        case ACTIONS.VEHICLE_MODELS_SET: {
            return { ...initialState, items: [...action.params] };
        }
        case ACTIONS.VEHICLE_MODELS_UPDATED: {
            const newState = { ...state, items: [] };
            state.items.forEach((vehicleModel) => {
                if (vehicleModel.id !== action.params.id) {
                    newState.items.push(vehicleModel);
                } else {
                    newState.items.push(action.params);
                }
            });
            return newState;
        }
        case ACTIONS.VEHICLE_MODELS_CREATED: {
            const newState = { ...state, items: [...state.items] };
            const params = Array.isArray(action.params) ? action.params[0] : action.params;
            const vehicleModelExist = newState.items.find(vehicleModel => vehicleModel.id === params.id);
            if (!vehicleModelExist) {
                newState.items.push(params);
            }
            return newState;
        }
        case ACTIONS.VEHICLE_MODELS_DELETED: {
            const items = state.items.filter(vehicleModel => vehicleModel.id !== action.params.id);
            const selected = state.selected.filter(vehicleModel => vehicleModel.id !== action.params.id);
            return { items, selected };
        }
        case ACTIONS.VEHICLE_MODELS_SINGLE_SELECT: {
            return singleSelectReducerFunc(state, action.params, 'id');
        }
        case ACTIONS.VEHICLE_MODELS_SELECT: {
            return bulkSelectReducerFunc(state, action.params, 'id');
        }
        case ACTIONS.VEHICLE_MODELS_UNSELECT: {
            return unselectReducerFunc(state, action.params, 'id');
        }
        default:
            return state;
    }
};

export default vehicleModels;
