import { TRACKABLE_CATEGORY } from 'common/constants';


export const selectVehicleModels = state => state.vehicleCertificationManagement.vehicleModels.items.reduce((memo, vm) => {
    const vehiclesCertifications = state.vehicleCertificationManagement.vehicleCertifications.items;
    const driversCertifications = state.vehicleCertificationManagement.driverCertifications.items;
    
    const vehiclesCount = vehiclesCertifications.filter(vehicleCert => vehicleCert.id === vm.id).length;
    const driversCount = driversCertifications.reduce((result, driverCertification) => {
        if (driverCertification.certification && driverCertification.certification.some(driverCert => driverCert.id === vm.id)) {
            result += 1;
        }
        return result;
    }, 0);
    memo.push({ ...vm, vehiclesCount, driversCount });
    return memo;
}, []);

function findVehModelNameById(certs, id) {
    const cert = certs.find(c => c.id === id);
    return cert ? cert.name : '';
}

export const selectVehicles = state => Object.values(state.entities.trackables.byUid).reduce((memo, trackable) => {
    if (trackable.category === TRACKABLE_CATEGORY.VEHICLE) {
        const vehicleCert = state.vehicleCertificationManagement.vehicleCertifications.items.find(vm => vm.obj_uid === trackable.uid);
        const vehicleModels = state.vehicleCertificationManagement.vehicleModels.items;
        memo.push({
            name: trackable.name,
            obj_uid: trackable.uid,
            vehicleModelName: vehicleCert ? findVehModelNameById(vehicleModels, vehicleCert.id) : '',
            vehicleModelId: vehicleCert ? vehicleCert.id : null,
        });
    }
    return memo;
}, []);

export const selectDrivers = state => Object.values(state.entities.trackables.byUid).reduce((memo, trackable) => {
    if (trackable.category === TRACKABLE_CATEGORY.PERSON) {
        const driver = state.vehicleCertificationManagement.driverCertifications.items.find(driverCert => driverCert.obj_uid === trackable.uid) || {};
        const vehicleModels = state.vehicleCertificationManagement.vehicleModels.items;
        const vehicleModelsNames = (driver.certification || []).map(cert => findVehModelNameById(vehicleModels, cert.id)).join(', ');
        const vehicleModelsIds = (driver.certification || []).map(cert => cert.id);
        memo.push({
            name: trackable.name,
            obj_uid: trackable.uid,
            vehicleModelsIds,
            vehicleModelsNames,
            certification: driver.certification || [],
        });
    }
    return memo;
}, []);

export const selectCheckedVMs = state => state.vehicleCertificationManagement.vehicleModels.selected;
export const selectDeleteVMStatus = state => state.vehicleCertificationManagement.modals.deleteVehicleModel.open;
export const selectDeletedVMs = state => state.vehicleCertificationManagement.modals.deleteVehicleModel.vehicleModels;
export const selectEditVMStatus = state => state.vehicleCertificationManagement.modals.editVehicleModel.open;
export const selectEditedVehModel = state => state.vehicleCertificationManagement.modals.editVehicleModel.vehicleModel;
export const selectCheckedDrivers = state => state.vehicleCertificationManagement.driverCertifications.selected;
export const selectCheckedVehicles = state => state.vehicleCertificationManagement.vehicleCertifications.selected;
export const selectDeleteVehicleStatus = state => state.vehicleCertificationManagement.modals.deleteVehicleCertification.open;
export const selectDeleteDriverStatus = state => state.vehicleCertificationManagement.modals.deleteDriverCertification.open;
export const selectEditVehicleStatus = state => state.vehicleCertificationManagement.modals.editVehicleCertification.open;
export const selectEditDriverStatus = state => state.vehicleCertificationManagement.modals.editDriverCertifications.open;
