import { addLocaleData } from 'react-intl';
import en from 'react-intl/locale-data/en';
import ru from 'react-intl/locale-data/ru';
import zh from 'react-intl/locale-data/zh';
import ja from 'react-intl/locale-data/ja';

// Our translated strings
import localeDataEn from './en.json';
import localeDataRu from './ru.json';
import localeDataZh from './zh.json';
import localeDataJa from './ja.json';

const localeData = {
    ...localeDataEn, ...localeDataRu, ...localeDataZh, ...localeDataJa,
};

addLocaleData([...en, ...ru, ...zh, ...ja]);

// Define user's language. Different browsers have the user locale defined
// on different fields on the `navigator` object, so we make sure to account
// for these different by checking all of them
let navLanguage = (navigator.languages && navigator.languages[0]) || navigator.language || navigator.userLanguage;

// Split locales with a region code
const languageWithoutRegionCode = navLanguage.toLowerCase().split(/[_-]+/)[0];

// Try full locale, try locale without region code, fallback to 'en'
export const messages = localeData[languageWithoutRegionCode] || localeData[navLanguage] || localeData.en;

if (!localeData[languageWithoutRegionCode] && !localeData[navLanguage]) {
    navLanguage = 'en';
}

export const language = navLanguage;
