import React, { Component } from 'react';
import { connect } from 'react-redux';
import PropTypes from 'prop-types';
import { setLocalStorageKeyValue } from 'utils';
import { STORAGE_KEY, ROUTES } from 'common';
import NavBar from 'components/NavBar';
import Content from 'components/Content';
import Layout from 'components/layout/Layout';
import NavBarLayout from 'components/layout/NavBarLayout';
import ContentLayout from 'components/layout/ContentLayout';
import 'antd/lib/date-picker/style/css';
import '../../styles/AppStyles.scss';


class App extends Component {
    static propTypes = {
        pathname: PropTypes.string,
        access: PropTypes.shape({}),
        history: PropTypes.shape({}),
    };
    
    static defaultProps = {
        pathname: '',
        access: {},
        history: {},
    };

    componentDidUpdate(prevProps) {
        const { pathname, access: { currentRole } } = prevProps;
        const roleChanged = currentRole !== this.props.access.currentRole;
        const pathChanged = pathname !== this.props.pathname;
        const rootPath = this.props.pathname === ROUTES.ROOT_ROUTE;
        const loadingPath = this.props.pathname === ROUTES.LOADING_ROUTE;

        if (roleChanged) {
            setLocalStorageKeyValue(STORAGE_KEY.LAST_PAGE, '');
        }

        if (pathChanged && !rootPath && !loadingPath) {
            setLocalStorageKeyValue(STORAGE_KEY.LAST_PAGE, this.props.pathname);
        }
    }

    render() {
        return (
            <Layout
                renderNavBar={() => <NavBarLayout renderContent={() => <NavBar />} />}
                renderMainContent={() => <ContentLayout renderContent={() => <Content history={this.props.history} />} />}
            />
        );
    }
}

const mapStateToProps = (state) => {
    const { access } = state.user;
    const { pages } = state.user.scope;
    const { pathname } = state.router.location;

    return { pages, pathname, access };
};

export default connect(mapStateToProps)(App);
