/* eslint-disable */
import L from 'leaflet';
import { IntlProvider } from 'react-intl';
import { recalculatePolygon, getVerticesLimit } from 'utils';
import Polygon from 'stores/classes/Polygon';
import store from 'stores/LocationStore';
import { LEAFLET } from 'common/ui-labels';
import { GEOMETRY_RESTRICTION_TYPES } from './index';
import { messages, language } from '../../../locales';


const { intl } = new IntlProvider({ locale: language, messages }, {}).getChildContext();

/**
 * Only changed methods joined with client/node_modules/leaflet-draw/dist/leaflet.draw-src.js
 * search: L.EditToolbar.Edit = L.Handler.extend({...})
 */
export const editToolbarExtend = () => ({
    statics: {
        TYPE: 'edit'
    },

    // @method initialize(): void
    initialize: function (map, options) {
        L.Handler.prototype.initialize.call(this, map);

        L.setOptions(this, options);
        // file client/node_modules/leaflet-draw/dist/leaflet.draw-src.js
        // search: L.drawLocal = {
        L.drawLocal = { // NEW
            draw: {
                handlers: {
                    ...L.drawLocal.draw.handlers, // 4 more
                    rectangle: {
                        tooltip: {
                            start: LEAFLET.DRAW.RECTANGLE_TOOLTIP.START(intl),
                        },
                    },
                    simpleshape: {
                        tooltip: {
                            end: LEAFLET.DRAW.SIMPLESHAPE_TOOLTIP.END(intl),
                        },
                    },
                    polygon: {
                        tooltip: {
                            cont: LEAFLET.DRAW.POLYGON_TOOLTIP.CONT(intl),
                            end: LEAFLET.DRAW.POLYGON_TOOLTIP.END(intl),
                            start: LEAFLET.DRAW.POLYGON_TOOLTIP.START(intl),
                        },
                    },
                    polyline: {
                        ...L.drawLocal.draw.handlers.polyline, // 1 more
                        error: LEAFLET.DRAW.POLYLINE_ERROR(intl),
                    },
                },
                toolbar: {
                    ...L.drawLocal.draw.toolbar,
                },
            },
            edit: {
                handlers: {
                    ...L.drawLocal.edit.handlers, // 1 more
                    edit: {
                        ...L.drawLocal.edit.handlers.edit, // 1 more
                        tooltip: {
                            text: LEAFLET.EDIT_TOOLTIP.TEXT(intl),
                            subtext: LEAFLET.EDIT_TOOLTIP.SUBTEXT(intl),
                        },
                    },
                },
                toolbar: {
                    ...L.drawLocal.edit.toolbar, // 2 more
                },
            },
        };

        // Store the selectable layer group for ease of access
        this._featureGroup = options.featureGroup;
        
        if (!(this._featureGroup instanceof L.FeatureGroup)) {
            throw new Error('options.featureGroup must be a L.FeatureGroup');
        }
        
        this._uneditedLayerProps = {};
        
        // Save the type so super can fire, need to do this as cannot do this.TYPE :(
        this.type = L.EditToolbar.Edit.TYPE;
        
        var version = L.version.split('.');
        //If Version is >= 1.2.0
        if (parseInt(version[0], 10) === 1 && parseInt(version[1], 10) >= 2) {
            L.EditToolbar.Edit.include(L.Evented.prototype);
        } else {
            L.EditToolbar.Edit.include(L.Mixin.Events);
        }
        const keys = Object.keys(this._featureGroup._layers); // NEW
        if (keys && keys.length) {  // NEW
            this._featureGroup._layers[keys[0]]._path = this._featureGroup._layers[keys[1]]._path;
        }
    },
    
    // @method save(): void
    // Save the layer geometries
    save: function () {
        var editedLayers = new L.LayerGroup();
        this._featureGroup.eachLayer(function (layer) {
            if (layer.edited) {
                editedLayers.addLayer(layer);
                layer.edited = false;
            }
        });
        console.log('editedLayers', this); // NEW
        this._map.fire(L.Draw.Event.EDITED, {layers: editedLayers});
    },

    _enableLayerEdit: function (e) {
        var layer = e.layer || e.target || e,
            pathOptions, poly;

        if (e.target && e.target._layers) { // NEW IF
            const firstLayer = Object.values(e.target._layers)[0];
            if (firstLayer && firstLayer.options && firstLayer.options.originalShape) {
                layer.options.originalShape = firstLayer.options.originalShape;
            }
        }

        // Back up this layer (if haven't before)
        this._backupLayer(layer);

        if (this.options.poly) {
            poly = L.Util.extend({}, this.options.poly);
            layer.options.poly = poly;
        }
        
        // Set different style for editing mode
        if (this.options.selectedPathOptions) {
            pathOptions = L.Util.extend({}, this.options.selectedPathOptions);
            
            // Use the existing color of the layer
            if (pathOptions.maintainColor) {
                pathOptions.color = layer.options.color;
                pathOptions.fillColor = layer.options.fillColor;
            }
            
            layer.options.original = L.extend({}, layer.options);
            layer.options.editing = pathOptions;
            
        }
        
        if (layer instanceof L.Marker) {
            if (layer.editing) {
                layer.editing.enable();
            }
            layer.dragging.enable();
            layer
                .on('dragend', this._onMarkerDragEnd)
                // #TODO: remove when leaflet finally fixes their draggable so it's touch friendly again.
                .on('touchmove', this._onTouchMove, this)
                .on('MSPointerMove', this._onTouchMove, this)
                .on('touchend', this._onMarkerDragEnd, this)
                .on('MSPointerUp', this._onMarkerDragEnd, this);
        } else {
            layer.editing.enable();
        }
    },
});

/**
 *Only changed methods joined with client/node_modules/leaflet-draw/dist/leaflet.draw-src.js
 * search: L.Edit.PolyVerticesEdit = L.Handler.extend({...})
 */
export const editPolyVerticesEditExtend = {
    _initMarkers: function () {
        if (!this._markerGroup) {
            this._markerGroup = new L.LayerGroup();
        }
        this._markers = [];
        
        var latlngs = this._defaultShape(),
            i, j, len, marker;
        
        for (i = 0, len = latlngs.length; i < len; i++) {

            marker = this._createMarker(latlngs[i], i);
            if (!this._isRectangleShape()) { // NEW
                marker.on('click', this._onMarkerClick, this);
            }
            marker.on('contextmenu', this._onContextMenu, this);
            this._markers.push(marker);
        }

        var markerLeft, markerRight;

        for (i = 0, j = len - 1; i < len; j = i++) {
            if (i === 0 && !(L.Polygon && (this._poly instanceof L.Polygon))) {
                continue;
            }
            
            markerLeft = this._markers[j];
            markerRight = this._markers[i];
            if (!this._isRectangleShape() && len < getVerticesLimit(store.getCurrentProject())) { // NEW IF
                this._createMiddleMarker(markerLeft, markerRight);
            }

            this._updatePrevNext(markerLeft, markerRight);
            this._createCenterMarker(); // NEW
        }
    },

    _createMarker: function (latlng, index, centerMarker = false) {
        // NEW centerMarker
        // Extending L.Marker in TouchEvents.js to include touch.
        const marker = new L.Marker.Touch(latlng, {
            centerMarker, // NEW
            draggable: true,
            icon: this.options.icon,
        });
        
        marker._origLatLng = latlng;
        marker._index = index;
        
        marker
            .on('dragstart', this._onMarkerDragStart, this)
            .on('drag', this._onMarkerDrag, this)
            .on('dragend', this._fireEdit, this)
            .on('touchmove', this._onTouchMove, this)
            .on('touchend', this._fireEdit, this)
            .on('MSPointerMove', this._onTouchMove, this)
            .on('MSPointerUp', this._fireEdit, this);
        
        if (this._markerGroup) { // NEW
            this._markerGroup.addLayer(marker);
        }
        
        
        return marker;
    },

    _onMarkerDragStart: function () {
        const latlngs = this._poly._latlngs; // NEW
        if (Array.isArray(latlngs) && Array.isArray(latlngs[0])) { // NEW
            this.initialPolyShape = latlngs[0].map(point => ({
                lat: point.lat,
                lng: point.lng,
            }));
        }
        
        this._poly.fire('editstart');
    },

    _onMarkerDrag: function (e) {
        var marker = e.target;
        var poly = this._poly;

        // console.log('==========================================');
        // console.log('poly', poly);
        // console.log('this', this);
        // console.log('marker', marker);
        // NEW to L.extend(marker._origLatLng, marker._latlng);
        if (marker.options.centerMarker && marker._origLatLng.lat) {
            const deltaLat = marker._origLatLng.lat - marker._latlng.lat;
            const deltaLng = marker._origLatLng.lng - marker._latlng.lng;
            let polyLatLngs = poly._latlngs[0];
            polyLatLngs = polyLatLngs.map(latlng => ({
                lat: latlng.lat - deltaLat,
                lng: latlng.lng - deltaLng,
            }));
            poly._setLatLngs(polyLatLngs);
        }
        
        if (this._isRectangleShape() && !marker.options.centerMarker) {
            const deltaLat = marker._origLatLng.lat - marker._latlng.lat;
            const deltaLng = marker._origLatLng.lng - marker._latlng.lng;
            
            const vertexDrag = marker._latlng;
            const vertexNext = marker._next._latlng;
            const vertexPrev = marker._prev._latlng;
            const vertexOpposite = marker._prev._prev._latlng;
            
            const recalculatedPolygone = recalculatePolygon({
                vertexDrag, vertexNext, vertexPrev, vertexOpposite, deltaLat, deltaLng,
            });
            
            poly._setLatLngs(recalculatedPolygone);
            
            const prev_latlng = recalculatedPolygone[1];
            const next_latlng = recalculatedPolygone[3];
            
            marker._prev.setLatLng(prev_latlng);
            marker._next.setLatLng(next_latlng);
        }
        
        if (poly && poly.intersects() && this.initialPolyShape) {
            poly._setLatLngs(this.initialPolyShape);
            
            const tooltip = poly._map._editTooltip; // Access the tooltip
            
            marker.dragging._draggable._onUp(e);
            
            if (tooltip) {
                tooltip.updateContent({
                    text: L.drawLocal.draw.handlers.polyline.error,
                });
            }
    
            setTimeout(() => {
                if (tooltip) {
                    tooltip.updateContent({
                        text: L.drawLocal.edit.handlers.edit.tooltip.text,
                        subtext: L.drawLocal.edit.handlers.edit.tooltip.subtext,
                    });
                }
            }, 1000);
        }

        L.extend(marker._origLatLng, marker._latlng);

        if (marker._middleLeft) {
            marker._middleLeft.setLatLng(this._getMiddleLatLng(marker._prev, marker));
        }
        if (marker._middleRight) {
            marker._middleRight.setLatLng(this._getMiddleLatLng(marker, marker._next));
        }
        
        if (poly.options.poly) {
            const tooltip = poly._map._editTooltip; // Access the tooltip
            
            // If we don't allow intersections and the polygon intersects
            if (!poly.options.poly.allowIntersection && poly.intersects()) {
                const originalColor = poly.options.color;
                poly.setStyle({color: this.options.drawError.color});
                
                // Manually trigger 'dragend' behavior on marker we are about to remove
                // WORKAROUND: introduced in 1.0.0-rc2, may be related to #4484
                if (L.version.indexOf('0.7') !== 0) {
                    marker.dragging._draggable._onUp(e);
                }
                // this._onMarkerClick(e); // Remove violating marker
                // FIXME: Reset the marker to it's original position (instead of remove)
                
                if (tooltip) {
                    tooltip.updateContent({
                        text: L.drawLocal.draw.handlers.polyline.error
                    });
                }
                
                // Reset everything back to normal after a second
                setTimeout(function () {
                    poly.setStyle({color: originalColor});
                    if (tooltip) {
                        tooltip.updateContent({
                            text: L.drawLocal.edit.handlers.edit.tooltip.text,
                            subtext: L.drawLocal.edit.handlers.edit.tooltip.subtext
                        });
                    }
                }, 1000);
            }
        }
        //refresh the bounds when draging
        this._poly._bounds._southWest = L.latLng(Infinity, Infinity);
        this._poly._bounds._northEast = L.latLng(-Infinity, -Infinity);
        var latlngs = this._poly.getLatLngs();
        this._poly._convertLatLngs(latlngs, true);
        this._poly.redraw();
        this._poly.fire('editdrag');
    },

    _onMarkerClick: function (e) {

        var minPoints = L.Polygon && (this._poly instanceof L.Polygon) ? 4 : 3,
            marker = e.target;
        
        // If removing this point would create an invalid polyline/polygon don't remove
        if (this._defaultShape().length < minPoints) {
            return;
        }

        // remove the marker
        this._removeMarker(marker);
        
        // update prev/next links of adjacent markers
        this._updatePrevNext(marker._prev, marker._next);
        
        // remove ghost markers near the removed marker
        if (marker._middleLeft) {
            this._markerGroup.removeLayer(marker._middleLeft);
        }
        if (marker._middleRight) {
            this._markerGroup.removeLayer(marker._middleRight);
        }

        // create a ghost marker in place of the removed one
        if (marker._prev && marker._next && !this._isRectangleShape()) { // CHANGE
            this._createMiddleMarker(marker._prev, marker._next);

        } else if (!marker._prev && marker._next) { // CHANGE
            marker._next._middleLeft = null;

        } else if (!marker._next && marker._prev) { // CHANGE
            marker._prev._middleRight = null;
        }
        
        this._fireEdit();
    },

    _onContextMenu: function (e) {
        var marker = e.target;
        var poly = this._poly;
        this._poly._map.fire(L.Draw.Event.MARKERCONTEXT, {marker: marker, layers: this._markerGroup, poly: this._poly});
        L.DomEvent.stopPropagation(); // CHANGE
    },
    
    _createMiddleMarker: function (marker1, marker2) {
        var latlng = this._getMiddleLatLng(marker1, marker2),
            marker = this._createMarker(latlng),
            onClick,
            onDragStart,
            onDragEnd;
        
        marker.setOpacity(0.6);
        
        marker1._middleRight = marker2._middleLeft = marker;

        onDragStart = function () {
            marker.off('touchmove', onDragStart, this);
            const i = marker2._index;
            
            marker._index = i;
            
            marker
                .off('click', onClick, this)
            
            if (!this._isRectangleShape()) { // NEW
                marker
                    .on('click', this._onMarkerClick, this);
            }

            latlng.lat = marker.getLatLng().lat;
            latlng.lng = marker.getLatLng().lng;
            this._spliceLatLngs(i, 0, latlng);
            this._markers.splice(i, 0, marker);
            
            marker.setOpacity(1);
            
            this._updateIndexes(i, 1);
            marker2._index++;
            this._updatePrevNext(marker1, marker);
            this._updatePrevNext(marker, marker2);
            
            this._poly.fire('editstart');
        };

        onDragEnd = function () {
            marker.off('dragstart', onDragStart, this);
            marker.off('dragend', onDragEnd, this);
            marker.off('touchmove', onDragStart, this);
            
            if (!this._isRectangleShape()) { // NEW
                this._createMiddleMarker(marker1, marker);
                this._createMiddleMarker(marker, marker2);
            }
        };
        
        onClick = function () {
            onDragStart.call(this);
            onDragEnd.call(this);
            this._fireEdit();
        };
        
        marker
            .on('click', onClick, this)
            .on('dragstart', onDragStart, this)
            .on('dragend', onDragEnd, this)
            .on('touchmove', onDragStart, this);

        if (this._markerGroup) { // NEW
            this._markerGroup.addLayer(marker);
        }
    },

    _createCenterMarker() { // NEW METHOD
        const polyCenter = this._poly.getCenter();
        const marker = this._createMarker([polyCenter.lat, polyCenter.lng], undefined, true);
        marker.setOpacity(0.6);

        this._markerGroup.addLayer(marker);
    },

    _getMiddleLatLng: function (marker1, marker2) {
        const map = this._poly._map;
        if (map) { // new IF
            const p1 = map.project(marker1.getLatLng());
            const p2 = map.project(marker2.getLatLng());
            return map.unproject(p1._add(p2)._divideBy(2));
        }
        return null;
    },

    // Add to leaflet methods the special private method which is determine originalShape restriction
    _isRectangleShape() { // NEW METHOD
        return this._poly && this._poly.options && this._poly.options.originalShape === GEOMETRY_RESTRICTION_TYPES.RECTANGLE;
    },

};

/**
 * Only changed methods joined with client/node_modules/leaflet-draw/dist/leaflet.draw-src.js
 * search: L.Draw.Polyline = L.Draw.Feature.extend({...})
 */
export const drawPolylineExtend = {
    options: {
        allowIntersection: false, // NEW
        repeatMode: false,
        drawError: {
            color: '#b00b00',
            timeout: 2500
        },
        icon: new L.DivIcon({
            iconSize: new L.Point(8, 8),
            className: 'leaflet-div-icon leaflet-editing-icon'
        }),
        touchIcon: new L.DivIcon({
            iconSize: new L.Point(20, 20),
            className: 'leaflet-div-icon leaflet-editing-icon leaflet-touch-icon',
        }),
        guidelineDistance: 20,
        maxGuideLineLength: 4000,
        shapeOptions: {
            stroke: true,
            color: '#3388ff',
            weight: 4,
            opacity: 0.5,
            fill: false,
            clickable: true
        },
        metric: true, // Whether to use the metric measurement system or imperial
        feet: true, // When not metric, to use feet instead of yards for display.
        nautic: false, // When not metric, not feet use nautic mile for display
        showLength: true, // Whether to display distance in the tooltip
        zIndexOffset: 2000, // This should be > than the highest z-index any map layers
        factor: 1, // To change distance calculation
        maxPoints: 0 // Once this number of points are placed, finish shape
    },

    // @method completeShape(): void
    // Closes the polyline between the first and last points
    completeShape: function () {
        const latlngs = this._poly._defaultShape ? this._poly._defaultShape() : this._poly.getLatLngs();
        const vertices = latlngs.map(latLng => ({ x: latLng.lat, y: latLng.lng })); // DEV-1052
        const polygon = new Polygon(vertices);

        if (this._markers.length <= 1 || !this._shapeIsValid() || polygon.selfIntersects) {
            this._showErrorTooltip();
            return;
        }

        this._fireCreatedEvent();
        this.disable();

        if (this.options.repeatMode) {
            this.enable();
        }
    },

    _finishShape: function () {
        const latlngs = this._poly._defaultShape ? this._poly._defaultShape() : this._poly.getLatLngs();
        const intersects = this._poly.newLatLngIntersects(latlngs[latlngs.length - 1]);
        const vertices = latlngs.map(latLng => ({ x: latLng.lat, y: latLng.lng })); // NEW DEV-1052
        const polygon = new Polygon(vertices);

        if ((!this.options.allowIntersection && intersects) || !this._shapeIsValid() || polygon.selfIntersects) {
            this._showErrorTooltip();
            return;
        }

        this._fireCreatedEvent();
        this.disable();

        if (this.options.repeatMode) {
            this.enable();
        }
    },

    _updateFinishHandler: function () {
        this._markers = this._markers ? this._markers : []; // NEW
        var markerCount = this._markers.length;
        // The last marker should have a click handler to close the polyline
        if (markerCount > 1) {
            this._markers[markerCount - 1].on('click', this._finishShape, this);
        }

        // Remove the old marker click handler (as only the last point should close the polyline)
        if (markerCount > 2) {
            this._markers[markerCount - 2].off('click', this._finishShape, this);
        }
    },

    _updateTooltip: function(latLng) {
        var text = this._getTooltipText();
        if (this._markers && this._markers.length === 0) { // NEW IF ELSE
            text.text = 'Click to define entry point';
        } else {
            text.text = 'Click to define exit point';
        }
        if (latLng) {
            this._tooltip.updatePosition(latLng);
        }

        if (!this._errorShown && this._tooltip) { // NEW && this._tooltip
            this._tooltip.updateContent(text);
        }
    },

    _updateRunningMeasure: function(latlng, added) {
        let markersLength = this._markers.length,
            previousMarkerIndex, distance;

        if (this._markers.length === 1) {
            this._measurementRunningTotal = 0;
        } else {
            previousMarkerIndex = markersLength - (added ? 2 : 1);

            // Calculate the distance based on the version
            if (L.GeometryUtil.isVersion07x()) {
                distance = latlng.distanceTo(this._markers[previousMarkerIndex].getLatLng()) * (this.options.factor || 1);
            } else if (this._markers && this._markers[previousMarkerIndex]) { // NEW IF ELSE
                distance = this._map.distance(latlng, this._markers[previousMarkerIndex].getLatLng()) * (this.options.factor || 1);
            } else {
                distance = 0;
            }

            this._measurementRunningTotal += distance * (added ? 1 : -1);
        }
    },
};

/**
 * No changes with client/node_modules/leaflet-draw/dist/leaflet.draw-src.js
 * Needs because L.Draw.Polyline extends(drawPolylineExtend) before
 * search: L.Draw.Polygon = L.Draw.Polyline.extend({...})
 */
export const drawPolygonExtend = {
    statics: {
        TYPE: 'polygon'
    },

    Poly: L.Polygon,

    options: {
        showArea: false,
        showLength: false,
        shapeOptions: {
            stroke: true,
            color: '#3388ff',
            weight: 4,
            opacity: 0.5,
            fill: true,
            fillColor: null, //same as color by default
            fillOpacity: 0.2,
            clickable: true
        },
        // Whether to use the metric measurement system (truthy) or not (falsy).
        // Also defines the units to use for the metric system as an array of
        // strings (e.g. `['ha', 'm']`).
        metric: true,
        feet: true, // When not metric, to use feet instead of yards for display.
        nautic: false, // When not metric, not feet use nautic mile for display
        // Defines the precision for each type of unit (e.g. {km: 2, ft: 0}
        precision: {}
    },

    // @method initialize(): void
    initialize: function (map, options) {
        L.Draw.Polyline.prototype.initialize.call(this, map, options);

        // Save the type so super can fire, need to do this as cannot do this.TYPE :(
        this.type = L.Draw.Polygon.TYPE;
    },

    _updateFinishHandler: function () {
        var markerCount = this._markers.length;

        // The first marker should have a click handler to close the polygon
        if (markerCount === 1) {
            this._markers[0].on('click', this._finishShape, this);
        }

        // Add and update the double click handler
        if (markerCount > 2) {
            this._markers[markerCount - 1].on('dblclick', this._finishShape, this);
            // Only need to remove handler if has been added before
            if (markerCount > 3) {
                this._markers[markerCount - 2].off('dblclick', this._finishShape, this);
            }
        }
    },

    _getTooltipText: function () {
        var text, subtext;

        if (this._markers.length === 0) {
            text = L.drawLocal.draw.handlers.polygon.tooltip.start;
        } else if (this._markers.length < 3) {
            text = L.drawLocal.draw.handlers.polygon.tooltip.cont;
            subtext = this._getMeasurementString();
        } else {
            text = L.drawLocal.draw.handlers.polygon.tooltip.end;
            subtext = this._getMeasurementString();
        }

        return {
            text: text,
            subtext: subtext
        };
    },

    _getMeasurementString: function () {
        var area = this._area,
            measurementString = '';


        if (!area && !this.options.showLength) {
            return null;
        }

        if (this.options.showLength) {
            measurementString = L.Draw.Polyline.prototype._getMeasurementString.call(this);
        }

        if (area) {
            measurementString += '<br>' + L.GeometryUtil.readableArea(area, this.options.metric, this.options.precision);
        }

        return measurementString;
    },

    _shapeIsValid: function () {
        return this._markers.length >= 3;
    },

    _vertexChanged: function (latlng, added) {
        var latLngs;

        // Check to see if we should show the area
        if (!this.options.allowIntersection && this.options.showArea) {
            latLngs = this._poly.getLatLngs();

            this._area = L.GeometryUtil.geodesicArea(latLngs);
        }

        L.Draw.Polyline.prototype._vertexChanged.call(this, latlng, added);
    },

    _cleanUpShape: function () {
        var markerCount = this._markers.length;

        if (markerCount > 0) {
            this._markers[0].off('click', this._finishShape, this);

            if (markerCount > 2) {
                this._markers[markerCount - 1].off('dblclick', this._finishShape, this);
            }
        }
    }
};
