import { USER_ROLES } from './user-roles';
import { ADMIN_TABS_ROUTES, ROUTES, REPORT_PATH, SYSTEM_TABS_ROUTES } from './constants';

const { modules_list } = require('../../../features/featuresList');

const getAddonRoutesForPage = (addons, route) => addons.reduce((memo, addon) => ((addon.tabs.page === route)
    ? memo[addon.tabs.systemName] = { [addon.tabs.systemName]: addon.tabs.path }
    : memo), {});

const adminAddonRoutes = getAddonRoutesForPage(modules_list, ROUTES.ADMIN_ROUTE);

// PROJECT SCOPE MENUS
export const REPORTS = {
    ALARMS_REPORT: REPORT_PATH.ALARMS,
    ZONE_ACTIVITY: REPORT_PATH.ZONE_ACTIVITY,
    PWS: REPORT_PATH.PWS,
    ATTENDANCE: REPORT_PATH.ATTENDANCE,
};

export const ADMINISTRATION = {
    PROJECT_USERS: ADMIN_TABS_ROUTES.USERS_PROJECT_SCOPE,
    TRACKABLE_OBJECTS: ADMIN_TABS_ROUTES.TRACKABLE_OBJECTS,
    GROUPS: ADMIN_TABS_ROUTES.GROUPS,
    ZONES: ADMIN_TABS_ROUTES.ZONES,
    SHIFTS: ADMIN_TABS_ROUTES.SHIFTS,
    ALARM_NOTIFICATIONS: ADMIN_TABS_ROUTES.NOTIFICATIONS,
    PROJECT_TAGS: ADMIN_TABS_ROUTES.NODES,
    ...adminAddonRoutes,
};

export const SYSTEM = {
    ANCHORS: SYSTEM_TABS_ROUTES.ANCHORS,
    SERVER: SYSTEM_TABS_ROUTES.SERVER,
};

// USER SCOPES

export const USER_SCOPES = {
    SYSTEM_SCOPE: {
        COMPANIES: ADMIN_TABS_ROUTES.COMPANIES,
        SUPER_USERS: ADMIN_TABS_ROUTES.SUPER_ADMIN_USERS,
    },
    COMPANY_SCOPE: {
        PROJECTS: ADMIN_TABS_ROUTES.PROJECTS,
        COMPANY_TAGS: ADMIN_TABS_ROUTES.NODES,
    },
    PROJECT_SCOPE: {
        SITE: ROUTES.SITE_ROUTE,
        DASHBOARD: ROUTES.DASHBOARD_ROUTE,
        REPORTS: {
            index: ROUTES.REPORTS_ROUTE,
            subpages: REPORTS,
        },
        ADMINISTRATION: {
            subpages: ADMINISTRATION,
        },
        SYSTEM: {
            subpages: SYSTEM,
        },
    },
};

export const USER_SCOPE_KEYS = {
    SYSTEM_SCOPE: 'SYSTEM_SCOPE',
    COMPANY_SCOPE: 'COMPANY_SCOPE',
    PROJECT_SCOPE: 'PROJECT_SCOPE',
};

export const getCurrentUserScope = (currentRole) => {
    let userScope = '';
    switch (currentRole) {
        case USER_ROLES.SYSTEM_ADMIN:
            userScope = USER_SCOPE_KEYS.SYSTEM_SCOPE;
            break;
        case USER_ROLES.COMPANY_ADMIN:
            userScope = USER_SCOPE_KEYS.COMPANY_SCOPE;
            break;
        case USER_ROLES.PROJECT_SYSTEM_ADMIN:
        case USER_ROLES.PROJECT_OPERATIONS_ADMIN:
        case USER_ROLES.PROJECT_MAINTAINER:
        case USER_ROLES.PROJECT_USER:
        default:
            userScope = USER_SCOPE_KEYS.PROJECT_SCOPE;
    }

    return userScope;
};

export const getDefaultPageForScope = (currentScope) => {
    const value = USER_SCOPES[currentScope];
    const key = Object.keys(USER_SCOPES[currentScope])[0];
    return value[key];
};

export const pageInDefaultScope = (path, currentScope = '') => currentScope && JSON.stringify(USER_SCOPES[currentScope]).includes(path);
