import React, { useEffect, useState } from 'react';
import parse from 'html-react-parser';
import * as api from 'api';
import { getLocalStorageValue, setLocalStorageKeyValue, removeLocalStorageKey, reloadBrowser } from 'utils/browserStorage';
import { STORAGE_KEY } from 'common/constants';


const DEVELOPMENT = process.env.NODE_ENV === 'development';

export default function BetaVersionButton() {
    const [beta, setBeta] = useState(null);
    useEffect(() => {
        api.getBeta()
            .then((data) => {
                setBeta(data);
            }).catch(() => {
                const isBetaDownloaded = getLocalStorageValue(STORAGE_KEY.BETA_PATH);
                if (isBetaDownloaded) {
                    removeLocalStorageKey(STORAGE_KEY.BETA_PATH);
                    location.reload();
                }
            });
    }, []);
    
    const betaPath = getLocalStorageValue(STORAGE_KEY.BETA_PATH);
    function handleClick() {
        if (DEVELOPMENT) {
            alert('Beta Version Access Available only in "production" regime');
            return;
        }
        if (betaPath) {
            removeLocalStorageKey(STORAGE_KEY.BETA_PATH);
        } else {
            setLocalStorageKeyValue(STORAGE_KEY.BETA_PATH, 'beta/');
        }
        reloadBrowser();
    }
    
    if (!beta) return null;

    const buttonHtmlString = betaPath ? (beta.htmlExit || '<i></i>') : (beta.htmlEnter || '<i></i>');
    const parsedButtonHtml = parse(buttonHtmlString);

    return (
        <button onClick={handleClick}>{parsedButtonHtml}</button>
    );
}
