import React, { useState, useEffect, useContext } from 'react';
import PropTypes from 'prop-types';
import * as api from 'api';
import { getCurrentVersion } from 'utils/utils';
import { FOOTER, PORTAL } from 'common/ui-labels';
import { getLocalStorageValue } from 'utils';
import { STORAGE_KEY } from 'common';
import { AppContext } from '../../context';

function RedpointVersion(props) {
    return (
        <div>
            <div className="Footer-Copyright">
                &#9400;
                {' '}
                {FOOTER.COPYRIGHT_FUNC(props.version.formattedDate)}
            </div>
            |
            <div className="Footer-Version">
                {FOOTER.VERSION} 
                {' '}
                {props.version.rppVersion}
            </div>
        </div>
    );
}

RedpointVersion.propTypes = {
    version: PropTypes.shape({
        formattedDate: PropTypes.string,
        rppVersion: PropTypes.string,
    }),
};

RedpointVersion.defaultProps = {
    version: {
        formattedDate: '',
        rppVersion: '',
    },
};

function CustomVersion() {
    const [customVersion, setCustomVersion] = useState(null);

    useEffect(() => {
        api.getVersion().then((version) => {
            setCustomVersion(version.custom_product_attributes || null);
        });
    }, []);

    if (!customVersion) {
        return null;
    }
    return (
        <div>
            <div className="Footer-Copyright">
                {customVersion.name}
            </div>
            |
            <div className="Footer-Version">
                {FOOTER.VERSION}
                {' '}
                {customVersion.version}
            </div>
        </div>
    );
}

function PortalButton(props) {
    const clickOnLogo = () => {
        const hostName = getLocalStorageValue(STORAGE_KEY.HOST_NAME);
        window.open(`${hostName}/app`, '_self');
    };

    if (!props.show) return null;
    
    return (
        <div
            style={{ textAlign: 'center', marginTop: '10px' }}
        >
            <span className="Login-Return-Portal" onClick={clickOnLogo}>
                {PORTAL.RETURN}
            </span>
        </div>
    );
}

PortalButton.defaultProps = {
    show: false,
};

PortalButton.propTypes = {
    show: PropTypes.bool,
};

function LoginFooter(props) {
    const rppVersion = getCurrentVersion();
    const { config } = useContext(AppContext);
    const showPortalBtn = config?.CENTRALIZED_SITE_WISE?.PORTAL_BUTTON;

    return (
        <div className="RPP-Footer" style={props.style}>
            <RedpointVersion version={rppVersion} />
            <CustomVersion />
            <PortalButton show={showPortalBtn} />
        </div>
    );
}

LoginFooter.propTypes = {
    style: PropTypes.shape(),
};

LoginFooter.defaultProps = {
    style: {},
};

export default LoginFooter;
