import React, { PureComponent } from 'react';
import { connect } from 'react-redux';
import { injectIntl } from 'react-intl';
import PropTypes from 'prop-types';
import { NAME_OF_GEAR_BUTTONS, PROJECT } from 'common/ui-labels';


class CompanyProjectBlock extends PureComponent {
    static propTypes = {
        intl: PropTypes.shape({
            formatMessage: PropTypes.func,
        }),
        company: PropTypes.shape({}),
        project: PropTypes.shape({}),
        isSidebarCollapsed: PropTypes.bool,
    };

    static defaultProps = {
        intl: {
            formatMessage: () => {},
        },
        company: {},
        project: {},
        isSidebarCollapsed: false,
    };

    constructor(props) {
        super(props);

        this.state = {
            isCompanyProjectBlockShowed: false,
        };

        this.companyProjectBlock = React.createRef();
    }

    componentDidMount() {
        document.addEventListener('mousedown', this.handleClickOutsideCompanyProjectBlock);
    }

    componentWillUnmount() {
        document.removeEventListener('mousedown', this.handleClickOutsideCompanyProjectBlock);
    }


    handleClickOutsideCompanyProjectBlock = (event) => {
        const companyProjectBlock = this.companyProjectBlock.current; // from ref

        if (companyProjectBlock && !companyProjectBlock.contains(event.target)) {
            this.setState({ isCompanyProjectBlockShowed: false });
        }
    };

    handleCollapsedModeClick = () => {
        const { isCompanyProjectBlockShowed } = this.state;
        this.setState({ isCompanyProjectBlockShowed: !isCompanyProjectBlockShowed });
    };

    render() {
        const {
            intl,
            company,
            project,
            isSidebarCollapsed,
        } = this.props;

        const { isCompanyProjectBlockShowed } = this.state;

        const companyName = company && company.name;
        const projectName = project && project.name;

        const NO_NAME = '---';
        const uiProjectName = projectName || NO_NAME;
        const uiCompanyName = companyName || NO_NAME;

        return (
            <React.Fragment>
                {(companyName || projectName) && !isSidebarCollapsed &&
                <div className="company-project-block">
                    <div className="company-project-block-label">{NAME_OF_GEAR_BUTTONS.COMPANY_TITLE(intl)}</div>
                    <div
                        className="company-project-block-name"
                        data-cy="company-project-block-company"
                        title={uiCompanyName}
                    >
                        {uiCompanyName}
                    </div>
                    <div className="company-project-block-label">{PROJECT(intl)}</div>
                    <div
                        className="company-project-block-name"
                        data-cy="company-project-block-project"
                        title={uiProjectName}
                    >
                        {uiProjectName}
                    </div>
                </div>}

                {(companyName || projectName) && isSidebarCollapsed &&
                <div
                    className="company-project-block"
                    ref={this.companyProjectBlock}
                >
                    <div
                        className="tooltip"
                        title={`${NAME_OF_GEAR_BUTTONS.COMPANY_TITLE(intl)} & ${PROJECT(intl)}`}
                        onClick={this.handleCollapsedModeClick}
                    >
                        <div className="tooltipButton">
                            <i className="fas fa-info" />
                        </div>
                        {isCompanyProjectBlockShowed &&
                        <div className="tooltip-text">
                            <button className="cross">
                                <i className="far fa-times-circle" />
                            </button>
                            <div className="company-project-block-label">{NAME_OF_GEAR_BUTTONS.COMPANY_TITLE(intl)}:</div>
                            <div>{uiCompanyName}</div>
                            <br />
                            <div className="company-project-block-label">{PROJECT(intl)}:</div>
                            <div>{uiProjectName}</div>
                        </div>}
                    </div>
                </div>}
            </React.Fragment>
        );
    }
}

const mapStateToProps = state => ({
    company: state.appContext.company,
    project: state.appContext.project,
});

export default connect(mapStateToProps)(injectIntl(CompanyProjectBlock));
