import React, { PureComponent } from 'react';
import { connect } from 'react-redux';
import PropTypes from 'prop-types';
import store from 'stores/LocationStore';
import { getQueryParam } from 'utils/browserStorage';
import { userLogoutFromCompanyAdmin, userLogoutFromProjectSystemAdmin } from 'stores/actions';

class Header extends PureComponent {
    static propTypes = {
        dispatch: PropTypes.func,
        isSidebarCollapsed: PropTypes.bool,
        areEntitiesLoaded: PropTypes.bool,
    };

    static defaultProps = {
        dispatch: () => {},
        isSidebarCollapsed: false,
        areEntitiesLoaded: false,
    };

    clickOnLogo = () => {
        const { dispatch, areEntitiesLoaded } = this.props;

        if (areEntitiesLoaded) { // it's not allowed to logout until all entities are loaded
            if (store.isCompanyAdminAsProjectSystemAdmin()) {
                dispatch(userLogoutFromProjectSystemAdmin());
            } else if (store.isOnBehalfOfSystemUser()) {
                dispatch(userLogoutFromCompanyAdmin());
            }
        }
    };

    render() {
        const { isSidebarCollapsed, areEntitiesLoaded } = this.props;

        const hostName = store.getHostName();
        const targetServer = getQueryParam('target_server');
        const search = targetServer ? `?target_server=${targetServer}` : '';

        return (
            <div className={`sidebar-header ${!areEntitiesLoaded ? 'disabled' : ''}`}>
                {
                    isSidebarCollapsed
                        ? (
                            <img
                                src={`${hostName}/logo/company-logo-small.png${search}`}
                                data-cy="logo-small"
                                className="Nav-Brand"
                                onClick={this.clickOnLogo}
                                alt=":("
                            />
                        ) : (
                            <img
                                src={`${hostName}/logo/product-nav-logo.png${search}`}
                                data-cy="logo-large"
                                className={`${isSidebarCollapsed ? ' invisible' : 'Nav-Brand-SiteWise'}`}
                                onClick={this.clickOnLogo}
                                alt=":("
                            />
                        )
                }
            </div>
        );
    }
}

const mapStateToProps = (state) => ({
    areEntitiesLoaded: state.entities.entitiesLoaded,
});

export default connect(mapStateToProps)(Header);
