import React, { useContext } from 'react';
import { connect } from 'react-redux';
import PropTypes from 'prop-types';
import { STORAGE_KEY } from 'common';
import { getLocalStorageValue } from 'utils';
import { AppContext } from '../../context';

function HeaderCentralizeSitewise(props) {
    const { config } = useContext(AppContext);
    const { isSidebarCollapsed } = props;

    const clickOnLogo = () => {
        const { areEntitiesLoaded } = props;

        if (areEntitiesLoaded) {
            const hostName = getLocalStorageValue(STORAGE_KEY.HOST_NAME);
            window.open(`${hostName}/app`, '_self');
        }
    };

    if (!config.CENTRALIZED_SITE_WISE.PORTAL_BUTTON || isSidebarCollapsed) {
        return null;
    }

    return (
        <div style={{ textAlign: 'right' }}>
            <span
                className="Return-Portal"
                onClick={clickOnLogo}
            >
                Return to portal
            </span>
        </div>
    );
}

HeaderCentralizeSitewise.defaultProps = {
    isSidebarCollapsed: false,
    areEntitiesLoaded: false,
};

HeaderCentralizeSitewise.propTypes = {
    isSidebarCollapsed: PropTypes.bool,
    areEntitiesLoaded: PropTypes.bool,
};

const mapStateToProps = (state) => ({
    areEntitiesLoaded: state.entities.entitiesLoaded,
});

export default connect(mapStateToProps)(HeaderCentralizeSitewise);
