import React from 'react';
import PropTypes from 'prop-types';
import { injectIntl } from 'react-intl';
import { Link } from 'react-router-dom';
import { getMenuItemClassName, getTitleText } from 'components/NavBar/navBarHelpers';
import Submenu from 'components/NavBar/NavigationMenu/Submenu';
import { getQueryParam } from 'utils';

function MenuItem(props) {
    const { id, currentPathname, monitorLink, item, intl, dispatch } = props;
    const targetServer = getQueryParam('target_server');
    const search = targetServer ? `?target_server=${targetServer}` : '';
    const navigateTo = (item.to && !item.isButton) ? (item.to + search) : search;

    return (
        <div
            key={id}
            className={getMenuItemClassName(currentPathname, item.to)}
        >
            <Link
                className="menu-item-link"
                to={navigateTo}
                title={getTitleText(item.title, intl)}
                key={id}
                data-cy={item.dataCy}
                onClick={
                    () => {
                        if (item.dispatchAction) {
                            dispatch(item.dispatchAction());
                        } else {
                            const openCloseStatus = props.getNavBarMenuOpenCloseStatus(item.to);
                            props.handleMenuItemClick(item.to, openCloseStatus);
                            props.setNavBarMenuOpenCloseStatus(item.to, !openCloseStatus);
                        }
                    }
                }
            >
                <span className="icon-wrapper">
                    {
                        item.iconClass
                        && (
                            <span className="icon">
                                <i className={item.iconClass} />
                            </span>
                        )
                    }
                </span>
                <span className="menu-item-link-name">
                    {item.label}
                </span>
            </Link>
            <Submenu
                currentPathname={currentPathname}
                monitorLink={monitorLink}
                id={id}
                item={item}
                closeAllNavBarMenus={props.closeAllNavBarMenus}
                getNavBarMenuOpenCloseStatus={props.getNavBarMenuOpenCloseStatus}
                setNavBarMenuOpenCloseStatus={props.setNavBarMenuOpenCloseStatus}
            />
        </div>
    );
}

MenuItem.propTypes = {
    item: PropTypes.shape({
        to: PropTypes.string,
        submenu: PropTypes.arrayOf(PropTypes.shape({})),
    }),
    id: PropTypes.number,
    currentPathname: PropTypes.string,
    monitorLink: PropTypes.string,
    intl: PropTypes.shape({
        formatMessage: PropTypes.func,
    }),
    dispatch: PropTypes.func,
    closeAllNavBarMenus: PropTypes.func,
    getNavBarMenuOpenCloseStatus: PropTypes.func,
    setNavBarMenuOpenCloseStatus: PropTypes.func,
    handleMenuItemClick: PropTypes.func,
};

MenuItem.defaultProps = {
    item: {
        to: '',
        submenu: [],
    },
    id: 0,
    currentPathname: '',
    monitorLink: null,
    intl: {
        formatMessage: () => {},
    },
    dispatch: () => {
    },
    closeAllNavBarMenus: () => {
    },
    getNavBarMenuOpenCloseStatus: () => {
    },
    setNavBarMenuOpenCloseStatus: () => {
    },
    handleMenuItemClick: () => {
    },
};

export default injectIntl(MenuItem);
