import React, { Fragment } from 'react';
import PropTypes from 'prop-types';
import SubmenuItem from './SubmenuItem';

function DefaultSubmenu(props) {
    const { item, id, currentPathname, monitorLink } = props;
    if (!item.submenu) {
        return null;
    }

    return (
        <>
            <input
                type="checkbox"
                name="radio"
                id={`menu_bar${id}`}
                className="submenu-toggle"
                defaultChecked={props.getNavBarMenuOpenCloseStatus(item.to)}
                onChange={(e) => {
                    props.setNavBarMenuOpenCloseStatus(item.to, e.target.checked);
                }}
            />
            <label className="dropdown-menu-arrow" htmlFor={`menu_bar${id}`}>
                <i className="fa fa-sort-down" />
            </label>
            <ul id={`links${id}`} className="submenu">
                {item.submenu.map((submenuItem, index) => (
                    <SubmenuItem
                        key={index}
                        monitorLink={monitorLink}
                        closeAllNavBarMenus={props.closeAllNavBarMenus}
                        currentPathname={currentPathname}
                        submenuItem={submenuItem}
                    />
                ))}
            </ul>
        </>
    );
}

DefaultSubmenu.propTypes = {
    item: PropTypes.shape({
        to: PropTypes.string,
        submenu: PropTypes.arrayOf(PropTypes.shape({})),
    }),
    id: PropTypes.number,
    currentPathname: PropTypes.string,
    monitorLink: PropTypes.string,
    closeAllNavBarMenus: PropTypes.func,
    getNavBarMenuOpenCloseStatus: PropTypes.func,
    setNavBarMenuOpenCloseStatus: PropTypes.func,
};

DefaultSubmenu.defaultProps = {
    item: {
        to: '',
        submenu: [],
    },
    id: 0,
    currentPathname: '',
    monitorLink: null,
    closeAllNavBarMenus: () => {
    },
    getNavBarMenuOpenCloseStatus: () => {
    },
    setNavBarMenuOpenCloseStatus: () => {
    },
};

export default DefaultSubmenu;
