import React, { useContext } from 'react';
import PropTypes from 'prop-types';
import { Link } from 'react-router-dom';
import { SYSTEM_TAB_BUTTONS } from 'common/constants';
import { getSubMenuItemClassName } from 'components/NavBar/navBarHelpers';
import { getQueryParam } from 'utils';
import { AppContext } from '../../../../context';

function SubmenuItem(props) {
    const { submenuItem, currentPathname, monitorLink } = props;
    const { config } = useContext(AppContext);
    let className = getSubMenuItemClassName(currentPathname, '/site_monitor');
    let disabled = false;
    let onClick = () => {
        props.closeAllNavBarMenus();
    };

    const targetServer = getQueryParam('target_server');
    const search = targetServer ? `?target_server=${targetServer}` : '';

    if (submenuItem.button && submenuItem.name === SYSTEM_TAB_BUTTONS.SITE_MONITOR) {
        if (!config.NAVBAR_MENU.SYSTEM.SITE_MONITOR) return null;
        className = `${className} ${!monitorLink ? 'submenu-item-disabled' : ''}`;
        disabled = !monitorLink;
        onClick = () => {
            if (monitorLink) {
                props.closeAllNavBarMenus();
                window.open(monitorLink, '_blank');
            }
        };
    }
    const navigateTo = (submenuItem.to || '#') + search;
    
    return (
        <li
            key={submenuItem.name}
            className={className}
        >
            <Link
                to={navigateTo}
                disabled={disabled}
                className="submenu-item-link"
                data-cy={submenuItem.dataCy}
                onClick={() => {
                    onClick();
                }}
            >
                <span className="icon-wrapper">
                    {
                        submenuItem.iconClass
                        && (
                            <span className="icon">
                                <i className={submenuItem.iconClass} />
                            </span>
                        )
                    }
                </span>
                <span className="submenu-item-link-name">
                    {submenuItem.label}
                </span>
                { submenuItem.linkIconClass
                    && (
                        <span className="sub-menu-button">
                            <i className={submenuItem.linkIconClass} />
                        </span>
                    )}
            </Link>
        </li>
    );
}

SubmenuItem.propTypes = {
    submenuItem: PropTypes.shape({
        button: PropTypes.bool,
        linkIconClass: PropTypes.string,
        name: PropTypes.string,
        label: PropTypes.shape({}),
        to: PropTypes.string,
        onClick: PropTypes.func,
        disabled: PropTypes.bool,
        iconClass: PropTypes.string,
    }),
    currentPathname: PropTypes.string,
    monitorLink: PropTypes.string,
    closeAllNavBarMenus: PropTypes.func,
};

SubmenuItem.defaultProps = {
    submenuItem: {
        label: {},
        to: '',
        onClick: () => {},
        disabled: false,
        iconClass: '',
    },
    currentPathname: '',
    monitorLink: '',
    closeAllNavBarMenus: () => {},
};

export default SubmenuItem;
