import React from 'react';
import PropTypes from 'prop-types';

import { getTimeByFormatAndTimezone } from 'utils/timeUtils';
import { WS_ACTIONS } from 'worker/common/constants';

import { changePlaybackParams, generatePlayback } from '../stores/actions';
import { TimeSlider } from './TimeSliderWrapper';

class ProgressBarWithTime extends React.Component {
    static propTypes = {
        playback: PropTypes.shape(),
        isPending: PropTypes.bool,
        dispatch: PropTypes.func,
        timezone: PropTypes.string,
    };
    
    static defaultProps = {
        playback: {},
        isPending: false,
        dispatch: () => {
        },
        timezone: 'Etc/GMT',
    };

    constructor(props) {
        super(props);
        this.state = {
            sliderMoving: false,
            sliderMovingTime: null,
        };
    }

    onChangePlaybackValue = (currentTs) => {
        if (!this.state.sliderMoving) {
            this.setState({ sliderMoving: true });
        }
        this.setState({ sliderMovingTime: currentTs });
    };

    onChangeCommitedPlaybackValue = (currentTs) => {
        const { setting, trackables } = this.props.playback;
        setting.currentTs = currentTs;
        setting.idProgressBar = currentTs;
        this.props.dispatch(changePlaybackParams({ currentTs }));
        this.props.dispatch({ type: WS_ACTIONS.PLAYBACK_PENDING_REQUEST });
        this.props.dispatch(generatePlayback({ setting, trackables: trackables.map(trackable => trackable.uid) }));
        this.setState({ sliderMoving: false });
    };

    dateTransformationForDisplay = (timeStamp) => {
        const { timezone } = this.props;

        return getTimeByFormatAndTimezone(new Date(timeStamp), 'MM/DD hh:mm:ss a', timezone);
    };

    render() {
        const { isPending } = this.props;
        const { popUpSettings, coords, startTs, finishTs, currentTs } = this.props.playback;

        const startTime = this.dateTransformationForDisplay(startTs);
        const finishTime = this.dateTransformationForDisplay(finishTs);

        return (
            <div className="ProgressBarWithTime">
                {
                    popUpSettings.show &&
                    <div
                        className="ProgressBarWithTime-Time-current"
                        style={{ left: `${coords.x}px` }}
                    >
                        <span>{popUpSettings.time}</span>
                    </div>
                }

                <TimeSlider
                    onChange={(event, val) => this.onChangePlaybackValue(val)}
                    onChangeCommitted={(event, val) => this.onChangeCommitedPlaybackValue(val)}
                    disabled={isPending}
                    aria-labelledby="discrete-slider"
                    valueLabelDisplay="auto"
                    step={10000}
                    value={this.state.sliderMoving ? this.state.sliderMovingTime : currentTs}
                    min={startTs}
                    max={finishTs}
                    valueLabelFormat={value => this.dateTransformationForDisplay(value)}
                />
                
                <div className="ProgressBarWithTime-Time">
                    <div className="ProgressBarWithTime-Time-elem ProgressBarWithTime-Time-start">
                        {startTime}
                    </div>
                    
                    <div className="ProgressBarWithTime-Time-elem ProgressBarWithTime-Time-finish">
                        {finishTime}
                    </div>
                </div>
            </div>
        );
    }
}

export default ProgressBarWithTime;
