import React from 'react';
import PropTypes from 'prop-types';
import { USER_ROLES, USERS_TAB } from 'common';


export function ProjectUserRoleSelect(props) {
    const { uid, role, onChange, intl, disabled, roles } = props;

    return (
        <select
            className="form-control input-sm"
            data-user-uid={uid}
            data-info="actions-section"
            onChange={onChange}
            value={role}
            disabled={disabled}
        >
            <ProjectUserRoleSelectOptions
                roles={roles}
                intl={intl}
            />
        </select>
    )
}


ProjectUserRoleSelect.defaultProps = {
    onChange: () => {},
    uid: null,
    disabled: false,
    role: '',
    roles: [],
    intl: {
        formatMessage: () => {
        },
    },
}

ProjectUserRoleSelect.propTypes = {
    onChange: PropTypes.func,
    uid: PropTypes.string,
    disabled: PropTypes.bool,
    role: PropTypes.string,
    roles: PropTypes.arrayOf(PropTypes.string),
    intl: PropTypes.shape({
        formatMessage: PropTypes.func,
    })
}


export function ProjectUserRoleSelectOptions(props) {
    const { intl, roles } = props;
    const ROLE_LABEL = {
        [USER_ROLES.PROJECT_USER]: USERS_TAB.USER_ROLES.PROJECT_USER(intl),
        [USER_ROLES.PROJECT_MAINTAINER]: USERS_TAB.USER_ROLES.PROJECT_MAINTAINER(intl),
        [USER_ROLES.PROJECT_OPERATIONS_ADMIN]: USERS_TAB.USER_ROLES.PROJECT_OPERATIONS_ADMIN(intl),
        [USER_ROLES.PROJECT_SYSTEM_ADMIN]: USERS_TAB.USER_ROLES.PROJECT_SYSTEM_ADMIN(intl),
        [USER_ROLES.COMPANY_ADMIN]: USERS_TAB.USER_ROLES.COMPANY_ADMIN(intl),
    }

    return roles.map((userRole) => (
        <option key={userRole} id={userRole} value={userRole}>{ROLE_LABEL[userRole] || userRole}</option>
    ))
}


ProjectUserRoleSelectOptions.defaultProps = {
    roles: [],
    intl: {
        formatMessage: () => {
        },
    },
}

ProjectUserRoleSelectOptions.propTypes = {
    roles: PropTypes.arrayOf(PropTypes.string),
    intl: PropTypes.shape({
        formatMessage: PropTypes.func,
    })
}
