import React from 'react';
import PropTypes from 'prop-types';
import { getFloorplanUrl } from 'utils/formatters';
import { lengthToDegree } from 'utils/simpleUtils';
import { getQueryParam } from 'utils/browserStorage';
import store from 'stores/LocationStore';
import ImageOverlay from './ImageOverlay';


function imageOverlayProps(floorplan) {
    const dim_x = floorplan.width * floorplan.image_scale;
    const dim_y = floorplan.height * floorplan.image_scale;

    const image_offset_x = floorplan.image_offset_x * floorplan.image_scale;
    const image_offset_y = floorplan.image_offset_y * floorplan.image_scale;

    const image_center_position = {
        lng: lengthToDegree(image_offset_x /* /100 */),
        lat: lengthToDegree(image_offset_y /* /100 */),
    };

    const SW = {
        lng: (image_center_position.lng + lengthToDegree(dim_x / 2)),
        lat: (image_center_position.lat - lengthToDegree(dim_y / 2)),
    };
    const NE = {
        lng: (image_center_position.lng - lengthToDegree(dim_x / 2)),
        lat: (image_center_position.lat + lengthToDegree(dim_y / 2)),
    };

    const bounds = [[SW.lat, SW.lng], [NE.lat, NE.lng]];
    const targetServer = getQueryParam('target_server');
    const search = targetServer ? `?target_server=${targetServer}` : '';
    return {
        bounds,
        position: {
            image_center_position,
        },
        rotation: floorplan.image_rotation,
        url: getFloorplanUrl(floorplan, store.getHostName()) + search,
    };
}

export default class LeafletFloorplan extends React.Component {
  static propTypes = {
      floorplan: PropTypes.object,
  };

  static defaultProps = {
      floorplan: {},
  };

  shouldComponentUpdate(nextProps) {
      return nextProps.floorplan.uid !== this.props.floorplan.uid;
  }

  render() {
      return (
          <ImageOverlay className="leaflet-floorplan" {...imageOverlayProps(this.props.floorplan)} />
      );
  }
}
