import React, { Fragment } from 'react';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { injectIntl } from 'react-intl';
import { LayerGroup } from 'react-leaflet';
import DivIcon from 'react-leaflet-div-icon';
import { NearMissPopUp } from 'components/leaflet/popups';
import { openNearMissEventPopup } from 'stores/actions/nearMissEventsActions';


class LeafletNearMissEventMarkers extends LayerGroup {
    static propTypes = {
        dispatch: PropTypes.func,
        popUpEvent: PropTypes.shape(),
        selectedNearMissMarker: PropTypes.number,
    };

    static defaultProps = {
        dispatch: () => {},
        popUpEvent: {},
        selectedNearMissMarker: null,
    };
    
    componentDidUpdate() {
        Object.keys(this.refs).forEach((key) => {
            const className = `leaflet-near-miss-marker${String(this.props.selectedNearMissMarker) === String(key) ? '-selected' : ''} fas fa-exclamation-triangle`;
            const keyRef = this.refs[key];
            if (keyRef && keyRef.leafletElement && keyRef.leafletElement._icon && keyRef.leafletElement._icon.className) {
                keyRef.leafletElement._icon.className = className;
            }
        });
    }

    onEventMarkerClick = (nearMissEventMarker) => {
        const { dispatch } = this.props;

        dispatch(openNearMissEventPopup({
            ...nearMissEventMarker,
        }));
    };

    onClosePopup = () => {
        this.props.dispatch(openNearMissEventPopup(null));
    };

    render() {
        const { events, popUpEvent } = this.props;
        if (!events || events.length === 0) {
            return (<Fragment />);
        }
        return (
            <div>
                {
                    events.map(event => (
                        <DivIcon
                            key={event.id}
                            ref={event.id}
                            className="leaflet-near-miss-marker fas fa-exclamation-triangle"
                            position={event.position}
                            styles={{ color: 'orange' }}
                            onClick={() => { this.onEventMarkerClick(event); }}
                        >
                            <span />
                        </DivIcon>
                    ))
                }
                <NearMissPopUp nearMissMarker={popUpEvent} onClosePopup={this.onClosePopup} />
            </div>
        );
    }
}

const mapStateToProps = state => ({
    popUpEvent: state.nearMissReport.popUpEvent,
    selectedNearMissMarker: state.nearMissReport.selectedNearMissMarker,
});

export default connect(mapStateToProps)(injectIntl(LeafletNearMissEventMarkers));

