import React, { Fragment, useState } from 'react';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { Polygon } from 'react-leaflet';
import DivIcon from 'react-leaflet-div-icon';
import { zonePositions, positionWithSublocationOffset } from 'utils/formatters';
import { VertexPopup } from 'components/leaflet/popups';


function LeafletZoneCoordinateLayer(props) {
    const [popup, setPopup] = useState(null);
    const [popupData, setPopupData] = useState({ x: 0, y: 0 });
    const positionsInMm = Object.values(props.positions);

    const zone = { zone_geometry: { positions: positionsInMm.map(pos => ({ x: pos.x, y: pos.y })) } };
    const positions = zonePositions(zone, props.sublocation);
    
    return (
        <Fragment>
            <Polygon
                fillOpacity={0.2}
                fillColor={props.error.geometryIntersects ? 'red' : 'orange'}
                color={props.error.geometryIntersects ? 'red' : 'orange'}
                weight={2}
                dashArray={props.error.geometryIntersects ? '5 10' : '1'}
                positions={positions}
            />
            {
                positions.map((position, index) => {
                    const pos = positionsInMm[index];
                    return (
                        <DivIcon
                            className="Big-Div-Icon"
                            key={index}
                            position={position}
                            onClick={() => {
                                setPopup({ position, index: pos.index });
                                const positionInMm = positionWithSublocationOffset(pos, props.sublocation);
                                setPopupData(positionInMm);
                            }}
                        >
                            <div style={{ fontSize: '10px !important' }}>{pos.index}</div>
                        </DivIcon>
                    );
                })
            }
            <VertexPopup
                onClose={() => { setPopup(null); }}
                position={popup && popup.position}
                data={popupData}
                index={popup && popup.index}
                show={!!popup}
            />
        </Fragment>
    );
}

LeafletZoneCoordinateLayer.propTypes = {
    positions: PropTypes.shape({}),
    sublocation: PropTypes.shape({}),
    error: PropTypes.shape({
        geometryIntersects: PropTypes.bool,
    }),
};

LeafletZoneCoordinateLayer.defaultProps = {
    positions: {},
    sublocation: {},
    error: {
        geometryIntersects: false,
    },
};


const mapStateToProps = (state, props) => {
    const { open, sublocation_uid, geometry } = state.modals.zoneModals.zoneCreateAdminPage;
    if (open) {
        const sublocation = state.entities.sublocations.find(_sublocation => _sublocation.uid === sublocation_uid);
        return {
            positions: geometry.vertices,
            error: props.error,
            sublocation,
        };
    }
    const { vertices, error } = state.siteViewZoneEditCoordinates;
    return {
        error,
        positions: vertices,
        sublocation: state.siteView.selectedSublocation,
    };
};

export default connect(mapStateToProps)(LeafletZoneCoordinateLayer);
