import React, { useEffect, useState } from 'react';
import PropTypes from 'prop-types';
import { Popup } from 'react-leaflet';

// eslint-disable-next-line import/prefer-default-export
export function PopUpWrapper({ children, ...props }) {
    const [visible, setVisible] = useState(true);

    function onVisibilityChange() {
        if (document.visibilityState === 'hidden') {
            setVisible(false);
        } else {
            setVisible(true);
        }
    }

    useEffect(() => {
        document.addEventListener('visibilitychange', onVisibilityChange);
        return () => {
            document.removeEventListener('visibilitychange', onVisibilityChange);
        };
    }, []);

    if (!visible) return null;

    return (
        <Popup {...props}>
            {children}
        </Popup>
    );
}


PopUpWrapper.propTypes = {
    children: PropTypes.node,
};
PopUpWrapper.defaultProps = {
    children: null,
};
