import React from 'react';
import PropTypes from 'prop-types';
import { TRACKABLE_CATEGORY } from 'common/constants';
import { convertMillimetersToMeters } from 'utils/formatters';
import { PopUpWrapper } from 'components/leaflet/PopUpWrapper';


export function NearMissPopUp(props) {
    const { nearMissMarker, onClosePopup } = props;

    if (!nearMissMarker) {
        return null;
    }

    return (
        <PopUpWrapper
            className="near-miss-popup"
            position={nearMissMarker.position}
            onClose={() => { onClosePopup(); }}
        >
            <div>
                <div className="RPP-PopUpRowsWrapper">
                    <div className="popup-row row">
                        <div className="col-md-4 popup-field-label">Distance (m):</div>
                        <div className="col-md-8 popup-field-value">
                            {convertMillimetersToMeters(nearMissMarker.distance).toFixed(1)}
                        </div>
                    </div>
                    <div className="popup-row row">
                        <div className="col-md-4 popup-field-label">Trigger time:</div>
                        <div className="col-md-8 popup-field-value">
                            {nearMissMarker.time}
                        </div>
                    </div>
                    {nearMissMarker.trackables.map(trackable => (
                        <div key={trackable.uid}>
                            <div className="popup-row row">
                                <div className="col-md-4 popup-field-label">{trackable.category === TRACKABLE_CATEGORY.VEHICLE ? 'Vehicle:' : 'Person:'}</div>
                                <div className="col-md-8 popup-field-value">
                                    {trackable.name}
                                </div>
                            </div>
                            {trackable.driver_uid && <div className="popup-row row">
                                <div className="col-md-4 popup-field-label">Driver:</div>
                                <div className="col-md-8 popup-field-value">{trackable.driver_name || ''}</div>
                            </div>}
                            <div className="popup-row row">
                                <div className="col-md-4 popup-field-label">Coordinate (m):</div>
                                <div className="col-md-8 popup-field-value">
                                    X: {convertMillimetersToMeters(trackable.x).toFixed(1)}, Y: {convertMillimetersToMeters(trackable.y).toFixed(1)}
                                </div>
                            </div>
                        </div>))
                    }
                </div>
            </div>
        </PopUpWrapper>);
}

NearMissPopUp.defaultProps = {
    nearMissMarker: {},
    onClosePopup: () => {},
};

NearMissPopUp.propTypes = {
    nearMissMarker: PropTypes.shape({}),
    onClosePopup: PropTypes.func,
};
