import React, { Fragment } from 'react';
import DatePicker from 'antd/es/date-picker';
import 'moment-timezone';
import PropTypes from 'prop-types';


const RenderDatePicker = ({ input, meta: { touched, error }, timeZone, disabledDate, disabled, showToday, placeholder }) => {
    const dateFormat = 'MM/DD/YYYY HH:mm';
    let timeValue;
    let onOkClose = false;
    return (
        <Fragment>
            <DatePicker
                allowClear={false}
                disabled={disabled}
                format={dateFormat}
                disabledDate={disabledDate}
                showTime={{ format: 'HH:mm' }}
                showToday={showToday}
                onOpenChange={(status) => {
                    if (!status && timeValue && !onOkClose) {
                        input.onChange(timeValue);
                        timeValue = undefined;
                    }
                    if (onOkClose) {
                        onOkClose = false;
                    }
                }}
                placeholder={placeholder}
                onChange={(time) => {
                    timeValue = time;
                    if (!time) {
                        input.onChange(null);
                    }
                }}
                onOk={(time) => {
                    onOkClose = true;
                    input.value = time;
                    input.onChange(input.value);
                }}
            />
            {touched && error && <span className="error">{error}</span>}
        </Fragment>
    );
};

RenderDatePicker.propTypes = {
    timeZone: PropTypes.string,
    disabledDate: PropTypes.string,
    showToday: PropTypes.bool,
    placeholder: PropTypes.string,
    meta: PropTypes.shape({
        touched: PropTypes.bool,
        error: PropTypes.string,
    }),
    disabled: PropTypes.bool,
    input: PropTypes.shape({}),
};

RenderDatePicker.defaultProps = {
    timeZone: null,
    disabledDate: null,
    showToday: false,
    placeholder: null,
    meta: {
        touched: false,
        error: '',
    },
    disabled: false,
    input: { },
};

export default RenderDatePicker;
