import React, { Fragment } from 'react';
import DatePicker from 'antd/es/date-picker';
import PropTypes from 'prop-types';

const { RangePicker } = DatePicker;

const RenderRangePicker = ({ input, meta: { touched, error }, placeholder, style }) => {
    const dateFormat = 'MM/DD/YYYY HH:mm';
    const timeFormat = 'HH:mm';
    let timeValue;
    let onOkClose = false;

    return (
        <Fragment>
            <RangePicker
                showTime={{ format: timeFormat }}
                format={dateFormat}
                placeholder={placeholder}
                style={style}
                onOpenChange={(status) => {
                    if (!status && timeValue && !onOkClose) {
                        input.onChange(timeValue);
                        timeValue = undefined;
                    }
                    if (onOkClose) {
                        onOkClose = false;
                    }
                }}
                onChange={(time) => {
                    timeValue = time;
                    input.onChange(time);
                }}
                onOk={(time) => {
                    onOkClose = true;
                    input.value = time;
                    input.onChange(input.value);
                }}
            />
            {touched && error && <span className="error">{error}</span>}
        </Fragment>
    );
};

RenderRangePicker.propTypes = {
    placeholder: PropTypes.oneOfType([
        PropTypes.string,
        PropTypes.arrayOf(PropTypes.string)
    ]),
    style: PropTypes.shape({}),
    input: PropTypes.shape({
        onChange: PropTypes.func,
        value: PropTypes.string,
    }),
    meta: PropTypes.shape({
        touched: PropTypes.bool,
        error: PropTypes.string,
    }),
};

RenderRangePicker.defaultProps = {
    placeholder: '',
    style: {},
    input: {
        onChange: () => {

        },
        value: '',
    },
    meta: {
        touched: false,
        error: '',
    },
};

export default RenderRangePicker;
