import React, { Fragment } from 'react';

import { TimeSlider } from 'components/TimeSliderWrapper';
import PropTypes from 'prop-types';

function RenderRangeSlider(props) {
    const { input: { value, onChange }, meta: { touched, error }, min, max, marks, valueLabelFormat, onTimeframeDragEnd } = props;
    return (
        <Fragment>
            <TimeSlider
                onChange={(event, val) => {
                    if (!event.target || event.target.getAttribute('data-id') !== 'marker') {
                        onChange(val);
                    }
                }}
                onChangeCommitted={(event, val) => {
                    if (!event.target || event.target.getAttribute('data-id') !== 'marker') {
                        onTimeframeDragEnd(val);
                    }
                }}
                marks={marks || []}
                value={value}
                aria-labelledby="range-slider"
                valueLabelDisplay="auto"
                min={min}
                max={max}
                valueLabelFormat={valueLabelFormat}
            />
            {touched && error && <span className="error">{error}</span>}
        </Fragment>
    );
}

RenderRangeSlider.propTypes = {
    valueLabelFormat: PropTypes.string,
    onTimeframeDragEnd: PropTypes.func,
    marks: PropTypes.array,
    min: PropTypes.number,
    max: PropTypes.number,
    input: PropTypes.shape({
        onChange: PropTypes.func,
        value: PropTypes.string,
    }),
    meta: PropTypes.shape({
        touched: PropTypes.bool,
        error: PropTypes.string,
    }),
};

RenderRangeSlider.defaultProps = {
    valueLabelFormat: '',
    onTimeframeDragEnd: () => {},
    marks: [],
    min: 0,
    max: 0,
    input: {
        onChange: () => {

        },
        value: '',
    },
    meta: {
        touched: false,
        error: '',
    },
};

export default RenderRangeSlider;
