import React, { Fragment } from 'react';
import PropTypes from 'prop-types';

const RenderSelectField = ({ input, dataId, dataCy, meta: { touched, error }, children, disabled, style, disabledTooltipText }) => (
    <Fragment>
        <select
            {...input}
            disabled={disabled}
            data-id={dataId}
            data-cy={dataCy}
            style={{ ...style, backgroundColor: disabled ? 'rgb(235, 235, 228)' : 'white' }}
            title={disabledTooltipText}
        >
            {children}
        </select>
        {touched && error && <span className="error">{error}</span>}
    </Fragment>
);


RenderSelectField.propTypes = {
    placeholder: PropTypes.string,
    style: PropTypes.shape({}),
    dataId: PropTypes.string,
    dataCy: PropTypes.string,
    disabledTooltipText: PropTypes.string,
    disabled: PropTypes.bool,
    children: PropTypes.oneOfType([
        PropTypes.arrayOf(PropTypes.node),
        PropTypes.node,
    ]),
    input: PropTypes.shape({
        onChange: PropTypes.func,
        value: PropTypes.oneOfType([PropTypes.number, PropTypes.string]),
    }),
    meta: PropTypes.shape({
        touched: PropTypes.bool,
        error: PropTypes.oneOfType([PropTypes.shape({}), PropTypes.string]),
    }),
};

RenderSelectField.defaultProps = {
    placeholder: '',
    style: { },
    dataId: '',
    dataCy: '',
    disabledTooltipText: '',
    disabled: false,
    children: [],
    input: {
        onChange: () => {

        },
        value: '',
    },
    meta: {
        touched: false,
        error: { },
    },
};
export default RenderSelectField;
