import React, { Fragment, useState } from 'react';
import TimePicker from 'antd/es/time-picker';
import moment from 'moment';
import 'moment-timezone';
import PropTypes from 'prop-types';


const RenderTimePicker = ({ input, meta: { touched, error }, disabled, placeholder, timeFormat, dataId, dataCy }) => {
    const [isOpen, setIsOpen] = useState(false);

    const handleOpenChange = open => setIsOpen(open);

    return (
        <Fragment>
            <TimePicker
                allowClear={false}
                disabled={disabled}
                format={timeFormat}
                data-id={dataId}
                data-cy={dataCy}
                minuteStep={15}
                open={isOpen}
                onOpenChange={handleOpenChange}
                value={input.value ? moment(input.value) : null}
                placeholder={placeholder}
                onChange={(time) => {
                    input.onChange(time);
                }}
            />
            {touched && error && <span className="error">{error}</span>}
        </Fragment>
    );
};

RenderTimePicker.propTypes = {
    disabled: PropTypes.bool,
    timeFormat: PropTypes.string,
    placeholder: PropTypes.string,
    input: PropTypes.shape({
        value: PropTypes.oneOfType([PropTypes.shape(), PropTypes.number, PropTypes.string]),
        onChange: PropTypes.func,
        onBlur: PropTypes.func,
    }),
    meta: PropTypes.shape({
        warning: PropTypes.string,
        error: PropTypes.oneOfType([PropTypes.shape({}), PropTypes.string]),
    }),
    dataId: PropTypes.string,
    dataCy: PropTypes.string,
};

RenderTimePicker.defaultProps = {
    disabled: false,
    timeFormat: 'HH:mm',
    placeholder: '',
    input: {},
    meta: {
        warning: '',
        error: '',
    },
    dataId: '',
    dataCy: '',
};

export default RenderTimePicker;
