import React, { useState, Fragment } from 'react';
import { WEEKDAYS_SHORT } from 'common/ui-labels';
import PropTypes from 'prop-types';

const convertArrayToMap = (mapInitEditMode = {}, arr = []) => {
    mapInitEditMode.forEach((_value, key, map) => map.set(key, arr.indexOf(key) !== -1));
    return mapInitEditMode;
};

const convertMapToArray = mapObj => Array.from(mapObj.entries()).reduce((memo, [key, val]) => ((val) ? memo.concat(parseInt(key)) : memo), []);

const RenderWeekdayPicker = ({ input, meta: { touched, error }, dataId, dataCy }) => {
    const mapInitEditMode = new Map();
    for (let i = 0; i < 7; i += 1) {
        mapInitEditMode.set(i, false);
    }
    const mapInit = (Array.isArray(input.value)) ? convertArrayToMap(mapInitEditMode, input.value) : mapInitEditMode;

    const [checked, setChecked] = useState(mapInit);

    const handleOnChange = (e) => {
        const checkedMap = new Map(checked);
        checkedMap.set(parseInt(e.target.id), e.target.checked);
        setChecked(checkedMap);

        const weekdaysArray = convertMapToArray(checkedMap);

        input.onChange(weekdaysArray);
        input.value = weekdaysArray;
    };

    return (
        <Fragment>
            <div className="dowPicker d-flex">
                {
                    [...Array(7).keys()].map(index => (<div key={index} className="dowPickerOption">
                        <input
                            id={index}
                            type="checkbox"
                            name="weekday"
                            data-id={dataId}
                            data-cy={dataCy}
                            checked={checked.get(index)}
                            onChange={handleOnChange}
                        />
                        <label htmlFor={index}>{WEEKDAYS_SHORT[index]}</label>
                    </div>))
                }
            </div>
            {touched && error && <span className="error">{error}</span>}
        </Fragment>
    );
};

RenderWeekdayPicker.propTypes = {
    input: PropTypes.shape({
        value: PropTypes.arrayOf(PropTypes.number),
        onChange: PropTypes.func,
        onBlur: PropTypes.func,
    }),
    meta: PropTypes.shape({
        warning: PropTypes.string,
        error: PropTypes.oneOfType([PropTypes.shape({}), PropTypes.string]),
    }),
    dataId: PropTypes.string,
    dataCy: PropTypes.string,
};

RenderWeekdayPicker.defaultProps = {
    input: {
        value: [],
    },
    meta: {
        warning: '',
        error: '',
    },
    dataId: '',
    dataCy: '',
};

export default RenderWeekdayPicker;
