import React from 'react';
import Select from 'react-select';
import PropTypes from 'prop-types';
import _isEmpty from 'lodash.isempty';

const SelectComponent = ({
    options, filterOptions, simpleValue, clearable = true, placeholder,
    noResultsText, input: { value, onChange, onBlur }, isDisabled,
    meta: { touched, error },
}) => {
    const _options = (!options || (Array.isArray(options) && options.length < 1))
        ? [{ value: '', label: '' }]
        : options;
    const _noResultsText = _isEmpty(noResultsText) ? 'No result found' : noResultsText;
    return (
        <>
            <Select
                disabled={isDisabled}
                simpleValue={simpleValue}
                clearable={clearable}
                filterOptions={filterOptions}
                options={_options}
                placeholder={placeholder}
                noResultsText={_noResultsText}
                className="menu-outer-top"
                onChange={onChange}
                value={value}
                onBlur={() => onBlur(value)}
            />
            {touched && error && <span className="error">{error}</span>}
        </>
    );
};

SelectComponent.propTypes = {
    options: PropTypes.arrayOf(PropTypes.shape({})),
    filterOptions: PropTypes.arrayOf(PropTypes.shape({})),
    simpleValue: PropTypes.bool,
    placeholder: PropTypes.string,
    noResultsText: PropTypes.shape({}),
    clearable: PropTypes.bool,
    isDisabled: PropTypes.bool,
    input: PropTypes.shape({
        value: PropTypes.oneOfType([PropTypes.shape(), PropTypes.number, PropTypes.string]),
        onChange: PropTypes.func,
        onBlur: PropTypes.func,
    }),
    meta: PropTypes.shape({
        error: PropTypes.oneOfType([
            PropTypes.shape({}),
            PropTypes.string,
        ]),
        touched: PropTypes.oneOfType([
            PropTypes.shape({}),
            PropTypes.string,
        ]),
        warning: PropTypes.oneOfType([
            PropTypes.shape({}),
            PropTypes.string,
        ]),
    }),
};

SelectComponent.defaultProps = {
    options: [],
    filterOptions: [],
    simpleValue: false,
    placeholder: '',
    noResultsText: { },
    clearable: false,
    isDisabled: false,
    input: {},
    meta: {
        warning: '',
        touched: '',
        error: '',
    },
};

export default SelectComponent;
