import React, { PureComponent } from 'react';
import { Map, LayersControl } from 'react-leaflet';
import PropTypes from 'prop-types';
import { injectIntl } from 'react-intl';

import LeafletFloorplan from '../../../components/leaflet/LeafletFloorplan';
import { DEFAULT_VALUES, ZONE_DETAILS_MODAL } from '../../../common';
import { MAP_BOUNDS } from '../../../utils';

const { Overlay } = LayersControl;

class Floorplan extends PureComponent {
    static propTypes = {
        relatedFloorplans: PropTypes.arrayOf(PropTypes.shape({})),
        selectFloorplan: PropTypes.func,
        intl: PropTypes.shape({
            formatMessage: PropTypes.func,
        }),
    };

    static defaultProps = {
        relatedFloorplans: [],
        selectFloorplan: () => {},
        intl: {
            formatMessage: () => {
            },
        },
    };

    render() {
        const { relatedFloorplans, selectFloorplan, intl } = this.props;

        return (
            <div className="floorPlanContainer text-center">
                {relatedFloorplans.map(floorplan => (
                    <div
                        key={floorplan.uid}
                        className="modal-floorplan-leaflet-list"
                        title={ZONE_DETAILS_MODAL.DOUBLE_CLICK_EXPAND(intl)}
                        onClick={() => {
                            selectFloorplan(floorplan);
                        }}
                    >

                        <Map
                            center={[0, 0]}
                            className="modal-floorplan-leaflet-thumb"
                            bounds={MAP_BOUNDS({}, floorplan)}
                            minZoom={DEFAULT_VALUES.MAP_ZOOM.MIN}
                            maxZoom={DEFAULT_VALUES.MAP_ZOOM.MAX}
                            doubleClickZoom={false}
                            zoom={DEFAULT_VALUES.MAP_ZOOM.DEFAULT_MODAl}
                        >
                            <LayersControl position="topright">
                                <Overlay checked name="Floorplan">
                                    <LeafletFloorplan floorplan={floorplan} />
                                </Overlay>
                            </LayersControl>
                        </Map>
                        <div key={floorplan.url}>{floorplan.url.split('/').pop()}</div>
                    </div>
                ))}

            </div>
        );
    }
}

export default injectIntl(Floorplan);
