import React from 'react';
import PropTypes from 'prop-types';
import { COMPONENTS } from 'common/ui-labels';
import { Spinner } from 'components/Spinner';


function SubmitButtons(props) {
    const { submit, invalid, close, saveDataId, cancelDataId, saveDataCy, cancelDataCy, className, inProcess } = props;
    return (
        <div className={className}>
            <button
                type="button"
                onClick={submit}
                disabled={invalid || inProcess}
                data-id={saveDataId}
                data-cy={saveDataCy}
            >
                {COMPONENTS.BUTTONS.SAVE}
                <Spinner
                    style={{ marginLeft: '10px' }}
                    show={inProcess}
                />
            </button>
            <button
                type="button"
                data-id={cancelDataId}
                data-cy={cancelDataCy}
                onClick={close}
            >
                {COMPONENTS.BUTTONS.CANCEL}
            </button>
        </div>
    );
}

SubmitButtons.propTypes = {
    close: PropTypes.func,
    submit: PropTypes.func,
    invalid: PropTypes.bool,
    inProcess: PropTypes.bool,
    saveDataId: PropTypes.string,
    cancelDataId: PropTypes.string,
    saveDataCy: PropTypes.string,
    cancelDataCy: PropTypes.string,
    className: PropTypes.string,
};

SubmitButtons.defaultProps = {
    close: () => {},
    submit: () => {},
    invalid: true,
    inProcess: false,
    saveDataId: undefined,
    cancelDataId: undefined,
    saveDataCy: undefined,
    cancelDataCy: undefined,
    className: '',
};

export default SubmitButtons;
