import React from 'react';
import { Field } from 'redux-form';
import PropTypes from 'prop-types';

import TextField from 'components/modals/TextField';
import RenderField from 'components/modals/RenderField';
import CustomInfoFieldComponent from 'components/modals/CustomInfoField';
import { LABELS, ZONE_ADD_CONFIGURATION_MODAL, COMPONENTS, DB_NAMES } from 'common/ui-labels';

const renderField = RenderField(6, 6);
const textField = TextField(6, 6);


function BasicOptions(props) {
    const { location_name, sublocation_name, zoneTypeName, isZoneTypeSelected, intl, activityHandler = () => {}, customInfoLength } = props;
    return (
        <section>
            <div className="Form-Line row">
                <Field
                    className="Form-Input"
                    name="location_name"
                    dataId="zone-add-configuration-site"
                    component={textField}
                    content_name={location_name}
                    label={COMPONENTS.FIELDS.SITE.SITE_FUNC(intl)}
                    disabled
                    type="text"
                />
            </div>
            
            <div className="Form-Line row">
                <Field
                    className="Form-Input"
                    name="sublocation_name"
                    dataId="zone-add-configuration-sublocation"
                    component={textField}
                    content_name={sublocation_name}
                    label={COMPONENTS.FIELDS.SITE.AREA_FUNC(intl)}
                    type="text"
                    disabled
                />
            </div>
            
            <div className="Form-Line row">
                <Field
                    className="Form-Input"
                    name="zone_type_name"
                    dataId="zone-add-configuration-type"
                    component={textField}
                    content_name={zoneTypeName}
                    label={ZONE_ADD_CONFIGURATION_MODAL.LABEL_ZONE_TYPE(intl)}
                    type="text"
                    disabled
                />
            </div>
            
            <div className="Form-Line row">
                <Field
                    className="Form-Input"
                    name="name"
                    dataId="zone-add-configuration-name"
                    component={renderField}
                    label={`${COMPONENTS.FIELDS.COMMON.NAME_FUNC(intl)} *`}
                    props={{ disabled: !isZoneTypeSelected }}
                    type="text"
                />
            </div>
            
            <div className="Form-Line row" style={{ textAlign: 'center', marginTop: '15px' }}>
                <div
                    className="Form-Label col-md-6"
                    style={{ fontSize: '1.2em' }}
                >
                    {DB_NAMES.ACTIVE(intl)}
                </div>
                <div className="col-md-6 text-left" data-id="zone-add-configuration-active">
                    <Field
                        name="activated"
                        component="input"
                        type="checkbox"
                        onChange={activityHandler}
                    />
                </div>
            </div>
            
            <CustomInfoFieldComponent
                placeholder={LABELS.CUSTOM_INFO_PLACEHOLDER(intl)}
                firstColumnWidth={6}
                dataId="zone-edit-custom-info"
                customInfoLength={customInfoLength}
            />
        </section>
    );
}

BasicOptions.propTypes = {
    activityHandler: PropTypes.func,
    intl: PropTypes.shape({
        formatMessage: PropTypes.func,
    }),
    location_name: PropTypes.string,
    zoneTypeName: PropTypes.string,
    sublocation_name: PropTypes.string,
    isZoneTypeSelected: PropTypes.bool,
    customInfoLength: PropTypes.number,
};

BasicOptions.defaultProps = {
    activityHandler: () => {},
    intl: {
        formatMessage: () => {},
    },
    location_name: '',
    zoneTypeName: '',
    sublocation_name: '',
    isZoneTypeSelected: true,
    customInfoLength: 0,
};

export default BasicOptions;
