import React, { Fragment } from 'react';
import { Field } from 'redux-form';
import PropTypes from 'prop-types';
import MultiSelectComponent from 'components/modals/MultiSelectComponent';
import { COMPONENTS, ZONE_APPLY_TO, TRACKABLES_AND_GROUPS } from 'common';
import { sortByField, filterSelectBoxOptions } from 'utils/utils';


function TrackablesAndGroups(props) {
    const { show, trackables = [], groups = [], intl } = props;
    const options = sortByField([...trackables, ...groups], 'name');
    
    if (!show) {
        return (<Fragment />);
    }
    
    return (
        <div className="Form-Line RPP-Group-advanced">
            <h4 className="RPP-Group-advanced-border-title">{TRACKABLES_AND_GROUPS.TITLE}</h4>
            
            <div className="row Form-Line">
                <div className="col-md-5" style={{ fontSize: '1.1em', fontWeight: 'bold' }}>
                    {TRACKABLES_AND_GROUPS.APPLY_TO}
                </div>
                <div className="col-md-7">
                    <div className="row">
                        <div className="col-md-1 text-left">
                            <Field
                                name="apply_to"
                                data-cy="apply_to"
                                component="input"
                                style={{ marginTop: '3px' }}
                                value={ZONE_APPLY_TO.ALL}
                                type="radio"
                            />
                        </div>
                        <div className="col-md-10">{TRACKABLES_AND_GROUPS.APPLY_TO_EXCEPT}</div>
                    </div>
                </div>
            </div>
            
            <div className="row Form-Line" style={{ marginTop: 0 }}>
                <div className="col-md-5" />
                <div className="col-md-7">
                    <div className="row">
                        <div className="col-md-1">
                            <Field
                                name="apply_to"
                                data-cy="apply_to"
                                component="input"
                                style={{ marginTop: '3px' }}
                                value={ZONE_APPLY_TO.LIST}
                                type="radio"
                            />
                        </div>
                        <div className="col-md-10">{TRACKABLES_AND_GROUPS.APPLY_TO_ONLY}</div>
                    </div>
                </div>
            </div>
            
            <div className="row">
                <div
                    className="Form-Label-Small col-md-5"
                    style={{ fontSize: '1.1em', fontWeight: 'bold' }}
                >
                    {TRACKABLES_AND_GROUPS.TITLE}
                </div>
                <div
                    className="col-md-7"
                    data-id="trackable-edit-zones"
                >
                    <Field
                        name="trackables_and_groups"
                        type="text"
                        label="Objective"
                        placeholder={COMPONENTS.SELECT_COMPONENT_PLACEHOLDER(intl)}
                        noResultsText={COMPONENTS.SELECT_COMPONENT_NO_RESULTS_TEXT}
                        options={options}
                        filterOptions={filterSelectBoxOptions}
                        scrollMenuIntoView
                        component={MultiSelectComponent}
                    />
                </div>
            </div>
        </div>
    );
}

TrackablesAndGroups.propTypes = {
    intl: PropTypes.shape({
        formatMessage: PropTypes.func,
    }),
    groups: PropTypes.arrayOf(PropTypes.shape()),
    trackables: PropTypes.arrayOf(PropTypes.shape()),
    show: PropTypes.bool,
};

TrackablesAndGroups.defaultProps = {
    intl: {
        formatMessage: () => {},
    },
    groups: [],
    trackables: [],
    show: true,
};

export default TrackablesAndGroups;
