import React from 'react';
import Modal from 'react-modal';
import { injectIntl } from 'react-intl';
import { connect } from 'react-redux';
import { reduxForm } from 'redux-form';
import PropTypes from 'prop-types';
import { NAME_OF_FORMS, ALARMS_INFO_MODAL, COMPONENTS } from 'common';
import { closeAlarmInfoModal } from 'stores/actions';
import { getUiConstForAdditionalInfoText, getTimeZoneOfProject, getDateByTz, getTimeByTz } from 'utils';


let AlarmInfoForm = (props) => {
    const { close, className, alarmInfo, intl, timeZone } = props;
    const { created_at, trackableName, additional_info } = alarmInfo.params;

    const date = getDateByTz(created_at, timeZone);
    const time = getTimeByTz(created_at, timeZone);
    
    return (
        <form className={className}>
            <div className="Form-Line row">
                <div className="Form-Label col-md-4">{COMPONENTS.FIELDS.NODE.TRACKABLE}</div>
                <div className="Form-Value col-md-8 multiple-lines-ellipsis" data-id="alarm-info-trackable" >{trackableName}</div>
            </div>
            <div className="Form-Line row">
                <div className="Form-Label col-md-4">{COMPONENTS.FIELDS.COMMON.TIME}</div>
                <div className="Form-Value col-md-8" data-id="alarm-info-time">{time}</div>
            </div>
            <div className="Form-Line row">
                <div className="Form-Label col-md-4">{ALARMS_INFO_MODAL.FORM.DATE}</div>
                <div className="Form-Value col-md-8" data-id="alarm-info-date">{date}</div>
            </div>
            <div className="Form-Line row">
                <div className="Form-Label col-md-4">{ALARMS_INFO_MODAL.FORM.DESCRIPTION}</div>
                <div
                    className="Form-Value col-md-8"
                    data-id="alarm-info-description"
                >
                    {additional_info && additional_info.text &&
                        getUiConstForAdditionalInfoText(intl, additional_info.text)}
                </div>
            </div>
            <div className="Form-Buttons">
                <button type="button" data-id="alarm-info-cancel" onClick={close}>{COMPONENTS.BUTTONS.CANCEL}</button>
            </div>
        </form>
    );
};

AlarmInfoForm.propTypes = {
    close: PropTypes.func,
    timeZone: PropTypes.string,
    alarmInfo: PropTypes.shape({
        params: PropTypes.shape({
            uid: PropTypes.string,
        }),
        open: PropTypes.bool,
    }),
    intl: PropTypes.shape({
        formatMessage: PropTypes.func,
    }),
    className: PropTypes.string,
};

AlarmInfoForm.defaultProps = {
    close: () => {
    },
    timeZone: 'Etc/GMT',
    alarmInfo: {
        params: {
            uid: '',
        },
        open: false,
    },
    intl: PropTypes.shape({
        formatMessage: PropTypes.func,
    }),
    className: '',
};

AlarmInfoForm = reduxForm({
    form: NAME_OF_FORMS.ALARM_INFO,
})(injectIntl(AlarmInfoForm));

class AlarmInfoModal extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        timeZone: PropTypes.string,
        alarmInfo: PropTypes.shape({
            params: PropTypes.shape({
                uid: PropTypes.string,
            }),
            open: PropTypes.bool,
        }),
        style: PropTypes.shape({
            content: PropTypes.object,
            overlay: PropTypes.object,
        }),
    };
    
    static defaultProps = {
        dispatch: () => {
        },
        timeZone: 'Etc/GMT',
        alarmInfo: {
            params: {
                uid: '',
            },
            open: false,
        },
        style: {
            content: {},
            overlay: {},
        },
    };
    
    close = () => {
        this.props.dispatch(closeAlarmInfoModal());
    };
    
    render() {
        const { style, alarmInfo, timeZone } = this.props;
        const { params } = alarmInfo;
        
        return (
            <Modal
                contentLabel="AlarmInfo"
                isOpen={alarmInfo.open}
                onRequestClose={this.close}
                style={style}
            >
                
                <div className="RPP-Modal">
                    <span className="Modal-Header">
                        {COMPONENTS.FIELDS.COMMON.VIEW_INFORMATION_FUNC(params && params.trackable && params.trackable.name)}
                    </span>
                    <AlarmInfoForm
                        className="Modal-Form"
                        close={this.close}
                        alarmInfo={alarmInfo}
                        timeZone={timeZone}
                    />
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = (state) => {
    const project = state.appContext.project;
    const timeZone = getTimeZoneOfProject(project);
    return {
        alarmInfo: state.modals.alarmModals.alarmInfo,
        timeZone,
    };
};

export default connect(mapStateToProps)(AlarmInfoModal);
