import React from 'react';
import Modal from 'react-modal';
import { connect } from 'react-redux';
import { reduxForm } from 'redux-form';
import PropTypes from 'prop-types';

import { NAME_OF_FORMS, TRACKABLE_TAG_ASSOCIATION, COMPONENTS } from 'common';
import { macToUpperCase } from 'utils';
import { closeTagUnAssignModal, closeTrackableAssociations } from 'stores/actions';

let TagUnAssignForm = (props) => {
    const { close, submit, className, submitSucceeded } = props;
    
    return (
        <form className={className}>
            <div className="Form-Buttons">
                <button
                    type="button"
                    data-id="tag-unassign-unassign"
                    disabled={submitSucceeded}
                    onClick={submit}
                >
                    {COMPONENTS.BUTTONS.UNASSIGN}
                </button>
                <button
                    type="button"
                    data-id="tag-unassign-cancel"
                    onClick={close}
                >
                    {COMPONENTS.BUTTONS.CANCEL}
                </button>
            </div>
        </form>
    );
};

TagUnAssignForm.propTypes = {
    close: PropTypes.func,
    submit: PropTypes.func,
    className: PropTypes.string,
    submitSucceeded: PropTypes.bool,
};

TagUnAssignForm.defaultProps = {
    close: () => {
    },
    submit: () => {
    },
    className: '',
    submitSucceeded: false,
};

TagUnAssignForm = reduxForm({
    form: NAME_OF_FORMS.TAG_UN_ASSIGN,
})(TagUnAssignForm);


class TagUnAssignModal extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        tagUnAssign: PropTypes.shape({
            params: PropTypes.shape({
                mac_address: PropTypes.string,
            }),
            open: PropTypes.bool,
        }),
        style: PropTypes.shape({
            overlay: PropTypes.object,
            content: PropTypes.object,
        }),
    };
    
    static defaultProps = {
        dispatch: () => {
        },
        tagUnAssign: {
            params: {
                mac_address: '',
            },
            open: false,
        },
        style: {
            overlay: {},
            content: {},
        },
    };
    
    close = () => {
        this.props.dispatch(closeTagUnAssignModal());
    };
    
    submit = () => {
        const tag = this.props.tagUnAssign.params;
        
        this.props.dispatch(closeTrackableAssociations({ mac_address: tag.mac_address }));
        this.props.dispatch(closeTagUnAssignModal());
    };
    
    render() {
        const { style, tagUnAssign } = this.props;
        const { params } = tagUnAssign;
        
        return (
            <Modal
                contentLabel="TagUnAssign"
                isOpen={tagUnAssign.open}
                onRequestClose={this.close}
                style={style}
            >
                
                <div className="RPP-Modal">
                    <span className="Modal-Header">
                        {TRACKABLE_TAG_ASSOCIATION.FORM.UNASSIGN_TAG_TRACKABLE_FUNC((params && params.trackable && params.trackable.name)
                            || '', (params && params && macToUpperCase(params.mac_address)) || '')}
                    </span>
                    <TagUnAssignForm
                        className="Modal-Form"
                        close={this.close}
                        onSubmit={this.submit}
                    />
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = state => ({
    tagUnAssign: state.modals.assignModals.tagUnAssign,
});

export default connect(mapStateToProps)(TagUnAssignModal);
