import React from 'react';
import Modal from 'react-modal';
import { connect } from 'react-redux';
import { reduxForm } from 'redux-form';
import PropTypes from 'prop-types';

import { NAME_OF_FORMS, TRACKABLE_TAG_ASSOCIATION, COMPONENTS } from 'common';
import { macToUpperCase } from 'utils';
import { closeTrackableUnAssignModal, closeTrackableAssociations } from 'stores/actions';

let TrackableUnAssignForm = (props) => {
    const { close, submit, className, submitSucceeded } = props;
    
    return (
        <form className={className}>
            <div className="Form-Buttons">
                <button
                    type="button"
                    data-id="trackable-unassign-unassign"
                    disabled={submitSucceeded}
                    onClick={submit}
                >
                    {COMPONENTS.BUTTONS.UNASSIGN}
                </button>
                <button
                    type="button"
                    data-id="trackable-unassign-cancel"
                    onClick={close}
                >
                    {COMPONENTS.BUTTONS.CANCEL}
                </button>
            </div>
        </form>
    );
};

TrackableUnAssignForm.propTypes = {
    close: PropTypes.func,
    submit: PropTypes.func,
    className: PropTypes.string,
    submitSucceeded: PropTypes.bool,
};

TrackableUnAssignForm.defaultProps = {
    close: () => {
    },
    submit: () => {
    },
    className: '',
    submitSucceeded: false,
};

TrackableUnAssignForm = reduxForm({
    form: NAME_OF_FORMS.TRACKABLE_UN_ASSIGN,
})(TrackableUnAssignForm);


class TrackableUnAssignModal extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        trackableUnAssign: PropTypes.shape({
            params: PropTypes.shape({
                name: PropTypes.string,
                uid: PropTypes.string,
            }),
            open: PropTypes.bool,
        }),
        style: PropTypes.shape({
            content: PropTypes.object,
            overlay: PropTypes.object,
        }),
    };
    
    static defaultProps = {
        dispatch: () => {
        },
        trackableUnAssign: {
            params: {
                name: '',
                uid: '',
            },
            open: false,
        },
        style: {
            content: {},
            overlay: {},
        },
    };
    
    close = () => {
        this.props.dispatch(closeTrackableUnAssignModal());
    };
    
    submit = () => {
        const trackable = this.props.trackableUnAssign.params;
        
        this.props.dispatch(closeTrackableAssociations({ obj_uid: trackable.uid }));
        this.props.dispatch(closeTrackableUnAssignModal());
    };
    
    render() {
        const { style } = this.props;
        const { params, open } = this.props.trackableUnAssign;
        
        return (
            <Modal
                contentLabel="trackableUnAssign"
                isOpen={open}
                onRequestClose={this.close}
                style={style}
            >
                
                <div className="RPP-Modal">
                    <span className="Modal-Header2-Grey">
                        {TRACKABLE_TAG_ASSOCIATION.FORM.UNASSIGN_TRACKABLE_TAG_FUNC((params && params.name)
                            || '', (params && params.node && macToUpperCase(params.node.mac_address)) || '')}
                    </span>
                    <TrackableUnAssignForm
                        className="Modal-Form"
                        close={this.close}
                        onSubmit={this.submit}
                    />
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = state => ({
    trackableUnAssign: state.modals.assignModals.trackableUnAssign,
});

export default connect(mapStateToProps)(TrackableUnAssignModal);
