import React from 'react';
import Modal from 'react-modal';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';

import { AUTH_MODAL } from 'common';
import { makeCopy } from 'utils/simpleUtils';
import { cookiesNotEnabledTryToClose } from 'stores/actions';


class CookiesNotEnabled extends React.PureComponent {
    static propTypes = {
        dispatch: PropTypes.func,
        style: PropTypes.shape({
            content: PropTypes.object,
            overlay: PropTypes.object,
        }),
        cookies: PropTypes.shape({
            open: PropTypes.bool,
        }),
    };
    
    static defaultProps = {
        dispatch: () => {
        },
        style: {
            content: {},
            overlay: {},
        },
        cookies: {
            open: false,
        },
    };
    
    tryToClose = (event) => {
        event.preventDefault();
        this.props.dispatch(cookiesNotEnabledTryToClose());
    };
    
    render() {
        const { cookies } = this.props;
        
        const style = makeCopy(this.props.style);
        style.content.width = '450px';
        
        return (
            <Modal
                contentLabel="CookiesNotEnabled"
                isOpen={cookies.open}
                onRequestClose={this.tryToClose}
                style={style}
            >
                
                <div className="RPP-Modal">
                    <form
                        className="Modal-Form"
                        onSubmit={this.tryToClose}
                    >
                        <div
                            className="Modal-Header2"
                            style={{ marginTop: '0px' }}
                            data-id="cookies-not-enabled-header"
                        >
                            {AUTH_MODAL.COOKIES_NOT_ENABLED.HEADER}
                        </div>
                        
                        <div className="Modal-Text" data-id="cookies-not-enabled-text">
                            {AUTH_MODAL.COOKIES_NOT_ENABLED.TEXT}
                        </div>
                        
                        <div className="Form-Buttons">
                            <button data-id="cookies-enabled" type="submit">{AUTH_MODAL.COOKIES_NOT_ENABLED.BUTTON_TEXT}</button>
                        </div>
                    </form>
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = state => ({
    cookies: state.modals.authModals.cookies,
});

export default connect(mapStateToProps)(CookiesNotEnabled);
