import React from 'react';
import Modal from 'react-modal';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { reduxForm } from 'redux-form';
import { injectIntl } from 'react-intl';

import { NAME_OF_FORMS, PROJECT_MODALS, COMPONENTS } from '../../common';
import { closeProjectsSettingsModal, closeProjectsSettingsModalBack } from '../../stores/actions';

let ProjectSettingsFormBack = (props) => {
    const { close, submit, className } = props;
    
    return (
        <form className={className}>
            <div className="Form-Text">{PROJECT_MODALS.PROJECT_SETTINGS.BACK.TEXT}</div>
            <div className="Form-Buttons">
                <button type="button" onClick={submit} data-id="project-settings-back-cancel">{COMPONENTS.BUTTONS.GO_BACK}</button>
                <button type="button" data-id="project-settings-back-close" onClick={close}>{COMPONENTS.FIELDS.COMMON.YES}</button>
            </div>
        </form>
    );
};

ProjectSettingsFormBack.propTypes = {
    close: PropTypes.func,
    submit: PropTypes.func,
    className: PropTypes.string,
    intl: PropTypes.shape({
        formatMessage: PropTypes.func,
    }),
};

ProjectSettingsFormBack.defaultProps = {
    close: () => {
    },
    submit: () => {
    },
    className: '',
    intl: {
        formatMessage: () => {
        },
    },
};

ProjectSettingsFormBack = reduxForm({
    form: NAME_OF_FORMS.PROJECTS_SETTINGS_BACK,
})(ProjectSettingsFormBack);

const mapStateToForm = state => ({
    initialValues: state.modals.authModals.projectsSettingsBack,
});
ProjectSettingsFormBack = connect(mapStateToForm)(injectIntl(ProjectSettingsFormBack));

class ProjectsSettingsModalBack extends React.PureComponent {
    static propTypes = {
        dispatch: PropTypes.func,
        projectsSettingsBack: PropTypes.shape({
            open: PropTypes.bool,
        }),
        style: PropTypes.shape(),
    };
    
    static defaultProps = {
        dispatch: () => {
        },
        projectsSettingsBack: {
            open: false,
        },
        style: {},
    };
    
    close = () => {
        this.props.dispatch(closeProjectsSettingsModal());
        this.props.dispatch(closeProjectsSettingsModalBack());
    };
    
    back = () => {
        this.props.dispatch(closeProjectsSettingsModalBack());
    };
    
    render() {
        const { projectsSettingsBack, style } = this.props;
        
        return (
            <Modal
                contentLabel="Welcome"
                isOpen={projectsSettingsBack.open}
                onRequestClose={this.close}
                style={style}
            >
                
                <div className="RPP-Modal">
                    <div className="Modal-Header">
                        {PROJECT_MODALS.PROJECT_SETTINGS.BACK.HEADER}
                    </div>
    
                    <ProjectSettingsFormBack className="Modal-Form" close={this.close} onSubmit={this.back} />

                </div>
            </Modal>
        );
    }
}

const mapStateToProps = state => ({
    projectsSettingsBack: state.modals.authModals.projectsSettingsBack,
});

export default connect(mapStateToProps)(ProjectsSettingsModalBack);
