import React from 'react';
import ReactDOM from 'react-dom';
import PropTypes from 'prop-types';

class CustomSlider extends React.Component {
    static propTypes = {
        onChange: PropTypes.func,
        min: PropTypes.number,
        max: PropTypes.number,
        defaultValue: PropTypes.number,
    };
    
    static defaultProps = {
        onChange: value => value,
        min: 0.1,
        max: 1,
        defaultValue: 0.1,
    };
    
    constructor(props) {
        super(props);
        this.state = { };
        this.slider = React.createRef();
    }
    
    componentDidMount() {
        const left = ReactDOM.findDOMNode(this).getBoundingClientRect().left;
        const width = ReactDOM.findDOMNode(this).getBoundingClientRect().width;
        const multiplier = width / (this.props.max - this.props.min);
        const currentValue = this.props.defaultValue;
        this.setState({
            left,
            width,
            multiplier,
            currentValue,
        });

        const sliderElement = this.slider.current; // from ref
        sliderElement.addEventListener('touchmove', this.bindUpdateStateHandler);
    }

    componentWillUnmount() {
        if ('ontouchstart' in window) {
            const sliderElement = this.slider.current; // from ref
            sliderElement.removeEventListener('touchmove', this.bindUpdateStateHandler);
        }
    }

    onMouseDown = (event) => {
        event.preventDefault(); // prevent selection start (browser action)
        this.updateStateHandler(event);
        document.addEventListener('mousemove', this.bindUpdateStateHandler);
        document.addEventListener('mouseup', this.onMouseUp);
    };

    onMouseUp = () => {
        document.removeEventListener('mousemove', this.bindUpdateStateHandler);
        document.removeEventListener('mouseup', this.onMouseUp);
    };

    bindUpdateStateHandler = this.updateStateHandler.bind(this);

    updateStateHandler(e) {
        const { pageX } = (e.changedTouches && e.changedTouches[0]) || e;
        const position = pageX - this.state.left;

        if (position < 0) {
            this.setState({
                currentValue: this.props.min,
            }, () => {
                this.props.onChange(this.state.currentValue);
            });
        } else if (position > (this.state.width)) {
            this.setState({
                currentValue: this.props.max,
            }, () => {
                this.props.onChange(this.state.currentValue);
            });
        } else {
            this.setState({
                currentValue: Math.round((100 * position) / this.state.multiplier) / 100,
            }, () => {
                this.props.onChange(this.state.currentValue);
            });
        }
    }
    
    render() {
        const sliderStyle = {
            borderTop: '15px solid rgba(0, 255, 0, 0)',
            borderRight: `${this.state.width}px solid grey`,
        };

        const cursorStyle = {
            position: 'absolute',
            left: `${((this.props.defaultValue * this.state.multiplier) + 10)}px`,
            width: '10px',
            height: '30px',
            backgroundColor: '#ADD8E6',
            cursor: 'pointer',
        };
        return (
            <div
                ref={(body) => {
                    this.body = body;
                }}
                style={{ width: '100%' }}
            >
                <div
                    ref={this.slider}
                    style={cursorStyle}
                    onMouseDown={this.onMouseDown}
                    onMouseUp={this.onMouseUp}
                />
                <div
                    style={sliderStyle}
                    onClick={this.mouseClickHandler}
                />
            </div>
        );
    }
}

export default CustomSlider;
