import React from 'react';
import Modal from 'react-modal';
import { connect } from 'react-redux';
import { push } from 'connected-react-router';
import { reduxForm } from 'redux-form';
import PropTypes from 'prop-types';
import _Get from 'lodash/get';
import { closeErrorModal } from 'stores/actions';
import { NAME_OF_FORMS, ROUTES } from 'common/constants';
import { COMPONENTS } from 'common/ui-labels';


let ErrorModalForm = (props) => {
    const { close, className, message } = props;
    
    return (
        <form className={className}>
            <div className="Form-DeleteTitle">
                { message }
            </div>
            <div className="Form-Buttons text-right">
                <button type="button" data-id="error-modal-close" onClick={close}>{COMPONENTS.BUTTONS.OK}</button>
            </div>
        </form>
    );
};
ErrorModalForm.propTypes = {
    close: PropTypes.func,
    className: PropTypes.string,
    message: PropTypes.string,
};
ErrorModalForm.defaultProps = {
    close: () => {},
    className: '',
    message: '',
};

ErrorModalForm = reduxForm({
    form: NAME_OF_FORMS.ERROR,
})(ErrorModalForm);

class ErrorModal extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        currentPath: PropTypes.string,
        generalError: PropTypes.shape({
            open: PropTypes.bool,
            message: PropTypes.string,
            title: PropTypes.string,
            onCloseRedirect: PropTypes.bool,
        }),
        mode: PropTypes.shape({
            onReturn: PropTypes.func,
        }),
        style: PropTypes.shape(),
    };
    
    static defaultProps = {
        currentPath: '',
        dispatch: () => {
        },
        generalError: {
            open: false,
            title: '',
            message: '',
            onCloseRedirect: false,
        },
        mode: null,
        style: {},
    };
    
    redirectOnClose = () => {
        const { generalError: { onCloseRedirect }, currentPath, dispatch } = this.props;
        if (onCloseRedirect && currentPath.includes(ROUTES.ADMIN_ROUTE)) {
            dispatch(push(ROUTES.SITE_ROUTE));
        }
    };
    
    close = () => {
        if (_Get(this.props, 'mode.onReturn', false)) {
            this.props.mode.onReturn();
        }
        this.redirectOnClose();
        this.props.dispatch(closeErrorModal());
    };
    
    render() {
        const { style, generalError } = this.props;
        
        return (
            <Modal
                contentLabel="nodeError"
                isOpen={generalError.open}
                onRequestClose={this.close}
                style={style}
            >
                <div className="RPP-Modal">
                    <span className="Modal-Header2" style={{ fontSize: '1.4em' }} data-id="error-modal">
                        {generalError.title}
                    </span>
                    <ErrorModalForm
                        className="Modal-Form"
                        message={generalError.message}
                        close={this.close}
                    />
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = state => ({
    currentPath: state.router.location.pathname,
    generalError: state.modals.commonModals.generalError,
    mode: state.siteView.mode,
});

export default connect(mapStateToProps)(ErrorModal);
