import React from 'react';
import Modal from 'react-modal';
import { connect } from 'react-redux';
import { reduxForm } from 'redux-form';
import PropTypes from 'prop-types';
import { NAME_OF_FORMS, DEFAULT_VALUES } from 'common/constants';
import { closeStatusNotificationPopup } from 'stores/actions/modalActions';


let StatusNotificationForm = (props) => {
    const { className, status, message } = props;
    let messageStyle = {};
    if (status === DEFAULT_VALUES.SUCCESS_STATUS) {
        messageStyle = { color: 'green' };
    } else if (status === DEFAULT_VALUES.UNSUCCESS_STATUS) {
        messageStyle = { color: 'red' };
    }
    return (
        <form className={className}>
            <div data-id="common-delete-message" className="Form-DeleteTitle" style={messageStyle}>
                {message}
            </div>
        </form>
    );
};

StatusNotificationForm.propTypes = {
    className: PropTypes.string,
    message: PropTypes.oneOfType([
        PropTypes.string,
        PropTypes.object,
    ]),
    status: PropTypes.string,
};

StatusNotificationForm.defaultProps = {
    className: '',
    message: '',
    status: '',
};

StatusNotificationForm = reduxForm({
    form: NAME_OF_FORMS.COMMON_DELETE,
})(StatusNotificationForm);


const StatusNotificationPopup = (props) => {
    const { style } = props;
    const { title, message, status, open } = props.statusNotificationPopup;
    const close = () => {
        props.dispatch(closeStatusNotificationPopup());
    };

    return (
        <Modal
            contentLabel="companyDelete"
            isOpen={open}
            onRequestClose={close}
            style={style}
        >
            <div className="RPP-Modal">
                <span className="Modal-Header2-Grey">
                    {title}
                </span>
                <StatusNotificationForm
                    className="Modal-Form"
                    status={status}
                    message={message}
                />
            </div>
        </Modal>
    );
};

StatusNotificationPopup.propTypes = {
    style: PropTypes.shape(),
    dispatch: PropTypes.func,
    statusNotificationPopup: PropTypes.shape({
        message: PropTypes.oneOfType([
            PropTypes.string,
            PropTypes.object,
        ]),
        title: PropTypes.oneOfType([
            PropTypes.string,
            PropTypes.object,
        ]),
        status: PropTypes.string,
        open: PropTypes.bool,
    }),
};

StatusNotificationPopup.defaultProps = {
    style: {},
    dispatch: () => { },
    statusNotificationPopup: {
        message: '',
        title: '',
        status: '',
        open: false,
    },
};

const mapStateToProps = state => ({
    statusNotificationPopup: state.modals.commonModals.statusNotificationPopup,
});

export default connect(mapStateToProps)(StatusNotificationPopup);
