import React from 'react';
import Modal from 'react-modal';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { reduxForm } from 'redux-form';
import { NAME_OF_FORMS } from 'common/constants';
import { COMPANY_DELETE_MODAL } from 'common/ui-labels';
import { closeCompanyDeleteModal, deleteCompany } from 'stores/actions';
import DeleteButtons from 'components/modals/DeleteButtons';


let CompanyDeleteForm = (props) => {
    const { close, submit, className, companiesToDelete, submitted } = props;

    const isBatchDelete = Array.isArray(companiesToDelete);

    const message = (isBatchDelete)
        ? COMPANY_DELETE_MODAL.SELECTED_COMPANIES
        : COMPANY_DELETE_MODAL.HEADER_FUNC(companiesToDelete.name);

    return (
        <form className={className}>
            {
                isBatchDelete && <div className="Form-Confirmation info-text" data-id="company-delete-message">
                    { COMPANY_DELETE_MODAL.NUMBER_OF_COMPANIES_SELECTED(<b>{companiesToDelete.length}</b>) }
                </div>
            }
            <div className="Form-DeleteTitle confirmation" data-id="company-delete-confirmation">
                {message}
            </div>
    
            <DeleteButtons submit={submit} close={close} submitted={submitted} dataId="company" />
        </form>
    );
};

CompanyDeleteForm.propTypes = {
    close: PropTypes.func,
    submit: PropTypes.func,
    className: PropTypes.string,
    submitted: PropTypes.bool,
    companiesToDelete: PropTypes.oneOfType([
        PropTypes.shape({
            name: PropTypes.string,
            uid: PropTypes.string,
        }),
        PropTypes.array,
    ]),
};

CompanyDeleteForm.defaultProps = {
    submit: () => {
    },
    close: () => {
    },
    className: '',
    submitted: false,
    companiesToDelete: {
        name: '',
        uid: '',
    },
};

CompanyDeleteForm = reduxForm({
    form: NAME_OF_FORMS.COMPANY_DELETE,
})(CompanyDeleteForm);


class CompanyDeleteModal extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        companyDelete: PropTypes.shape({
            open: PropTypes.bool,
            params: PropTypes.oneOfType([
                PropTypes.shape({ name: PropTypes.string }),
                PropTypes.arrayOf(PropTypes.shape()),
            ]),
        }),
        style: PropTypes.shape(),
    };
    
    static defaultProps = {
        dispatch: () => {
        },
        companyDelete: {
            open: false,
            params: {
                name: '',
            },
        },
        style: {},
    };
    
    constructor(props) {
        super(props);
        this.state = {
            submitted: false,
        };
    }
    
    close = () => {
        this.props.dispatch(closeCompanyDeleteModal());
    };
    
    submit = () => {
        this.setState({ submitted: true });
        this.props.dispatch(deleteCompany(this.props.companyDelete.params));
        this.props.dispatch(closeCompanyDeleteModal());
    };
    
    render() {
        const { style, companyDelete } = this.props;

        return (
            <Modal
                contentLabel="companyDelete"
                isOpen={companyDelete.open}
                onRequestClose={this.close}
                shouldCloseOnOverlayClick={false}
                onAfterClose={() => {
                    this.setState({ submitted: false });
                }}
                style={style}
            >
                <div className="RPP-Modal">
                    <CompanyDeleteForm
                        className="Modal-Form"
                        submitted={this.state.submitted}
                        close={this.close}
                        onSubmit={this.submit}
                        companiesToDelete={companyDelete.params}
                    />
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = state => ({
    companyDelete: state.modals.companyModals.companyDelete,
});

export default connect(mapStateToProps)(CompanyDeleteModal);
