import React from 'react';
import Modal from 'react-modal';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { reduxForm } from 'redux-form';

import { NAME_OF_FORMS } from '../../common/constants';
import { COMPONENTS } from '../../common/ui-labels';
import { closeCompanyDetailsModal } from '../../stores/actions';


let CompanyDetailsForm = (props) => {
    const { close, params, className } = props;
    return (
        <form className={className}>
            <div className="Form-Line row">
                <div className="Form-Label col-md-4">{COMPONENTS.FIELDS.COMMON.NAME}</div>
                <div className="Form-Value col-md-8 multiple-lines-ellipsis" data-id="company-details-name">{params.name}</div>
            </div>
            <div className="Form-Line row">
                <div className="Form-Label col-md-4">{COMPONENTS.FIELDS.COMPANY.WEBSITE}</div>
                <div className="Form-Value col-md-8 multiple-lines-ellipsis" data-id="company-details-website">{params.website}</div>
            </div>
            <div className="Form-Line row">
                <div className="Form-Label col-md-4">{COMPONENTS.FIELDS.USER.PHONE}</div>
                <div className="Form-Value col-md-8 multiple-lines-ellipsis" data-id="company-details-phone">{params.phone}</div>
            </div>
            <div className="Form-Buttons OneBtn">
                <button type="button" data-id="company-details-close" onClick={close}>{COMPONENTS.BUTTONS.CLOSE}</button>
            </div>
        </form>
    );
};

CompanyDetailsForm.propTypes = {
    close: PropTypes.func,
    className: PropTypes.string,
    params: PropTypes.shape({
        name: PropTypes.string,
        website: PropTypes.string,
        phone: PropTypes.string,
    }),
};

CompanyDetailsForm.defaultProps = {
    close: () => {
    },
    className: '',
    params: {
        name: '',
        website: '',
        phone: '',
    },
};

CompanyDetailsForm = reduxForm({
    form: NAME_OF_FORMS.COMPANY_DETAILS,
})(CompanyDetailsForm);


class CompanyDetailsModal extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        companyDetails: PropTypes.shape({
            open: PropTypes.bool,
            params: PropTypes.shape({
                name: PropTypes.string,
            }),
        }),
        style: PropTypes.shape(),
    };
    
    static defaultProps = {
        dispatch: () => {
        },
        companyDetails: {
            open: false,
            params: {
                name: '',
            },
        },
        style: {},
    };
    
    close = () => {
        this.props.dispatch(closeCompanyDetailsModal());
    };
    
    render() {
        const { style, companyDetails } = this.props;
        return (
            <Modal
                contentLabel="companyDetails"
                isOpen={companyDetails.open}
                onRequestClose={this.close}
                style={style}
            >
                
                <div className="RPP-Modal">
                    <span className="Modal-Header multiple-lines-ellipsis">
                        {COMPONENTS.FIELDS.COMMON.VIEW_INFORMATION_FUNC(companyDetails.params ? companyDetails.params.name : '')}
                    </span>
                    <CompanyDetailsForm
                        className="Modal-Form"
                        close={this.close}
                        params={companyDetails.params}
                    />
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = state => ({
    companyDetails: state.modals.companyModals.companyDetails,
});

export default connect(mapStateToProps)(CompanyDetailsModal);
