import React from 'react';
import PropTypes from 'prop-types';
import Modal from 'react-modal';
import { connect } from 'react-redux';
import { reduxForm } from 'redux-form';
import { createStructuredSelector } from 'reselect';
import isEqual from 'lodash/isEqual';
import { NAME_OF_FORMS } from 'common/constants';
import { closeGroupDeleteModal, deleteGroup } from 'stores/actions';
import { GROUP_DELETE_MODAL } from 'common/ui-labels';
import DeleteButtons from 'components/modals/DeleteButtons';


let GroupDeleteForm = (props) => {
    const { close, submit, className, initialValues, submitted } = props;

    const isBatchDelete = Array.isArray(initialValues);

    const message = (isBatchDelete)
        ? GROUP_DELETE_MODAL.FORM.TITLE.MULTI
        : GROUP_DELETE_MODAL.FORM.TITLE.SINGLE_FUNC(initialValues.name);

    return (
        <form className={className}>
            {
                isBatchDelete && <div className="Form-Confirmation info-text" data-id="group-delete-message">
                    { GROUP_DELETE_MODAL.NUMBER_OF_GROUPS_SELECTED(<b>{initialValues.length}</b>) }
                </div>
            }
            <div className="Form-DeleteTitle confirmation" data-id="group-delete-confirmation">
                {message}
            </div>
            
            <DeleteButtons submit={submit} close={close} submitted={submitted} dataId="group" />
        </form>
    );
};

GroupDeleteForm.propTypes = {
    close: PropTypes.func,
    submit: PropTypes.func,
    className: PropTypes.string,
    submitted: PropTypes.bool,
    initialValues: PropTypes.oneOfType([
        PropTypes.shape({
            name: PropTypes.string,
            uid: PropTypes.string,
        }),
        PropTypes.array,
    ]),
};

GroupDeleteForm.defaultProps = {
    close: () => {
    },
    submit: () => {
    },
    className: '',
    submitted: false,
    initialValues: {
        name: '',
        uid: '',
    },
};

GroupDeleteForm = reduxForm({
    form: NAME_OF_FORMS.COMPANY_DELETE,
})(GroupDeleteForm);

const mapStateToForm = state => ({
    initialValues: state.modals.groupModals.groupDelete.params,
});
GroupDeleteForm = connect(mapStateToForm)(GroupDeleteForm);

class GroupDeleteModal extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        groupDelete: PropTypes.shape({
            params: PropTypes.oneOfType([
                PropTypes.shape({
                    params: PropTypes.shape({
                        mac_address: PropTypes.string,
                        uid: PropTypes.string,
                    }),
                    open: PropTypes.bool,
                }),
                PropTypes.array,
            ]),
            open: PropTypes.bool,
        }),
        style: PropTypes.shape({
            overlay: PropTypes.object,
            content: PropTypes.object,
        }),
    };
    
    static defaultProps = {
        dispatch: () => {
        },
        groupDelete: {
            params: {
                mac_address: '',
                uid: '',
            },
            open: false,
        },
        style: {
            overlay: {},
            content: {},
        },
    };
    
    constructor(props) {
        super(props);
        this.state = {
            submitted: false,
        };
    }
    
    shouldComponentUpdate(nextProps, nextState) {
        return !isEqual(nextProps, this.props) || nextState.submitted !== this.state.submitted;
    }
    
    close = () => {
        this.props.dispatch(closeGroupDeleteModal());
    };
    
    submit = () => {
        this.setState({ submitted: true });
        this.props.dispatch(deleteGroup(this.props.groupDelete.params));
    };
    
    render() {
        const { style } = this.props;
        
        return (
            <Modal
                contentLabel="groupDelete"
                isOpen={this.props.groupDelete.open}
                shouldCloseOnOverlayClick={false}
                onAfterClose={() => {
                    this.setState({ submitted: false });
                }}
                onRequestClose={this.close}
                style={style}
            >
                
                <div className="RPP-Modal">
                    <GroupDeleteForm
                        submitted={this.state.submitted}
                        className="Modal-Form"
                        close={this.close}
                        onSubmit={this.submit}
                    />
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = createStructuredSelector({
    groupDelete: state => state.modals.groupModals.groupDelete,
});

export default connect(mapStateToProps)(GroupDeleteModal);
