import React from 'react';
import PropTypes from 'prop-types';
import Modal from 'react-modal';
import { connect } from 'react-redux';

import { prepareSensorSpecialCasesForServer, prepareSensorInterfaceForServer } from 'utils/utils';
import { makeCopy } from 'utils/simpleUtils';
import { DEFAULT_VALUES } from 'common/constants';
import { GROUP_EDIT_MODAL } from 'common/ui-labels';
import { closeGroupEditModal, editGroup, createGroup } from 'stores/actions';
import { getParseGroupEdit } from './utils';
import GroupEditForm from './GroupEditForm';

const createValue = (values) => {
    const valueCopy = makeCopy(values);
    delete valueCopy.selector;

    const sensorInterface = prepareSensorInterfaceForServer(valueCopy.sensorInterface);
    const sensorSpecialCases = prepareSensorSpecialCasesForServer(valueCopy.sensorSpecialCases);

    valueCopy.sensor_config = sensorInterface.concat(sensorSpecialCases);

    return valueCopy;
};

class GroupEditModal extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        groupEdit: PropTypes.shape({
            params: PropTypes.shape({
                mac_address: PropTypes.string,
                uid: PropTypes.string,
                name: PropTypes.string,
                angle: PropTypes.number,
                distance: PropTypes.number,
            }),
            open: PropTypes.bool,
        }),
        style: PropTypes.shape({
            overlay: PropTypes.object,
            content: PropTypes.object,
        }),
    };
    
    static defaultProps = {
        dispatch: () => {
        },
        groupEdit: {
            params: {
                mac_address: '',
                uid: '',
                name: '',
                distance: DEFAULT_VALUES.LLL_COVERAGE_DISTANCE,
                angle: DEFAULT_VALUES.LLL_COVERAGE_ANGLE,
            },
            open: false,
        },
        style: {
            overlay: {},
            content: {},
        },
    };
    
    close = () => {
        this.props.dispatch(closeGroupEditModal());
    };

    submit = (values) => {
        const transformedValues = createValue(values);
        const editedGroup = this.props.groupEdit.params ? this.props.groupEdit.params.uid : null;

        if (editedGroup) {
            this.props.dispatch(editGroup(transformedValues));
        } else {
            this.props.dispatch(createGroup(transformedValues));
        }
        this.props.dispatch(closeGroupEditModal());
    };
    
    render() {
        const currentStyle = makeCopy(this.props.style);
        currentStyle.content.width = '800px';
        currentStyle.content.maxHeight = 'calc(100vh - 30px)';
        currentStyle.content.overflowY = 'auto';
        currentStyle.content.overflowX = 'hidden';
        currentStyle.content.transform = 'translate(-50%, -50%)';
        
        return (
            <Modal
                contentLabel="groupEdit"
                isOpen={this.props.groupEdit.open}
                onRequestClose={this.close}
                style={currentStyle}
            >
                
                <div className="RPP-Modal">
                    <span className="Modal-Header">
                        {this.props.groupEdit.params && this.props.groupEdit.params.uid
                            ? this.props.groupEdit.params.name
                            : GROUP_EDIT_MODAL.TITLE}
                    </span>
                    <GroupEditForm
                        className="Modal-Form"
                        close={this.close}
                        onSubmit={this.submit}
                    />
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = state => ({
    groupEdit: getParseGroupEdit(state),
});

export default connect(mapStateToProps)(GroupEditModal);
