import React from 'react';
import Modal from 'react-modal';
import { connect } from 'react-redux';
import { reduxForm } from 'redux-form';
import PropTypes from 'prop-types';
import { NAME_OF_FORMS } from 'common/constants';
import { closeDeleteNodeModal, deleteNodes } from 'stores/actions';
import { NODE_DELETE_MODAL } from 'common/ui-labels';
import DeleteButtons from 'components/modals/DeleteButtons';


let NodeDeleteForm = (props) => {
    const { close, submit, className, assigned_to, initialValues, submitted } = props;
    const { mac_address } = initialValues;

    const isBatchDelete = !props.initialValues.mac_address;
    const isAssigned = !!assigned_to.length;

    const numberOfAssigned = assigned_to.length;
    const isSingleAssigned = !isBatchDelete && numberOfAssigned === 1;

    const assignedTkoName = isSingleAssigned ? assigned_to[0].name : '';

    const isAnyAssigned = numberOfAssigned > 0;
    const tobeDeletedCount = initialValues.length;

    const singleAssignedMessage = NODE_DELETE_MODAL.MESSAGE.SINGLE.ASSIGN_FUNC(<b>{mac_address}</b>, <b>{assignedTkoName}</b>);
    const batchAssignedMessage = isAnyAssigned
        ? NODE_DELETE_MODAL.MESSAGE.MULTI.ASSIGNED_COMMON(<b>{numberOfAssigned}</b>, <b>{tobeDeletedCount}</b>)
        : NODE_DELETE_MODAL.NUMBER_OF_TAGS_SELECTED(<b>{tobeDeletedCount}</b>);

    const singleDeleteConfirmation = NODE_DELETE_MODAL.MESSAGE.SINGLE.NOT_ASSIGN_FUNC(!isAssigned && mac_address);
    const confirmationMessage = isBatchDelete
        ? NODE_DELETE_MODAL.MESSAGE.MULTI.NOT_ASSIGN
        : singleDeleteConfirmation;

    return (
        <form className={className}>
            {
                (isBatchDelete || isSingleAssigned) && <div className="Form-Confirmation info-text" data-id="trackable-delete-message">
                    { isSingleAssigned ? singleAssignedMessage : batchAssignedMessage }
                </div>
            }

            <div className="Form-DeleteTitle confirmation" data-id="node-delete-details">
                { confirmationMessage }
            </div>
    
            <DeleteButtons submit={submit} close={close} submitted={submitted} dataId="node" />
        </form>
    );
};

NodeDeleteForm.propTypes = {
    initialValues: PropTypes.oneOfType([PropTypes.arrayOf(PropTypes.shape()), PropTypes.shape()]),
    close: PropTypes.func,
    submit: PropTypes.func,
    className: PropTypes.string,
    submitted: PropTypes.bool,
    assigned_to: PropTypes.arrayOf(PropTypes.object),
};

NodeDeleteForm.defaultProps = {
    initialValues: {},
    close: () => {},
    submit: () => {},
    className: '',
    submitted: false,
    assigned_to: [],
};

NodeDeleteForm = reduxForm({
    form: NAME_OF_FORMS.NODE_DELETE,
})(NodeDeleteForm);

const mapStateToForm = state => ({
    initialValues: state.modals.nodeModals.nodeDelete.params,
});

NodeDeleteForm = connect(mapStateToForm)(NodeDeleteForm);

class NodeDeleteModal extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        associationsMap: PropTypes.shape({}),
        trackablesMap: PropTypes.shape({}),
        nodeDelete: PropTypes.shape({
            params: PropTypes.oneOfType([PropTypes.arrayOf(PropTypes.shape()), PropTypes.shape()]),
            open: PropTypes.bool,
        }),
        style: PropTypes.shape(),
    };
    
    static defaultProps = {
        dispatch: () => { },
        associationsMap: {},
        trackablesMap: {},
        nodeDelete: {
            params: {},
            open: false,
        },
        style: {},
    };
    
    constructor(props) {
        super(props);
        this.state = {
            submitted: false,
        };
    }
    
    close = () => {
        this.props.dispatch(closeDeleteNodeModal());
    };
    
    submit = () => {
        this.setState({ submitted: true });
        this.props.dispatch(deleteNodes(this.props.nodeDelete.params));
        this.props.dispatch(closeDeleteNodeModal());
    };
    
    findTrackableByMac = (mac_address) => {
        const trackable_uid = this.props.associationsMap[mac_address];
        if (!trackable_uid) {
            return null;
        }
        return this.props.trackablesMap[trackable_uid];
    };
    
    render() {
        const { style } = this.props;
        const mac_address = this.props.nodeDelete.params ? this.props.nodeDelete.params.mac_address : '';
        const isBatchDelete = Array.isArray(this.props.nodeDelete.params);
        const assigned_to = [];
        
        if (isBatchDelete) {
            this.props.nodeDelete.params.forEach((node) => {
                const trackable = this.findTrackableByMac(node.mac_address);
                if (trackable) {
                    assigned_to.push(trackable);
                }
            });
        } else if (mac_address && this.findTrackableByMac(mac_address)) {
            assigned_to.push(this.findTrackableByMac(mac_address));
        }

        return (
            <Modal
                contentLabel="companyDelete"
                isOpen={this.props.nodeDelete.open}
                onRequestClose={this.close}
                shouldCloseOnOverlayClick={false}
                onAfterClose={() => {
                    this.setState({ submitted: false });
                }}
                style={style}
            >
                <div className="RPP-Modal">
                    <NodeDeleteForm
                        className="Modal-Form"
                        assigned_to={assigned_to}
                        submitted={this.state.submitted}
                        close={this.close}
                        onSubmit={this.submit}
                    />
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = state => ({
    nodeDelete: state.modals.nodeModals.nodeDelete,
    associationsMap: state.entities.associations.byMac,
    trackablesMap: state.entities.trackables.byUid,
});

export default connect(mapStateToProps)(NodeDeleteModal);
