import React from 'react';
import PropTypes from 'prop-types';
import Modal from 'react-modal';
import { connect } from 'react-redux';
import { Field, reduxForm } from 'redux-form';

import { NAME_OF_FORMS, NODE_MODAL, DEFAULT_VALUES, COMPONENTS } from '../../common';

import { closeNodeImportCheckTwoModal, closeImportNodeModal, validateCsvMacAddresses } from '../../stores/actions';

let NodeImportCheckTwoForm = (props) => {
    const {
        close, submit, back, className,
    } = props;
    const column = props.column;
    const parseData = props.parsedData.map(data => data[column]);

    return (
        <form className={className}>
            <div className="Form-Line">
                <div className="Form-Label">
                    {COMPONENTS.FIELDS.NODE.MAC_ADDRESS} :
                </div>
                <div style={{ maxHeight: '300px', overflowY: 'auto' }}>{parseData.map((data, index) => (
                    <div
                        className="node-error-message-box"
                        data-id={`node-import-check-two-${data}`}
                        key={index}
                    >
                        {data}
                    </div>))}
                </div>
            </div>
            <div className="Form-Line">
                <div data-id="node-import-check-two-has-header">
                    <label className="checkbox-label">
                        <Field
                            name="hasHeader"
                            component="input"
                            type="checkbox"
                            style={{ marginTop: '-2px' }}
                        />
                        {NODE_MODAL.NODE_IMPORT_CHECK_MODAL.HAS_HEADER}
                    </label>
                </div>
            </div>
            <div className="Form-Buttons OneBtn">
                <button type="button" data-id="node-import-check-two-back" onClick={back}>
                    {COMPONENTS.BUTTONS.GO_BACK}
                </button>
                <button type="button" data-id="node-import-check-two-import" onClick={submit}>
                    {COMPONENTS.BUTTONS.IMPORT}
                </button>
                <button type="button" data-id="node-import-check-two-cancel" onClick={close}>
                    {COMPONENTS.BUTTONS.CANCEL}
                </button>
            </div>
        </form>
    );
};
NodeImportCheckTwoForm = reduxForm({
    form: NAME_OF_FORMS.NODE_IMPORT_CHECK_TWO,
})(NodeImportCheckTwoForm);

NodeImportCheckTwoForm.propTypes = {
    close: PropTypes.func,
    submit: PropTypes.func,
    back: PropTypes.func,
    parsedData: PropTypes.arrayOf(PropTypes.array),
    className: PropTypes.string,
    column: PropTypes.number,
};

NodeImportCheckTwoForm.defaultProps = {
    close: () => {
    },
    submit: () => {
    },
    back: () => {
    },
    parsedData: [],
    className: '',
    column: 0,
};

const mapStateToForm = state => ({
    parsedData: state.modals.nodeModals.nodeImport.parseData ? state.modals.nodeModals.nodeImport.parseData : [],
    column: state.modals.nodeModals.nodeImport.column,
});

NodeImportCheckTwoForm = connect(mapStateToForm)(NodeImportCheckTwoForm);

class NodeImportCheckTwoModal extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        style: PropTypes.shape({}),
        column: PropTypes.number,
        parsedData: PropTypes.arrayOf(PropTypes.array),
        nodeDetails: PropTypes.shape({
            open: PropTypes.bool,
        }),
    };
    
    static defaultProps = {
        dispatch: () => {},
        style: {},
        column: 0,
        parsedData: [],
        nodeDetails: {
            open: false,
        },
    };
    
    submit = (formData) => {
        const removeHeader = formData.hasHeader ? formData.hasHeader : false;
        const column = this.props.column;
        const parseData = this.props.parsedData.map(data => data[column]);
        if (removeHeader) {
            parseData.splice(0, 1);
        }
        this.props.dispatch(validateCsvMacAddresses({ data: parseData }));
        this.props.dispatch(closeNodeImportCheckTwoModal());
    };
    
    close = () => {
        this.props.dispatch(closeNodeImportCheckTwoModal());
        this.props.dispatch(closeImportNodeModal());
    };
    
    back = () => {
        this.props.dispatch(closeNodeImportCheckTwoModal());
    };
    
    render() {
        const { style } = this.props;
        
        return (
            <Modal
                contentLabel="projectDetails"
                isOpen={this.props.nodeDetails.open}
                onRequestClose={this.close}
                style={style}
            >
                
                <div className="RPP-Modal">
                    <span className="Modal-Header">
                        {NODE_MODAL.NODE_IMPORT_CHECK_MODAL.CHECK_IMPORT}
                    </span>
                    <NodeImportCheckTwoForm
                        className="Modal-Form"
                        close={this.close}
                        back={this.back}
                        onSubmit={this.submit}
                    />
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = state => ({
    nodeDetails: state.modals.nodeModals.nodeImportCheckTwo,
    parsedData: state.modals.nodeModals.nodeImport.parseData ? state.modals.nodeModals.nodeImport.parseData : DEFAULT_VALUES.empty_array,
    column: state.modals.nodeModals.nodeImport.column,
});

export default connect(mapStateToProps)(NodeImportCheckTwoModal);
