import React from 'react';
import PropTypes from 'prop-types';
import Modal from 'react-modal';
import { connect } from 'react-redux';
import { reduxForm } from 'redux-form';
import { NAME_OF_FORMS, NOTIFICATION_TYPE } from 'common/constants';
import { closeNotificationDeleteModal, deleteNotification } from 'stores/actions';
import { NOTIFICATION_DELETE_MODAL } from 'common/ui-labels';
import DeleteButtons from 'components/modals/DeleteButtons';


const getNotificationsType = (params) => {
    if (params && params.uid) {
        return params.notification_type === NOTIFICATION_TYPE.ALARM;
    } else if (params && params.length > 0 && params[0]) {
        return params[0].notification_type === NOTIFICATION_TYPE.ALARM;
    }
    return false;
};

let NotificationDeleteForm = (props) => {
    const { close, submit, className, initialValues, submitted } = props;
    const isAlarmNotification = getNotificationsType(initialValues);
    let message;

    const isBatchDelete = Array.isArray(initialValues);

    if (isAlarmNotification) {
        message = (isBatchDelete)
            ? NOTIFICATION_DELETE_MODAL.TITLE_MULTI
            : NOTIFICATION_DELETE_MODAL.TITLE_FUNC(initialValues.name);
    } else {
        message = (isBatchDelete)
            ? NOTIFICATION_DELETE_MODAL.SYSTEM_TITLE_MULTI
            : NOTIFICATION_DELETE_MODAL.SYSTEM_TITLE_FUNC(initialValues.name);
    }

    return (
        <form className={className}>
            {
                isBatchDelete && <div className="Form-Confirmation info-text" data-id="notification-delete-message">
                    { NOTIFICATION_DELETE_MODAL.NUMBER_OF_NOTIFICATIONS_SELECTED(<b>{initialValues.length}</b>) }
                </div>
            }
            <div className="Form-DeleteTitle confirmation" data-id="notification-delete-confirmation">
                {message}
            </div>
    
            <DeleteButtons submit={submit} close={close} submitted={submitted} dataId="notification" />
        </form>
    );
};

NotificationDeleteForm.propTypes = {
    close: PropTypes.func,
    submit: PropTypes.func,
    submitted: PropTypes.bool,
    initialValues: PropTypes.oneOfType([
        PropTypes.object,
        PropTypes.array,
    ]),
    className: PropTypes.string,
};

NotificationDeleteForm.defaultProps = {
    close: () => {
    },
    submit: () => {
    },
    submitted: false,
    initialValues: {},
    className: '',
};

NotificationDeleteForm = reduxForm({
    form: NAME_OF_FORMS.NOTIFICATION_DELETE,
})(NotificationDeleteForm);

const mapStateToForm = state => ({
    initialValues: state.modals.notificationModals.notificationDelete.params,
});

NotificationDeleteForm = connect(mapStateToForm)(NotificationDeleteForm);

class NotificationDeleteModal extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        notificationDelete: PropTypes.shape({
            params: PropTypes.oneOfType([
                PropTypes.shape({
                    uid: PropTypes.string,
                    name: PropTypes.string,
                }),
                PropTypes.arrayOf(PropTypes.shape({
                    uid: PropTypes.string,
                    name: PropTypes.string,
                })),
            ]),
            open: PropTypes.bool,
        }),
        style: PropTypes.shape({}),
    };
    
    static defaultProps = {
        dispatch: () => {
        },
        notificationDelete: {
            params: {
                uid: '',
                name: '',
            },
            open: false,
        },
        style: {},
    };
    
    constructor(props) {
        super(props);
        this.state = {
            submitted: false,
        };
    }
    
    close = () => {
        this.props.dispatch(closeNotificationDeleteModal());
    };
    
    submit = () => {
        this.setState({ submitted: true });
        if (this.props.notificationDelete.params.uid) {
            this.props.dispatch(deleteNotification({ uid: this.props.notificationDelete.params.uid }));
        } else {
            this.props.notificationDelete.params.forEach((notification) => {
                this.props.dispatch(deleteNotification({ uid: notification.uid }));
            });
        }
        
        this.props.dispatch(closeNotificationDeleteModal());
    };
    
    render() {
        const { style } = this.props;

        return (
            <Modal
                contentLabel="notificationDelete"
                isOpen={this.props.notificationDelete.open}
                onRequestClose={this.close}
                shouldCloseOnOverlayClick={false}
                onAfterClose={() => {
                    this.setState({ submitted: false });
                }}
                style={style}
            >
                
                <div className="RPP-Modal">
                    <NotificationDeleteForm
                        className="Modal-Form"
                        submitted={this.state.submitted}
                        close={this.close}
                        onSubmit={this.submit}
                    />
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = state => ({
    notificationDelete: state.modals.notificationModals.notificationDelete,
});

export default connect(mapStateToProps)(NotificationDeleteModal);
