import React from 'react';
import PropTypes from 'prop-types';
import Modal from 'react-modal';
import { connect } from 'react-redux';
import { reduxForm } from 'redux-form';
import { NAME_OF_FORMS } from 'common/constants';
import { PROJECT_MODALS } from 'common/ui-labels';
import { closeProjectDeleteModal, deleteProject } from 'stores/actions';
import DeleteButtons from 'components/modals/DeleteButtons';


let ProjectDeleteForm = (props) => {
    const { close, submit, className, submitted } = props;
    return (
        <form className={className}>
            <div className="Form-DeleteTitle confirmation" data-id="project-delete-name">
                {PROJECT_MODALS.DELETE_MODAL.CONFIRMATION_FUNC(props.initialValues.name)}
            </div>
    
            <DeleteButtons submit={submit} close={close} submitted={submitted} dataId="project" />
        </form>
    );
};

ProjectDeleteForm = reduxForm({
    form: NAME_OF_FORMS.PROJECT_DELETE,
})(ProjectDeleteForm);

ProjectDeleteForm.propTypes = {
    close: PropTypes.func,
    submit: PropTypes.func,
    submitted: PropTypes.bool,
    initialValues: PropTypes.oneOfType([
        PropTypes.object,
        PropTypes.array,
    ]),
    className: PropTypes.string,
};

ProjectDeleteForm.defaultProps = {
    close: () => {
    },
    submit: () => {
    },
    submitted: false,
    initialValues: {},
    className: '',
};

const mapStateToForm = state => ({
    initialValues: state.modals.projectModals.projectDelete.params,
});
ProjectDeleteForm = connect(mapStateToForm)(ProjectDeleteForm);


class ProjectDeleteModal extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        projectDelete: PropTypes.shape({
            params: PropTypes.oneOfType([
                PropTypes.shape({
                    uid: PropTypes.string,
                    name: PropTypes.string,
                }),
                PropTypes.arrayOf(PropTypes.shape({
                    uid: PropTypes.string,
                    name: PropTypes.string,
                })),
            ]),
            open: PropTypes.bool,
        }),
        style: PropTypes.shape({}),
    };
    
    static defaultProps = {
        dispatch: () => {
        },
        projectDelete: {
            params: {
                uid: '',
                name: '',
            },
            open: false,
        },
        style: {},
    };
    
    constructor(props) {
        super(props);
        this.state = {
            submitted: false,
        };
    }

    close = () => {
        this.props.dispatch(closeProjectDeleteModal());
    };
    
    submit = () => {
        const { projectDelete: { params: { uid } } } = this.props;
        this.setState({ submitted: true });
        if (uid) {
            this.props.dispatch(deleteProject({ uid }));
        }
        this.props.dispatch(closeProjectDeleteModal());
    };
    
    render() {
        const { style } = this.props;
        return (
            <Modal
                contentLabel="companyDelete"
                isOpen={this.props.projectDelete.open}
                onRequestClose={this.close}
                shouldCloseOnOverlayClick={false}
                onAfterClose={() => {
                    this.setState({ submitted: false });
                }}
                style={style}
            >
                <div className="RPP-Modal">
                    <ProjectDeleteForm
                        className="Modal-Form"
                        close={this.close}
                        submitted={this.state.submitted}
                        onSubmit={this.submit}
                    />
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = state => ({
    projectDelete: state.modals.projectModals.projectDelete,
});

export default connect(mapStateToProps)(ProjectDeleteModal);
