import React from 'react';
import Modal from 'react-modal';
import { connect } from 'react-redux';
import PropTypes from 'prop-types';
import { bulkAssignTrackable, closeTrackableBulkAssignModal } from 'stores/actions';
import { TRACKABLE_MODAL } from 'common';
import { TrackableBulkAssignForm } from './TrackableBulkAssignForm';
import { makeCopy } from 'utils/simpleUtils';

function TrackableBulkAssignModal(props) {
    const { style, trackableBulkAssign: { open }, close, submit } = props;
    const currentStyle = makeCopy(style);
    currentStyle.content.maxHeight = '85vh';

    return (
        <Modal
            contentLabel="TrackableBulkAssignModal"
            isOpen={open}
            shouldCloseOnOverlayClick={false}
            onRequestClose={close}
            style={currentStyle}
        >
            <div className="RPP-Modal">
                <span className="Modal-Header multiple-lines-ellipsis" data-id="zone-bulk-edit-title">
                    {TRACKABLE_MODAL.BULK_ASSIGN.HEADER}
                </span>
                <span className="grey-text">{TRACKABLE_MODAL.BULK_ASSIGN.DESCRIPTION}</span>
                <TrackableBulkAssignForm
                    className="Modal-Form"
                    close={close}
                    onSubmit={submit}
                />
            </div>
        </Modal>
    );
}

TrackableBulkAssignModal.propTypes = {
    trackableBulkAssign: PropTypes.shape({
        open: PropTypes.bool,
        params: PropTypes.shape({}),
    }),
    style: PropTypes.shape({}),
    close: PropTypes.func,
    submit: PropTypes.func,
};
TrackableBulkAssignModal.defaultProps = {
    trackableBulkAssign: {},
    style: {},
    close: () => {},
    submit: () => {},
};

const mapDispatchToProps = (dispatch) => ({
    submit: (values) => dispatch(bulkAssignTrackable(values)),
    close: () => dispatch(closeTrackableBulkAssignModal()),
});

const mapStateToProps = (state) => ({
    trackableBulkAssign: state.modals.trackableModals.trackableBulkAssign,
});

export default connect(mapStateToProps, mapDispatchToProps)(TrackableBulkAssignModal);
