import React from 'react';
import PropTypes from 'prop-types';
import { COMPONENTS, DB_NAMES, TRACKABLE_BULK_EDIT, TRACKABLE_MODAL } from 'common/ui-labels';
import { POS_UPDATE_INTERVAL } from 'common/constants';
import { Field } from 'redux-form';
import { isAssetTag, preventInputNotNumber } from 'utils/utils';
import RenderTooltipHelper from 'components/RenderTooltipHelper';
import RenderSimpleTimeDurationField from 'components/modals/RenderSimpleTimeDurationField';
import SelectComponent from 'components/modals/SelectComponent';
import { RenderFieldWithPadding } from 'components/modals/RenderFieldWithPadding';

const renderReducedField = RenderFieldWithPadding(4, 4, undefined, 4);

function getOptions(intl) {
    return [
        { value: 0, label: DB_NAMES.NONE(intl) },
        { value: 0.25, label: '0.25s' },
        { value: 0.5, label: '0.5s' },
        { value: 1, label: '1s' },
        { value: 2, label: '2s' },
        { value: 5, label: '5s' },
        { value: 10, label: '10s' },
    ]
}

export function AdvancedSectionForm({ advanced_checkbox, intl, category }) {
    const updateIntervalOptions = getOptions(intl);
    const isAsset = isAssetTag(category);

    return (<section>
        <div className="Form-Line row" data-id="trackable-bulk-edit-advanced-checkbox-text">
            <div className="Form-Label col-md-4">{TRACKABLE_BULK_EDIT.ADVANCED_OPTIONS}</div>
            <div className="col-md-1" data-id="trackable-bulk-edit-advanced-checkbox">
                <Field
                    name="advanced_checkbox"
                    id="advanced_checkbox"
                    component="input"
                    type="checkbox"
                    style={{ width: '19px', height: '19px' }}
                />
            </div>
        </div>
        <section style={{ display: advanced_checkbox ? 'block' : 'none' }}>
            <div className="Form-Line row" data-id="trackable-bulk-edit-default-height">
                <Field
                    type="text"
                    onChange={(e) => {
                        preventInputNotNumber(e);
                    }}
                    className="Form-Input"
                    name="defaultHeight"
                    dataCy="defaultHeight"
                    component={renderReducedField}
                    masked={false}
                    label={TRACKABLE_MODAL.EDIT.FORM.DEFAULT_HEIGHT_FUNC(intl)}
                />
            </div>
            <div className="Form-Line row">
                <div className="Form-Label col-md-4" />
                <div className="Form-Label col-md-4">
                    {TRACKABLE_MODAL.EDIT.FORM.UPDATE_INTERVAL_FUNC(intl)}
                    <RenderTooltipHelper
                        tooltipText={TRACKABLE_MODAL.EDIT.FORM.UPDATE_INTERVAL_HELP_FUNC(intl)}
                    />
                </div>
                <div className="col-md-4" data-id="trackable-bulk-edit-position-update">
                    {
                        isAsset
                            ? (
                                <Field
                                    type="text"
                                    className="input"
                                    name="position_update_interval"
                                    component={RenderSimpleTimeDurationField}
                                    defaultValue={POS_UPDATE_INTERVAL.MIN}
                                />
                            ) : (
                                <Field
                                    clearable={false}
                                    className="Form-Input"
                                    name="position_update_interval"
                                    placeholder={COMPONENTS.SELECT_COMPONENT_PLACEHOLDER(intl)}
                                    noResultsText={COMPONENTS.SELECT_COMPONENT_NO_RESULTS_TEXT}
                                    options={updateIntervalOptions}
                                    component={SelectComponent}
                                />
                            )
                    }
                </div>
            </div>
        </section>
    </section>)
}

AdvancedSectionForm.propTypes = {
    advanced_checkbox: PropTypes.bool,
    category: PropTypes.string,
    intl: PropTypes.shape({
        formatMessage: PropTypes.func,
    }),
};

AdvancedSectionForm.defaultProps = {
    advanced_checkbox: false,
    category: '',
    intl: {
        formatMessage: () => {},
    },
};
