import React from 'react';
import { COMPONENTS, TRACKABLE_BULK_EDIT, TRACKABLE_MODAL } from 'common/ui-labels';
import RenderTooltipHelper from 'components/RenderTooltipHelper';
import { Field } from 'redux-form';
import { filterSelectBoxOptions, isAssetTag, preventInputNotNumber, sortByField } from 'utils/utils';
import PropTypes from 'prop-types';
import MultiSelectComponent from 'components/modals/MultiSelectComponent';
import { RenderFieldWithPadding } from 'components/modals/RenderFieldWithPadding';

const renderFieldPadding = RenderFieldWithPadding(4, 4, undefined, 4);

export function BufferForm({ category_checkbox, buffer_checkbox, category, intl, trackables, groups }) {
    const options = sortByField([...trackables, ...groups], 'name');
    const disabled = !category_checkbox || (isAssetTag(category) || !category);
    return (
        <section>
            <div className="Form-Line row">
                <div className="Form-Label col-md-4">
                    {TRACKABLE_MODAL.BUFFER}
                    <RenderTooltipHelper tooltipText={TRACKABLE_BULK_EDIT.BUFFER_TOOLTIP} placement="bottom" />
                </div>
                <div className="col-md-1" data-id="trackable-edit-buffer">
                    <Field
                        name="buffer_checkbox"
                        id="buffer_checkbox"
                        props={{ disabled, 'data-cy': 'trackable-edit-buffer' }}
                        component="input"
                        type="checkbox"
                        style={{ width: '19px', height: '19px' }}
                    />
                </div>
            </div>

            <section style={{ display: buffer_checkbox ? 'block' : 'none' }}>
                <div className="Form-Line row" data-id="trackable-edit-buffer-radius">
                    <Field
                        type="text"
                        onChange={(e) => {
                            preventInputNotNumber(e);
                        }}
                        data-cy="trackable-edit-buffer-radius"
                        className="Form-Input"
                        name="buffer_radius"
                        component={renderFieldPadding}
                        masked={false}
                        label={TRACKABLE_MODAL.EDIT.FORM.BUFFER_RADIUS_FUNC(intl)}
                    />
                </div>
                <div className="Form-Line row">
                    <div className="col-md-4" />
                    <div className="Form-Label col-md-4">{TRACKABLE_MODAL.EDIT.FORM.BUFFER_ACTIVE}</div>
                    <div className="col-md-1" data-id="trackable-edit-active-buffer">
                        <Field
                            name="active_buffer"
                            data-cy="trackable-edit-active-buffer"
                            id="active_buffer"
                            component="input"
                            type="checkbox"
                            style={{ width: '19px', height: '19px' }}
                        />
                    </div>
                </div>
                <div className="Form-Line row">
                    <div className="col-md-4" />
                    <div className="Form-Label col-md-4" style={{ fontWeight: 'bold' }}>{TRACKABLE_MODAL.EDIT.FORM.BUFFER_EXCEPTIONS}</div>
                    <div className="col-md-4" data-id="trackable-edit-zones">
                        <Field
                            name="trackables_and_groups"
                            type="text"
                            data-cy="trackable-edit-buffer-trackables-and-groups"
                            label="Objective"
                            placeholder={COMPONENTS.SELECT_COMPONENT_PLACEHOLDER(intl)}
                            options={options}
                            filterOptions={filterSelectBoxOptions}
                            noResultsText={COMPONENTS.SELECT_COMPONENT_NO_RESULTS_TEXT}
                            component={MultiSelectComponent}
                            scrollMenuIntoView
                        />
                    </div>
                </div>
            </section>
        </section>
    )
}

BufferForm.propTypes = {
    category: PropTypes.string,
    uid: PropTypes.string,
    trackables: PropTypes.arrayOf(PropTypes.shape({})),
    buffer_checkbox: PropTypes.bool,
    category_checkbox: PropTypes.bool,
    groups: PropTypes.arrayOf(PropTypes.shape({})),
    intl: PropTypes.shape({
        formatMessage: PropTypes.func,
    }),
}

BufferForm.defaultProps = {
    category: '',
    uid: '',
    trackables: [],
    category_checkbox: false,
    buffer_checkbox: false,
    groups: [],
    intl: {
        formatMessage: () => {},
    },
}
