import React from 'react';
import { TRACKABLE_BULK_EDIT } from 'common/ui-labels';
import RenderTooltipHelper from 'components/RenderTooltipHelper';
import { Field } from 'redux-form';
import { isAssetTag } from 'utils/utils';
import { ProximityWarningSystem } from 'modals/trackable/TrackableBulkEditModal/ProximityWarningSystem';
import PropTypes from 'prop-types';
import { DEFAULT_VALUES } from 'common/constants';

export function PwsForm(props) {
    const {
        pws_checkbox, category_checkbox, safe_distance, distance, alert_distance, delay, angle, dispatch, intl,
        role, t2tNoAlarmUid, trackables, groups, trackableCategory, pin, category
    } = props;
    const disabled = isAssetTag(category) || !category_checkbox;
    return (
        <section>
            <div className="Form-Line row" data-id="trackable-bulk-edit-pws-checkbox-text">
                <div className="Form-Label col-md-4">
                    {TRACKABLE_BULK_EDIT.PWS_TITLE}
                    <span style={{ position: 'absolute' }}><RenderTooltipHelper tooltipText={TRACKABLE_BULK_EDIT.PWS_TOOLTIP} placement="bottom"/></span>
                </div>
                <div className="col-md-1" data-id="trackable-bulk-edit-pws-checkbox">
                    <Field
                        name="pws_checkbox"
                        id="pws_checkbox"
                        component="input"
                        type="checkbox"
                        props={{ disabled }}
                        style={{ width: '19px', height: '19px' }}
                    />
                </div>
            </div>
            <section style={{ display: pws_checkbox ? '' : 'none' }}>
                <div className="Form-Line row">
                    <div className="col-md-4" />
                    <div className="col-md-8">
                        <ProximityWarningSystem
                            safe_distance={safe_distance}
                            distance={distance}
                            alert_distance={alert_distance}
                            delay={delay}
                            angle={angle}
                            dispatch={dispatch}
                            intl={intl}
                            role={role}
                            t2tNoAlarmUid={t2tNoAlarmUid}
                            trackables={trackables}
                            showAlarmDisableForField
                            groups={groups}
                            trackableCategory={trackableCategory}
                            isStationary={false}
                            pin={pin}
                            paddingLeft={3}
                        />
                    </div>
                </div>
            </section>
    </section>)
}

PwsForm.propTypes = {
    pws_checkbox: PropTypes.bool,
    category_checkbox: PropTypes.bool,
    intl: PropTypes.shape({
        formatMessage: PropTypes.func,
    }),
    dispatch: PropTypes.func,
    role: PropTypes.string,
    delay: PropTypes.number,
    alert_distance: PropTypes.number,
    distance: PropTypes.number,
    safe_distance: PropTypes.number,
    pin: PropTypes.string,
    category: PropTypes.string,
    angle: PropTypes.number,
    trackables: PropTypes.arrayOf(PropTypes.shape({})),
    groups: PropTypes.arrayOf(PropTypes.shape({})),
    t2tNoAlarmUid: PropTypes.string,
    trackableCategory: PropTypes.string,
}

PwsForm.defaultProps = {
    pws_checkbox: false,
    category_checkbox: false,
    intl: {
        formatMessage: () => {},
    },
    dispatch: () => {},
    role: '',
    category: '',
    delay: 0,
    alert_distance: 0,
    distance: 0,
    safe_distance: 0,
    pin: DEFAULT_VALUES.LLL_TRACKABLE_PIN,
    angle: DEFAULT_VALUES.LLL_COVERAGE_ANGLE,
    trackables: [],
    groups: [],
    t2tNoAlarmUid: '',
    trackableCategory: '',
}
