import Modal from 'react-modal';
import React from 'react';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import 'react-select/dist/react-select.css';
import { makeCopy } from 'utils/simpleUtils';
import { closeTrackableBulkEditModal, openTrackableBulkEditWarningModal } from 'stores/actions';
import { TRACKABLE_BULK_EDIT } from 'common/ui-labels';
import { isPerson, isUnspecified, isVehicle } from 'utils';

import { TrackableBulkEditForm } from './TrackableBulkEditForm';

class TrackableBulkEditModal extends React.Component {
    close = () => {
        this.props.dispatch(closeTrackableBulkEditModal());
    };
    
    submit = (_trackableValues) => {
        const trackableValues = {
            editedTrackables: _trackableValues.editedTrackables,
        };
        if (_trackableValues.groups_checkbox) {
            trackableValues.groupList = _trackableValues.groupList;
            trackableValues.groups_checkbox = true;
        }

        if (_trackableValues.category_checkbox) {
            trackableValues.category = _trackableValues.category;
            trackableValues.category_checkbox = true;
        }

        if (_trackableValues.advanced_checkbox) {
            trackableValues.defaultHeight = _trackableValues.defaultHeight;
            trackableValues.position_update_interval = _trackableValues.position_update_interval;
            trackableValues.advanced_checkbox = true;
        }

        if (trackableValues.category && _trackableValues.pws_checkbox) {
            trackableValues.pws_checkbox = true;
            trackableValues.angle = _trackableValues.angle;
            trackableValues.isStationary = false;
            trackableValues.alert_distance = _trackableValues.alert_distance;
            trackableValues.distance = _trackableValues.distance;
            trackableValues.safe_distance = _trackableValues.safe_distance;
            trackableValues.alarm_back = _trackableValues.alarm_back;
            trackableValues.delay = _trackableValues.delay;
            trackableValues.pin = _trackableValues.pin;
            trackableValues.haptic = _trackableValues.haptic;
            trackableValues.buzzer = _trackableValues.buzzer;
            trackableValues.role = _trackableValues.role;
            trackableValues.t2t_no_alarm_uid = _trackableValues.t2t_no_alarm_uid;
        }

        if (_trackableValues.custom_info_checkbox) {
            trackableValues.custom_info_checkbox = true;
            trackableValues.custom_info = _trackableValues.custom_info;
        }

        const isValidCategoryForBufferSave = trackableValues.category && (isVehicle(trackableValues.category) || isUnspecified(trackableValues.category) || isPerson(trackableValues.category));
        if (isValidCategoryForBufferSave && _trackableValues.buffer_checkbox) {
            trackableValues.buffer_checkbox = true;
            trackableValues.buffer_radius = _trackableValues.buffer_radius;
            trackableValues.active_buffer = _trackableValues.active_buffer;
            trackableValues.trackables_and_groups = _trackableValues.trackables_and_groups;
        }

        this.props.dispatch(openTrackableBulkEditWarningModal(trackableValues));
    };
    
    render() {
        const { style, trackableBulkEdit } = this.props;
        
        const style2 = makeCopy(style);
        style2.content.width = 750;
        style2.content.top = '50%';
        style2.content.maxHeight = '100%';
        
        return (
            <Modal
                contentLabel="trackableEdit"
                isOpen={trackableBulkEdit.open}
                onRequestClose={this.close}
                shouldCloseOnOverlayClick={false}
                style={style2}
            >
                <div className="RPP-Modal">
                    <span className="Modal-Header multiple-lines-ellipsis" data-id="trackable-edit-update-title">
                        {TRACKABLE_BULK_EDIT.INFO_TITLE}
                    </span>
                    <span className="grey-text">
                        {TRACKABLE_BULK_EDIT.UNDER_TITLE}
                    </span>
                    <TrackableBulkEditForm
                        className="Modal-Form"
                        close={this.close}
                        onSubmit={this.submit}
                    />
                </div>
            </Modal>
        );
    }
}

TrackableBulkEditModal.propTypes = {
    dispatch: PropTypes.func,
    style: PropTypes.shape({}),
    trackableBulkEdit: PropTypes.shape({
        open: PropTypes.bool,
    }),
};

TrackableBulkEditModal.defaultProps = {
    dispatch: () => { },
    style: {},
    trackableBulkEdit: {
        open: false,
    },
};

const mapStateToProps = (state) => ({
    trackableBulkEdit: state.modals.trackableModals.trackableBulkEdit,
});

export default connect(mapStateToProps)(TrackableBulkEditModal);
