import React from 'react';
import Modal from 'react-modal';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { Field, reduxForm, touch, change } from 'redux-form';
import { injectIntl } from 'react-intl';
import RenderSelectField from 'components/modals/RenderSelectField';
import { NAME_OF_FORMS, COMPONENTS, TIME_IN_MINUTES, USER_ROLES_DISPLAY, USER_ROLES, COMMON_LABELS, USER_ACCESS_CONTROL_MODAL, EXPIRATION_TIMEOUT_LIST, SESSION_TIMEOUT_LIST } from 'common';
import { makeCopy } from 'utils/simpleUtils';
import { closeUserAccessControlEditCompanyScopeModal, openUserAccessControlWarningModal } from 'stores/actions';


const validate = (values, props) => {
    const errors = {};
    if (values.accountExpirationTimeout === '') {
        errors.accountExpirationTimeout = USER_ACCESS_CONTROL_MODAL.ERRORS.COULD_NOT_BE_EMPTY;
        props.dispatch(touch(NAME_OF_FORMS.USER_ROLE_EDIT, 'accountExpirationTimeout'));
    } else if (!EXPIRATION_TIMEOUT_LIST.includes(Number(values.accountExpirationTimeout))) {
        errors.accountExpirationTimeout = USER_ACCESS_CONTROL_MODAL.ERRORS.ACTUAL_MINUTES_FUNC(values.accountExpirationTimeout);
        props.dispatch(touch(NAME_OF_FORMS.USER_ROLE_EDIT, 'accountExpirationTimeout'));
    }

    if (values.sessionTimeout === '') {
        errors.sessionTimeout = USER_ACCESS_CONTROL_MODAL.ERRORS.COULD_NOT_BE_EMPTY;
        props.dispatch(touch(NAME_OF_FORMS.USER_ROLE_EDIT, 'sessionTimeout'));
    } else if (!SESSION_TIMEOUT_LIST.includes(Number(values.sessionTimeout))) {
        errors.sessionTimeout = USER_ACCESS_CONTROL_MODAL.ERRORS.ACTUAL_MINUTES_FUNC(values.sessionTimeout);
        props.dispatch(touch(NAME_OF_FORMS.USER_ROLE_EDIT, 'sessionTimeout'));
    }
    return errors;
};

function onRoleChange(newValue, usersAccessControl, dispatch) {
    const existedRole = usersAccessControl.find(r => r.role === newValue);
    dispatch(change(NAME_OF_FORMS.USER_ROLE_EDIT, 'accountExpirationTimeout', existedRole.accountExpirationTimeout));
    dispatch(change(NAME_OF_FORMS.USER_ROLE_EDIT, 'sessionTimeout', existedRole.sessionTimeout));
}

let UserControlEditCompanyScopeForm = (props) => {
    const { close, submit, invalid, className, intl, usersAccessControl, dispatch } = props;

    return (
        <form className={className}>
            <div className="Form-Line row">
                <div htmlFor="name" className="Form-Label col-md-6">User type</div>
                <div className="col-md-6">
                    <Field
                        className="form-control input-sm "
                        name="role"
                        dataId="user-role-edit-role"
                        style={{ fontSize: '14px' }}
                        onChange={(e, nextVal) => onRoleChange(nextVal, usersAccessControl, dispatch) }
                        component={RenderSelectField}
                    >
                        <option value={USER_ROLES.COMPANY_ADMIN}>{USER_ROLES_DISPLAY[USER_ROLES.COMPANY_ADMIN]}</option>
                        <option value={USER_ROLES.PROJECT_SYSTEM_ADMIN}>{USER_ROLES_DISPLAY[USER_ROLES.PROJECT_SYSTEM_ADMIN]}</option>
                        <option value={USER_ROLES.PROJECT_OPERATIONS_ADMIN}>{USER_ROLES_DISPLAY[USER_ROLES.PROJECT_OPERATIONS_ADMIN]}</option>
                        <option value={USER_ROLES.PROJECT_MAINTAINER}>{USER_ROLES_DISPLAY[USER_ROLES.PROJECT_MAINTAINER]}</option>
                        <option value={USER_ROLES.PROJECT_USER}>{USER_ROLES_DISPLAY[USER_ROLES.PROJECT_USER]}</option>

                    </Field>
                </div>
            </div>

            <div className="Form-Line row">
                <div htmlFor="name" className="Form-Label col-md-6">{COMMON_LABELS.USER_SESSION_TIMEOUT}</div>
                <div className="col-md-6">
                    <Field
                        className="form-control input-sm "
                        name="sessionTimeout"
                        dataId="user-role-edit-session-timeout"
                        style={{ fontSize: '14px' }}
                        component={RenderSelectField}
                    >
                        <option />
                        <option value={0}>{COMPONENTS.FIELDS.COMMON.NEVER_FUNC(intl)}</option>
                        <option value={TIME_IN_MINUTES.HALF_HOUR}>{COMMON_LABELS.MINS_30(intl)}</option>
                        <option value={TIME_IN_MINUTES.HOUR}>{COMMON_LABELS.HOUR_1(intl)}</option>
                        <option value={TIME_IN_MINUTES.TWO_HOURS}>{COMMON_LABELS.HOURS_2(intl)}</option>
                        <option value={TIME_IN_MINUTES.FOUR_HOURS}>{COMMON_LABELS.HOURS_4(intl)}</option>
                        <option value={TIME_IN_MINUTES.EIGHT_HOURS}>{COMMON_LABELS.HOURS_8(intl)}</option>
                        <option value={TIME_IN_MINUTES.SIXTEEN_HOURS}>{COMMON_LABELS.HOURS_16(intl)}</option>
                        <option value={TIME_IN_MINUTES.ONE_DAY}>{COMMON_LABELS.HOURS_24(intl)}</option>
                    </Field>
                </div>
            </div>

            <div className="Form-Line row">
                <div htmlFor="name" className="Form-Label col-md-6">{COMPONENTS.FIELDS.USER.ACCOUNT_EXPIRATION_TIMEOUT}</div>
                <div className="col-md-6">
                    <Field
                        className="form-control input-sm "
                        name="accountExpirationTimeout"
                        dataId="user-role-edit-account-expiration-timeout"
                        style={{ fontSize: '14px' }}
                        component={RenderSelectField}
                    >
                        <option />
                        <option value={0}>{COMPONENTS.FIELDS.COMMON.NEVER_FUNC(intl)}</option>
                        <option value={TIME_IN_MINUTES.ONE_DAY}>{COMMON_LABELS.DAY_1(intl)}</option>
                        <option value={TIME_IN_MINUTES.WEEK}>{COMMON_LABELS.DAYS_7(intl)}</option>
                        <option value={TIME_IN_MINUTES.MONTH}>{COMMON_LABELS.DAYS_30(intl)}</option>
                        <option value={TIME_IN_MINUTES.THREE_MONTHS}>{COMMON_LABELS.DAYS_90(intl)}</option>
                        <option value={TIME_IN_MINUTES.HALF_YEAR}>{COMMON_LABELS.DAYS_180(intl)}</option>
                        <option value={TIME_IN_MINUTES.YEAR}>{COMMON_LABELS.DAYS_365(intl)}</option>
                    </Field>
                </div>
            </div>
            
            <div className="Form-Buttons">
                <button type="button" data-id="user-role-edit-save" onClick={submit} disabled={invalid}>{COMPONENTS.BUTTONS.SAVE}</button>
                <button type="button" data-id="user-role-edit-cancel" onClick={close}>{COMPONENTS.BUTTONS.CANCEL}</button>
            </div>
        </form>
    );
};

UserControlEditCompanyScopeForm.propTypes = {
    initialValues: PropTypes.shape({}),
    formState: PropTypes.shape({}),
    usersAccessControl: PropTypes.arrayOf(PropTypes.shape({})),
    userAccessControlEditCompanyScope: PropTypes.shape({}),
    className: PropTypes.string,
    close: PropTypes.func,
    submit: PropTypes.func,
    intl: PropTypes.shape({
        formatMessage: PropTypes.func,
    }),
};

UserControlEditCompanyScopeForm.defaultProps = {
    initialValues: {},
    formState: {},
    usersAccessControl: [],
    userAccessControlEditCompanyScope: {},
    className: '',
    close: () => {},
    submit: () => {},
    intl: {
        formatMessage: () => {},
    },
};

UserControlEditCompanyScopeForm = reduxForm({
    form: NAME_OF_FORMS.USER_ROLE_EDIT,
    validate,
})(injectIntl(UserControlEditCompanyScopeForm));

const mapStateToForm = (state) => {
    const initialValues = state.entities.usersAccessControl[0];

    return {
        initialValues,
        formState: state.form,
        usersAccessControl: state.entities.usersAccessControl,
        userAccessControlEditCompanyScope: state.modals.userModals.userAccessControlEditCompanyScope,
    };
};

UserControlEditCompanyScopeForm = connect(mapStateToForm)(injectIntl(UserControlEditCompanyScopeForm));

class UserControlEditModalCompanyScope extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        userAccessControlEditCompanyScope: PropTypes.shape({}),
        style: PropTypes.shape({}),
    };
    
    static defaultProps = {
        dispatch: () => {},
        userAccessControlEditCompanyScope: {},
        style: {},
    };
    
    close = () => {
        this.props.dispatch(closeUserAccessControlEditCompanyScopeModal());
    };
    
    submit = (values) => {
        this.props.dispatch(openUserAccessControlWarningModal(values));
    };
    
    render() {
        const currentStyle = makeCopy(this.props.style);
        currentStyle.content.width = '600px';

        return (
            <Modal
                contentLabel="userControlEditCompany"
                isOpen={this.props.userAccessControlEditCompanyScope.open}
                onRequestClose={this.close}
                style={currentStyle}
            >
                <div className="RPP-Modal">
                    <span className="Modal-Header multiple-lines-ellipsis" data-id="user-access-control-edit-title">
                        {USER_ACCESS_CONTROL_MODAL.TITLE.EDIT}
                    </span>
                    <UserControlEditCompanyScopeForm
                        className="Modal-Form"
                        close={this.close}
                        onSubmit={this.submit}
                    />
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = state => ({
    userAccessControlEditCompanyScope: state.modals.userModals.userAccessControlEditCompanyScope,
});

export default connect(mapStateToProps)(UserControlEditModalCompanyScope);
