import React from 'react';
import PropTypes from 'prop-types';
import { Field, FieldArray, change } from 'redux-form';
import { SCHEDULE_FORM, COMPONENTS, COMMON_LABELS } from 'common/ui-labels';
import { NAME_OF_FORMS } from 'common/constants';
import RenderTooltipHelper from 'components/RenderTooltipHelper';
import RenderInputTypeNumber from 'components/modals/RenderInputTypeNumber';


const renderHourMinutes = ({ hourName, minuteName }) => ({ readOnly }) => (
    <div className="d-inline-block">
        <div className="Schedule-Mask">
            <Field
                component={RenderInputTypeNumber}
                min="00"
                max="24"
                step="1"
                name={hourName}
                dataCy={hourName}
                readOnly={readOnly}
            />
            <div className="d-inline-block">:</div>
            <Field
                component={RenderInputTypeNumber}
                name={minuteName}
                dataCy={minuteName}
                min="00"
                max="59"
                step="1"
                readOnly={readOnly}
            />
        </div>
    </div>
);

const renderActivePeriodField = ({ timeFieldFrom, timeFieldTo }) => ({ readOnly, meta: { error } }) => (
    <div>
        <FieldArray
            name="timeFrom"
            component={timeFieldFrom}
            readOnly={readOnly}
        />
        <div className="d-inline-block" style={{ margin: '0 10px 0 10px' }}>
            -
        </div>
        <FieldArray
            name="timeTo"
            component={timeFieldTo}
            readOnly={readOnly}
        />
        {error && <div className="error">{error}</div>}
    </div>
);

const timeFieldFrom = renderHourMinutes({ hourName: 'fromHour', minuteName: 'fromMinute' });
const timeFieldTo = renderHourMinutes({ hourName: 'toHour', minuteName: 'toMinute' });
const activePeriod = renderActivePeriodField({ timeFieldFrom, timeFieldTo });


function ActivityScheduleForm({ disabled, dispatch, active24, activity_schedule_option, intl }) {
    return (
        <section>
            <div className="Form-Line row" style={{ textAlign: 'center', marginTop: '15px' }}>
                <div className="Form-Label col-md-6" style={{ fontSize: '1.2em' }}>
                    Activity schedule
                    <RenderTooltipHelper
                        tooltipText={COMMON_LABELS.ZONE_BULK_EDIT_AVAILABLE(intl)}
                        placement="bottom"
                    />
                </div>
                <div className="col-md-6 text-left" data-id="zone-bulk-edit-activity-schedule">
                    <Field
                        name="activity_schedule_option"
                        component="input"
                        type="checkbox"
                        props={{ disabled }}
                        onChange={ () => {
                            dispatch(change(NAME_OF_FORMS.ZONE_BULK_EDIT_ADMIN_PAGE, 'active24', true));
                        }}
                    />
                </div>
            </div>

            <div className="Form-Line RPP-Group-advanced" style={{ display: (activity_schedule_option && !disabled) ? 'block' : 'none' }}>
                <h4 className="RPP-Group-advanced-border-title">{SCHEDULE_FORM.ACTIVITY_SCHEDULE}</h4>
                <div className="Form-Line row">
                    <div className="Form-Label col-md-4" style={{ fontSize: '1.1em' }}>
                        {SCHEDULE_FORM.CHECKBOX}
                    </div>
                    <div
                        className="col-md-8 text-left"
                        data-id="zone-add-configuration-active"
                        data-cy="zone-add-configuration-active24"
                    >
                        <Field
                            name="active24"
                            component="input"
                            type="checkbox"
                        />
                    </div>
                </div>

                <div className="Form-Line row" style={{ opacity: active24 ? 0.6 : 1 }}>
                    <div
                        className="Form-Label col-md-4"
                        style={{ fontSize: '1.1em' }}
                    >
                        {COMPONENTS.FIELDS.ZONE.ACTIVE_PERIOD}
                    </div>
                    <div className="col-md-8 text-left">
                        <div className="Zone-Edit-Schedule">
                            <FieldArray
                                name="activePeriod"
                                component={activePeriod}
                                readOnly={active24}
                            />
                        </div>
                    </div>
                </div>
            </div>
        </section>
    );
}

ActivityScheduleForm.propTypes = {
    active24: PropTypes.bool,
    intl: PropTypes.shape({
        formatMessage: PropTypes.func,
    }),
    disabled: PropTypes.bool,
    dispatch: PropTypes.func,
    activity_schedule_option: PropTypes.bool,
};

ActivityScheduleForm.defaultProps = {
    active24: false,
    intl: { formatMessage: () => {} },
    disabled: true,
    dispatch: () => {},
    activity_schedule_option: true,
};

export default ActivityScheduleForm;
