import React from 'react';
import Modal from 'react-modal';
import { connect } from 'react-redux';
import { Field, reduxForm } from 'redux-form';
import PropTypes from 'prop-types';
import { injectIntl } from 'react-intl';

import RenderSelectField from 'components/modals/RenderSelectField';
import { closeZoneChooseTypeModal, closeZoneCreateAdminPageModal, chooseZoneType } from 'stores/actions';
import { getZoneTypeOptions } from 'utils/zoneUtils';
import { makeCopy } from 'utils/simpleUtils';
import { COMPONENTS } from 'common/ui-labels';
import { NAME_OF_FORMS } from 'common/constants';


let ZoneChooseTypeForm = (props) => {
    const {
        close, className, formState, chooseType, zonePrototypes, intl,
    } = props;
    
    const chooseAreaFormState = formState[NAME_OF_FORMS.ZONE_CHOOSE_TYPE] || {};
    let selectedZoneType;
    
    if (chooseAreaFormState && chooseAreaFormState.values) {
        selectedZoneType = chooseAreaFormState.values.zone_type;
    }
    
    return (
        <form className={className}>
            <div className="row Form-Line" style={{ textAlign: 'center' }}>
                <div className="col-md-4 col-sm-4 Form-Label">{COMPONENTS.FIELDS.ZONE.ZONE_TYPE} *</div>
                <div className="col-md-8 col-sm-8">
                    <Field
                        className="form-control input-sm "
                        name="zone_type"
                        dataCy="zone_type"
                        style={{ fontSize: '14px' }}
                        component={RenderSelectField}
                    >
                        <option value="" />
                        {getZoneTypeOptions(zonePrototypes, intl)}

                    </Field>
                </div>
            </div>

            <div className="Form-Buttons">
                <button
                    type="button"
                    disabled={!selectedZoneType}
                    data-id="zone-choose-next"
                    onClick={chooseType.bind(this, selectedZoneType)}
                >
                    {COMPONENTS.BUTTONS.NEXT}
                </button>
                <button type="button" data-id="zone-choose-cancel" onClick={close}>{COMPONENTS.BUTTONS.CANCEL}</button>
            </div>
        </form>
    );
};

ZoneChooseTypeForm.propTypes = {
    close: PropTypes.func,
    zonePrototypes: PropTypes.arrayOf(PropTypes.shape()),
    className: PropTypes.string,
    chooseType: PropTypes.func,
    formState: PropTypes.shape(),
    intl: PropTypes.shape({
        formatMessage: PropTypes.func,
    }),
};

ZoneChooseTypeForm.defaultProps = {
    close: () => {
    },
    zonePrototypes: [],
    chooseType: () => {
    },
    className: '',
    formState: {},
    intl: {
        formatMessage: () => {
        },
    },
};

ZoneChooseTypeForm = reduxForm({
    form: NAME_OF_FORMS.ZONE_CHOOSE_TYPE,
})(ZoneChooseTypeForm);

const mapStateToForm = state => (
    {
        formState: state.form,
    }
);

ZoneChooseTypeForm = connect(mapStateToForm)(injectIntl(ZoneChooseTypeForm));


class ZoneChooseTypeAdminPageModal extends React.Component {
    static propTypes = {
        zonePrototypes: PropTypes.arrayOf(PropTypes.shape()),
        dispatch: PropTypes.func,
        style: PropTypes.shape({
            overlay: PropTypes.object,
            content: PropTypes.object,
        }),
        zoneChooseTypeAdminPage: PropTypes.shape({
            open: PropTypes.bool,
        }),
    };

    static defaultProps = {
        zonePrototypes: [],
        dispatch: () => {
        },
        style: {
            overlay: {},
            content: {},
        },
        zoneChooseTypeAdminPage: {
            open: false,
        },
    };

    close = () => {
        this.props.dispatch(closeZoneChooseTypeModal());
        this.props.dispatch(closeZoneCreateAdminPageModal());
    };
    
    chooseType = (zone_type_name) => {
        this.props.dispatch(chooseZoneType({ zone_type_name }));
        this.props.dispatch(closeZoneChooseTypeModal());
    };

    render() {
        const { style, zoneChooseTypeAdminPage } = this.props;

        const customStyle = makeCopy(style);
        customStyle.content.width = 430;

        return (
            <Modal
                contentLabel="zoneChooseTypeAdminPage"
                isOpen={zoneChooseTypeAdminPage.open}
                onRequestClose={this.close}
                style={customStyle}
            >
                
                <div className="RPP-Modal">
                    <span className="Modal-Header" data-id="zone-add-title">
                        {COMPONENTS.FIELDS.ZONE.ZONE_SELECT_TYPE_MODAL_TITLE}
                    </span>
                    <ZoneChooseTypeForm
                        className="Modal-Form"
                        close={this.close}
                        zonePrototypes={this.props.zonePrototypes}
                        chooseType={this.chooseType}
                    />
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = state => ({
    zoneChooseTypeAdminPage: state.modals.zoneModals.zoneChooseTypeAdminPage,
    zonePrototypes: state.entities.zonesPrototypes,
});

export default connect(mapStateToProps)(ZoneChooseTypeAdminPageModal);
