import React, { useState, useEffect } from 'react';
import PropTypes from 'prop-types';
import _IsNumber from 'lodash/isNumber';
import { convertMetersToMillimeters, convertMillimetersToMeters } from 'utils/formatters';

function InputCoordinate(props) {
    const { setSent, setValue, value, label, className } = props;
    return (
        <div className={className}>
            <span>{label}:</span>
            <span>
                <input
                    data-cy="coordinates"
                    type="number"
                    className="Small-Input No-Arrow-Input"
                    value={value !== null ? value : ''}
                    onChange={(event) => {
                        setSent(false);
                        const _value = event.target.value;
                        if (_value === '') {
                            setValue(null);
                        } else {
                            setValue(Number(_value));
                        }
                    }}
                />
            </span>
        </div>
    );
}

InputCoordinate.propTypes = {
    setSent: PropTypes.func,
    setValue: PropTypes.func,
    value: PropTypes.number,
    label: PropTypes.string,
    className: PropTypes.string,
};

InputCoordinate.defaultProps = {
    setSent: () => {},
    setValue: () => {},
    value: null,
    label: '',
    className: '',
};

export default function VertexOption(props) {
    const offsetX = props.sublocation?.offset_x || 0;
    const offsetY = props.sublocation?.offset_y || 0;
    // propsX, propsY are using for data representation and these values should be modified to show user not absolute but relative positions
    // that are taken into account sublocation offset
    const propsX = (!isNaN(props?.x) && props?.x !== null) ? props?.x - convertMillimetersToMeters(offsetX) : null;
    const propsY = (!isNaN(props?.y) && props?.y !== null) ? props?.y - convertMillimetersToMeters(offsetY) : null;
    const [x, setX] = useState(propsX);
    const [y, setY] = useState(propsY);
    const [sent, setSent] = useState(false);
    
    useEffect(() => {
        if (_IsNumber(x) && _IsNumber(y) && !sent) {
            const vertex = {
                index: props.index,
                x: Math.round(convertMetersToMillimeters(x) + offsetX),
                y: Math.round(convertMetersToMillimeters(y) + offsetY),
            };
            props.addVertex(vertex);
            setSent(true);
        } else if ((!_IsNumber(x) || !_IsNumber(y)) && !sent) {
            props.removeVertex(props.index);
            setSent(true);
        }
    }, [props, x, y, sent]);
    
    return (
        <div className="row Form-Line" style={{ marginTop: '5px', display: 'flex', alignItems: 'center' }}>
            <div className="col-md-1" style={{ fontWeight: 'bold' }}>{props.index}.</div>
            <InputCoordinate
                className="col-md-5"
                setSent={setSent}
                setValue={setX}
                value={x}
                label="X"
            />
            <InputCoordinate
                className="col-md-5"
                setSent={setSent}
                setValue={setY}
                value={y}
                label="Y"
            />
        </div>
    );
}

VertexOption.propTypes = {
    index: PropTypes.number,
    addVertex: PropTypes.func,
    removeVertex: PropTypes.func,
    x: PropTypes.number,
    y: PropTypes.number,
    sublocation: PropTypes.shape({
        offset_x: PropTypes.number,
        offset_y: PropTypes.number,
        uid: PropTypes.string,
    }),
};

VertexOption.defaultProps = {
    index: 0,
    addVertex: () => {},
    removeVertex: () => {},
    x: null,
    y: null,
    sublocation: {
        offset_x: 0,
        offset_y: 0,
        uid: '',
    },
};
