import React from 'react';
import PropTypes from 'prop-types';
import { Field } from 'redux-form';

import TextField from 'components/modals/TextField';
import RenderField from 'components/modals/RenderField';
import { LABELS, COMPONENTS } from 'common/ui-labels';
import CustomInfoFieldComponent from 'components/modals/CustomInfoField';

const renderField = RenderField(5, 7, 'Form-Label-Average');
const textField = TextField(5, 7, 'Form-Label-Average');

function BasicOptions(props) {
    const { location_name = '', zoneTypeName = '', sublocation_name = '', intl = {}, customInfoLength } = props;
    return (
        <div className="Form-Line">
            <div className="row" style={{ marginBottom: '5px' }}>
                <Field
                    className="Form-Input"
                    name="location_uid"
                    dataCy="location"
                    content_name={location_name}
                    component={textField}
                    label={COMPONENTS.FIELDS.SITE.SITE}
                    type="text"
                />
            </div>
        
            <div className="row" style={{ marginBottom: '5px' }}>
                <Field
                    className="Form-Input"
                    name="sublocation_uid"
                    dataCy="sublocation"
                    content_name={sublocation_name}
                    component={textField}
                    label={COMPONENTS.FIELDS.SITE.AREA}
                    type="text"
                />
            </div>
        
            <div className="row" style={{ marginBottom: '5px' }}>
                <Field
                    className="Form-Input"
                    name="zone_type_name"
                    dataCy="zone_type_name"
                    content_name={zoneTypeName}
                    component={textField}
                    label={COMPONENTS.FIELDS.ZONE.ZONE_TYPE}
                    type="text"
                />
            </div>
        
            <div className="row" style={{ marginBottom: '5px' }}>
                <Field
                    className="Form-Input"
                    name="name"
                    dataCy="name"
                    component={renderField}
                    label={`${COMPONENTS.FIELDS.COMMON.NAME_FUNC(intl)} *`}
                    type="text"
                />
            </div>
            <CustomInfoFieldComponent
                placeholder={LABELS.CUSTOM_INFO_PLACEHOLDER(intl)}
                firstColumnWidth={5}
                dataId="zone-edit-custom-info"
                customInfoLength={customInfoLength}
            />
        </div>
    );
}

BasicOptions.propTypes = {
    intl: PropTypes.shape({
        formatMessage: PropTypes.func,
    }),
    location_name: PropTypes.string,
    zoneTypeName: PropTypes.string,
    sublocation_name: PropTypes.string,
    customInfoLength: PropTypes.number,
};

BasicOptions.defaultProps = {
    intl: {
        formatMessage: () => {},
    },
    location_name: '',
    zoneTypeName: '',
    sublocation_name: '',
    customInfoLength: 0,
};

export default BasicOptions;
