import React from 'react';
import PropTypes from 'prop-types';
import { Map, LayersControl } from 'react-leaflet';

import LeafletFloorplan from '../../../components/leaflet/LeafletFloorplan';

import { DEFAULT_VALUES, ZONE_DETAILS_MODAL } from '../../../common';
import { saveOptionsZoneCreateModal } from '../../../stores/actions';
import { MAP_BOUNDS } from '../../../utils';

const { Overlay } = LayersControl;

const NotSelectedFloorBody = ({
    leafletClass, dispatch, intl, createZoneFormState, floorplans, selectedFloorplanUid,
    selectedSublocationUid, selectFloorplan,
}) => (
    <div
        className="Zone-Details-Body"
        style={{ display: selectedFloorplanUid ? 'none' : 'flex', justifyContent: 'center' }}
    >
        {floorplans
            .filter(floorplan => floorplan.sublocation_uid === selectedSublocationUid)
            .map(floorplan => (
                <div
                    style={{
                        display: 'inline-block',
                        width: '25%',
                        margin: '3px',
                        height: '200px',
                    }}
                    key={floorplan.uid}
                >
                    <div
                        key={floorplan.uid}
                        className={leafletClass}
                        title={ZONE_DETAILS_MODAL.DOUBLE_CLICK_EXPAND(intl)}
                        onMouseOver={(e) => {
                            e.currentTarget.style.borderColor = 'red';
                            e.currentTarget.style.borderWidth = '2px';
                        }}
                        onMouseLeave={(e) => {
                            e.currentTarget.style.borderColor = 'gray';
                            e.currentTarget.style.borderWidth = '1px';
                        }}
                        onClick={() => {
                            dispatch(saveOptionsZoneCreateModal(createZoneFormState.values));
                            selectFloorplan(floorplan.uid);
                            return undefined;
                        }}
                        onDoubleClick={() => {
                            dispatch(saveOptionsZoneCreateModal(createZoneFormState.values));
                            selectFloorplan(floorplan.uid);
                            return undefined;
                        }}
                    >
                        
                        <Map
                            center={[0, 0]}
                            className="zone-modal"
                            bounds={MAP_BOUNDS(selectedSublocationUid, floorplan)}
                            style={{ height: '20vh' }}
                            doubleClickZoom={false}
                            minZoom={DEFAULT_VALUES.MAP_ZOOM.MIN}
                            maxZoom={DEFAULT_VALUES.MAP_ZOOM.MAX}
                            zoom={DEFAULT_VALUES.MAP_ZOOM.DEFAULT_MODAl}
                        >
                            <LayersControl position="topright">
                                <Overlay checked name="Floorplan">
                                    <LeafletFloorplan floorplan={floorplan} />
                                </Overlay>
                            </LayersControl>
                        </Map>
                    </div>
                    <div key={floorplan.url}>{floorplan.url.split('/').pop()}</div>
                </div>
            ))
        }
    </div>
);

NotSelectedFloorBody.propTypes = {
    intl: PropTypes.shape({
        formatMessage: PropTypes.func,
    }),
    dispatch: PropTypes.func,
    floorplans: PropTypes.arrayOf(PropTypes.shape()),
    leafletClass: PropTypes.string,
    selectFloorplan: PropTypes.func,
    createZoneFormState: PropTypes.shape(),
    selectedFloorplanUid: PropTypes.string,
    selectedSublocationUid: PropTypes.string,
    
};

NotSelectedFloorBody.defaultProps = {
    intl: {
        formatMessage: () => {
        },
    },
    dispatch: () => {
    },
    floorplans: [],
    leafletClass: '',
    selectFloorplan: () => {
    },
    createZoneFormState: {},
    selectedFloorplanUid: '',
    selectedSublocationUid: '',
};

export default NotSelectedFloorBody;
