import React from 'react';
import Modal from 'react-modal';
import { connect } from 'react-redux';
import { reduxForm } from 'redux-form';
import PropTypes from 'prop-types';
import { NAME_OF_FORMS } from 'common/constants';
import { ZONE_DELETE_MODAL } from 'common/ui-labels';
import { closeZoneDeleteModal, deleteZones } from 'stores/actions';
import DeleteButtons from 'components/modals/DeleteButtons';


let ZoneDeleteForm = (props) => {
    const { close, submit, className, zonesToDelete, submitted } = props;

    const isBatchDelete = Array.isArray(zonesToDelete);

    const message = (isBatchDelete)
        ? ZONE_DELETE_MODAL.BATCH_DELETE_MESSAGE
        : ZONE_DELETE_MODAL.SINGLE_DELETE_MESSAGE_FUNC(zonesToDelete.name);

    return (
        <form className={className} onSubmit={submit}>
            {
                isBatchDelete && <div className="Form-Confirmation info-text" data-id="group-delete-message">
                    { ZONE_DELETE_MODAL.NUMBER_OF_ZONES_SELECTED(<b>{zonesToDelete.length}</b>) }
                </div>
            }
            <div className="Form-DeleteTitle confirmation" data-id="group-delete-confirmation">
                {message}
            </div>
    
            <DeleteButtons submit={submit} close={close} submitted={submitted} dataId="zone" />
        </form>
    );
};

ZoneDeleteForm.propTypes = {
    close: PropTypes.func,
    submit: PropTypes.func,
    className: PropTypes.string,
    submitted: PropTypes.bool,
    zonesToDelete: PropTypes.oneOfType([
        PropTypes.shape({
            name: PropTypes.string,
        }),
        PropTypes.array,
    ]),
};

ZoneDeleteForm.defaultProps = {
    close: () => {
    },
    submit: () => {
    },
    className: '',
    submitted: false,
    zonesToDelete: {
        name: '',
    },
};

ZoneDeleteForm = reduxForm({
    form: NAME_OF_FORMS.ZONE_DELETE,
})(ZoneDeleteForm);

class ZoneDeleteModal extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        zoneDelete: PropTypes.shape({
            params: PropTypes.oneOfType([
                PropTypes.shape({
                    uid: PropTypes.string,
                }),
                PropTypes.array,
            ]),
            open: PropTypes.bool,
        }),
        style: PropTypes.shape({
            overlay: PropTypes.object,
            content: PropTypes.object,
        }),
    };
    
    static defaultProps = {
        dispatch: () => {
        },
        zoneDelete: {
            params: {
                uid: '',
            },
            open: false,
        },
        style: {
            overlay: {},
            content: {},
        },
    };
    
    constructor(props) {
        super(props);
        this.state = {
            submitted: false,
        };
    }
    
    close = () => {
        this.props.dispatch(closeZoneDeleteModal());
    };
    
    submit = () => {
        const { params } = this.props.zoneDelete;
        this.setState({ submitted: true });
        this.props.dispatch(deleteZones(params));
    };
    
    render() {
        const { style, zoneDelete: { params, open } } = this.props;

        return (
            <Modal
                contentLabel="zoneDelete"
                isOpen={open}
                onRequestClose={this.close}
                shouldCloseOnOverlayClick={false}
                onAfterClose={() => {
                    this.setState({ submitted: false });
                }}
                style={style}
            >
                <div className="RPP-Modal">
                    <ZoneDeleteForm
                        className="Modal-Form"
                        submitted={this.state.submitted}
                        close={this.close}
                        onSubmit={this.submit}
                        zonesToDelete={params}
                    />
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = state => ({
    zoneDelete: state.modals.zoneModals.zoneDelete,
});

export default connect(mapStateToProps)(ZoneDeleteModal);
