import React from 'react';
import PropTypes from 'prop-types';

import { ZONE_APPLY_TO, NAMES_OF_TABS, TRACKABLES_AND_GROUPS } from '../../../common';
import { getTrackableGroupNameByUid } from '../../../utils';

const defineApplyToText = (zoneTypeName, apply_to) => (apply_to === ZONE_APPLY_TO.LIST
    ? TRACKABLES_AND_GROUPS.APPLY_TO_ONLY
    : TRACKABLES_AND_GROUPS.APPLY_TO_EXCEPT);

const ApplyTo = ({ apply_to, zone_exceptions_uids, groups, trackables, zone_display_name }) => (
    <div>
        <div className="row Form-Line">
            <div className="col-md-5 Form-Label">{TRACKABLES_AND_GROUPS.APPLY_TO}</div>
            <div
                className="col-md-7 Form-Value"
                data-id="zone-details-site-status"
                data-cy="zone-details-site-apply-to"
            >
                {defineApplyToText(zone_display_name, apply_to)}
            </div>
        </div>
        {zone_exceptions_uids && zone_exceptions_uids.length > 0 &&
        <div className="row Form-Line">
            <div className="col-md-5 Form-Label">
                <div>{NAMES_OF_TABS.TRACKABLE_OBJECTS},</div>
                <div className="text-lowercase">{NAMES_OF_TABS.GROUPS}</div>
            </div>
            <div
                className="col-md-6 Form-Value zone-details-groups-trackables-list"
                data-id="zone-details-site-status"
                data-cy="zone-details-site-trackable-and-group"
            >
                {getTrackableGroupNameByUid(zone_exceptions_uids, groups, trackables)}
            </div>
        </div>
        
        }
    </div>
);
ApplyTo.propTypes = {
    apply_to: PropTypes.string,
    zone_exceptions_uids: PropTypes.arrayOf(PropTypes.string),
    groups: PropTypes.arrayOf(PropTypes.shape({})),
    trackables: PropTypes.arrayOf(PropTypes.shape({})),
    zone_display_name: PropTypes.string,
};

ApplyTo.defaultProps = {
    apply_to: '',
    zone_exceptions_uids: [],
    groups: [],
    trackables: [],
    zone_display_name: '',
};

export default ApplyTo;
