import React from 'react';
import Modal from 'react-modal';
import PropTypes from 'prop-types';
import _Get from 'lodash/get';
import { connect } from 'react-redux';
import { COMPONENTS, DEFAULT_VALUES } from 'common';
import { closeZoneDetailsModal, selectOneZoneDetailsModal, unSelectOneZoneDetailsModal } from 'stores/actions';
import { handleLeafletDeltaZoom, getZoneDetailsAndZoneTypeName } from 'utils';
import { makeCopy } from 'utils/simpleUtils';
import { ZonePrototype } from 'stores/classes';

import ZoneDetailsAdminPageForm from './ZoneDetailsAdminPageForm';

class ZoneDetailsAdminPageModal extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        zoneTypeName: PropTypes.string,
        style: PropTypes.shape({
            overlay: PropTypes.object,
            content: PropTypes.object,
        }),
        zoneDetailsAdminPage: PropTypes.shape({
            params: PropTypes.shape({
                name: PropTypes.string,
            }),
            open: PropTypes.bool,
        }),
    };
    
    static defaultProps = {
        dispatch: () => {
        },
        zoneTypeName: '',
        style: {
            overlay: {},
            content: {},
        },
        zoneDetailsAdminPage: {
            params: {
                name: '',
            },
            open: false,
        },
    };
    
    constructor(props) {
        super(props);
        
        this.defaultState = {
            leaflet: null,
            zoom: DEFAULT_VALUES.MAP_ZOOM.DEFAULT,
        };
        
        this.state = this.defaultState;
    }
    
    onMove = (event) => {
        this.setState({
            // eslint-disable-next-line
            zoom: event.target._zoom,
        });
    };
    
    setLeafletToState = (leaflet) => {
        if (leaflet) {
            leaflet = handleLeafletDeltaZoom(leaflet);
            this.setState({
                leaflet,
            });
        }
    };
    
    close = () => {
        this.props.dispatch(closeZoneDetailsModal());
        
        this.setState(this.defaultState);
    };
    
    floorplanSelect = (floorplan) => {
        this.props.dispatch(selectOneZoneDetailsModal(floorplan));
    };
    
    floorplanUnSelect = () => {
        this.props.dispatch(unSelectOneZoneDetailsModal());
        
        this.setState(this.defaultState);
    };
    
    render() {
        const { style, zoneDetailsAdminPage } = this.props;
        const currentStyle = makeCopy(style);
        currentStyle.content.width = '70%';
        currentStyle.content.maxHeight = '90vh';
        currentStyle.content.overflowY = 'auto';
        const zoneName = _Get(zoneDetailsAdminPage, 'params.name', '');
        const boundsForScale = this.state.leaflet ? this.state.leaflet.leafletElement.getBounds() : {};
        
        
        return (
            <Modal
                contentLabel="userDetails"
                isOpen={this.props.zoneDetailsAdminPage.open}
                onRequestClose={this.close}
                style={currentStyle}
            >
                <div className="RPP-Modal">
                    <span className="Modal-Header multiple-lines-ellipsis" data-id="zone-details-title">
                        {COMPONENTS.FIELDS.COMMON.VIEW_INFORMATION_FUNC(zoneName)}
                    </span>
                    <ZoneDetailsAdminPageForm
                        className="Modal-Form"
                        close={this.close}
                        zoneTypeName={this.props.zoneTypeName}
                        params={zoneDetailsAdminPage.params}
                        selectFloorplan={this.floorplanSelect}
                        unSelectFloorplan={this.floorplanUnSelect}
                        boundsForScale={boundsForScale}
                        onMove={this.onMove}
                        zoom={this.state.zoom}
                        setLeafletToState={this.setLeafletToState}
                    />
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = (state) => {
    const { details, zoneTypeName } = getZoneDetailsAndZoneTypeName(state.modals.zoneModals.zoneDetailsAdminPage, ZonePrototype.getAllZonePrototypes(state));
    return {
        zoneDetailsAdminPage: details,
        zoneTypeName,
    };
};

export default connect(mapStateToProps)(ZoneDetailsAdminPageModal);
