import React, { Component } from 'react';
import PropTypes from 'prop-types';
import Modal from 'react-modal';
import { connect } from 'react-redux';
import { editSitePageZone, stopLiveMode, startLiveMode, closeZoneEditGeoSitePage } from 'stores/actions';
import ZoneEditGeoSitePageForm from './ZoneEditGeoSitePageForm';


const style = {
    overlay: {
        position: 'fixed',
        width: '500px',
        height: 'auto',
        top: '0',
        left: 'calc(100% - 470px)',
        right: 'auto',
        bottom: 'auto',
        backgroundColor: 'rgba(255, 255, 255, 0)',
        zIndex: '1000',
        overflow: 'visible',
    },
    content: {
        width: '500px',
        height: '100vh',
        top: '0',
        left: 'calc(100% - 500px)',
        right: 'auto',
        bottom: '0',
        marginRight: '0',
        transform: 'translate(0, 0)',
        boxShadow: '0px 0px 37px 5px rgba(189,183,189,1)',
        overflow: 'visible',
    },
};

class ZoneEditGeoSitePageModal extends Component {
    static propTypes = {
        dispatch: PropTypes.func,
        zoneEdit: PropTypes.shape({
            params: PropTypes.shape({
                name: PropTypes.string,
            }),
            open: PropTypes.bool,
        }),
        style: PropTypes.shape({}),
    };

    static defaultProps = {
        dispatch: () => {
        },
        zoneEdit: {
            params: {
                name: '',
            },
            open: false,
        },
        style: {},
    };
    componentDidUpdate(prevProps) {
        if (this.props.zoneEdit.open && this.props.zoneEdit.open !== prevProps.zoneEdit.open) {
            this.props.dispatch(stopLiveMode());
        } else if (this.props.zoneEdit.open !== prevProps.zoneEdit.open) {
            this.props.dispatch(startLiveMode());
        }
    }

    close = () => {
        this.props.dispatch(closeZoneEditGeoSitePage());
    };

    submit = (params) => {
        this.props.dispatch(editSitePageZone(params));
        this.props.dispatch(closeZoneEditGeoSitePage());
    };

    render() {
        const title = this.props.zoneEdit.params ? this.props.zoneEdit.params.name : ' ';
        return (
            <Modal
                contentLabel="zoneEditGeoSitePage"
                isOpen={this.props.zoneEdit.open}
                onRequestClose={this.close}
                shouldCloseOnOverlayClick={false}
                style={style}
            >
                <div className="RPP-Modal">
                    <span
                        className="Modal-Header multiple-lines-ellipsis"
                        data-id="zone-edit-site-page-title"
                    >
                        {title}
                    </span>
                    <ZoneEditGeoSitePageForm
                        className="Modal-Form"
                        close={this.close}
                        onSubmit={this.submit}
                        params={this.props.zoneEdit.params}
                    />
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = state => ({
    zoneEdit: state.modals.zoneModals.zoneEditGeoSitePage,
});

export default connect(mapStateToProps)(ZoneEditGeoSitePageModal);
