import React, { Component } from 'react';
import PropTypes from 'prop-types';
import Modal from 'react-modal';
import { connect } from 'react-redux';
import { editSitePageZone, closeZoneEditSitePageModal, stopLiveMode, startLiveMode } from 'stores/actions';
import ZoneEditSitePageForm from './ZoneEditSitePageForm';


class ZoneEditSitePageModal extends Component {
    static propTypes = {
        dispatch: PropTypes.func,
        zoneEdit: PropTypes.shape({
            params: PropTypes.shape({
                name: PropTypes.string,
            }),
            open: PropTypes.bool,
        }),
        style: PropTypes.shape(),
    };
    
    static defaultProps = {
        dispatch: () => {
        },
        zoneEdit: {
            params: {
                name: '',
            },
            open: false,
        },
        style: {},
    };
    componentDidUpdate(prevProps) {
        if (this.props.zoneEdit.open && this.props.zoneEdit.open !== prevProps.zoneEdit.open) {
            this.props.dispatch(stopLiveMode());
        } else if (this.props.zoneEdit.open !== prevProps.zoneEdit.open) {
            this.props.dispatch(startLiveMode());
        }
    }

    close = () => {
        this.props.dispatch(closeZoneEditSitePageModal());
    };
    
    submit = (params) => {
        this.props.dispatch(editSitePageZone(params));
    };
    
    render() {
        const { style } = this.props;
        const title = this.props.zoneEdit.params ? this.props.zoneEdit.params.name : ' ';
        return (
            <Modal
                contentLabel="userDetails"
                isOpen={this.props.zoneEdit.open}
                onRequestClose={this.close}
                style={style}
            >
                <div className="RPP-Modal">
                    <span
                        className="Modal-Header multiple-lines-ellipsis"
                        data-id="zone-edit-site-page-title"
                    >
                        {title}
                    </span>
                    <ZoneEditSitePageForm
                        className="Modal-Form"
                        close={this.close}
                        onSubmit={this.submit}
                        params={this.props.zoneEdit.params}
                    />
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = state => ({
    zoneEdit: state.modals.zoneModals.zoneEditSitePage,
});

export default connect(mapStateToProps)(ZoneEditSitePageModal);
