import React from 'react';
import PropTypes from 'prop-types';
import { userHasPrivileges } from 'utils';
import { USER_ROLES } from 'common/user-roles';
import { COMPONENTS } from 'common/ui-labels';


export function ProjectUsersActions(props) {
    const currentUserRole = props.currentUser.role || props.currentUser?.access?.currentRole;
    const hasPrivileges = userHasPrivileges(currentUserRole, props.tableUser?.role);
    const defaultIconClass = 'inner-table-action';
    const disableIconClass = 'disable-click';
    const detailsBtnClassName = () =>  `fa fa-info-circle ${defaultIconClass}`;
    const editBtnClassName = () => {
        if (!hasPrivileges || props.tableUser?.role === USER_ROLES.COMPANY_ADMIN || props.currentUser.email === props.tableUser.email) {
            return `fa fa-pencil-alt ${disableIconClass}`;
        }
        return `fa fa-pencil-alt ${defaultIconClass}`;
    }
    const deleteBtnClassName = () => {
        if (!hasPrivileges || props.tableUser?.role === USER_ROLES.COMPANY_ADMIN || props.currentUser.email === props.tableUser.email) {
            return `fa fa-times ${disableIconClass}`;
        }
        return `fa fa-times ${defaultIconClass}`;
    }

    return (
        <section data-info="actions-section" style={{ whiteSpace: 'nowrap' }}>
            <i
                data-info="actions-section"
                data-id="users-project-actions-info"
                onClick={() => { props.showUserInfo(props.tableUser); }}
                title={COMPONENTS.SHOW_DETAILS(props.intl)}
                className={detailsBtnClassName()}
                aria-hidden="true"
            />
            <i
                data-info="actions-section"
                data-id="users-project-actions-edit"
                onClick={() => { props.openEditModal(props.tableUser); }}
                title={COMPONENTS.EDIT(props.intl)}
                className={editBtnClassName()}
                aria-hidden="true"
            />
            <i
                data-info="actions-section"
                data-id="users-project-actions-remove"
                onClick={() => { props.openDeleteModal(props.tableUser); }}
                title={COMPONENTS.DELETE(props.intl)}
                className={deleteBtnClassName()}
                aria-hidden="true"
            />
        </section>
    );
}

ProjectUsersActions.defaultProps = {
    tableUser: {},
    currentUser: {},
    intl: {
        formatMessage: () => {
        },
    },
    openDeleteModal: () => {},
    openEditModal: () => {},
    showUserInfo: () => {},
}

ProjectUsersActions.propTypes = {
    tableUser: PropTypes.shape({}),
    currentUser: PropTypes.shape({}),
    intl: PropTypes.shape({
        formatMessage: PropTypes.func,
    }),
    openDeleteModal: PropTypes.func,
    openEditModal: PropTypes.func,
    showUserInfo: PropTypes.func,
}
