import React from 'react';
import PropTypes from 'prop-types';
import { DASHBOARD_WIDGETS, COMPONENTS } from 'common';
import { getActiveShiftTimeFrame } from 'utils/timeUtils';
import MarkedBlock from 'components/uiBlocks/MarkedBlock';
import MarkedBlockMultiLine from 'components/uiBlocks/MarkedBlockMultiLine';


export default function ShiftInfo(props) {
    const { CURRENT_SHIFT_WIDGET: {
        NO_ACTIVE_SHIFT,
        TIME_ELAPSED,
    } } = DASHBOARD_WIDGETS;
    const { SHIFT, START, END } = COMPONENTS.FIELDS.SHIFT;

    const { shift, timeZone } = props;

    if (!props.shift) {
        return (
            <div
                className="no-current-shift-message"
                data-cy="shift-no-active"
            >
                {NO_ACTIVE_SHIFT}
            </div>
        );
    }

    const { timeElapsed, start, end } = getActiveShiftTimeFrame(shift, timeZone);

    return (
        <div className="current-active-shift">
            <MarkedBlock
                label={SHIFT}
                value={shift.name}
                dataCy="dashboard-shift-name"
            />
            <MarkedBlock
                label={TIME_ELAPSED}
                value={timeElapsed}
                dataCy="dashboard-shift-current-time"
            />

            <MarkedBlockMultiLine>
                <MarkedBlock
                    label={START}
                    value={start}
                    dataCy="dashboard-shift-start"
                />
                <MarkedBlock
                    label={END}
                    value={end}
                    dataCy="dashboard-shift-end"
                />
            </MarkedBlockMultiLine>
        </div>
    );
}

ShiftInfo.propTypes = {
    shift: PropTypes.shape({
        name: PropTypes.string,
        start: PropTypes.string,
        end: PropTypes.string,
    }),
    timeZone: PropTypes.string,
};

ShiftInfo.defaultProps = {
    shift: null,
    timeZone: '',
};
