import React from 'react';
import PropTypes from 'prop-types';
import DashboardWidget from 'stores/classes/DashboardWidget';
import { DASHBOARD_WIDGET_NAME } from 'common/ui-labels';
import widgets from '../dashboard/widgets';


const getWidgetClassName = (isExpanded, widgetName) => {
    const widgetClassName = [`Dashboard-Widget ${widgetName.toLowerCase()}`];
    widgetClassName.push('col-md-12 col-lg-12 col-sm-12');
    widgetClassName.push(isExpanded ? 'expanded' : '');
    return widgetClassName.join(' ');
};

const Widget = (props) => {
    const {
        name, onCloseWidget, onExpandWidget, isExpanded, activityWidgetLoading, currentActiveShift,
    } = props;
    
    const CurrentWidget = widgets[name];
    const widget = new DashboardWidget(props);

    const widgetClassName = getWidgetClassName(isExpanded, name);

    return (
        <div className={widgetClassName}>
            <header className="Widget-Header">
                <div className="title">{DASHBOARD_WIDGET_NAME[name]}</div>
                <div className="buttons">
                    <button
                        className={`button expand ${activityWidgetLoading ? 'disabled' : ''}`}
                        onClick={onExpandWidget}
                        disabled={activityWidgetLoading}
                        data-cy={`widget-${name.toLowerCase()}-extend`}
                    >
                        <i className={isExpanded ? 'fa fa-compress' : 'fa fa-expand'} />
                    </button>
                    <button
                        className="button disable"
                        onClick={onCloseWidget}
                        data-cy={`widget-${name.toLowerCase()}-close`}
                    >
                        <i className="fa fa-times" />
                    </button>
                </div>
            </header>

            <div className="Widget-Body">
                {
                    CurrentWidget ?
                        <CurrentWidget
                            widgetName={name}
                            widget={widget}
                            currentActiveShift={currentActiveShift}
                        />
                        :
                        ''
                }
            </div>
        </div>
    );
};

Widget.propTypes = {
    name: PropTypes.string,
    onCloseWidget: PropTypes.func,
    onExpandWidget: PropTypes.func,
    isExpanded: PropTypes.bool,
    activityWidgetLoading: PropTypes.bool,
    currentActiveShift: PropTypes.shape({}),
};

Widget.defaultProps = {
    name: '',
    onCloseWidget: () => {
    },
    onExpandWidget: () => {
    },
    isExpanded: false,
    activityWidgetLoading: false,
    currentActiveShift: null,
};

export default Widget;
