import React, { Component } from 'react';
import { connect } from 'react-redux';
import PropTypes from 'prop-types';
import { dashboardChangeWidgets } from 'stores/actions/dashboardActions';
import Widget from './Widget';


class WidgetsContainer extends Component {
    static propTypes = {
        dispatch: PropTypes.func,
        widgets: PropTypes.arrayOf(PropTypes.object),
        activityWidgetLoading: PropTypes.bool,
        activeShift: PropTypes.shape({}),
    };
    
    static defaultProps = {
        dispatch: () => {
        },
        widgets: [{}],
        activityWidgetLoading: false,
        activeShift: null,
    };
    
    onCloseWidget = (widget) => {
        this.props.dispatch(dashboardChangeWidgets({
            ...widget,
            active: false,
        }));
    };

    onExpandWidget = (widget) => {
        this.updateWidgetUIState(widget.name);
    };

    updateWidgetUIState = (widgetName) => {
        const { widgets, dispatch } = this.props;

        const targetWidget = widgets.find(widget => widget.name === widgetName);

        dispatch(dashboardChangeWidgets({ ...targetWidget, isExpanded: !targetWidget.isExpanded }));
    };

    render() {
        const { activityWidgetLoading, widgets, activeShift } = this.props;

        return (
            <div className="Dashboard-Widgets middle-align">
                {
                    !widgets ?
                        ''
                        :
                        <div className="Dashboard-Widgets-Container">
                            {
                                widgets.filter(widget => widget.active).map((widget, i, arr) => (
                                    <Widget
                                        {...widget}
                                        currentActiveShift={activeShift}
                                        activityWidgetLoading={activityWidgetLoading}
                                        onCloseWidget={() => this.onCloseWidget(widget)}
                                        onExpandWidget={() => this.onExpandWidget(widget)}
                                        key={widget.name}
                                        activeWidgetsCount={arr.length}
                                    />
                                ))
                            }
                        </div>
                }
            </div>
        );
    }
}

export default connect()(WidgetsContainer);
