import React, { Fragment, useEffect, useState } from 'react';
import PropTypes from 'prop-types';
import { injectIntl } from 'react-intl';
import { durationFormatting } from 'utils/formatters';
import { REPORT_TABLE, COMPONENTS } from 'common/ui-labels';

import TotalCountLabelValue from '../TotalCountLabelValue';


function LastUpdated(props) {
    const { lastUpdated, loading } = props;
    if (loading) return (<i className="fa fa-spinner fa-spin" style={{ color: 'grey' }} />);
    return <span style={{ fontWeight: 'bold' }}>{lastUpdated || '-'}</span>;
}

LastUpdated.propTypes = {
    lastUpdated: PropTypes.string,
    loading: PropTypes.bool,
};

LastUpdated.defaultProps = {
    lastUpdated: '',
    loading: false,
};

function AlarmsCount(props) {
    const { count, loading } = props;
    if (loading) return (<i className="fa fa-spinner fa-spin" style={{ color: 'grey' }} />);
    return count || 0;
}

AlarmsCount.propTypes = {
    count: PropTypes.number,
    loading: PropTypes.bool,
};

AlarmsCount.defaultProps = {
    count: 0,
    loading: false,
};

function Header(props) {
    const { updatedAt, uncertifiedOps, emergencyCalls, zoneViolations, loading, intl, isExpanded } = props;
    const [lastUpdated, setLastUpdated] = useState(null);
    const getDuration = () => (updatedAt ? durationFormatting(new Date() - new Date(updatedAt), intl).text : null);

    const {
        HEADER_ZONE_VIOLATIONS,
        HEADER_UNCERTIFIED_OPERATIONS,
        HEADER_EMERGENCY_CALLS,
    } = REPORT_TABLE.ALARMS_TABLE;

    const { LAST_UPDATED } = COMPONENTS.FIELDS.NODE;

    useEffect(() => {
        setLastUpdated(getDuration());
        const interval = setInterval(() => {
            if (updatedAt) {
                setLastUpdated(getDuration());
            } else {
                setLastUpdated(null);
            }
        }, 10000);
        return function cleanup() {
            clearInterval(interval);
        };
    }, [updatedAt, loading]);

    return (
        <Fragment>
            <div className="widget-body-last-updated">
                <span className="capitalizedText">{LAST_UPDATED}: </span>
                <LastUpdated loading={loading} lastUpdated={lastUpdated} />
            </div>
            <div className="widget-counters">
                <TotalCountLabelValue
                    label={HEADER_ZONE_VIOLATIONS}
                    isColumnDirection={!isExpanded}
                    dataCy="dashboard-alarm-header-zone-violations"
                    value={<AlarmsCount loading={loading} count={zoneViolations} />}
                />
                <TotalCountLabelValue
                    isColumnDirection={!isExpanded}
                    label={HEADER_UNCERTIFIED_OPERATIONS}
                    dataCy="dashboard-alarm-header-uncertified-operations"
                    value={<AlarmsCount loading={loading} count={uncertifiedOps} />}
                />
                <TotalCountLabelValue
                    isColumnDirection={!isExpanded}
                    label={HEADER_EMERGENCY_CALLS}
                    dataCy="dashboard-alarm-header-emergency-calls"
                    value={<AlarmsCount loading={loading} count={emergencyCalls} />}
                />
            </div>
        </Fragment>
    );
}

Header.propTypes = {
    updatedAt: PropTypes.string,
    zoneViolations: PropTypes.number,
    uncertifiedOps: PropTypes.number,
    emergencyCalls: PropTypes.number,
    intl: PropTypes.shape({
        formatMessage: PropTypes.func,
    }),
    loading: PropTypes.bool,
    isExpanded: PropTypes.bool,
};

Header.defaultProps = {
    updatedAt: '',
    zoneViolations: 0,
    uncertifiedOps: 0,
    emergencyCalls: 0,
    intl: {
        formatMessage: () => {},
    },
    loading: false,
    isExpanded: false,
};

export default injectIntl(Header);
