import React, { useEffect, useState } from 'react';
import PropTypes from 'prop-types';
import { COMPONENTS, DASHBOARD_WIDGETS } from 'common/ui-labels';
import { durationFormatting } from 'utils/formatters';
import { injectIntl } from 'react-intl';
import TotalCountLabelValue from '../TotalCountLabelValue';


function LastUpdated(props) {
    const { lastUpdated, loading } = props;
    if (loading) return (<i className="fa fa-spinner fa-spin" style={{ color: 'grey' }} />);
    return <span style={{ fontWeight: 'bold' }}>{lastUpdated || '-'}</span>;
}

LastUpdated.propTypes = {
    lastUpdated: PropTypes.string,
    loading: PropTypes.bool,
};

LastUpdated.defaultProps = {
    lastUpdated: '',
    loading: false,
};

function Header(props) {
    const { people, vehicles, others, isExpanded, loading, updatedAt, intl } = props;
    const [lastUpdated, setLastUpdated] = useState(null);
    const getDuration = () => (updatedAt ? durationFormatting(new Date() - new Date(updatedAt), intl).text : null);

    useEffect(() => {
        setLastUpdated(getDuration());
        const interval = setInterval(() => {
            if (updatedAt) {
                setLastUpdated(getDuration());
            } else {
                setLastUpdated(null);
            }
        }, 10000);
        return function cleanup() {
            clearInterval(interval);
        };
    }, [updatedAt, loading]);

    const { PEOPLE, VEHICLES, OTHERS } = DASHBOARD_WIDGETS.CURRENT_SHIFT_WIDGET;
    const { LAST_UPDATED } = COMPONENTS.FIELDS.NODE;

    return (
        <div className="widget-counters">
            <div className="widget-body-last-updated">
                <span className="capitalizedText">{LAST_UPDATED}: </span>
                <LastUpdated loading={loading} lastUpdated={lastUpdated} />
            </div>
            <TotalCountLabelValue
                label={PEOPLE}
                isColumnDirection={!isExpanded}
                value={people}
                dataCy="dashboard-shift-summary-people"
            />
            <TotalCountLabelValue
                isColumnDirection={!isExpanded}
                label={VEHICLES}
                value={vehicles}
                dataCy="dashboard-shift-summary-vehicles"
            />
            <TotalCountLabelValue
                isColumnDirection={!isExpanded}
                label={OTHERS}
                value={others}
                dataCy="dashboard-shift-summary-others"
            />
        </div>
    );
}

Header.propTypes = {
    people: PropTypes.number,
    vehicles: PropTypes.number,
    others: PropTypes.number,
    isExpanded: PropTypes.bool,
    loading: PropTypes.bool,
    updatedAt: PropTypes.string,
    intl: PropTypes.shape({
        formatMessage: PropTypes.func,
    }),
};

Header.defaultProps = {
    people: 0,
    vehicles: 0,
    others: 0,
    isExpanded: false,
    loading: false,
    updatedAt: '',
    intl: {
        formatMessage: () => {},
    },
};

export default injectIntl(Header);
