import React from 'react';
import PropTypes from 'prop-types';
import { injectIntl } from 'react-intl';
import { Column, Table } from 'react-virtualized';
import 'react-virtualized/styles.css';
import withSortSelect from 'components/HOC/withSortSelect';
import { DASHBOARD_WIDGETS } from 'common';


class VirtualTable extends React.Component {
    static propTypes = {
        // Props from HOC
        sort: PropTypes.func,
        sortBy: PropTypes.string,
        trStyleFormat: PropTypes.func,
        sortDisplayItems: PropTypes.func,
        sortDirection: PropTypes.string,
        
        // Props from parent
        allItems: PropTypes.shape(),
        totalCount: PropTypes.number,
        tableSize: PropTypes.shape(),
        dispatch: PropTypes.func,
        trClassFormat: PropTypes.func,
    };
    static defaultProps = {
        // Props from HOC
        sort: () => { },
        sortBy: '',
        trStyleFormat: () => { },
        sortDisplayItems: () => { },
        sortDirection: '',
        
        // Props from parent
        allItems: new Map(),
        totalCount: 0,
        tableSize: {},
        dispatch: () => { },
        trClassFormat: () => { },
    };
    
    constructor(props) {
        super(props);
        this.totalCount = props.totalCount;
        this.dispatch = props.dispatch;
        
        // HOC Methods
        this.trClassFormat = props.trClassFormat.bind(this);
        this.trStyleFormat = props.trStyleFormat.bind(this);
        this.sort = props.sort.bind(this);
        this.sortDisplayItems = props.sortDisplayItems.bind(this);
    }
    
    render() {
        const { sortBy, sortDirection, tableSize, allItems } = this.props;
        const displayItems = this.sortDisplayItems([...allItems.values()]);
        const displayCount = displayItems.length;

        const dataColumnWidth = tableSize.width * 0.215;
        const allColumnsWidthExceptName = tableSize.width - dataColumnWidth * 3;


        return (
            <section style={{ width: tableSize.width }}>
                <Table
                    sortBy={sortBy}
                    sort={this.sort}
                    sortDirection={sortDirection}
                    className="Virtual-Table-Big current-shift-zones-summary"
                    width={tableSize.width} // required
                    height={tableSize.height} // required
                    gridClassName="Virtual-Table-Grid"
                    rowHeight={tableSize.rowHeight} // required
                    headerHeight={0} // required
                    rowClassName={({ index }) => this.trClassFormat(displayItems, { index })}
                    rowStyle={({ index }) => this.trStyleFormat(displayItems, { index })}
                    // onRowClick={({ event, index, rowData }) => this.handleSelectRow(displayCount, { event, index, rowData })}
                    rowCount={displayCount} // required
                    rowGetter={({ index }) => displayItems[index]} // required
                >
                    <Column
                        label={<span title="">#</span>}
                        dataKey="name"
                        width={allColumnsWidthExceptName}
                        disableSort
                        className="Virtual-Table-Column-Left text-small first-column"
                    />
                    <Column
                        label={<span title="">{DASHBOARD_WIDGETS.CURRENT_SHIFT_WIDGET.PEOPLE}</span>}
                        dataKey="people_active"
                        width={dataColumnWidth}
                        className="Virtual-Table-Column-Center"
                    />
                    <Column
                        label={<span title="">{DASHBOARD_WIDGETS.CURRENT_SHIFT_WIDGET.VEHICLES}</span>}
                        dataKey="vehicle_active"
                        width={dataColumnWidth}
                        className="Virtual-Table-Column-Center"
                    />
                    <Column
                        label={<span title="">{DASHBOARD_WIDGETS.CURRENT_SHIFT_WIDGET.OTHERS}</span>}
                        dataKey="others_actual"
                        width={dataColumnWidth}
                        className="Virtual-Table-Column-Center"
                    />
                </Table>
            </section>
        );
    }
}

export default injectIntl(withSortSelect(VirtualTable));
