import React from 'react';
import { injectIntl } from 'react-intl';
import { BootstrapTable, TableHeaderColumn } from 'react-bootstrap-table';
import PropTypes from 'prop-types';
import { BOOTSTRAP_TABLE_SORT } from 'common/constants';
import { DASHBOARD_WIDGETS, TABLES } from 'common/ui-labels';
import { formatDbNameToHumanReadable } from 'utils/htmlUtils';


const { WIN_STATUS_WIDGET } = DASHBOARD_WIDGETS;

const lastHeardClassName = (tdData, anchor) => (anchor.node && anchor.node.responsive) ? '' : 'redText';

const AnchorsTable = (props) => {
    const { winAnchors, formatInactivity } = props;
    
    const formatAnchorType = (type) => {
        if (type) {
            return formatDbNameToHumanReadable(props.intl, type);
        }
        return '';
    };
    
    const options = {
        noDataText: (TABLES.NO_DATA_TO_DISPLAY),
        defaultSortName: 'last_heard',
        defaultSortOrder: BOOTSTRAP_TABLE_SORT.DESC,
    };

    return (
        <div className="Tabs-Anchors">
            <BootstrapTable
                className="Widget-Table"
                data={[...winAnchors]}
                options={options}
                condensed
                striped
                hover
            >
                <TableHeaderColumn
                    dataField="name"
                    dataAlign="left"
                    headerAlign="center"
                    isKey
                    columnTitle
                    dataSort
                >
                    {WIN_STATUS_WIDGET.ANCHORS_TAB_TABLE_NODE_NAME_COLUMN}
                </TableHeaderColumn>
                <TableHeaderColumn
                    dataField="type"
                    dataFormat={formatAnchorType}
                    dataAlign="center"
                    headerAlign="center"
                    columnTitle
                    dataSort
                    width="70"
                >
                    {WIN_STATUS_WIDGET.ANCHORS_TAB_TABLE_NODE_TYPE_COLUMN}
                </TableHeaderColumn>
                <TableHeaderColumn
                    columnClassName={lastHeardClassName}
                    dataField="last_heard"
                    dataAlign="center"
                    dataFormat={formatInactivity}
                    headerAlign="center"
                    columnTitle
                    dataSort
                    width="180"
                >
                    {WIN_STATUS_WIDGET.ANCHORS_TAB_TABLE_INACTIVITY_COLUMN}
                </TableHeaderColumn>
            </BootstrapTable>
        </div>
    );
};

AnchorsTable.propTypes = {
    winAnchors: PropTypes.arrayOf(PropTypes.object),
    formatInactivity: PropTypes.func,
    intl: PropTypes.shape({
        formatMessage: PropTypes.func,
    }),
};

AnchorsTable.defaultProps = {
    winAnchors: [{}],
    formatInactivity: () => {
    },
    intl: {
        formatMessage: () => {
        },
    },
};

export default injectIntl(AnchorsTable);
