import React, { Fragment } from 'react';
import PropTypes from 'prop-types';
import { injectIntl } from 'react-intl';
import { DASHBOARD_WIDGETS, COMPONENTS } from 'common/ui-labels';
import TotalCountLabelValue from '../TotalCountLabelValue';

const { WIN_STATUS_WIDGET } = DASHBOARD_WIDGETS;

function Header(props) {
    const { anchorsAndBridges, inactiveAnchorsAndBridges, tags, inactiveTags, lowBattery, isExpanded } = props;
    const { ANCHORS_TAB_HEADER_ANCHOR, TAGS_HEADER_TAGS, TAGS_HEADER_LOW_BATTERY } = WIN_STATUS_WIDGET;

    const { INACTIVE } = COMPONENTS.FIELDS.COMMON;

    return (
        <Fragment>
            <div className="row">
                <div className="widget-counters col-md-6">
                    <TotalCountLabelValue
                        label={ANCHORS_TAB_HEADER_ANCHOR}
                        isColumnDirection={!isExpanded}
                        value={anchorsAndBridges}
                        dataCy="dashboard-device-status-anchor"
                    />
                    <TotalCountLabelValue
                        isColumnDirection={!isExpanded}
                        label={INACTIVE}
                        value={inactiveAnchorsAndBridges}
                        dataCy="dashboard-device-status-inactive-anchor"
                    />
                </div>
                <div className="widget-counters col-md-6">
                    <TotalCountLabelValue
                        isColumnDirection={!isExpanded}
                        label={TAGS_HEADER_TAGS}
                        value={tags}
                        dataCy="dashboard-device-status-tag"
                    />
                    <TotalCountLabelValue
                        isColumnDirection={!isExpanded}
                        label={TAGS_HEADER_LOW_BATTERY}
                        value={lowBattery}
                        dataCy="dashboard-device-status-low-battery"
                    />
                    <TotalCountLabelValue
                        isColumnDirection={!isExpanded}
                        label={INACTIVE}
                        value={inactiveTags}
                        dataCy="dashboard-device-status-inactive-tag"
                    />
                </div>
            </div>
        </Fragment>
    );
}

Header.propTypes = {
    anchorsAndBridges: PropTypes.number,
    tags: PropTypes.number,
    inactiveTags: PropTypes.number,
    lowBattery: PropTypes.number,
    isExpanded: PropTypes.bool,
};

Header.defaultProps = {
    anchorsAndBridges: 0,
    tags: 0,
    inactiveTags: 0,
    lowBattery: 0,
    isExpanded: false,
};

export default injectIntl(Header);
