import React, { useState } from 'react';
import { injectIntl } from 'react-intl';
import { BootstrapTable, TableHeaderColumn } from 'react-bootstrap-table';
import PropTypes from 'prop-types';
import _Get from 'lodash/get';
import { BOOTSTRAP_TABLE_SORT } from 'common/constants';
import { DASHBOARD_WIDGETS, TABLES, COMPONENTS } from 'common/ui-labels';
import { formatDbNameToHumanReadable } from 'utils/htmlUtils';


const { WIN_STATUS_WIDGET } = DASHBOARD_WIDGETS;

const TagsTable = (props) => {
    const { nodes, formatInactivity, formatBattery, intl } = props;
    const options = {
        noDataText: (TABLES.NO_DATA_TO_DISPLAY),
        defaultSortName: 'battery',
        defaultSortOrder: BOOTSTRAP_TABLE_SORT.DESC,
    };

    const lastHeardClassName = (tdData, node) => (node.responsive) ? '' : 'redText';

    const [sortOrder, setSortOrder] = useState(BOOTSTRAP_TABLE_SORT.DESC);

    const sortBatteryLevel = (a, b, order) => {
        if (sortOrder !== order) {
            setSortOrder(order);
        }

        const sortFunct = (n1, n2) => {
            if (n1.responsive && n2.responsive) {
                return _Get(n1, 'battery.pr', 999) - _Get(n2, 'battery.pr', 999);
            }

            return (n1.responsive) ? -1 : 1;
        };

        return (order === BOOTSTRAP_TABLE_SORT.DESC) ? sortFunct(a, b) : sortFunct(b, a);
    };

    const formatNodeType = (type) => {
        if (type) {
            return formatDbNameToHumanReadable(intl, type);
        }
        return '';
    };

    return (
        <div className="Tabs-Tags">
            <BootstrapTable
                className="Widget-Table"
                data={nodes}
                options={options}
                hover
                condensed
                striped
            >
                <TableHeaderColumn
                    dataField="trackable_name"
                    dataAlign="left"
                    headerAlign="center"
                    isKey
                    columnTitle
                    dataSort
                >
                    {COMPONENTS.FIELDS.NODE.TRACKABLE}
                </TableHeaderColumn>
                <TableHeaderColumn
                    dataField="node_type"
                    dataFormat={formatNodeType}
                    dataAlign="center"
                    headerAlign="center"
                    hidden
                    columnTitle
                    dataSort
                >
                    {WIN_STATUS_WIDGET.ANCHORS_TAB_TABLE_NODE_TYPE_COLUMN}
                </TableHeaderColumn>
                <TableHeaderColumn
                    columnClassName={lastHeardClassName}
                    dataField="last_heard"
                    dataAlign="center"
                    dataFormat={data => formatInactivity(data, intl)}
                    headerAlign="center"
                    columnTitle
                    dataSort
                    width="180"
                >
                    {WIN_STATUS_WIDGET.ANCHORS_TAB_TABLE_INACTIVITY_COLUMN}
                </TableHeaderColumn>
                <TableHeaderColumn
                    columnClassName="device-status-widget-battery"
                    dataField="battery"
                    dataAlign="center"
                    dataFormat={formatBattery}
                    headerAlign="center"
                    sortFunc={sortBatteryLevel}
                    dataSort
                    width="110"
                >
                    {WIN_STATUS_WIDGET.TAGS_TAB_TABLE_BATTERY_LEVEL_COLUMN}
                </TableHeaderColumn>
            </BootstrapTable>
        </div>
    );
};

TagsTable.propTypes = {
    nodes: PropTypes.arrayOf(PropTypes.object),
    formatInactivity: PropTypes.func,
    formatBattery: PropTypes.func,
    intl: PropTypes.shape({
        formatMessage: PropTypes.func,
    }),
};

TagsTable.defaultProps = {
    nodes: [{}],
    formatInactivity: () => {
    },
    formatBattery: () => {
    },
    intl: {
        formatMessage: () => {
        },
    },
};

export default injectIntl(TagsTable);
