import React from 'react';

import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { BootstrapTable, TableHeaderColumn } from 'react-bootstrap-table';
import { getServerLoggerDebuggerState, postDebuggerState, getUpdateValueDebuggerState,
    getUpdateKeyDebuggerState, deleteDebuggerState } from '../../stores/actions';
import { DEFAULT_VALUES } from './../../common';

import { mapFormatter } from './formatters';

class DebuggerTab extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        data: PropTypes.arrayOf(PropTypes.shape()),
        debuggerValue: PropTypes.string,
        debuggerKey: PropTypes.string,
    };
    
    static defaultProps = {
        dispatch: () => {
        },
        data: [],
        debuggerValue: '',
        debuggerKey: '',
    };
    
    onOk = () => {
        this.props.dispatch(getServerLoggerDebuggerState());
    };

    onUpdateValue = (e) => {
        this.props.dispatch(getUpdateValueDebuggerState(e.target.value));
    };
    
    onUpdateKey = (e) => {
        this.props.dispatch(getUpdateKeyDebuggerState(e.target.value));
    };
    
    onSend = () => {
        this.props.dispatch(postDebuggerState(this.props.debuggerKey, JSON.parse(this.props.debuggerValue)));
    };
    
    onClear = () => {
        this.props.dispatch(deleteDebuggerState());
    };
    
    onClearSingle = (row) => {
        this.props.dispatch(postDebuggerState(row.key, null));
    };
    
    actionFormatter = (cell, row) => (
        <button onClick={this.onClearSingle.bind(this, row)}> Remove </button>
    );
    
    render() {
        const { data, debuggerValue, debuggerKey } = this.props;
        
        return (
            <div className="AppLayout-Admin-Tab col-md-12">
                <h4 className="text-center AdminTab-Subtitle">
                    <button className="Control-Button" onClick={this.onOk}>
                        GET SERVER DEBUGGER STATE
                    </button>
                </h4>
    
                File/Folder: <input value={debuggerKey} onChange={this.onUpdateKey} /><br />
                Configuration value: <input value={debuggerValue} onChange={this.onUpdateValue} /><br />
                <button onClick={this.onSend}> Send </button>
                <button onClick={this.onClear}> Clear </button><br />
                
                <hr />
                <BootstrapTable
                    data={data}
                    bodyStyle={{ overflowX: 'auto' }}
                    bodyContainerClass="Admin-BootstrapTable"
                    pagination
                    condensed
                    striped
                    search
                    hover
                >
                    <TableHeaderColumn
                        dataField="key"
                        width="300"
                        headerAlign="center"
                        dataSort
                        isKey
                    >
                        Key
                    </TableHeaderColumn>
                    <TableHeaderColumn
                        dataField="value"
                        dataFormat={mapFormatter}
                        dataAlign="left"
                        headerAlign="center"
                        dataSort
                    >
                        Value
                    </TableHeaderColumn>
                    <TableHeaderColumn
                        dataFormat={this.actionFormatter}
                        dataAlign="left"
                        headerAlign="center"
                        width="100"
                    >
                        Action
                    </TableHeaderColumn>
                </BootstrapTable>
            </div>
        );
    }
}

const mapStateToProps = state => ({
    data: state.loggerPage.serverDebuggerState || DEFAULT_VALUES.empty_array,
    debuggerValue: state.loggerPage.serverDebuggerValue || '{"level": "debug"}',
    debuggerKey: state.loggerPage.serverDebuggerKey || 'routes',
});

export default connect(mapStateToProps)(DebuggerTab);
