import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { Route, Switch } from 'react-router-dom';

import { changeLastLoggerPath } from 'stores/actions';
import { ROUTES } from 'common/constants';

import PageTabs from '../PageTabs';
import loggerTabs from './loggerTabs';

class LoggerPageContent extends Component {
    static propTypes = {
        dispatch: PropTypes.func,
        currentPath: PropTypes.string,
        lastPath: PropTypes.string,
        tabs: PropTypes.arrayOf(PropTypes.shape()),
    };
    
    static defaultProps = {
        dispatch: () => {},
        currentPath: '',
        lastPath: '',
        tabs: [],
    };
    
    componentDidMount() {
        const { lastPath, currentPath, tabs } = this.props;
        const paths = tabs.map((tab) => tab.path);
        if ((!lastPath && currentPath === ROUTES.LOGGER_ROUTE) || paths.indexOf(lastPath) === -1) {
            this.navigateToRoute(paths[0]);
        } else {
            this.navigateToRoute(lastPath);
        }
    }
    
    navigateToRoute = (path) => {
        this.props.dispatch(changeLastLoggerPath(path));
        this.props.dispatch(push(path)); // TODO:
    };
    
    render() {
        return (
            <div className="AppLayout-Admin Admin-Tabs">
                <PageTabs
                    tabs={this.props.tabs}
                    currentPath={this.props.currentPath}
                    navigateToRoute={this.navigateToRoute}
                />
                <Switch>
                    {this.props.tabs.map((tab) => (
                        <Route
                            key={tab.path}
                            path={tab.path}
                            component={loggerTabs[tab.systemName]}
                        />
                    ))}
                </Switch>
            </div>
        );
    }
}

const mapStateToProps = (state) => ({
    tabs: state.user.scope.pages.find((page) => page.path === ROUTES.LOGGER_ROUTE).tabs,
    currentPath: state.router.location.pathname,
    lastPath: state.loggerPage.lastPath,
    selectedTab: state.loggerPage.selectedTab,
});

export default connect(mapStateToProps)(LoggerPageContent);
