import React from 'react';
import PropTypes from 'prop-types';
import { BootstrapTable, TableHeaderColumn } from 'react-bootstrap-table';
import { mapFormatter, columnFormatter } from './formatters';

class MessageProcessorGeneralMapTable extends React.Component {
    static propTypes = {
        title: PropTypes.string,
        data: PropTypes.arrayOf(PropTypes.shape({})),
        columns: PropTypes.arrayOf(PropTypes.shape({})),
        keyColumn: PropTypes.arrayOf(PropTypes.shape({})),
        objectColumn: PropTypes.arrayOf(PropTypes.shape({})),
    };
    
    static defaultProps = {
        title: '',
        data: [],
        columns: [],
        keyColumn: [{
            key: true,
            dataField: 'key',
            width: '150',
            display: 'Key',
        }],
        objectColumn: [{
            width: '*',
            display: 'Object',
        }],
    };
    
    render() {
        const {
            objectColumn, keyColumn,
            columns, title, data,
        } = this.props;
        const cols = keyColumn.concat(columns).concat(objectColumn);
        return (
            <div>
                <h3 className="text-center">{title}</h3>
                <BootstrapTable
                    data={data}
                    bodyStyle={{ overflowX: 'auto' }}
                    bodyContainerClass="Admin-BootstrapTable"
                    pagination
                    condensed
                    striped
                    search
                    hover
                >
                    {cols.map((c, idx) => {
                        if (c.dataField) {
                            return (
                                <TableHeaderColumn
                                    dataFormat={columnFormatter}
                                    width={c.width}
                                    dataField={c.dataField}
                                    headerAlign="center"
                                    isKey={c.key}
                                    key={idx}
                                    searchable
                                >
                                    {c.display}
                                </TableHeaderColumn>);
                        }
                        return (
                            <TableHeaderColumn
                                dataFormat={mapFormatter}
                                headerAlign="center"
                                key={idx}
                            >
                                {c.display}
                            </TableHeaderColumn>);
                    })}
                </BootstrapTable>
            </div>
        );
    }
}

export default MessageProcessorGeneralMapTable;

