import React from 'react';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { injectIntl } from 'react-intl';
import { BootstrapTable, TableHeaderColumn, SearchField } from 'react-bootstrap-table';
import { DEFAULT_VALUES, TRACKABLE_CATEGORY } from 'common/constants';
import { TABLES, REPORT_TABLE, COMPONENTS, NAMES_OF_TABS } from 'common/ui-labels';
import { trOddEvenClassFormat } from 'utils/htmlUtils';


function AlarmsTable(props) {
    const { data, options, status, intl } = props;

    const createAddDeleteBtn = () => {
        if (!options || status === 0) return <section />;
        const trackables = Object.keys(data).length;
        return (
            <div className="row" style={{ marginLeft: '5px' }}>
                <div className="row">
                    <div className="col-md-6"><b>{NAMES_OF_TABS.TRACKABLE_OBJECTS}:</b> {trackables}</div>
                </div>
            </div>);
    };
    
    const categoryFormatter = (cell) => {
        if (!cell) {
            return TRACKABLE_CATEGORY.UNSPECIFIED;
        }
        return cell;
    };
    
    const trClassFormat = () => 'Table-Row-CursorPointer';
    
    const createCustomSearchField = () => (
        <SearchField
            data-id="projects-search"
            data-cy="alarm-table-search"
            placeholder={TABLES.SEARCH(intl)}
        />
    );
    

    const tableOptions = {
        onlyOneExpanding: true,
        noDataText: (TABLES.NO_DATA_TO_DISPLAY),
        expandBy: 'column',
        expandRowBgColor: 'white',
        searchField: createCustomSearchField,
        btnGroup: createAddDeleteBtn,
        beforeShowError: () => true,
    };
    const headerStyle = {
        marginBottom: '0',
    };
    const selectRow = {
        mode: 'radio',
        hideSelectColumn: true,
        bgColor: DEFAULT_VALUES.SELECTED_ROW_COLOR,
    };

    return (
        <section>
            <BootstrapTable
                trClassName={(row, rowIndex) => (`${trOddEvenClassFormat(row, rowIndex)} ${trClassFormat()}`)}
                tableBodyClass="automation-companies-table"
                data={data}
                options={tableOptions}
                selectRow={selectRow}
                headerStyle={headerStyle}
                bodyStyle={{
                    maxHeight: window.innerHeight * 0.45,
                    overflow: 'scroll',
                    overflowX: 'auto',
                    overflowY: 'auto',
                }}
                bodyContainerClass="Admin-BootstrapTable"
                expandColumnOptions={{
                    expandColumnVisible: false,
                    columnWidth: 30,
                }}
                hover
                condensed
                search
                className="middle-align"
            >
                <TableHeaderColumn row="0" hidden />
                <TableHeaderColumn
                    row="0"
                    rowSpan="2"
                    dataField="id"
                    headerAlign="center"
                    dataFormat={(cell, row, enumObject, index) => index + 1}
                    dataAlign="center"
                    width="20"
                >
                    #
                </TableHeaderColumn>
                <TableHeaderColumn
                    row="0"
                    rowSpan="2"
                    dataField="name"
                    width="260px"
                    tdAttr={{ 'data-id': 'trackable-name' }}
                    headerAlign="center"
                    dataAlign="center"
                >
                    {COMPONENTS.FIELDS.COMMON.NAME}
                </TableHeaderColumn>
                <TableHeaderColumn
                    row="0"
                    rowSpan="2"
                    headerAlign="center"
                    dataField="category"
                    dataAlign="center"
                    tdAttr={{ 'data-id': 'trackable-category' }}
                    dataFormat={categoryFormatter}
                    dataSort
                >
                    <span className="capitalizedText">{COMPONENTS.FIELDS.NODE.CATEGORY}</span>
                </TableHeaderColumn>
                <TableHeaderColumn
                    row="0"
                    colSpan="2"
                    headerAlign="center"
                    width="140"
                >
                    <span className="capitalizedText">{REPORT_TABLE.ALARMS_TABLE.HEADER_ZONE_VIOLATIONS}</span>
                </TableHeaderColumn>
                <TableHeaderColumn
                    row="0"
                    colSpan="2"
                    headerAlign="center"
                    width="140"
                >
                    <span className="capitalizedText">{REPORT_TABLE.ALARMS_TABLE.HEADER_UNCERTIFIED_OPERATIONS}</span>
                </TableHeaderColumn>
                <TableHeaderColumn
                    row="0"
                    colSpan="2"
                    headerAlign="center"
                    width="140"
                >
                    <span className="capitalizedText">{REPORT_TABLE.ALARMS_TABLE.HEADER_EMERGENCY_CALLS}</span>
                </TableHeaderColumn>
                <TableHeaderColumn
                    row="1"
                    dataField="uid"
                    searchable={false}
                    hidden
                    isKey
                >
                    Uid
                </TableHeaderColumn>
                <TableHeaderColumn
                    dataField="zoneViolations"
                    tdAttr={{ 'data-id': 'zone-violations' }}
                    dataSort
                    headerAlign="center"
                    dataAlign="center"
                    searchable={false}
                    row="1"
                >
                    {COMPONENTS.FIELDS.COMMON.COUNT}
                </TableHeaderColumn>
                <TableHeaderColumn
                    dataField="zoneViolationsDuration"
                    tdAttr={{ 'data-id': 'zone-violations-duration' }}
                    headerAlign="center"
                    dataAlign="center"
                    dataSort
                    searchable={false}
                    row="1"
                >
                    {COMPONENTS.FIELDS.COMMON.DURATION}
                </TableHeaderColumn>
                <TableHeaderColumn
                    dataField="uncertifiedOps"
                    tdAttr={{ 'data-id': 'uncertified-operations' }}
                    dataSort
                    headerAlign="center"
                    dataAlign="center"
                    searchable={false}
                    row="1"
                >
                    {COMPONENTS.FIELDS.COMMON.COUNT}
                </TableHeaderColumn>
                <TableHeaderColumn
                    dataField="uncertifiedOpsDuration"
                    tdAttr={{ 'data-id': 'uncertified-operations-duration' }}
                    dataSort
                    headerAlign="center"
                    dataAlign="center"
                    searchable={false}
                    row="1"
                >
                    {COMPONENTS.FIELDS.COMMON.DURATION}
                </TableHeaderColumn>
                <TableHeaderColumn
                    dataField="emergencyCalls"
                    tdAttr={{ 'data-id': 'emergency-calls' }}
                    dataSort
                    headerAlign="center"
                    dataAlign="center"
                    searchable={false}
                    row="1"
                >
                    {COMPONENTS.FIELDS.COMMON.COUNT}
                </TableHeaderColumn>
                <TableHeaderColumn
                    dataField="emergencyCallsDuration"
                    tdAttr={{ 'data-id': 'emergency-calls-duration' }}
                    dataSort
                    headerAlign="center"
                    dataAlign="center"
                    searchable={false}
                    row="1"
                >
                    {COMPONENTS.FIELDS.COMMON.DURATION}
                </TableHeaderColumn>
            </BootstrapTable>
        </section>
    );
}

AlarmsTable.propTypes = {
    data: PropTypes.arrayOf(PropTypes.shape({})),
    intl: PropTypes.shape({
        formatMessage: PropTypes.func,
    }),
    status: PropTypes.number,
    options: PropTypes.shape({
        shift_name: PropTypes.string,
        from: PropTypes.string,
        to: PropTypes.string,
    }),
};

AlarmsTable.defaultProps = {
    data: [],
    intl: {
        formatMessage: () => {},
    },
    status: 0,
    options: {
        shift_name: '',
        from: '',
        to: '',
    },
};

const mapStateToProps = state => ({
    data: state.reports.alarmsReport.tableData,
    options: state.reports.alarmsReport.report,
});

export default connect(mapStateToProps)(injectIntl(AlarmsTable));
