import React from 'react';
import PropTypes from 'prop-types';
import { SERVER_REPORT_TYPES } from 'common/constants';
import { REPORTS_SIDE_BAR, REPORTS_SELECTOR } from 'common/ui-labels';
import ReportsLoader from 'components/ReportsLoader';
import ReportMenu from 'pages/reports/ReportMenu';
import DistanceTable from 'pages/reports/Distance/DistanceTable';


function Distance(props) {
    return (
        <div className="AppLayout-Selector">
            <ReportMenu
                title={REPORTS_SIDE_BAR.TRAVEL_DISTANCE}
                subTitle={REPORTS_SELECTOR.ACTIVITY_STATISTICS_DISTANCE_DISCRIPTION}
                type={SERVER_REPORT_TYPES.TRACKABLE_DISTANCE_REPORT}
                isReady={props.status === 100}
                reportListLoading={props.reportListLoading}
                reports={props.reports}
                timezone={props.timezone}
                options={props.options}
                report_uid={props.report_uid}
            />
            {props.showProgress && <ReportsLoader status={props.status} />}
            {!props.showProgress && <div className="report-content row">
                <div className="col-lg-12 col-md-12">
                    <div style={{ textAlign: 'right', marginBottom: 5 }} />
                    <DistanceTable status={props.status} timezone={props.timezone} />
                </div>
            </div>}
        </div>
    );
}

Distance.propTypes = {
    showProgress: PropTypes.bool,
    status: PropTypes.number,
    reportListLoading: PropTypes.bool,
    timezone: PropTypes.string,
    report_uid: PropTypes.string,
    options: PropTypes.shape({}),
    reports: PropTypes.arrayOf(PropTypes.shape({})),
};

Distance.defaultProps = {
    showProgress: false,
    status: 0,
    reportListLoading: false,
    timezone: 'Etc/GMT',
    report_uid: '',
    options: {},
    reports: [],
};
export default Distance;
