import React, { Component, Fragment } from 'react';
import PropTypes from 'prop-types';
import { SortDirection, AutoSizer } from 'react-virtualized';
import { getTimeByFormatAndTimezone } from 'utils/timeUtils';
import VirtualTable from './VirtualTable';


export default class ExpandableTable extends Component {
    static propTypes = {
        distances: PropTypes.arrayOf(PropTypes.number),
        ranges: PropTypes.arrayOf(PropTypes.number),
        startTime: PropTypes.number,
        timezone: PropTypes.string,
    };
    
    static defaultProps = {
        distances: [],
        ranges: [],
        startTime: 0,
        timezone: 'Etc/GMT',
    };
    
    constructor(props) {
        super(props);
        
        this.state = {
            containerWidth: 0,
            containerHeight: 0,
        };
    }
    
    render() {
        const { distances, ranges, timezone, startTime } = this.props;
        const { containerWidth, containerHeight } = this.state;

        const getLocalTime = time => getTimeByFormatAndTimezone(time, 'HH:mm', timezone);

        const data = ranges.map((range, index) => {
            const timeFrom = !index ? getLocalTime(startTime) : getLocalTime(ranges[index - 1]);
            const timeto = getLocalTime(range);

            return ({ range: `${timeFrom} - ${timeto}`, distance: distances[index] });
        });
        const count = data.length;

        return (
            <div className="Expandable-Component" style={{ height: '100% !important' }}>
                <AutoSizer
                    onResize={({ height, width }) => {
                        const maxHeight = count > 10 ? 200 : (count + 1) * 20;
                        this.setState({
                            containerWidth: width,
                            containerHeight: maxHeight,
                        });
                    }}
                >
                    {({ height, width }) => (
                        <Fragment>
                            <VirtualTable
                                defaultSortName="date"
                                defaultSortOrder={SortDirection.ASC}
                                tableSize={{
                                    width: containerWidth,
                                    height: containerHeight,
                                    headerHeight: 30,
                                    rowHeight: 20,
                                }}
                                allItems={data}
                                totalCount={count}
                                ranges={ranges}
                                timezone={timezone}
                            />
                        </Fragment>
                    )}
                </AutoSizer>
            </div>
        );
    }
}
