import React from 'react';
import PropTypes from 'prop-types';
import { injectIntl } from 'react-intl';
import { Column, Table } from 'react-virtualized';
import 'react-virtualized/styles.css';
import withSortSelect from 'components/HOC/withSortSelect';
import { virtualizedHeaderRenderer } from 'utils/htmlUtils';
import { REPORT_TABLE, COMPONENTS } from 'common';


class VirtualTable extends React.Component {
    static propTypes = {
        // Props from HOC
        sort: PropTypes.func,
        sortBy: PropTypes.string,
        trStyleFormat: PropTypes.func,
        sortDisplayItems: PropTypes.func,
        sortDirection: PropTypes.string,
        
        // Props from parent
        allItems: PropTypes.shape(),
        totalCount: PropTypes.number,
        tableSize: PropTypes.shape(),
        dispatch: PropTypes.func,
        trClassFormat: PropTypes.func,
    };
    static defaultProps = {
        // Props from HOC
        sort: () => { },
        sortBy: '',
        trStyleFormat: () => { },
        sortDisplayItems: () => { },
        sortDirection: '',
        
        // Props from parent
        allItems: new Map(),
        totalCount: 0,
        tableSize: {},
        dispatch: () => { },
        trClassFormat: () => { },
    };
    
    constructor(props) {
        super(props);
        this.totalCount = props.totalCount;
        this.dispatch = props.dispatch;
        
        // HOC Methods
        this.trClassFormat = props.trClassFormat.bind(this);
        this.trStyleFormat = props.trStyleFormat.bind(this);
        this.sort = props.sort.bind(this);
        this.sortDisplayItems = props.sortDisplayItems.bind(this);
    }
    
    render() {
        const { sortBy, sortDirection, tableSize, allItems } = this.props;
        const displayItems = this.sortDisplayItems([...allItems.values()]);
        const displayCount = displayItems.length;
        
        return (
            <section style={{ width: tableSize.width }}>
                <Table
                    sortBy={sortBy}
                    sort={this.sort}
                    sortDirection={sortDirection}
                    className="Virtual-Table-Big"
                    width={tableSize.width} // required
                    height={tableSize.height} // required
                    gridClassName="Virtual-Table-Grid"
                    rowHeight={tableSize.rowHeight} // required
                    headerHeight={tableSize.headerHeight} // required
                    headerClassName="Virtual-Table-Header react-bs-container-header"
                    rowClassName={({ index }) => this.trClassFormat(displayItems, { index })}
                    rowStyle={({ index }) => this.trStyleFormat(displayItems, { index })}
                    rowCount={displayCount} // required
                    rowGetter={({ index }) => displayItems[index]} // required
                >
                    <Column
                        label={<span title="">#</span>}
                        headerRenderer={virtualizedHeaderRenderer}
                        dataKey="number"
                        width={50}
                        disableSort
                        className="Virtual-Table-Column-Left text-small"
                    />
                    <Column
                        label={<span title="">{COMPONENTS.FIELDS.COMMON.TIME}</span>}
                        headerRenderer={virtualizedHeaderRenderer}
                        dataKey="date"
                        width={400}
                        className="Virtual-Table-Column-Left text-small"
                    />
                    <Column
                        label={<span title="">{REPORT_TABLE.PWS_TABLE.EXP_HEADER_DURATION}</span>}
                        headerRenderer={virtualizedHeaderRenderer}
                        dataKey="duration"
                        width={300}
                        className="Virtual-Table-Column-Center"
                    />
                    <Column
                        label={<span title="">{REPORT_TABLE.PWS_TABLE.EXP_HEADER_DISTANCE}</span>}
                        headerRenderer={virtualizedHeaderRenderer}
                        dataKey="distance"
                        width={tableSize.width - 700}
                        className="Virtual-Table-Column-Center"
                    />
                </Table>
            </section>
        );
    }
}

export default injectIntl(withSortSelect(VirtualTable));
