import React from 'react';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { createReport } from 'stores/actions/reportsActions/generalReportActions';
import { REPORT_BUTTON } from 'common/ui-labels';
import { CLIENT_REPORT_TYPES } from 'common/constants';


function ActionButton(props) {
    const { from, to, trackables } = props.options;
    const runReport = () => {
        if (from && to && trackables) {
            const params = {
                timezone: props.timezone,
                from,
                to,
                trackable_uid: trackables[0],
            };
            props.dispatch(createReport(params, props.type));
        }
    };
    
    if (props.type !== CLIENT_REPORT_TYPES.PWS_REPORT) {
        return null;
    }

    return (
        <section>
            <div className="reports-refresh-button-row">
                {
                    <button
                        className="action-refresh"
                        onClick={runReport}
                        disabled={!props.options.from || !props.options.to || !(props.options.locations || props.options.trackables)}
                    >
                        {REPORT_BUTTON.RUN_REPORT}
                    </button>
                }
            </div>
        </section>
    );
}

ActionButton.propTypes = {
    options: PropTypes.shape({
        from: PropTypes.string,
        to: PropTypes.string,
        locations: PropTypes.arrayOf(PropTypes.string),
        trackables: PropTypes.arrayOf(PropTypes.string),
    }),
    dispatch: PropTypes.func, 
    type: PropTypes.string,
    timezone: PropTypes.string,
};

ActionButton.defaultProps = {
    options: {
        from: new Date().toISOString(),
        to: new Date().toISOString(),
        locations: [],
        trackables: [],
    },
    dispatch: () => {},
    type: '',
    timezone: '',
};

export default connect()(ActionButton);
