import React, { Fragment } from 'react';
import PropTypes from 'prop-types';
import ActionBar from './ActionBar';
import ReportsList from './ReportsList';
import ActionButton from './ActionButton';


export default function ReportMenu(props) {
    return (
        <Fragment>
            <h3 className="report-title text-center">
                <strong>{props.title}</strong>
            </h3>
            <h4 className="text-center page-subtitle">{props.subTitle}</h4>
            <hr />
            <div>
                <ActionBar isDataReady={props.isReady} type={props.type} timezone={props.timezone} options={props.options} />
                {props.reports && <ReportsList
                    reports={props.reports}
                    type={props.type}
                    reportListLoading={props.reportListLoading}
                    options={props.options}
                    timezone={props.timezone}
                    report_uid={props.report_uid}
                />}
            </div>
            <div>
                <ActionButton options={props.options} type={props.type} timezone={props.timezone} />
            </div>
        </Fragment>
    );
}

ReportMenu.propTypes = {
    title: PropTypes.shape(),
    subTitle: PropTypes.shape(),
    type: PropTypes.string,
    isReady: PropTypes.bool,
    reportListLoading: PropTypes.bool,
    reports: PropTypes.arrayOf(PropTypes.shape({})),
    options: PropTypes.shape({}),
    timezone: PropTypes.string,
    report_uid: PropTypes.string,
};

ReportMenu.defaultProps = {
    title: null,
    subTitle: null,
    type: '',
    isReady: false,
    reportListLoading: false,
    reports: null,
    options: null,
    timezone: 'Etc/Gmt',
    report_uid: '',
};
