import React, { Component, Fragment } from 'react';
import PropTypes from 'prop-types';
import { SortDirection, AutoSizer } from 'react-virtualized';
import VirtualTable from './VirtualTable';


export default class ExpandableTable extends Component {
    static propTypes = {
        data: PropTypes.arrayOf(PropTypes.shape({})),
    };
    
    static defaultProps = {
        data: [],
    };
    
    constructor(props) {
        super(props);
        
        this.state = {
            containerWidth: 0,
            containerHeight: 0,
        };
    }
    
    render() {
        const { data } = this.props;
        const { containerWidth, containerHeight } = this.state;
        const count = data.length;
        const allItems = data.reduce((memo, obj, index) => {
            memo.set(index, obj);
            return memo;
        }, new Map());
        
        return (
            <div className="Expandable-Component" style={{ height: '100% !important' }}>
                <AutoSizer
                    onResize={({ height, width }) => {
                        const maxHeight = count > 10 ? 200 : (count + 1) * 20;
                        this.setState({
                            containerWidth: width,
                            containerHeight: maxHeight,
                        });
                    }}
                >
                    {({ height, width }) => (
                        <Fragment>
                            <VirtualTable
                                defaultSortName="date"
                                defaultSortOrder={SortDirection.ASC}
                                tableSize={{
                                    width: containerWidth,
                                    height: containerHeight,
                                    headerHeight: 30,
                                    rowHeight: 20,
                                }}
                                allItems={allItems}
                                totalCount={count}
                            />
                        </Fragment>
                    )}
                </AutoSizer>
            </div>
        );
    }
}
