import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { Tab, Tabs, TabList, TabPanel } from 'react-tabs';
import { injectIntl } from 'react-intl';

import { selectTabInSiteView, changeClientHeight } from 'stores/actions';
import { RIGHT_SIDE_BAR_TABLES } from 'common/ui-labels';
import { SITE_VIEW_RIGHT_SIDE_BAR } from 'common/constants';

import SiteViewAlarmsTab from './Tabs/SiteViewAlarmsTab';
import SiteViewTrackablesTab from './Tabs/SiteViewTrackablesTab';
import SiteViewZonesTab from './Tabs/SiteViewZonesTab';
import SiteViewNearMissTab from './Tabs/SiteViewNearMissTab';


class RightSideBarTables extends Component {
    static propTypes = {
        intl: PropTypes.shape({
            formatMessage: PropTypes.func,
        }),
        selectedTab: PropTypes.number,
        nearMissReady: PropTypes.bool,
        dispatch: PropTypes.func,
        zoneTableRowElements: PropTypes.arrayOf(PropTypes.shape()),
    };
    
    static defaultProps = {
        intl: {
            formatMessage: () => {
            },
        },
        selectedTab: 0,
        nearMissReady: false,
        dispatch: () => {
        },
        zoneTableRowElements: [],
    };
    
    componentDidMount() {
        this.updateDimensions();
        window.addEventListener('resize', this.updateDimensions.bind(this));
    }
    
    componentWillUnmount() {
        window.removeEventListener('resize', this.updateDimensions.bind(this));
    }
    
    updateDimensions = () => {
        if (this.refs.alarmContainer && this.refs.alarmContainer.clientHeight) {
            const result = this.refs.alarmContainer.clientHeight - 60; // - height of search line fixed size
            this.props.dispatch(changeClientHeight(result));
        }
        if (this.refs.zoneContainer && this.refs.zoneContainer.clientHeight) {
            const result = this.refs.zoneContainer.clientHeight - 60; // - height of search line fixed size
            this.props.dispatch(changeClientHeight(result));
        }
        if (this.refs.trackableContainer && this.refs.trackableContainer.clientHeight) {
            const result = this.refs.trackableContainer.clientHeight - 60; // - height of search line fixed size
            this.props.dispatch(changeClientHeight(result));
        }
        if (this.refs.nearMissContainer && this.refs.nearMissContainer.clientHeight) {
            const result = this.refs.nearMissContainer.clientHeight - 60; // - height of search line fixed size
            this.props.dispatch(changeClientHeight(result));
        }
    };
    
    handleSelectTab = (index) => {
        this.props.dispatch(selectTabInSiteView(index));
    };
    
    render() {
        const { intl, zoneTableRowElements, nearMissReady } = this.props;
        
        return (
            <div>
                <Tabs
                    className="RPP-Right-Site-Tabs"
                    onSelect={this.handleSelectTab}
                    selectedIndex={this.props.selectedTab}
                >
                    <TabList className="Tabs-List">
                        <Tab
                            data-id="site-view-tab-alarms"
                            className={`List-Elem ${this.props.selectedTab === SITE_VIEW_RIGHT_SIDE_BAR.ALARMS_TAB_ID ? 'List-Elem-Selected' : ''}`}
                            key={SITE_VIEW_RIGHT_SIDE_BAR.ALARMS_TAB_ID}
                        >{RIGHT_SIDE_BAR_TABLES.TITLES.ALARMS_FUNC(intl)}
                        </Tab>
                        <Tab
                            data-id="site-view-tab-zones"
                            className={`List-Elem ${this.props.selectedTab === SITE_VIEW_RIGHT_SIDE_BAR.ZONES_TAB_ID ? 'List-Elem-Selected' : ''}`}
                            key={SITE_VIEW_RIGHT_SIDE_BAR.ZONES_TAB_ID}
                        >{RIGHT_SIDE_BAR_TABLES.TITLES.ZONES_FUNC(intl)}
                        </Tab>
                        <Tab
                            data-id="site-view-tab-trackables"
                            className={`List-Elem ${this.props.selectedTab === SITE_VIEW_RIGHT_SIDE_BAR.TRACKABLES_TAB_ID ? 'List-Elem-Selected' : ''}`}
                            key={SITE_VIEW_RIGHT_SIDE_BAR.TRACKABLES_TAB_ID}
                        >{RIGHT_SIDE_BAR_TABLES.TITLES.TRACKABLES_FUNC(intl)}
                        </Tab>
                        {nearMissReady && <Tab
                            data-id="site-view-tab-near-miss"
                            className={`List-Elem ${this.props.selectedTab === SITE_VIEW_RIGHT_SIDE_BAR.EVENTS_TAB_ID ? 'List-Elem-Selected' : ''}`}
                            key={SITE_VIEW_RIGHT_SIDE_BAR.EVENTS_TAB_ID}
                        >{RIGHT_SIDE_BAR_TABLES.TITLES.NEAR_MISS_FUNC(intl)}
                        </Tab>}
                    </TabList>
                    <TabPanel>
                        <div ref="alarmContainer" className="RPP-Right-Site-Tab col-md-12">
                            <SiteViewAlarmsTab />
                        </div>
                    </TabPanel>
                    <TabPanel>
                        <div ref="zoneContainer" className="RPP-Right-Site-Tab col-md-12">
                            <SiteViewZonesTab zoneTableRowElements={zoneTableRowElements} />
                        </div>
                    </TabPanel>
                    <TabPanel>
                        <div ref="trackableContainer" className="RPP-Right-Site-Tab col-md-12">
                            <SiteViewTrackablesTab />
                        </div>
                    </TabPanel>
                    {nearMissReady && <TabPanel>
                        <div ref="nearMissContainer" className="RPP-Right-Site-Tab col-md-12">
                            <SiteViewNearMissTab />
                        </div>
                    </TabPanel>}
                </Tabs>
            </div>
        );
    }
}

const mapStateToProps = (state) => {
    const { reportUid, byUid } = state.nearMissReport;
    const nearMissReady = byUid[reportUid] && byUid[reportUid].ready;
    let selectedTab = state.siteView.selectedTab;
    if (!nearMissReady && selectedTab === SITE_VIEW_RIGHT_SIDE_BAR.EVENTS_TAB_ID) {
        selectedTab = SITE_VIEW_RIGHT_SIDE_BAR.ALARMS_TAB_ID;
    }
    
    return {
        selectedTab,
        nearMissReady,
    };
};

export default connect(mapStateToProps)(injectIntl(RightSideBarTables));
