import _isEmpty from 'lodash/isEmpty';
import { EDIT_ZONE_MODE, COMPONENTS } from 'common/ui-labels';
import PropTypes from 'prop-types';
import React from 'react';


export default function Buttons(props) {
    const {
        width,
        creatingZone,
        handleFinishClick,
        handleSubmitClick,
        handleCancelClick,
        isFinishButtonVisible,
        isFinishButtonDisabled,
    } = props;

    return (
        <div className="Drawing-Button-Wrap">
            {
                isFinishButtonVisible && <button
                    className="Drawing-Button btn"
                    disabled={width <= 0 || isFinishButtonDisabled}
                    onClick={() => {
                        handleFinishClick();
                    }}
                >
                    {EDIT_ZONE_MODE.CLOSE_SHAPE}
                </button>
            }
            <button
                className="Drawing-Button btn btn-primary"
                disabled={width <= 0 || _isEmpty(creatingZone.zoneGeometryInDegrees)}
                onClick={() => { handleSubmitClick(); }}
            >
                {COMPONENTS.BUTTONS.CONTINUE}
            </button>
            <button
                className="Drawing-Button btn"
                onClick={() => { handleCancelClick(); }}
            >
                {COMPONENTS.BUTTONS.CANCEL}
            </button>
        </div>
    );
}

Buttons.propTypes = {
    width: PropTypes.number,
    creatingZone: PropTypes.shape({}),
    handleSubmitClick: PropTypes.func,
    handleCancelClick: PropTypes.func,
    handleFinishClick: PropTypes.func,
    isFinishButtonVisible: PropTypes.bool,
    isFinishButtonDisabled: PropTypes.bool,
};

Buttons.defaultProps = {
    width: 0,
    creatingZone: {},
    handleSubmitClick: () => {},
    handleCancelClick: () => {},
    handleFinishClick: () => {},
    isFinishButtonVisible: false,
    isFinishButtonDisabled: false,
};
