import React, { Fragment } from 'react';
import PropTypes from 'prop-types';

import { isSpaghettiMode, isNearMissMode, isPlaybackMode } from 'utils/simpleUtils';
import SiteViewPlaybackControl from './SiteViewPlaybackControl';
import SiteViewSpaghettiDiagramControls from './SiteViewSpaghettiDiagramControls';
import SiteViewUnresponsiveStatusBar from './SiteViewUnresponsiveStatusBar';
import SiteViewNearMissControls from './SiteViewNearMissMode/SiteViewNearMissControls';


const SiteViewFooter = props => (
    <div className="RPP-Site-Footer">
        <SiteViewUnresponsiveStatusBar hiddenTkoUnresponsiveCount={props.hiddenTkoUnresponsiveCount} />
        {
            props.mode && <Fragment>
                {
                    isPlaybackMode(props.mode.name) && <SiteViewPlaybackControl />
                }
                {
                    isSpaghettiMode(props.mode.name) && <SiteViewSpaghettiDiagramControls />
                }
                {
                    isNearMissMode(props.mode.name) && <SiteViewNearMissControls />
                }
            </Fragment>
        }
    </div>
);

SiteViewFooter.propTypes = {
    hiddenTkoUnresponsiveCount: PropTypes.number,
    mode: PropTypes.shape({
        name: PropTypes.string,
        onReturn: PropTypes.func,
    }),
};

SiteViewFooter.defaultProps = {
    hiddenTkoUnresponsiveCount: 0,
    mode: {
        name: '',
        onReturn: () => {
        },
    },
};

export default SiteViewFooter;
