import React from 'react';
import PropTypes from 'prop-types';
import _Get from 'lodash/get';
import { formatDbNameToHumanReadable, getFullDateByTz } from 'utils';
import { Zone as ZoneSelector } from 'stores/classes/Selectors';

const getAlarmText = (intl, alarm) => formatDbNameToHumanReadable(intl, alarm.alarm_name);

export default function AlarmExpandedTable(props) {
    const date = getFullDateByTz(props.alarm.created_at, props.timeZone);
    const text = getAlarmText(props.intl, props.alarm);
    const zone = (!!props.alarm && !!props.alarm.zone_uid) && ZoneSelector.getZoneByUid(props.alarm.zone_uid);
    const contact = _Get(props, 'alarm.additional_info.contact_name');
    return (
        <table className="table table-striped RPP-SpacesNormal">
            <tbody>
                <tr style={{ borderBottom: '1px solid #d3d3d3' }}>
                    <td style={{ width: '5%' }} />
                    <td style={{ float: 'left', width: '30%' }}>{date}</td>
                    <td style={{ float: 'left', width: (zone || contact) ? '30%' : '65%' }}>{text}</td>
                    {zone && <td style={{ float: 'left', width: '35%' }}>{zone.name}</td>}
                    {contact && <td style={{ float: 'left', width: '35%' }}>{contact}</td>}
                </tr>
            </tbody>
        </table>
    );
}

AlarmExpandedTable.propTypes = {
    alarm: PropTypes.shape({
        created_at: PropTypes.string,
        zone_uid: PropTypes.string,
        additional_info: PropTypes.shape({
            text: PropTypes.string,
            contact_name: PropTypes.string,
        }),
    }),
    timeZone: PropTypes.string,
    intl: PropTypes.shape({
        formatMessage: PropTypes.func,
    }),
};

AlarmExpandedTable.defaultProps = {
    alarm: {
        created_at: '',
        zone_uid: '',
        additional_info: {
            text: '',
            contact_name: null,
        },
    },
    timeZone: 'Etc/GMT',
    intl: {
        formatMessage: () => {
        },
    },
};
