import React, { useEffect } from 'react';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { injectIntl } from 'react-intl';
import { TABLES } from 'common';

function SearchField(props) {
    let timeout;
    useEffect(() => () => {
        if (timeout) clearTimeout(timeout);
    }, []);
    const { intl, items, searchFields, setFilterItems } = props;

    return (
        <input
            type="text"
            data-cy="alarm-table-search"
            className="form-control input-sm"
            style={{ width: '100%' }}
            placeholder={TABLES.SEARCH(intl)}
            onChange={(e) => {
                const { value } = e.target;
                const regex = new RegExp(value, 'i');
                clearTimeout(timeout);
                timeout = setTimeout(() => {
                    const filteredItems = items
                        .filter(item => searchFields.some(field => (item[field] && item[field].match(regex))));
                    setFilterItems(filteredItems, value);
                }, 600);
            }}
        />
    );
}

SearchField.propTypes = {
    intl: PropTypes.shape({ formatMessage: PropTypes.func }),
    items: PropTypes.arrayOf(PropTypes.shape({})),
    searchFields: PropTypes.arrayOf(PropTypes.string),
    setFilterItems: PropTypes.func,
};
SearchField.defaultProps = {
    intl: { formatMessage: () => { } },
    items: [],
    searchFields: [],
    setFilterItems: () => {},
};

function TableButtons(props) {
    const { intl, items, searchFields, setFilterItems } = props;
    return (
        <div className="Table row" style={{ marginBottom: '10px' }}>
            <div className="col-md-7" />
            <div className="col-md-5 text-right">
                <SearchField
                    intl={intl}
                    items={items}
                    searchFields={searchFields}
                    setFilterItems={setFilterItems}
                />
            </div>
        </div>
    );
}

TableButtons.propTypes = {
    intl: PropTypes.shape({ formatMessage: PropTypes.func }),
    items: PropTypes.arrayOf(PropTypes.shape({})),
    searchFields: PropTypes.arrayOf(PropTypes.string),
    setFilterItems: PropTypes.func,
};

TableButtons.defaultProps = {
    intl: { formatMessage: () => {} },
    items: [],
    searchFields: [],
    setFilterItems: () => {},
};

export default connect()(injectIntl(TableButtons));
