import React from 'react';
import { BootstrapTable, TableHeaderColumn } from 'react-bootstrap-table';
import { isCustomZone, isInfoZone } from 'utils/zoneUtils';
import { zoneSeverityColor } from 'utils/simpleUtils';
import { ZONE_SEVERITY } from 'common/constants';


function ZonesPopUpTable(props) {
    const formatZoneAlarmLevel = (cell, row) => {
        if (isCustomZone(row) || isInfoZone(row)) {
            return null;
        }
        return (
            <div style={{
                backgroundColor: zoneSeverityColor(row.zone_alarm_level),
                textAlign: 'center',
                width: '90%',
                color: row.zone_alarm_level === ZONE_SEVERITY.GUARDED ? 'black' : 'white',
            }}
            >
                {row.zone_alarm_level}
            </div>
        );
    };

    const formatIsActive = (cell, row) => {
        return <div style={{ textAlign: 'center' }}>{row.active ? 'Active' : 'Inactive'}</div>;
    };

    const options = {
        defaultSortName: 'name',
        onRowClick: props.handleRowClick,
    };

    return (
        <BootstrapTable
            data={props.zones}
            options={options}
            tableBodyClass="lineless-table popup-info"
            trClassName="cursor-pointer"
            bordered={false}
            hover
        >
            <TableHeaderColumn
                dataField="uid"
                searchable={false}
                hidden
                isKey
            />
            <TableHeaderColumn
                columnClassName="text-ellipsis"
                dataField="name"
                tdAttr={{ 'data-id': 'zoneName' }}
                dataAlign="left"
                headerAlign="center"
            >
                Name
            </TableHeaderColumn>
            <TableHeaderColumn
                columnClassName="text-ellipsis"
                dataField="zone_type"
                dataFormat={(cell, row) => row.zone_type?.display_name || row.zone_type_name}
                tdAttr={{ 'data-id': 'zoneType' }}
                dataAlign="left"
                headerAlign="center"
            >
                Type
            </TableHeaderColumn>
            <TableHeaderColumn
                columnClassName="text-ellipsis"
                dataField="status"
                dataFormat={formatIsActive}
                tdAttr={{ 'data-id': 'zoneStatus' }}
                dataAlign="left"
                headerAlign="center"
            >
                Status
            </TableHeaderColumn>
            <TableHeaderColumn
                columnClassName="text-ellipsis"
                dataField="severity"
                dataFormat={formatZoneAlarmLevel}
                tdAttr={{ 'data-id': 'zoneStatus' }}
                dataAlign="left"
                headerAlign="center"
            >
                Severity
            </TableHeaderColumn>
        </BootstrapTable>
    )
}

export default ZonesPopUpTable;
