import * as api from 'api';
import { ACTIONS, STORAGE_KEY } from 'common/constants';
import { getSessionStorageValue, LocationStoreMethods } from 'utils/browserStorage';
import { errorHandlerGetRequest } from 'stores/actions/errorHandlerActions';


export const changeSHMParams = params => (dispatch, getState) => {
    const { user, appContext } = getState();
    const userEmail = user.email || getSessionStorageValue(STORAGE_KEY.USER_EMAIL);
    const projectUid = (appContext.project && appContext.project.uid) || null;
    
    if (params.context) {
        LocationStoreMethods.setToLocalStorage(STORAGE_KEY.LAST_CONTEXT_OF_SHM, params.context, userEmail, projectUid);
    }
    dispatch({
        type: ACTIONS.SHM_CHANGE_PARAMS,
        params,
    });
};

export const getServerStatus = () => dispatch => api.getHost()
    .then((result) => {
        dispatch(changeSHMParams({ serverStatus: result.serverStatus }));
    })
    .catch((err) => { errorHandlerGetRequest(err, dispatch); });

export const getUptimeStatus = () => dispatch => api.getUptimeStatus()
    .then((data) => {
        const uptime = data.uptime.map((row) => {
            if (row.children) {
                for (let i = 0; i < row.children.length; i += 1) {
                    row.seconds = row.seconds > row.children[i].seconds ? row.seconds : row.children[i].seconds;
                    row.children[i].uptime = (row.children[i].status === 'failed') ? '' : row.children[i].uptime;
                }
            }
            row.seconds = row.seconds || 0;
            row.uptime = (row.status === 'failed') ? '' : row.uptime;
            return row;
        });
        dispatch(changeSHMParams({ uptime }));
    })
    .catch((err) => { errorHandlerGetRequest(err, dispatch); });

export const getActiveConnectionStatus = () => dispatch => api.getActiveConnectionStatus()
    .then((result) => {
        dispatch(changeSHMParams({
            connections: result.connections.map((x, i) => {
                x.key = i;
                return x;
            }),
        }));
    })
    .catch((err) => { errorHandlerGetRequest(err, dispatch); });
