import { stopSpaghettiWorker, clearSpaghettiDiagramParams } from 'stores/actions/spaghettiActions';
import { ACTIONS, STORAGE_KEY } from 'common/constants';
import { WS_ACTIONS } from 'worker';
import { siteViewClearMode, setClusterPopUp, selectLeafletItemForPopup } from 'stores/actions/siteViewActions';
import { getSessionStorageValue, LocationStoreMethods } from 'utils/browserStorage';

export const clearAllStore = () => ({ type: ACTIONS.CLEAR_STORE });
export const clearNearMissReportParams = () => ({ type: ACTIONS.CLEAR_NEAR_MISS_REPORT });
export const clearPlaybackInStore = () => ({ type: WS_ACTIONS.PLAYBACK_CLEAR });
export const clearSpaghettiDiagram = () => (dispatch) => {
    dispatch(clearSpaghettiDiagramParams());
    dispatch(siteViewClearMode());
};
export const clearNearMissReport = () => (dispatch) => {
    dispatch(clearNearMissReportParams());
    dispatch(siteViewClearMode());
};
export const stopWorker = () => (dispatch, getState) => {
    const state = getState();
    state && state.worker && state.worker.worker && state.worker.worker.terminate();
    dispatch({
        type: WS_ACTIONS.WORKER_STOP,
    });
};


export const clearStoreData = () => (dispatch) => {
    dispatch(stopWorker());
    dispatch(stopSpaghettiWorker());
    
    dispatch(clearAllStore());
};

export const clearStore = () => (dispatch, getState) => {
    const { user, appContext } = getState();
    const userEmail = user.email || getSessionStorageValue(STORAGE_KEY.USER_EMAIL);
    const projectUid = (appContext.project && appContext.project.uid) || null;
    LocationStoreMethods.setToLocalStorage(STORAGE_KEY.LAST_PROJECT, null, userEmail, projectUid);
    
    dispatch(clearStoreData());
};

export const closeInfoPopups = () => (dispatch) => {
    // close a cluster popup if opened
    dispatch(setClusterPopUp(null));

    // close a trackable popup if opened
    dispatch(selectLeafletItemForPopup(null));
};
