import { ACTIONS, STORAGE_KEY } from 'common/constants';
import { getSessionStorageValue, LocationStoreMethods } from 'utils/browserStorage';
import DashboardWidget from 'stores/classes/DashboardWidget';
import { aggregateDashboardAlarms, formatDashboardAlarms } from 'utils/alarmUtils';
import * as api from 'api';


export const alarmsDashboardError = () => ({
    type: ACTIONS.DASHBOARD_ALARMS_ERROR,
    params: { message: 'Error during alarms dashboard requesting', title: 'Dashboard error' },
});

export const alarmsDashboardSet = params => ({
    type: ACTIONS.DASHBOARD_ALARMS_SET,
    params,
});

export const alarmsDashboardLoad = () => ({
    type: ACTIONS.DASHBOARD_ALARMS_LOADING,
});

const dashboardWidgetsChange = newWidgets => ({
    type: ACTIONS.DASHBOARD_CHANGE_WIDGETS,
    params: { newWidgets },
});

export const dashboardChangeWidgets = params => (dispatch, getState) => {
    const { dashboard, user, appContext } = getState();
    const userEmail = user.email || getSessionStorageValue(STORAGE_KEY.USER_EMAIL);
    const projectUid = (appContext.project && appContext.project.uid) || null;

    const newWidgets = dashboard.widgets.reduce((memo, widget) => {
        if (widget.name === params.name) {
            memo.browser.push(new DashboardWidget(params));
            memo.store.push({ ...params });
        } else {
            memo.browser.push(new DashboardWidget(widget));
            memo.store.push({ ...widget });
        }
        return memo;
    }, { browser: [], store: [] });

    LocationStoreMethods.setToLocalStorage(STORAGE_KEY.LAST_DASHBOARD_WIDGETS, newWidgets.browser, userEmail, projectUid);
    dispatch(dashboardWidgetsChange(newWidgets.store));
};

export const getAlarmsDashboard = params => async (dispatch) => {
    try {
        const { from, to, area_uid } = params;
        if (!from || !to || !area_uid) return;

        dispatch(alarmsDashboardLoad());
        const alarms = await api.getAlarmsForPeriod(from, to, area_uid);
        const result = formatDashboardAlarms(aggregateDashboardAlarms(alarms));
        dispatch(alarmsDashboardSet(result));
    } catch (err) {
        dispatch(alarmsDashboardError());
    }
};
