import * as api from 'api';
import { ACTIONS } from 'common/constants';
import { errorHandler, errorHandlerGetRequest } from 'stores/actions/errorHandlerActions';


export const loadAlarms = () => async (dispatch) => {
    try {
        const alarms = await api.getActiveAlarms();
        dispatch({
            type: ACTIONS.ALARMS_SET,
            params: alarms,
        });
    } catch (err) {
        errorHandlerGetRequest(err, dispatch);
    }
};

const getRequestBody = (item) => {
    const request = {};
    
    if (item.state) {
        request.state = item.state;
    }
    if (item.acknowledged !== undefined) {
        request.acknowledged = item.acknowledged;
        request.acknowledged_by = item.acknowledgedBy;
    }
    
    return request;
};

export const acknowledgeAlarm = alarm => async (dispatch) => {
    try {
        const request = getRequestBody(alarm);
        const alarmData = await api.updateAlarm(alarm.uid, request);

        dispatch({
            type: ACTIONS.ALARM_ACKNOWLADGE,
            params: alarmData,
        });
    } catch (err) {
        errorHandler(err, dispatch);
    }
};

export const clearAlarms = () => ({
    type: ACTIONS.ALARMS_CLEAR,
});
