import * as api from 'api';

import { ACTIONS, STORAGE_KEY } from 'common/constants';
import { setAppContext } from 'stores/actions/appContextActions';
import { makeCopy } from 'utils/simpleUtils';
import { getLocalStorageValue } from 'utils/browserStorage';
import { errorHandler, errorHandlerGetRequest } from 'stores/actions/errorHandlerActions';


const companyFormat = company => ({
    ...company,
    ...company.user_params,
});

export const loadCompanies = () => dispatch => api.getCompanies()
    .then((companies) => {
        const formattedCompanies = companies
            .filter(company => company.uid !== getLocalStorageValue(STORAGE_KEY.SYSTEM_COMPANY_UID))
            .map(company => companyFormat(company));
        
        dispatch({
            type: ACTIONS.COMPANIES_SET,
            params: formattedCompanies,
        });
    })
    .catch((err) => {
        console.error(err);
        errorHandlerGetRequest(err, dispatch);
    });

export const createCompany = params => (dispatch, getState) => {
    const paramsCopy = makeCopy(params);

    return api.createCompany(paramsCopy)
        .then((res) => {
            const formattedCompany = companyFormat(res.company);

            dispatch({
                type: ACTIONS.COMPANY_CREATE,
                params: formattedCompany,
            });
        })
        .catch((err) => {
            console.error(err);
            errorHandler(err, dispatch);
        });
};

export const editCompany = params => (dispatch, getState) => {
    const parameters = {
        ...params,
        tag_allocation: !!params.tag_allocation,
        user_params: {
            ...params.user_params,
            tag_allocation: params.tag_allocation,
        },
    };

    return api.updateCompany(parameters)
        .then((_company) => {
            const formattedCompany = companyFormat(_company);
            const { appContext: { company } } = getState();

            if (company && company.uid === _company.uid) {
                dispatch(setAppContext({ company: formattedCompany }));
            } else {
                dispatch({
                    type: ACTIONS.COMPANY_UPDATE,
                    params: formattedCompany,
                });
            }
        })
        .catch((err) => { errorHandler(err, dispatch); });
};

export const deleteCompany = params => (dispatch) => {
    if (params.uid) {
        return api.deleteCompany(params.uid)
            .then(() => {
                dispatch({
                    type: ACTIONS.COMPANY_DELETE,
                    params,
                });
            })
            .catch((err) => { errorHandler(err, dispatch); });
    }
    const promises = [];
    
    for (let i = 0; i < params.length; i += 1) {
        promises.push(api.deleteCompany(params[i].uid, dispatch)
            .then(() => {
                dispatch({
                    type: ACTIONS.COMPANY_DELETE,
                    params,
                });
            })
            .catch((err) => {
                errorHandler(err, dispatch);
            }));
    }
    
    return Promise.all(promises);
};
