import * as api from 'api';
import { ACTIONS, MODAL_ACTIONS } from 'common/constants';
import { errorHandler } from 'stores/actions/errorHandlerActions';


export const sendMessage = (recipient, message) => dispatch => api.sendMessage(recipient, message).then(({ data }) => {
    if (data.Error) {
        dispatch({
            type: ACTIONS.MESSAGE_ERROR,
            params: { status: 'error' },
        });
    } else if (data.Status) {
        dispatch({
            type: MODAL_ACTIONS.MODAL_OPEN_MESSAGE_SUCCESS_SEND,
            params: {
                recipient,
                message,
            },
        });
    }
})
    .catch((err) => { errorHandler(err, dispatch); });

export const sendMessages = (recipients, message) => dispatch => Promise.all(recipients.map(x => api.sendMessage(x, message))).then((array) => {
    let success = true;
    array.forEach(({ data }) => {
        if (data.Error) {
            success = false;
        }
    });
    return success;
}).then((success) => {
    if (success) {
        dispatch({
            type: MODAL_ACTIONS.MODAL_OPEN_MESSAGE_SUCCESS_SEND,
            params: {
                recipients,
                message,
            },
        });
    } else {
        dispatch({
            type: ACTIONS.MESSAGE_ERROR,
            params: { status: 'error' },
        });
    }
})
    .catch((err) => { errorHandler(err, dispatch); });

export const sendMessaging = (from, to, body) => dispatch => api.sendMessaging(from, to, body).then(() => {
    dispatch({
        type: MODAL_ACTIONS.MODAL_OPEN_MESSAGE_SUCCESS_SEND,
        params: {
            from,
            recipient: to,
            message: body,
        },
    });
})
    .catch((err) => { errorHandler(err, dispatch); });

export const saveMessage = message => (dispatch) => {
    dispatch({
        type: ACTIONS.MESSAGE_SAVE,
        params: { message },
    });
};

export const selectTrackablesAndGroups = selectedItems => (dispatch) => {
    dispatch({
        type: ACTIONS.MESSAGE_SELECT_ITEMS,
        params: { selectedItems },
    });
};

export const clearMessage = () => (dispatch) => {
    dispatch({
        type: ACTIONS.MESSAGE_CLEAR,
    });
};
