import * as api from 'api';
import { ACTIONS } from 'common/constants';
import { errorHandler, errorHandlerGetRequest } from 'stores/actions/errorHandlerActions';


export const loadProjects = () => async (dispatch) => {
    try {
        const projects = await api.getProjects();
        dispatch({
            type: ACTIONS.PROJECTS_SET,
            params: projects,
        });
    } catch (err) {
        console.error(err);
        errorHandlerGetRequest(err, dispatch);
    }
};

export const createProject = params => (dispatch, getState) => {
    const project = {
        project: {
            name: params.name,
            user_params: {
                manager: params.manager ? params.manager : '',
                timezone: params.timezone,
            },
        },
    };

    return api.createProject(project)
        .then((projectData) => {
            dispatch({
                type: ACTIONS.PROJECTS_CREATE,
                params: projectData,
            });
        })
        .catch((err) => { errorHandler(err, dispatch); });
};

export const editProject = params => (dispatch) => {
    const { uid } = params;

    const project = {
        project: {
            name: params.name,
            user_params: {
                manager: params.manager,
                timezone: params.timezone,
            },
        },
    };

    return api.updateProject(project, uid)
        .then((projectData) => {
            dispatch({
                type: ACTIONS.PROJECTS_UPDATE,
                params: projectData,
            });
        })
        .catch((err) => { errorHandler(err, dispatch); });
};


export const deleteProject = params => (dispatch) => api.deleteProject(params.uid)
    .then(() => {
        dispatch({
            type: ACTIONS.PROJECTS_DELETE,
            params,
        });
    })
    .catch((err) => { errorHandler(err, dispatch); });

export const selectProject = params => (dispatch) => {
    dispatch({
        type: ACTIONS.PROJECT_SELECT,
        params,
    });
};
