import * as api from 'api';
import { ACTIONS } from 'common/constants';
import { errorHandlerGetRequest } from 'stores/actions/errorHandlerActions';


export const loadSubscribers = () => dispatch => new Promise(async (resolve) => {
    try {
        const subscribers = await api.getSubscribers();
        dispatch({
            type: ACTIONS.SUBSCRIBERS_SET,
            params: subscribers,
        });
    } catch (err) {
        console.warn(err);
        errorHandlerGetRequest(err, dispatch);
    }
    resolve();
});

export const loadSystemNotificationSubscribers = () => async dispatch => new Promise(async (resolve) => {
    try {
        const systemNotificationSubscribers = await api.getSystemNotificationSubscribers();
        dispatch({
            type: ACTIONS.SYSTEM_SUBSCRIBERS_SET,
            params: systemNotificationSubscribers,
        });
    } catch (err) {
        console.warn(err);
        errorHandlerGetRequest(err, dispatch);
    }

    resolve();
});

export const createSubscriber = params => async (dispatch, getState) => {
    try {
        const subscriber = await api.createSubscriber(params);
        if (!getState().worker.isWebSocketOn) {
            await dispatch({
                type: ACTIONS.SUBSCRIBER_CREATE,
                params: subscriber,
            });
        }
    } catch (err) {
        console.error('createSubscriber err: ', err);
        errorHandlerGetRequest(err, dispatch);
    }
};

export const updateSubscriber = params => async (dispatch, getState) => {
    try {
        const subscriber = await api.updateSubscriber(params);
        if (!getState().worker.isWebSocketOn) {
            await dispatch({
                type: ACTIONS.SUBSCRIBER_UPDATE,
                params: subscriber,
            });
        }
    } catch (err) {
        console.error('updateSubscriber err', err);
        errorHandlerGetRequest(err, dispatch);
    }
};

export const deleteSubscriber = params => async (dispatch, getState) => {
    try {
        const subscriber = await api.deleteSubscriber(params);
        if (!getState().worker.isWebSocketOn) {
            await dispatch({
                type: ACTIONS.SUBSCRIBER_DELETE,
                params: subscriber,
            });
        }
    } catch (err) {
        console.error('deleteSubscriber err', err);
        errorHandlerGetRequest(err, dispatch);
    }
};
