import { ACTIONS, SAGA_ACTIONS } from 'common/constants';
import * as api from 'api';
import Association from 'stores/classes/Association';
import { errorHandlerGetRequest } from 'stores/actions/errorHandlerActions';
import { clearAdminPageSelectedItems } from 'stores/actions/adminPageActions';
import {
    trackableBulkAssignApplyErrorModal,
    submitTrackableBulkAssignModal,
    closeTrackableBulkAssignModal,
} from 'stores/actions/modalActions/trackableModalActions';

export const loadTrackables = () => ({ type: SAGA_ACTIONS.SAGA_TRACKABLES_LOAD });

export const loadCompanyTrackables = () => ({ type: SAGA_ACTIONS.SAGA_TRACKABLES_COMPANY_LOAD });

export const closeCreateEditTrackableLLL = () => ({ type: SAGA_ACTIONS.SAGA_TRACKABLES_CREATE_LLL_CLOSE });

export const createEditTrackableLLL = (params) => ({ type: SAGA_ACTIONS.SAGA_TRACKABLES_CREATE_LLL, params });

export const createEditTrackable = (params) => ({ type: SAGA_ACTIONS.SAGA_TRACKABLES_CREATE, params });

export const bulkEditTrackable = (params) => ({ type: SAGA_ACTIONS.SAGA_TRACKABLES_BULK_EDIT, params });

export const deleteTrackable = (params) => ({ type: SAGA_ACTIONS.SAGA_TRACKABLES_DELETE, params });

export const saveTrackablePositionFromState = (params) => ({ type: SAGA_ACTIONS.SAGA_TRACKABLES_EDIT_POSITION, params });

export async function getTrackablesForPeriod(params, dispatch) {
    try {
        const { from, to, sublocation_uid } = params;
        
        const trackables = await api.loadAllTrackablesForPeriod(sublocation_uid, from, to);
        const associations = await api.getActiveTrackObjectAssociationsForInterval(from / 1000, to / 1000);
        return trackables
            .filter((tko) => !!associations.find((association) => new Association(association).isAssociationObjectUidEqualTo(tko.uid)))
            .map((tko) => {
                // If no need to show trackable before it moving
                delete tko.position;
                return ({
                    ...tko,
                    value: tko.uid,
                    label: tko.name,
                });
            });
    } catch (error) {
        errorHandlerGetRequest(error, dispatch);
    }
    
    return [];
}

export const loadTrackableTemplates = () => async (dispatch) => {
    try {
        const templates = await api.loadTrackableTemplates();
        dispatch({
            type: ACTIONS.TRACKABLE_TEMPLATES_SET,
            params: templates,
        });
    } catch (err) {
        console.warn(err);
        errorHandlerGetRequest(err, dispatch);
    }
};

export const bulkAssignTrackable = (params) => async (dispatch) => {
    dispatch(submitTrackableBulkAssignModal());

    let error;
    const savedAssociationsMap = { size: 0 };
    if (params.assignedItems) {
        for (let i = 0; i < params.assignedItems.length; i += 1) {
            const { mac_address, trackable_uid: obj_uid } = params.assignedItems[i];
            const association = await api.createTrackableAssociations({ mac_address, obj_uid });
            if (association) {
                savedAssociationsMap[association.obj_uid] = association.mac_address;
                savedAssociationsMap.size += 1;
                dispatch({ type: ACTIONS.TRACKABLES_ASSOCIATION_CREATE, params: association });
            } else {
                error = true;
            }
        }
    }

    if (error) {
        dispatch(trackableBulkAssignApplyErrorModal(savedAssociationsMap));
    } else {
        dispatch(clearAdminPageSelectedItems());
        dispatch(closeTrackableBulkAssignModal());
    }
};
