import * as api from 'api';
import { WORKER_METHODS, WS_ACTIONS } from 'worker';
import { ACTIONS } from 'common/constants';
import { stopLiveMode, startLiveMode } from 'stores/actions/workerActions';
import { clearPlaybackInStore, closeInfoPopups } from 'stores/actions/commonActions';
import { siteViewClearMode } from 'stores/actions/siteViewActions';
import { errorHandlerGetRequest } from 'stores/actions/errorHandlerActions';
import { LocationStoreMethods } from 'utils/browserStorage';
import PlaybackWorker from 'playback/playback.worker.js'; // handled by plugin worker-loader in webpack config
import { getQueryParam } from 'utils/browserStorage'; // handled by plugin worker-loader in webpack config

let playbackWorker;

const runPlaybackWorker = () => (dispatch) => {
    const { email, token, project, hostname } = LocationStoreMethods.getParamsFromStorage();
    playbackWorker = new PlaybackWorker();
    const targetServer = getQueryParam('target_server');

    playbackWorker.postMessage({
        method: WORKER_METHODS.PLAYBACK_INIT,
        params: { email, token, project, hostname, queryParams: { target_server: targetServer } },
    });
    
    playbackWorker.onmessage = (message) => {
        const { type, params } = message.data;
        
        dispatch({ type, params });
    };
};

export const changePlaybackParams = (params) => (dispatch) => {
    dispatch({
        type: WS_ACTIONS.PLAYBACK_CHANGE_PARAMS,
        params,
    });
};

const loadZonesIncludeRemoved = (params) => (dispatch) => new Promise((resolve) => {
    api.getZonesIncludeRemoved(params)
        .then((zones) => {
            dispatch({
                type: ACTIONS.ZONES_INCLUDE_REMOVED_SET,
                params: zones,
            });

            resolve();
        })
        .catch((err) => { errorHandlerGetRequest(err, dispatch); });
});

export const loadAssociationForPlayback = (params) => async (dispatch) => {
    const { from, to } = params;

    const associations = await api.getActiveTrackObjectAssociationsForInterval(from / 1000, to / 1000);
    dispatch({
        type: ACTIONS.TRACKABLES_ASSOCIATION_PLAYBACK_SET,
        params: associations,
    });
};

export const generatePlayback = ({ setting, trackables }) => (dispatch, getState) => {
    if (!playbackWorker) {
        dispatch(runPlaybackWorker());
    }
    if (getState().heatmap.currentHeatmaps.length > 0) {
        dispatch({ type: ACTIONS.HEATMAP_CLEAR });
    }

    dispatch(stopLiveMode());
    
    dispatch({ type: ACTIONS.ALARMS_PLAYBACK_CLEAR });
    
    const params = { setting: { ...setting, trackables } };
    
    playbackWorker.postMessage({
        method: WORKER_METHODS.PLAYBACK_GENERATE,
        params,
    });
    dispatch(loadZonesIncludeRemoved(setting));
};

export const clearPlayback = () => (dispatch) => {
    dispatch(siteViewClearMode());
    dispatch(closeInfoPopups());
    dispatch(clearPlaybackInStore());
    dispatch(startLiveMode());

    if (playbackWorker) {
        playbackWorker.terminate();
        playbackWorker = undefined;
    } else {
        console.warn('Playback worker is not running');
    }
};

export const getHistoryPos = (params) => () => {
    playbackWorker.postMessage({
        method: WORKER_METHODS.PLAYBACK_GET_DATA,
        params,
    });
};
