import { ACTIONS, STORAGE_KEY } from 'common/constants';
import _Has from 'lodash/has';
import _isUndefined from 'lodash/isUndefined';
import { initialState } from 'stores/reducers/siteViewFilter';
import { getSessionStorageValue, LocationStoreMethods } from 'utils/browserStorage';
import { ZonePrototype } from 'stores/classes';

export const changeParamsOnSiteView = params => ({
    type: ACTIONS.SITE_VIEW_CHANGE_PARAMS,
    params,
});

export const changeParamsOnLeaflet = params => (dispatch, getState) => {
    const { user, appContext } = getState();
    const userEmail = user.email || getSessionStorageValue(STORAGE_KEY.USER_EMAIL);
    const projectUid = (appContext.project && appContext.project.uid) || null;

    const leafletFilter = {};
    const leafletFilters = ['zoom', 'bounds', 'center'];
    Object.keys(params).forEach((param) => {
        if (leafletFilters.some(x => param.includes(x))) {
            leafletFilter[param] = params[param];
        }
    });

    LocationStoreMethods.setToLocalStorage(STORAGE_KEY.LAST_STATE_OF_LEAFLET, leafletFilter, userEmail, projectUid);

    dispatch({
        type: ACTIONS.SITE_VIEW_LEAFLET_SET_PARAMS,
        params,
    });
};


export const clearFloorplan = () => (dispatch, getState) => new Promise((resolve) => {
    const { user, appContext } = getState();
    const userEmail = user.email || getSessionStorageValue(STORAGE_KEY.USER_EMAIL);
    const projectUid = (appContext.project && appContext.project.uid) || null;

    LocationStoreMethods.setToLocalStorage(STORAGE_KEY.LAST_FLOORPLAN, null, userEmail, projectUid);
    dispatch({
        type: ACTIONS.SITE_VIEW_SELECT_FLOORPLAN,
        params: {
            selectedFloorplan: null,
        },
    });

    resolve();
});

export const selectFloorplan = selectedFloorplan => (dispatch, getState) => {
    const { user, appContext } = getState();
    const userEmail = user.email || getSessionStorageValue(STORAGE_KEY.USER_EMAIL);
    const projectUid = (appContext.project && appContext.project.uid) || null;

    LocationStoreMethods.setToLocalStorage(STORAGE_KEY.LAST_FLOORPLAN, selectedFloorplan, userEmail, projectUid);
    dispatch({
        type: ACTIONS.SITE_VIEW_SELECT_FLOORPLAN,
        params: {
            selectedFloorplan,
        },
    });
};

export const updateLeaflet = () => (dispatch, getState) => {
    dispatch(selectFloorplan(getState().siteView.selectedFloorplan)); // for full update leaflet
};

export const selectLocation = selectedLocation => (dispatch, getState) => {
    const { user, appContext } = getState();
    const userEmail = user.email || getSessionStorageValue(STORAGE_KEY.USER_EMAIL);
    const projectUid = (appContext.project && appContext.project.uid) || null;

    LocationStoreMethods.setToLocalStorage(STORAGE_KEY.LAST_LOCATION, selectedLocation, userEmail, projectUid);
    dispatch({
        type: ACTIONS.SITE_VIEW_SELECT_LOCATION,
        params: {
            selectedLocation,
        },
    });
    dispatch(updateLeaflet());
};

export const selectSublocation = selectedSublocation => (dispatch, getState) => {
    const { user, appContext } = getState();
    const userEmail = user.email || getSessionStorageValue(STORAGE_KEY.USER_EMAIL);
    const projectUid = (appContext.project && appContext.project.uid) || null;

    LocationStoreMethods.setToLocalStorage(STORAGE_KEY.LAST_SUBLOCATION, selectedSublocation, userEmail, projectUid);
    dispatch({
        type: ACTIONS.SITE_VIEW_SELECT_SUBLOCATION,
        params: {
            selectedSublocation,
        },
    });

    dispatch(updateLeaflet());
};

export const selectTabInSiteView = selectedTab => (dispatch, getState) => {
    const { user, appContext } = getState();
    const userEmail = user.email || getSessionStorageValue(STORAGE_KEY.USER_EMAIL);
    const projectUid = (appContext.project && appContext.project.uid) || null;

    LocationStoreMethods.setToLocalStorage(STORAGE_KEY.LAST_INDEX_OF_SITE_VIEW_TABS, selectedTab, userEmail, projectUid);
    dispatch({
        type: ACTIONS.SITE_VIEW_SELECT_TAB,
        params: {
            selectedTab,
        },
    });
};

export const changeOpeningSideBar = () => (dispatch, getState) => {
    const { user, appContext, siteView } = getState();
    const userEmail = user.email || getSessionStorageValue(STORAGE_KEY.USER_EMAIL);
    const projectUid = (appContext.project && appContext.project.uid) || null;

    const isOpenSideBar = !siteView.isOpenSideBar;
    LocationStoreMethods.setToLocalStorage(STORAGE_KEY.LAST_STATE_OF_RIGHT_SIDE_BAR, isOpenSideBar, userEmail, projectUid);

    dispatch({
        type: ACTIONS.SITE_VIEW_CHANGE_OPENING_SIDE_BAR,
    });

    if (siteView.selectedFloorplan) {
        dispatch(updateLeaflet());
    }
};

export const openFilter = () => dispatch => (
    new Promise((resolve) => {
        dispatch({
            type: ACTIONS.SITE_VIEW_CHANGE_OPENING_FILTER,
            params: {
                isOpenObjectFilter: true,
            },
        });
        resolve();
    })
);

export const openCloseGroupFilter = () => (dispatch, getState) => {
    dispatch({
        type: ACTIONS.SITE_VIEW_CHANGE_OPENING_FILTER,
        params: {
            isOpenGroupFilter: !getState().siteViewFilter.objectFilter.isOpenGroupFilter,
        },
    });
};

export const openCloseUnresponsiveFilter = () => (dispatch, getState) => {
    dispatch({
        type: ACTIONS.SITE_VIEW_CHANGE_OPENING_FILTER,
        params: {
            isOpenInactiveFilter: !getState().siteViewFilter.objectFilter.isOpenInactiveFilter,
        },
    });
};

export const closeFilters = () => ({
    type: ACTIONS.SITE_VIEW_CHANGE_OPENING_FILTER,
    params: {
        isOpenObjectFilter: false,
        isOpenGroupFilter: false,
        isOpenInactiveFilter: false,
    },
});

export const changeFilter = filter => ({
    type: ACTIONS.SITE_VIEW_CHANGE_FILTER,
    params: filter,
});

export const selectTrackables = uids => ({
    type: ACTIONS.SITE_VIEW_FILTER_SELECT_TRACKABLES,
    params: uids,
});

export const unselectTrackables = uids => ({
    type: ACTIONS.SITE_VIEW_FILTER_UNSELECT_TRACKABLES,
    params: uids,
});

export const changeGroupFilter = filter => ({
    type: ACTIONS.SITE_VIEW_CHANGE_GROUP_FILTER,
    params: filter,
});

export const changeUnresponsiveFilter = filter => ({
    type: ACTIONS.SITE_VIEW_CHANGE_UNRESPONSIVE_FILTER,
    params: filter,
});

export const siteViewClearMode = () => ({
    type: ACTIONS.SITE_VIEW_CLEAR_MODE,
});

export const siteViewChangeSelectedItems = selectedItem => ({
    type: ACTIONS.SITE_VIEW_CHANGE_SELECTED_ITEMS,
    params: selectedItem,
});

export const selectLeafletItemForPopup = item => ({
    type: ACTIONS.SITE_VIEW_SELECTED_LEAFLET_ELEMENT,
    params: item,
});

export const siteViewSelectItems = (items) => {
    let payload = items;
    if (payload.constructor !== Array) {
        payload = [items];
    }

    return {
        type: ACTIONS.SITE_VIEW_SELECT_ITEMS,
        params: payload,
    };
};

export const siteViewUnselectItems = (items) => {
    let payload = items;
    if (payload.constructor !== Array) {
        payload = [items];
    }

    return {
        type: ACTIONS.SITE_VIEW_UNSELECT_ITEMS,
        params: payload,
    };
};

export const changeMode = ({ name, type, onReturn }) => (dispatch, getState) => {
    if ((!name || !onReturn || !type) && getState().siteView.mode) {
        const { mode } = getState().siteView;
        name = name || mode.name;
        type = type || mode.type;
        onReturn = onReturn || mode.onReturn;
    }

    dispatch(changeParamsOnSiteView({
        mode: { name, type, onReturn },
    }));
};

export const addCreatedZoneGeometry = geometry => ({
    type: ACTIONS.SITE_VIEW_ADD_CREATED_GEOMETRY,
    params: geometry,
});

export const setZoneGeometryRestriction = geometry_restriction => ({
    type: ACTIONS.SITE_VIEW_ADD_CREATED_GEOMETRY_RESTRICTION,
    params: geometry_restriction,
});

export const setZoneTypeName = zone_type_name => ({
    type: ACTIONS.SITE_VIEW_ADD_CREATED_GEOMETRY_TYPE,
    params: zone_type_name,
});

export const rotateZoneGeometry = rotation => ({
    type: ACTIONS.SITE_VIEW_ROTATE_CREATED_GEOMETRY,
    params: rotation,
});

export const setZoneWidth = width => (dispatch, getState) => {
    const { user, appContext } = getState();
    const userEmail = user.email || getSessionStorageValue(STORAGE_KEY.USER_EMAIL);
    const projectUid = (appContext.project && appContext.project.uid) || null;
    LocationStoreMethods.setToLocalStorage(STORAGE_KEY.LAST_DIRECTIONAL_ZONE_WIDTH, width, userEmail, projectUid);
    dispatch({
        type: ACTIONS.SITE_VIEW_SET_ZONE_WIDTH,
        params: width,
    });
};

export const clearCreateZoneMode = () => ({
    type: ACTIONS.SITE_VIEW_CLEAR_CREATED_MODE,
});

export const changeClientHeight = height => (dispatch) => {
    dispatch(changeParamsOnSiteView({
        height,
    }));
};

export const setClusterPopUp = cluster => (dispatch) => {
    dispatch({
        type: ACTIONS.SITE_VIEW_SET_CLUSTER_POP_UP,
        params: cluster,
    });
};

export const setLayerFilter = params => (dispatch, getState) => {
    const { user, appContext } = getState();
    const userEmail = user.email || getSessionStorageValue(STORAGE_KEY.USER_EMAIL);
    const projectUid = (appContext.project && appContext.project.uid) || null;
    const viewFilter = LocationStoreMethods.getFromLocalStorage(STORAGE_KEY.LAST_STATE_OF_VIEW_FILTER, userEmail, projectUid) || initialState.leaflet;
    const prefixOfParamViewFilter = 'isShowing';
    const { siteViewFilter } = getState();
    const { leaflet, layerFilter } = siteViewFilter;

    Object.keys(leaflet || {}).forEach((param) => {
        if (param.includes(prefixOfParamViewFilter)) {
            viewFilter[param] = leaflet[param];
        }
    });
    Object.keys(params || {}).forEach((param) => {
        if (param.includes(prefixOfParamViewFilter)) {
            viewFilter[param] = params[param];
        }
    });

    const zonePrototypes = ZonePrototype.getAllZonePrototypes(getState());
    const allCustomZoneFilters = param => zonePrototypes.reduce((memo, customZone) => {
        const zoneTypeName = customZone.zone_type.name;
        const { isShowingAllZones } = param;

        memo[`isShowing_${zoneTypeName}`] = isShowingAllZones;
        memo[`isShowingActive_${zoneTypeName}`] = isShowingAllZones;
        memo[`isShowingInactive_${zoneTypeName}`] = isShowingAllZones;

        return memo;
    }, {});

    const allZoneFilters = param => ({
        isShowingAlarmZones: param.isShowingAllZones,
        isShowingInfoZones: param.isShowingAllZones,
        isShowingActiveZonesOnly: param.isShowingAllZones,
        isShowingInactiveZonesOnly: param.isShowingAllZones,
        isShowingActiveInfoZones: param.isShowingAllZones,
        isShowingInactiveInfoZones: param.isShowingAllZones,
        isShowingActiveAlarmZones: param.isShowingAllZones,
        isShowingInactiveAlarmZones: param.isShowingAllZones,
        ...allCustomZoneFilters(param),
    });

    const infoZoneFilters = param => ({
        isShowingActiveInfoZones: !!param.isShowingInfoZones && layerFilter.isShowingActiveZonesOnly,
        isShowingInactiveInfoZones: !!param.isShowingInfoZones && layerFilter.isShowingInactiveZonesOnly,
    });

    const alarmZoneFilters = param => ({
        isShowingActiveAlarmZones: !!param.isShowingAlarmZones && layerFilter.isShowingActiveZonesOnly,
        isShowingInactiveAlarmZones: !!param.isShowingAlarmZones && layerFilter.isShowingInactiveZonesOnly,
    });

    const allActiveZoneFilters = (param) => {
        const { isShowingActiveZonesOnly } = param;
        const { isShowingInfoZones, isShowingAlarmZones } = layerFilter;

        const activeCustomZoneParams = zonePrototypes.reduce((memo, customZone) => {
            const zoneTypeName = customZone.zone_type.name;
            memo[`isShowingActive_${zoneTypeName}`] =
                layerFilter[`isShowing_${zoneTypeName}`] && isShowingActiveZonesOnly;

            return memo;
        }, {});

        return {
            isShowingActiveInfoZones: isShowingInfoZones && isShowingActiveZonesOnly,
            isShowingActiveAlarmZones: isShowingAlarmZones && isShowingActiveZonesOnly,
            ...activeCustomZoneParams,
        };
    };

    const allInactiveZoneFilters = (param) => {
        const { isShowingInactiveZonesOnly } = param;
        const { isShowingInfoZones, isShowingAlarmZones } = layerFilter;

        const inactiveCustomZoneParams = zonePrototypes.reduce((memo, customZone) => {
            const zoneTypeName = customZone.zone_type.name;
            memo[`isShowingInactive_${zoneTypeName}`] =
                layerFilter[`isShowing_${zoneTypeName}`] && isShowingInactiveZonesOnly;

            return memo;
        }, {});

        return {
            isShowingInactiveInfoZones: isShowingInfoZones && isShowingInactiveZonesOnly,
            isShowingInactiveAlarmZones: isShowingAlarmZones && isShowingInactiveZonesOnly,
            ...inactiveCustomZoneParams,
        };
    };

    const updateChildrenFilterFor = (filterName, param, getFilterParams) => (_Has(param, filterName) ? Object.assign(param, getFilterParams(param)) : param);

    const getCustomZoneType = param => zonePrototypes.find((customZone) => {
        const zoneTypeName = customZone.zone_type.name;
        return _Has(param, `isShowing_${zoneTypeName}`);
    });

    const customZoneParams = (customZoneTypeName, param) => {
        const { isShowingActiveZonesOnly, isShowingInactiveZonesOnly } = layerFilter;
        const customZoneFilter = param[`isShowing_${customZoneTypeName}`];

        return {
            [`isShowingActive_${customZoneTypeName}`]: customZoneFilter && isShowingActiveZonesOnly,
            [`isShowingInactive_${customZoneTypeName}`]: customZoneFilter && isShowingInactiveZonesOnly,
        };
    };

    let _params = Object.assign({}, params);

    _params = updateChildrenFilterFor('isShowingActiveZonesOnly', _params, allActiveZoneFilters);
    _params = updateChildrenFilterFor('isShowingInactiveZonesOnly', _params, allInactiveZoneFilters);
    _params = updateChildrenFilterFor('isShowingInfoZones', _params, infoZoneFilters);
    _params = updateChildrenFilterFor('isShowingAlarmZones', _params, alarmZoneFilters);
    _params = updateChildrenFilterFor('isShowingAllZones', _params, allZoneFilters);

    const customZoneType = getCustomZoneType(params);
    if (!_isUndefined(customZoneType)) {
        const customZoneTypeName = customZoneType.zone_type.name;
        const customZoneFilter = `isShowing_${customZoneTypeName}`;
        _params = updateChildrenFilterFor(customZoneFilter, _params, customZoneParams.bind(this, customZoneTypeName));
    }

    const notCustomZoneFilters = currentFilter => ({
        isShowingAlarmZones: layerFilter.isShowingAlarmZones,
        isShowingInfoZones: layerFilter.isShowingInfoZones,
        isShowingActiveZonesOnly: layerFilter.isShowingActiveZonesOnly,
        isShowingInactiveZonesOnly: layerFilter.isShowingInactiveZonesOnly,
        ...currentFilter,
    });

    const getCustomZonesFilter = param => zonePrototypes.reduce((memo, customZone) => {
        const zoneTypeName = customZone.zone_type.name;
        const customZoneTypeName = `isShowing_${zoneTypeName}`;

        memo[customZoneTypeName] = _isUndefined(param[customZoneTypeName])
            ? layerFilter[customZoneTypeName]
            : param[customZoneTypeName];
        return memo;
    }, {});

    const areAllZonesChecked = (filter) => {
        const {
            isShowingAlarmZones,
            isShowingInfoZones,
            isShowingActiveZonesOnly,
            isShowingInactiveZonesOnly,
        } = notCustomZoneFilters(filter);

        const customZones = getCustomZonesFilter(filter);

        const areAllCustomZoneChecked = Object.values(customZones).every(el => el);

        return isShowingAlarmZones
            && isShowingInfoZones
            && isShowingActiveZonesOnly
            && isShowingInactiveZonesOnly
            && areAllCustomZoneChecked;
    };

    const isAtLeastOneChecked = (filter) => {
        const {
            isShowingAlarmZones,
            isShowingInfoZones,
            isShowingActiveZonesOnly,
            isShowingInactiveZonesOnly,
        } = notCustomZoneFilters(filter);

        const customZones = getCustomZonesFilter(filter);

        const isAtleastOneCustomZoneChecked = Object.values(customZones).some(el => el);

        return (isShowingActiveZonesOnly || isShowingInactiveZonesOnly)
            && (isShowingAlarmZones || isShowingInfoZones || isAtleastOneCustomZoneChecked);
    };

    // updating "All Zones" checkbox state only if it was not clicked directly
    if (_isUndefined(params.isShowingAllZones)) {
        if (areAllZonesChecked(params)) {
            _params.isShowingAllZones = true;
        } else if (isAtLeastOneChecked(params)) {
            // This is actual for the indeterminate state of a checkbox
            _params.isShowingAllZones = null;
        } else {
            _params.isShowingAllZones = false;
        }
    }

    LocationStoreMethods.setToLocalStorage(STORAGE_KEY.LAST_STATE_OF_VIEW_FILTER, { ...viewFilter, ..._params }, userEmail, projectUid);

    dispatch({
        type: ACTIONS.SITE_VIEW_LAYER_FILTER,
        params: { ..._params },
    });
};
