import { DEFAULT_VALUES } from 'common/constants';
import { DB_NAMES } from 'common/ui-labels';
import { getNotificationTypes } from 'utils/utils';


export default class Notification {
    constructor(notification) {
        this.active = notification.active;
        this.conditions = notification.conditions;
        this.created_at = notification.created_at;
        this.id = notification.id;
        this.name = notification.name;
        this.notification_type = notification.notification_type;
        this.project_uid = notification.project_uid;
        this.removed_at = notification.removed_at;
        this.types = notification.types;
        this.uid = notification.uid;
        this.updated_at = notification.updated_at;
    }
    
    getProperties() {
        return { ...this };
    }
    
    formattedNotification(state, intl) {
        const props = this.getProperties();
        const alarmTypes = getNotificationTypes(Notification.getNotificationsTypes(state), intl);
    
        props.email = props.types ? props.types.email : '';
        props.phone = props.types ? props.types.phone : '';
        props.active = !!props.active;
        props.activeText = props.active ? DB_NAMES.ACTIVE(intl) : DB_NAMES.INACTIVE(intl);
        props.zone_severity_level = props.conditions.zone_severity_level;
        props.alarm_type_list = props.conditions && Array.isArray(props.conditions.alarm_type_list)
            ? props.conditions.alarm_type_list.map(alarm_type => alarmTypes.find((alarm_type_item) => {
                // 945 old version of alarm_type_list name
                if (alarm_type === 'zone_violation_alarm') {
                    alarm_type = 'zone_violation';
                }
                if (alarm_type === 'buffer_violation_alarm') {
                    alarm_type = 'buffer_violation';
                }
                return alarm_type_item.uid === alarm_type;
            }))
            : DEFAULT_VALUES.empty_array;
        return props;
    }
    
    static getAllNotifications(state) {
        return state.entities.notifications;
    }
    
    static getNotificationsTypes(state) {
        return state.entities.notificationTypes;
    }
}
