export default class TrackableTemplate {
    /**
     * Extract all templates variables into single array of object by trackable category
     * @param {String} category - trackable category
     * @param {Array<TrackableTemplates>} trackableTemplates - all trackable templates
     * @return {Array<TrackableTemplateVariable>}
     * @example [
     *      { "htmlType": "input", "label": "Serial number", "name": "serial_number", "required": true, "type": "text" }
     * ]
     */
    static getTemplatePropertyByCategory(category, trackableTemplates = []) {
        return trackableTemplates.reduce((memo, item) => {
            if (item.category === category) {
                item.variables.forEach((variable) => {
                    memo.push(variable);
                });
            }
            return memo;
        }, []);
    }

    /**
     * Extract all templates variables into single array of object
     * @param {Array<TrackableTemplates>} trackableTemplates - all trackable templates
     * @return {Array<TrackableTemplateVariable>}
     * @example [
     *      { "htmlType": "input", "label": "Serial number", "name": "serial_number", "required": true, "type": "text" }
     * ]
     */
    static getTemplateProperty(trackableTemplates = []) {
        return trackableTemplates.reduce((memo, item) => {
            item.variables.forEach((variable) => {
                memo.push(variable);
            });
            return memo;
        }, []);
    }
}