import { setRolesToUser } from 'utils/utils';

export default class User {
    constructor(user) {
        this.uid = user.uid;
        this.email = user.email;
        this.first_name = user.first_name;
        this.last_name = user.last_name;
        this.sign_in_count = user.sign_in_count;
        this.last_sign_in_at = user.last_sign_in_at;
        this.project_uid = user.project_uid || null;
        this.company_uid = user.company_uid || null;
        this.created_at = user.created_at;
        this.updated_at = user.updated_at;
        this.role = user.user_role || user.role;
        // default values by validation schema
        this.user_details = user.user_details || {};
    }

    #getFullName() {
        const hasSpace = !!(this.first_name && this.last_name);
        if (hasSpace) return this.first_name + ' ' + this.last_name;
        return this.first_name || this.last_name || '';
    }
    
    getProperties() {
        return { ...this };
    }
    
    belongToProject(project) {
        return this.project_uid === project?.uid;
    }
    
    getFormattedSuperAdminUser() {
        return { ...this, name: this.#getFullName() };
    }
    
    getFormattedUser(project) {
        const formattedUser = { ...this };
        formattedUser.name = this.#getFullName();
        formattedUser.roles = setRolesToUser(formattedUser);
        formattedUser.phone_number = (this.user_details && this.user_details.phone_number) || '';
        formattedUser.role = this.role;
        formattedUser.project_uid = this.project_uid || '';
        formattedUser.project = project?.name || '';

        return formattedUser;
    }
    
    static getAllUsers = state => Object.values(state.entities.users.byUid);
}
