import { createStore, applyMiddleware, compose } from 'redux';
import { routerMiddleware } from 'connected-react-router';
import thunk from 'redux-thunk';
import createSagaMiddleware from 'redux-saga';
import { createLogger } from 'redux-logger';
import { createBrowserHistory } from 'history';
import { SERVER_CONFIG, CUSTOM_LOCAL_STORE_KEYS } from 'common/constants';
import reducers from 'stores/reducers';
import { getLocalStorageValue } from 'utils/browserStorage';
import { stringToBoolean } from 'utils/utils';
import { cookiesNotEnabledOpen, cookiesNotEnabledClose } from 'stores/actions/modalActions/authActions';
import rootSagas from 'stores/sagas';

const composeEnhancer = window.REDUX_DEVTOOLS_EXTENSION_COMPOSE || compose;

export const history = createBrowserHistory({
    basename: `${process.env.PUBLIC_PATH || ''}/#`,
    forceRefresh: false,
});

const sagaMiddleware = createSagaMiddleware();

const checkForCookieMiddleware = store => next => (action) => {
    if (!navigator.cookieEnabled) {
        if (!store.getState().modals.authModals.cookies.open) {
            next(cookiesNotEnabledOpen());
        }
    } else {
        if (store.getState().modals.authModals.cookies.open && action.type !== cookiesNotEnabledClose().type) {
            store.dispatch(cookiesNotEnabledClose());
            // if it have not hostName yet -> state before login and do reload (for setting up application)
            // because before, when cookie was disable - setting up could not happen
            if (!store.getState().appContext.hostName) {
                location.reload();
            }
        }
        next(action);
    }
};

const middlewares = [thunk, routerMiddleware(history), checkForCookieMiddleware, sagaMiddleware];

if (stringToBoolean(getLocalStorageValue(CUSTOM_LOCAL_STORE_KEYS.REDUX_LOGGER))) {
    middlewares.push(createLogger());
}

function configureStore() {
    const store = createStore(
        reducers(history, {}),
        composeEnhancer(applyMiddleware(...middlewares)),
    );
    
    sagaMiddleware.run(rootSagas);
    
    store.addonsReducers = {};
    
    store.injectReducer = (key, reducer) => {
        store.addonsReducers[key] = reducer;
        store.replaceReducer(reducers(history, store.addonsReducers));
    };
    
    return store;
}

export const store = configureStore();

