import { NOTIFY_ACTIONS } from 'worker';
import { ACTIONS, ALARM_STATES } from 'common/constants';
import Alarm from 'stores/classes/Alarm';

const initialState = [];

const alarmSet = (state, elem) => {
    if (state.find(x => x.uid === elem.uid)) {
        return state;
    }
    return [...state, new Alarm(elem)];
};

const alarmClear = (state, elem) => {
    const nextState = [];
    state.forEach((alarm) => {
        if (alarm.uid !== elem.uid) {
            nextState.push(alarm);
        }
    });
    return nextState;
};

const alarmClearOnObject = (state, obj_uid) => {
    const nextState = [];
    state.forEach((alarm) => {
        if (alarm.obj_uid !== obj_uid) {
            nextState.push(alarm);
        }
    });
    return nextState;
};


const alarms = (state = initialState, action) => {
    switch (action.type) {
        case ACTIONS.ALARMS_SET:
            return action.params.map(alarm => new Alarm(alarm));
        case ACTIONS.ALARMS_CLEAR:
            return [...initialState];
        case NOTIFY_ACTIONS.ALARM_SET:
            return alarmSet(state, action.params);
        case ACTIONS.ALARM_CLEAR:
        case ACTIONS.ALARM_ACKNOWLADGE:
            return alarmClear(state, action.params);
        case NOTIFY_ACTIONS.ALARMS: {
            let newState = [...state];
            action.params
                .sort((a, b) => a.timestamp - b.timestamp)
                .forEach((elem) => {
                    if (elem.state.toLowerCase() === ALARM_STATES.CLEAR) {
                        newState = alarmClear(newState, elem);
                    } else if (elem.state.toLowerCase() === ALARM_STATES.SET) {
                        newState = alarmSet(newState, elem);
                    }
                });
            return newState;
        }
        case NOTIFY_ACTIONS.TRACKABLE_OBJECT_DELETED:
        case ACTIONS.TRACKABLE_DELETE:
            return alarmClearOnObject(state, action.params.uid);
        default:
            return state;
    }
};

export default alarms;
