import { NOTIFY_ACTIONS } from 'worker';
import { ACTIONS } from 'common/constants';
import Association from 'stores/classes/Association';
import { getNotifyParams } from 'utils/storeUtils';

const initialState = {
    byObjUid: {},
    byMac: {},
};

function makeStateCopy(state) {
    return {
        byObjUid: { ...state.byObjUid },
        byMac: { ...state.byMac },
    };
}

const associations = (state = initialState, action) => {
    switch (action.type) {
        case ACTIONS.TRACKABLES_ASSOCIATION_SET: {
            const newState = { byObjUid: {}, byMac: {} };
            action.params.forEach((association) => {
                newState.byObjUid[association.obj_uid] = new Association(association);
                newState.byMac[association.mac_address.toUpperCase()] = association.obj_uid;
            });
            
            return newState;
        }
        case ACTIONS.TRACKABLES_ASSOCIATION_CLEAR:
            return { ...initialState };
        case NOTIFY_ACTIONS.TRACKABLE_OBJECT_ASSOCIATION_CREATED:
        case ACTIONS.TRACKABLES_ASSOCIATION_CREATE: {
            const newState = makeStateCopy(state);
            const params = getNotifyParams(action);
            params.forEach((param) => {
                newState.byObjUid[param.obj_uid] = new Association(param);
                newState.byMac[param.mac_address.toUpperCase()] = param.obj_uid;
            });

            return newState;
        }
        case NOTIFY_ACTIONS.TRACKABLE_OBJECT_ASSOCIATION_UPDATED: {
            const newState = makeStateCopy(state);
            const params = getNotifyParams(action);
            params.forEach((param) => {
                const unassignTrackableUid = newState.byMac[param.mac_address.toUpperCase()];
                const removed = new Date(param.removed_at).getTime() <= new Date().getTime();

                if (removed) {
                    delete newState.byObjUid[param.obj_uid];
                    delete newState.byMac[param.mac_address.toUpperCase()];
                } else if (unassignTrackableUid) {
                    delete newState.byObjUid[unassignTrackableUid];
                    newState.byObjUid[param.obj_uid] = new Association(param);
                    newState.byMac[param.mac_address.toUpperCase()] = param.obj_uid;
                } else {
                    delete newState.byObjUid[param.trob_uid];
                    newState.byObjUid[param.obj_uid] = new Association(param);
                    newState.byMac[param.mac_address.toUpperCase()] = param.obj_uid;
                }
            });
            return newState;
        }
        case ACTIONS.TRACKABLES_ASSOCIATION_CLOSE: {
            const newState = makeStateCopy(state);
            const params = getNotifyParams(action);
            params.forEach((param) => {
                const association = newState.byObjUid[param.obj_uid];

                if (association) {
                    delete newState.byObjUid[association.obj_uid];
                    delete newState.byMac[association.mac_address.toUpperCase()];
                }
            });
            return newState;
        }
        default:
            return state;
    }
};

export default associations;
