import { NOTIFY_ACTIONS } from 'worker';
import { ACTIONS } from 'common/constants';
import Company from 'stores/classes/Company';
import { getNotifyParams } from 'utils/storeUtils';

const initialState = [];

const companies = (state = initialState, action) => {
    switch (action.type) {
        case ACTIONS.COMPANIES_SET:
            return action.params.map(company => new Company(company));
        case ACTIONS.COMPANIES_CLEAR:
            return [...initialState];
        case NOTIFY_ACTIONS.COMPANY_UPDATED:
        case ACTIONS.COMPANY_UPDATE: {
            const params = getNotifyParams(action);
            return state.map((company) => {
                const param = params.find(_param => _param.uid === company.uid);
                if (param) {
                    return new Company(param);
                }
                return company;
            });
        }
        case NOTIFY_ACTIONS.COMPANY_CREATED:
        case ACTIONS.COMPANY_CREATE: {
            const newState = [...state];
            const params = getNotifyParams(action);
            params.forEach((param) => {
                newState.push(new Company(param));
            });
            return newState;
        }

        case NOTIFY_ACTIONS.COMPANY_DELETED:
        case ACTIONS.COMPANY_DELETE: {
            const params = getNotifyParams(action);
            return state.filter((company) => {
                const param = params.find(_param => _param.uid === company.uid);
                return !param;
            });
        }
        default:
            return state;
    }
};

export default companies;
