import { NOTIFY_ACTIONS } from 'worker';
import { ACTIONS } from 'common/constants';
import Project from 'stores/classes/Project';
import { getNotifyParams } from 'utils/storeUtils';

const initialState = [];

const projects = (state = initialState, action) => {
    switch (action.type) {
        case ACTIONS.PROJECTS_SET:
            return action.params.map(project => new Project(project));
        case ACTIONS.PROJECTS_CLEAR:
            return [...initialState];
        case NOTIFY_ACTIONS.PROJECT_UPDATED:
        case ACTIONS.PROJECTS_UPDATE: {
            const params = getNotifyParams(action);
            return state.map((project) => {
                const param = params.find(_param => _param.uid === project.uid);
                if (param) {
                    return new Project(param);
                }
                return project;
            });
        }
        case NOTIFY_ACTIONS.PROJECT_CREATED:
        case ACTIONS.PROJECTS_CREATE: {
            const newState = [...state];
            const params = getNotifyParams(action);
            params.forEach((param) => {
                newState.push(new Project(param));
            });
            return newState;
        }
        case NOTIFY_ACTIONS.PROJECT_DELETED:
        case ACTIONS.PROJECTS_DELETE: {
            const params = getNotifyParams(action);
            return state.filter((project) => {
                const param = params.find(_param => _param.uid === project.uid);
                return !param;
            });
        }
        default:
            return state;
    }
};

export default projects;
