import { NOTIFY_ACTIONS } from 'worker';
import { ACTIONS } from 'common/constants';
import WinAnchor from 'stores/classes/WinAnchor';
import { getNotifyParams } from 'utils/storeUtils';

const initialState = {
    byUid: {},
    shouldNotCheckStatus: true,
};

function makeStateCopy(state) {
    return {
        ...state,
        byUid: { ...state.byUid },
    };
}

const winAnchors = (state = initialState, action) => {
    switch (action.type) {
        case ACTIONS.WIN_ANCHORS_SET: {
            const newState = makeStateCopy(state);
            action.params.forEach((winAnchor) => {
                newState.byUid[winAnchor.uid] = new WinAnchor(winAnchor);
            });
            return newState;
        }
        case NOTIFY_ACTIONS.WIN_ANCHOR_CREATED:
        case NOTIFY_ACTIONS.WIN_ANCHOR_UPDATED: {
            const newState = makeStateCopy(state);
            const params = getNotifyParams(action);
            params.forEach((param) => {
                newState.byUid[param.uid] = new WinAnchor(param);
            });
            return newState;
        }
        case NOTIFY_ACTIONS.WIN_ANCHOR_DELETED: {
            const newState = makeStateCopy(state);
            const params = getNotifyParams(action);
            params.forEach((param) => {
                delete newState.byUid[param.uid];
            });
            return newState;
        }
        case ACTIONS.WIN_ANCHORS_CHECK_STATE: {
            const newState = makeStateCopy(state);
            newState.shouldNotCheckStatus = false;
            return newState;
        }
        case ACTIONS.WIN_ANCHORS_CLEAR: {
            return { ...initialState };
        }
        default:
            return state;
    }
};

export default winAnchors;
