import { NOTIFY_ACTIONS } from 'worker';
import { ACTIONS } from 'common/constants';
import Zone from 'stores/classes/Zone';
import { getNotifyParams } from 'utils/storeUtils';

const initialState = {
    byUid: {},
};

function makeStateCopy(state) {
    return {
        byUid: { ...state.byUid },
    };
}

const zones = (state = initialState, action) => {
    switch (action.type) {
        case ACTIONS.ZONES_SET: {
            const newState = { byUid: {} };
            action.params.forEach((zone) => {
                newState.byUid[zone.uid] = new Zone(zone);
            });
            
            return newState;
        }
        case ACTIONS.ZONES_CLEAR:
            return { ...initialState };
        case NOTIFY_ACTIONS.ZONE_CREATED:
        case ACTIONS.ZONE_CREATE: {
            const newState = makeStateCopy(state);
            const params = getNotifyParams(action);
            params.forEach((param) => {
                newState.byUid[param.uid] = new Zone(param);
            });

            return newState;
        }
        case NOTIFY_ACTIONS.ZONE_UPDATED:
        case ACTIONS.ZONE_UPDATE: {
            const newState = makeStateCopy(state);
            const params = getNotifyParams(action);
            params.forEach((param) => {
                newState.byUid[param.uid] = new Zone(param);
            });
            
            return newState;
        }
        case NOTIFY_ACTIONS.ZONE_DELETED:
        case ACTIONS.ZONE_DELETE: {
            const newState = makeStateCopy(state);
            const params = getNotifyParams(action);
            params.forEach((param) => {
                delete newState.byUid[param.uid];
            });

            return newState;
        }
        default:
            return state;
    }
};


export default zones;
