import { ACTIONS } from 'common/constants';


const initialState = {
    lastPath: '/logger',
    actions: null,
    messageProcessorState: null,
    serverDebuggerValue: null,
};

function tryParseJSON(value) {
    try {
        return JSON.parse(value);
    } catch (e) {
        return null;
    }
}

const loggerPage = (state = initialState, action) => {
    switch (action.type) {
        case ACTIONS.RELOAD_CONTEXT:
            return {
                ...state,
                lastPath: action.params.lastPath || initialState.lastPath,
            };
        case ACTIONS.LOGGER_PAGE_CHANGE_LAST_PATH: {
            return {
                ...state,
                lastPath: action.params.lastPath,
            };
        }
        case ACTIONS.LOGGER_PAGE_GET_LOGGER_STATUS: {
            return {
                ...state,
                serverDebuggerState: action.params.data.map(([key, value]) => ({ key, value })),
            };
        }
        case ACTIONS.LOGGER_GET_ACTIONS_FROM_DB: {
            const actions = action.params.data.map((a) => {
                if (a.created_by) {
                    a.created_by = tryParseJSON(a.created_by);
                }
                if (a.plist) {
                    a.plist = tryParseJSON(a.plist) || a.plist;
                }
                return a;
            });
            return {
                ...state,
                actions,
            };
        }
        case ACTIONS.LOGGER_GET_MESSAGE_PROCESSOR_MAP: {
            if (!action.params || !action.params.data || !action.params.data.messageProcessorMaps) {
                return state;
            }
            const { messageProcessorMaps } = action.params.data;
            
            const messageProcessorStateObject = Object.keys(messageProcessorMaps).reduce((r, key) => {
                if (key !== 'date') {
                    r[key] = messageProcessorMaps[key].map(value => ({ ...value[1], key: value[0] }));
                }
                return r;
            }, {});
    
            const messageProcessorMap = state.messageProcessorState || new Map();
            messageProcessorMap.set(messageProcessorMaps.date, messageProcessorStateObject);
            
            return {
                ...state,
                messageProcessorState: messageProcessorMap,
            };
        }
        case ACTIONS.ADMIN_PAGE_CLEAR:
            return { ...initialState };
        case ACTIONS.LOGGER_PAGE_UPDATE_VALUE: {
            return {
                ...state,
                serverDebuggerValue: action.params,
            };
        }
        case ACTIONS.LOGGER_PAGE_UPDATE_KEY: {
            return {
                ...state,
                serverDebuggerKey: action.params,
            };
        }
        default:
            return state;
    }
};

export default loggerPage;
