import { MODAL_ACTIONS } from 'common/constants';

const initialState = {
    open: false,
    saving: false,
    savingError: false,
    assignedItems: [],
    selectedTrackableMap: {},
    selectedMacAddressMap: {},
    idxMacAddressMap: {},
    idxTrackableMap: {},
    savedCount: 0,
};

function calculateMaps(assignedItems) {
    return (assignedItems || []).reduce((memo, item, idx) => {
        const { mac_address, trackable_uid } = item;
        if (mac_address) {
            memo.selectedMacAddressMap[mac_address.toUpperCase()] = !!mac_address;
            memo.idxMacAddressMap[idx] = mac_address.toUpperCase();
        }
        if (trackable_uid) {
            memo.selectedTrackableMap[trackable_uid] = !!trackable_uid;
            memo.idxTrackableMap[idx] = trackable_uid;
        }
        return memo;
    }, { selectedTrackableMap: {}, selectedMacAddressMap: {}, idxTrackableMap: {}, idxMacAddressMap: {} });
}

const trackableBulkAssign = (state = initialState, action) => {
    switch (action.type) {
        case MODAL_ACTIONS.MODAL_OPEN_BULK_TRACKABLE_ASSIGN: {
            const newState = { ...state, assignedItems: [...state.assignedItems], open: true };
            for (const idx in action.params) {
                const item = action.params[idx];
                newState.selectedTrackableMap[item.uid] = true;
                newState.idxTrackableMap[idx] = item.uid;
                newState.assignedItems[idx] = { trackable_uid: item.uid };
            }
            return newState;
        }
        case MODAL_ACTIONS.MODAL_CLOSE_BULK_TRACKABLE_ASSIGN: {
            return { ...initialState };
        }
        case MODAL_ACTIONS.MODAL_BULK_TRACKABLE_ASSIGN_SUBMITTED: {
            return { ...state, saving: true };
        }
        case MODAL_ACTIONS.MODAL_BULK_TRACKABLE_ASSIGN_ADD_ASSIGN_ITEM: {
            return { ...state, assignedItems: [...state.assignedItems, { trackable_uid: null, mac_address: null }] };
        }
        case MODAL_ACTIONS.MODAL_BULK_TRACKABLE_ASSIGN_REMOVE_ASSIGN_ITEM: {
            const assignedItems = state.assignedItems.filter((_, idx) => idx !== action.params);
            const assocMaps = calculateMaps(assignedItems);

            return { ...state, assignedItems, ...assocMaps};
        }
        case MODAL_ACTIONS.MODAL_BULK_TKO_ASSIGN_UPDATE_TKO: {
            const { trackable_uid, index } = action.params;
            const newState = { ...state, assignedItems: [...state.assignedItems] };
            newState.assignedItems[index] = {...newState.assignedItems[index], trackable_uid};

            if (!trackable_uid) {
                const tko_uid = newState.idxTrackableMap[index];
                delete newState.idxTrackableMap[index];
                delete newState.selectedTrackableMap[tko_uid];
            } else {
                newState.idxTrackableMap[index] = trackable_uid;
                newState.selectedTrackableMap[trackable_uid] = true;
            }
            return newState;
        }
        case MODAL_ACTIONS.MODAL_BULK_TKO_ASSIGN_UPDATE_MAC: {
            const { mac_address, index } = action.params;
            const newState = { ...state, assignedItems: [...state.assignedItems] };

            newState.assignedItems[index] = {...newState.assignedItems[index], mac_address};
            if (!mac_address) {
                const mac = newState.idxMacAddressMap[index];
                delete newState.idxMacAddressMap[index];
                delete newState.selectedMacAddressMap[mac];
            } else {
                newState.idxMacAddressMap[index] = mac_address.toUpperCase();
                newState.selectedMacAddressMap[mac_address.toUpperCase()] = true;
            }
            return newState;
        }
        case MODAL_ACTIONS.MODAL_CLOSE_BULK_TRACKABLE_HANDLE_ERROR: {
            const assignedItems = state.assignedItems.filter((item) => !action.params[item.trackable_uid]);
            const assocMaps = calculateMaps(assignedItems);

            const savedCount = action.params.size;
            return { ...state, assignedItems, ...assocMaps, saving: false, savingError: true, savedCount };
        }
        default:
            return state;
    }
};

export default trackableBulkAssign;
