import { NEAR_MISS_WORKER_METHODS } from 'near-miss-event/common/constants';
import { ACTIONS } from 'common/constants';


const initialState = {
    error: null,
    reportUid: null,
    displayFrom: null,
    displayTo: null,
    byUid: {},
    selectedNearMissMarker: null,
    popUpEvent: null,
};

function getStateCopy(state, reportUid) {
    if (reportUid) {
        return {
            ...state,
            byUid: {
                ...state.byUid,
                [reportUid]: {
                    ...state.byUid[reportUid],
                },
            },
        };
    }
    return {
        ...state,
        byUid: {
            ...state.byUid,
        },
    };
}

const nearMissReport = (state = initialState, action) => {
    switch (action.type) {
        case ACTIONS.CLEAR_NEAR_MISS_REPORT: {
            return { ...initialState };
        }
        case NEAR_MISS_WORKER_METHODS.SET_NEAR_MISS_EVENTS: {
            const { reportUid, events, timeLineMarkers } = action.params;
            const newState = getStateCopy(state, reportUid);
            newState.byUid[reportUid].ready = true;
            newState.byUid[reportUid].loading = false;
            newState.byUid[reportUid].events = events;
            if (timeLineMarkers) {
                newState.byUid[reportUid].timeLineMarkers = timeLineMarkers;
            }
            newState.isNearMissShowing = true;

            return newState;
        }
        case NEAR_MISS_WORKER_METHODS.SET_NEAR_MISS_PARAMS: {
            const { reportUid, options } = action.params;
            const newState = getStateCopy(state);
            newState.byUid[reportUid] = {
                ready: false, loading: true, ...options,
            };
            newState.reportUid = reportUid;
            newState.displayFrom = options.timeframe.dateFrom;
            newState.displayTo = options.timeframe.dateTo;
        
            return newState;
        }
        case NEAR_MISS_WORKER_METHODS.NEAR_MISS_ERROR: {
            const newState = getStateCopy(initialState);
            const { error } = action.params;
            newState.error = error;
            
            return newState;
        }
        case ACTIONS.NEAR_MISS_REPORT_CHANGE_DISPLAY_TIME_FRAME: {
            const newState = getStateCopy(state);
            const { displayFrom, displayTo } = action.params;
            newState.displayFrom = displayFrom;
            newState.displayTo = displayTo;
            
            return newState;
        }
        case ACTIONS.OPEN_NEAR_MISS_EVENT_MARKER_POPUP:
            return {
                ...state,
                popUpEvent: action.params,
                selectedNearMissMarker: action.params ? action.params.id : action.params,
            };
        default:
            return state;
    }
};

export default nearMissReport;
