import { ACTIONS } from 'common/constants';


const initialState = {
    status: 0,
    reportListLoading: false,
    reportLoading: false,
    error: null,
    tableData: [],
    uid: null,
    report: null,
    reports: [],
    filter: { },
};

const trackableDistanceReport = (state = initialState, action) => {
    switch (action.type) {
        case ACTIONS.SET_DISTANCE_REPORT_LIST: {
            return {
                ...initialState,
                filter: {
                    ...state.filter,
                },
                reports: action.params,
                reportListLoading: false,
            };
        }
        case ACTIONS.LOADING_DISTANCE_REPORT_LIST: {
            return {
                ...initialState,
                tableData: [...state.tableData],
                filter: { ...state.filter },
                reportListLoading: true,
            };
        }
        case ACTIONS.LOADING_DISTANCE_REPORT: {
            return {
                ...initialState,
                tableData: [...state.tableData],
                reports: [...state.reports],
                filter: { ...state.filter },
                reportLoading: true,
            };
        }
        case ACTIONS.SET_DISTANCE_REPORT: {
            const status = action.params.status ? action.params.status : state.status;
            return {
                ...state,
                status,
                reportLoading: false,
                tableData: action.params.data.trackables,
                uid: action.params.uid,
                report: {
                    from: action.params.from,
                    to: action.params.to,
                    from_iso: action.params.from_iso,
                    to_iso: action.params.to_iso,
                    shift_name: action.params.shift_name,
                    site_name: action.params.site_name,
                    site_uid: action.params.site_uid,
                    ranges: action.params.data.ranges,
                },
            };
        }
        case ACTIONS.CLEAR_DISTANCE_REPORT:
            return {
                ...initialState,
                reports: [...state.reports],
                reportListLoading: false,
                filter: {
                    ...state.filter,
                },
            };
        case ACTIONS.SET_DISTANCE_REPORT_ERROR: {
            return {
                ...initialState,
                error: action.params,
                reportListLoading: false,
                reportLoading: false,
            };
        }
        case ACTIONS.SET_DISTANCE_REPORT_DATE:
        case ACTIONS.ADVANCED_SELECT_TRACKABLE_DISTANCE_REPORT: {
            return {
                ...state,
                filter: {
                    ...state.filter,
                    ...action.params,
                },
            };
        }
        default:
            return state;
    }
};

export default trackableDistanceReport;
