import { ACTIONS } from 'common/constants';

const initialState = {
    selectedLocation: null,
    selectedSublocation: null,
    selectedFloorplan: null,
    selectedItems: [],
    clusterTrackables: [],
    selectedCluster: null,
    selectedTab: 0,
    selectedLeafletElement: null, // for showing popup on anchor layer
    
    isOpenSideBar: true,
    
    isAlarmsDismissed: false,
    
    height: 50,
    mode: null,
    geometry: {
        zoneGeometryInDegrees: [],
        zoneGeometryInMillimeters: [],
        restriction: [],
        zone_type_name: '',
    },
    rotation: 0,
    width: 2,
    // {func, args}
    lastMode: null,
};

const siteView = (state = initialState, action) => {
    let isExist;
    switch (action.type) {
        case ACTIONS.RELOAD_CONTEXT: {
            const { selectedLocation, selectedSublocation, selectedFloorplan, selectedTab, isOpenSideBar } = action.params;
            return {
                ...state,
                selectedLocation: selectedLocation || initialState.selectedLocation,
                selectedSublocation: selectedSublocation || initialState.selectedSublocation,
                selectedFloorplan: selectedFloorplan || initialState.selectedFloorplan,
                selectedTab: selectedTab || initialState.selectedTab,
                isOpenSideBar,
            };
        }
        case ACTIONS.SITE_VIEW_SELECT_LOCATION:
            return { ...state, ...action.params };
        case ACTIONS.SITE_VIEW_SELECT_SUBLOCATION:
            return { ...state, ...action.params };
        case ACTIONS.SITE_VIEW_SELECT_FLOORPLAN:
            return { ...state, ...action.params };
        case ACTIONS.SITE_VIEW_SELECT_TAB:
            return { ...state, ...action.params };
        case ACTIONS.SITE_VIEW_CHANGE_PARAMS:
            return { ...state, ...action.params };
        case ACTIONS.SITE_VIEW_SET_CLUSTER_TRUCKABLES: {
            return { ...state, clusterTrackables: action.params };
        }
        case ACTIONS.SITE_VIEW_SET_CLUSTER_POP_UP: {
            return { ...state, selectedCluster: action.params };
        }
        case ACTIONS.SITE_VIEW_CHANGE_SELECTED_ITEMS: {
            let selectedItems = [];
            
            isExist = state.selectedItems.find((item) => item.uid === action.params.uid);
            
            if (isExist) {
                state.selectedItems.forEach((item) => {
                    if (item.uid !== action.params.uid) {
                        selectedItems.push(item);
                    }
                });
            } else {
                selectedItems = [...state.selectedItems, action.params];
            }
            
            return {
                ...state,
                selectedItems,
            };
        }
        case ACTIONS.SITE_VIEW_SELECT_ITEMS: {
            const selectedItems = [];
            
            state.selectedItems.forEach((storeItem) => {
                const storeHasItem = action.params.find((selectedItem) => storeItem.uid === selectedItem.uid);
                if (!storeHasItem) {
                    selectedItems.push(storeItem);
                }
            });
            
            selectedItems.push(...action.params);
            
            return {
                ...state,
                selectedItems,
            };
        }
        case ACTIONS.SITE_VIEW_UNSELECT_ITEMS: {
            const selectedItems = [];
            
            state.selectedItems.forEach((item) => {
                const alreadyExist = action.params.find((unselectItem) => unselectItem.uid === item.uid);
                
                if (!alreadyExist) {
                    selectedItems.push(item);
                }
            });
            
            return {
                ...state,
                selectedItems,
            };
        }
        case ACTIONS.SITE_VIEW_CHANGE_OPENING_SIDE_BAR:
            return {
                ...state,
                isOpenSideBar: !state.isOpenSideBar,
            };
        case ACTIONS.SITE_VIEW_SELECTED_LEAFLET_ELEMENT:
            return {
                ...state,
                selectedLeafletElement: action.params,
            };
        case ACTIONS.SITE_VIEW_ADD_CREATED_GEOMETRY: {
            const { zoneGeometryInDegrees, zoneGeometryInMillimeters } = action.params;
            return {
                ...state,
                geometry: {
                    ...state.geometry,
                    zoneGeometryInDegrees,
                    zoneGeometryInMillimeters,
                },
            };
        }
        case ACTIONS.SITE_VIEW_ADD_CREATED_GEOMETRY_RESTRICTION: {
            return {
                ...state,
                geometry: {
                    ...state.geometry,
                    restriction: action.params,
                },
            };
        }
        case ACTIONS.SITE_VIEW_ADD_CREATED_GEOMETRY_TYPE: {
            return {
                ...state,
                geometry: {
                    ...state.geometry,
                    zone_type_name: action.params,
                },
            };
        }
        case ACTIONS.SITE_VIEW_ROTATE_CREATED_GEOMETRY: {
            return {
                ...state,
                rotation: action.params,
            };
        }
        case ACTIONS.SITE_VIEW_SET_ZONE_WIDTH: {
            return {
                ...state,
                width: action.params,
            };
        }
        case ACTIONS.HEATMAP_CLEAR:
        case ACTIONS.SITE_VIEW_CLEAR_CREATED_MODE: {
            return {
                ...state,
                rotation: initialState.rotation,
                mode: initialState.mode,
                geometry: initialState.geometry,
            };
        }
        case ACTIONS.SITE_VIEW_CLEAR_MODE:
            return {
                ...state,
                mode: initialState.mode,
            };
        case ACTIONS.SITE_VIEW_CLEAR:
            return { ...initialState };
        case ACTIONS.SET_LAST_MODE: {
            return {
                ...state,
                lastMode: action.params,
            };
        }
        case ACTIONS.CLEAR_LAST_MODE: {
            return {
                ...state,
                lastMode: null,
            };
        }
        default:
            return state;
    }
};

export default siteView;
