import _xor from 'lodash/xor';
import { WORKER_METHODS } from 'worker/common/constants';
import { ACTIONS } from '../../common/constants';


const initialState = {
    error: null,
    spaghettiId: null,
    trackables: {},
    byId: {},
    isSpaghettiDiagramShowing: false,
    marker: null,
    filteredTrailUids: [],
    selectedIdleTimeMarker: null,
};

function getStateCopy(state, spaghettiId) {
    if (spaghettiId) {
        return {
            ...state,
            byId: {
                ...state.byId,
                [spaghettiId]: {
                    ...state.byId[spaghettiId],
                },
            },
        };
    }
    return {
        ...state,
        byId: {
            ...state.byId,
        },
    };
}

const spaghetti = (state = initialState, action) => {
    switch (action.type) {
        case ACTIONS.CLEAR_SPAGHETTI_DIAGRAM: {
            return {
                ...initialState,
                byId: { ...state.byId },
            };
        }
        case WORKER_METHODS.SPAGHETTI_POSITIONS: {
            const { trackables, spaghettiId, timeframe } = action.params;
            const newState = getStateCopy(state, spaghettiId);
            newState.byId[spaghettiId].ready = true;
            newState.byId[spaghettiId].loading = false;
            newState.byId[spaghettiId].error = null;
            newState.byId[spaghettiId].timeframe = timeframe;
            // preselection all trackables for trails filter if not set
            if (!newState.byId[spaghettiId].filteredTrailUids) {
                newState.byId[spaghettiId].filteredTrailUids = Object.values(trackables).map(to => to.uid);
            }
            newState.trackables = trackables;
            newState.marker = null;
            return newState;
        }
        case WORKER_METHODS.SET_SPAGHETTI_ID: {
            const { spaghettiId, options } = action.params;
            const newState = getStateCopy(state);
            newState.byId[spaghettiId] = {
                ready: false, loading: true, error: null, ...options,
            };
            newState.spaghettiId = spaghettiId;
        
            return newState;
        }
        case WORKER_METHODS.SPAGHETTI_ERROR: {
            const newState = getStateCopy(initialState);
            newState.error = action.params;
            
            return newState;
        }
        case ACTIONS.SPAGHETTI_DIAGRAM_CHANGE_VIEW_MODE:
            return {
                ...state,
                ...action.params,
            };
        case ACTIONS.SELECT_IDLE_TIME_MARKER:
            return {
                ...state,
                selectedIdleTimeMarker: action.params,
            };
        case ACTIONS.FILTERED_SPAGHETTI_DIAGRAM_TRAILS: {
            const { spaghettiId, filteredTrailUids } = action.params;
            const newState = getStateCopy(state, spaghettiId);
            const prevFilteredTrailUids = newState.byId[spaghettiId].filteredTrailUids || [];
            const currentFilteredTrailUids = Array.isArray(filteredTrailUids) ? filteredTrailUids : [filteredTrailUids];
            newState.byId[spaghettiId].filteredTrailUids = _xor(prevFilteredTrailUids, currentFilteredTrailUids);

            return newState;
        }
        default:
            return state;
    }
};

export default spaghetti;
