import { put } from 'redux-saga/effects';
import { push } from 'connected-react-router';
import { HTTP_STATUS, ERROR_MESSAGES, ACTIONS } from 'common/constants';
import { openErrorModal } from 'stores/actions/modalActions/commonModalActions';
import { LocationStoreMethods } from 'utils/browserStorage';
import { clearStoreData } from 'stores/actions/commonActions';


export default function* errorHandler(err) {
    const status = err.response && err.response.status;
    const message = err.response && err.response.data && err.response.data.message;
    if (status === HTTP_STATUS.UNAUTHORIZED_ERROR && ERROR_MESSAGES.TOKEN_EXPIRED === message) {
        console.warn(ERROR_MESSAGES.TOKEN_EXPIRED);

        LocationStoreMethods.clearUserParamsFromStorage();
        yield put(clearStoreData());
        yield put({ type: ACTIONS.USER_LOGOUT });
        yield put(push('/'));
        return;
    }

    if (status === HTTP_STATUS.TOO_MANY_REQUESTS) {
        const errMessage = 'We cannot reach the page at this time. Please try again later.';
        yield put(openErrorModal({ message: errMessage, title: 'Server is busy. Too many requests.' }));
    } else {
        console.error('UnknownError');
        console.error(err);
    }
}
