import { select, delay, fork, takeEvery, call, put, all } from 'redux-saga/effects';
import * as api from 'api';

import { ACTIONS, DEFAULT_VALUES, SAGA_ACTIONS } from 'common/constants';
import { TRACKABLE_DELETE_MODAL } from 'common/ui-labels';
import { closeStatusNotificationPopup, openStatusNotificationPopup } from 'stores/actions/modalActions/commonModalActions';
import { closeTrackableDeleteModal } from 'stores/actions/modalActions/trackableModalActions';
import { deleteSingleZone, loadZones } from 'stores/sagas/zone/zoneSagas';
import { trackableByUid, associationByToUid } from 'stores/sagas/selectors';
import errorHandler from 'stores/sagas/commonSaga';


export function* deleteSingleTrackable(params) {
    try {
        const trackable = yield select(trackableByUid, params.uid);
        const association = yield select(associationByToUid, trackable.uid);
    
        if (trackable.self_zone_uid) {
            yield call(deleteSingleZone, trackable.self_zone_uid);
        }
    
        yield call(api.deleteTrackable, params);
    
        if (association) {
            yield put({ type: ACTIONS.TRACKABLES_ASSOCIATION_CLOSE, params: association });
        }
    
        yield put({ type: ACTIONS.TRACKABLE_DELETE, params });
    } catch (err) {
        console.error(err);
        yield call(errorHandler, err);
    }
}

export function* deleteTrackable(action) {
    try {
        const { deleteParams, intl } = action.params;
        let message = '';
        let title = '';
        const status = DEFAULT_VALUES.SUCCESS_STATUS;

        if (deleteParams.uid) {
            message = TRACKABLE_DELETE_MODAL.CONFIRM_MODAL.MESSAGE_SINGLE_FUNC(intl);
            title = TRACKABLE_DELETE_MODAL.CONFIRM_MODAL.TITLE_SINGLE_FUNC(intl, deleteParams.name);

            yield call(deleteSingleTrackable, deleteParams);
        } else {
            let trackableNames = '';
            yield all(deleteParams.map((trackable) => {
                trackableNames += `${trackable.name} `;
                return call(deleteSingleTrackable, trackable);
            }));

            message = TRACKABLE_DELETE_MODAL.CONFIRM_MODAL.MESSAGE_MULTI_FUNC(intl, trackableNames);
            title = TRACKABLE_DELETE_MODAL.CONFIRM_MODAL.TITLE_MULTI_FUNC(intl);
        }
        
        yield call(loadZones);
        yield put(closeTrackableDeleteModal());
        yield put(openStatusNotificationPopup({ title, message, status }));
        yield delay(3000);
        yield put(closeStatusNotificationPopup());
    } catch (err) {
        console.error(err);
        yield call(errorHandler, err);
    }
}


function* watchDeleteTrackable() {
    yield takeEvery(SAGA_ACTIONS.SAGA_TRACKABLES_DELETE, deleteTrackable);
}

export default function* trackableDeleteSaga() {
    return yield all([
        fork(watchDeleteTrackable),
    ]);
}
