import { takeEvery, all, fork, select, call, put } from 'redux-saga/effects';
import * as api from 'api';

import { ACTIONS, SAGA_ACTIONS } from 'common/constants';
import errorHandler from 'stores/sagas/commonSaga';
import { trackableByUid } from 'stores/sagas/selectors';

export function* replaceTrackableGroups(params) {
    try {
        const trackable = yield select(trackableByUid, params.uid);
        const groupList = params.groupList.map((group) => group.uid);
        yield call(api.replaceTrackableGroups, trackable, groupList, false);

        trackable.groups = groupList;
        trackable.default_height = trackable.default_height * 1000;

        yield put({ type: ACTIONS.TRACKABLE_UPDATE, params: trackable });
    } catch (err) {
        console.error(err);
        yield call(errorHandler, err);
    }
}

function* loadTrackables() {
    try {
        const trackables = yield call(api.loadTrackObjects);
        yield put({ type: ACTIONS.TRACKABLES_SET, params: trackables });
    } catch (err) {
        console.error(err);
        yield call(errorHandler, err);
    }
}

function* loadCompanyTrackables() {
    try {
        const trackables = yield call(api.loadCompanyTrackObjects);
        yield put({ type: ACTIONS.TRACKABLES_SET, params: trackables });
    } catch (err) {
        console.error(err);
        yield call(errorHandler, err);
    }
}

function* watchLoadTrackables() {
    yield takeEvery(SAGA_ACTIONS.SAGA_TRACKABLES_LOAD, loadTrackables);
}

function* watchLoadCompanyTrackables() {
    yield takeEvery(SAGA_ACTIONS.SAGA_TRACKABLES_COMPANY_LOAD, loadCompanyTrackables);
}

export function* trackablesSagas() {
    return yield all([
        fork(watchLoadTrackables),
        fork(watchLoadCompanyTrackables),
    ]);
}
