import { all, fork, call, put, takeEvery, select } from 'redux-saga/effects';
import { SAGA_ACTIONS } from 'common/constants';
import { formatZoneGeometryOnCreate } from 'common/formatters/zoneFormatters';
import { formatCreatedZone } from 'utils/zoneUtils';
import { clearZoneChooseGeometryModal, closeZoneAddConfigurationModal, closeZoneCreateAdminPageModal } from 'stores/actions/modalActions/zoneModalActions';
import { siteViewClearMode } from 'stores/actions/siteViewActions';
import { createZone } from 'stores/sagas/zone/zoneSagas';
import { groupsMap, trackablesMap, zonePrototypeList } from 'stores/sagas/selectors';
import errorHandler from 'stores/sagas/commonSaga';


function* createSitePageZone(action) {
    try {
        const trackables = yield select(trackablesMap);
        const groups = yield select(groupsMap);
        const zone = action.params;
        const zonesPrototypes = yield select(zonePrototypeList); // store.getZonesPrototypes(); //

        const newZone = yield call(formatCreatedZone, zonesPrototypes, { ...zone, ...zone.params }, { zone_geometry: zone.params.zone_geometry }, trackables, groups);
        yield call(createZone, newZone);
        yield put(closeZoneAddConfigurationModal());
        yield put(clearZoneChooseGeometryModal());
    } catch (err) {
        yield call(errorHandler, err);
    }
}

function* createAdminPageZone(action) {
    try {
        const trackables = yield select(trackablesMap);
        const groups = yield select(groupsMap);
        const zonesPrototypes = yield select(zonePrototypeList); // store.getZonesPrototypes(); //
        const zone = action.params;
        const zone_geometry = {
            positions: [],
        };
        if (action.params.coordinateMode) {
            zone_geometry.positions = Object.values(action.params.geometry.vertices).map(pos => ({
                x: pos.x,
                y: pos.y,
            }));
        } else {
            zone_geometry.positions = yield call(formatZoneGeometryOnCreate, zone.geometry, zone.rotation, zone.width);
        }

        const newZone = yield call(formatCreatedZone, zonesPrototypes, zone, { zone_geometry }, trackables, groups);

        yield call(createZone, newZone);
        yield put(closeZoneCreateAdminPageModal());
        yield put(siteViewClearMode());
    } catch (err) {
        yield call(errorHandler, err);
    }
}


function* watchCreateSitePageZone() {
    yield takeEvery(SAGA_ACTIONS.SAGA_ZONES_CREATE_SITE_PAGE, createSitePageZone);
}

function* watchCreateAdminPageZone() {
    yield takeEvery(SAGA_ACTIONS.SAGA_ZONES_CREATE_ADMIN_PAGE, createAdminPageZone);
}

export default function* zoneCreateSaga() {
    return yield all([
        fork(watchCreateSitePageZone),
        fork(watchCreateAdminPageZone),
    ]);
}
