import { ALARM_NAMES } from 'common/constants';
import { durationHumanize } from 'utils/timeUtils';


export function getAlarms(state) {
    const isPlaybackOpen = (state.playback && state.playback.isOpenPlayBackControl);
    if (isPlaybackOpen) {
        return state.playback.alarms;
    }
    return state.entities.alarms;
}

function handleAlarmByType(data, alarm) {
    const trackable = data.trackables[alarm.trackable_uid];

    if (alarm.alarm_name === ALARM_NAMES.ZONE_VIOLATION || alarm.alarm_name === ALARM_NAMES.BUFFER_VIOLATION) {
        data.zoneViolations += 1;
        trackable.zoneViolations += 1;
        trackable.zoneViolationsDuration += alarm.duration;
    } else if (alarm.alarm_name === ALARM_NAMES.UNCERTIFIED_OPERATION) {
        data.uncertifiedOps += 1;
        trackable.uncertifiedOps += 1;
        trackable.uncertifiedOpsDuration += alarm.duration;
    } else if (alarm.alarm_name === ALARM_NAMES.EMERGENCY_BUTTON) {
        data.emergencyCalls += 1;
        trackable.emergencyCalls += 1;
        trackable.emergencyCallsDuration += alarm.duration;
    }

    return data;
}

export function aggregateDashboardAlarms(alarms) {
    return alarms.reduce((result, alarm) => {
        if (!result.trackables[alarm.trackable_uid]) {
            result.trackables[alarm.trackable_uid] = {
                uid: alarm.trackable_uid,
                name: alarm.trackable_name,
                category: alarm.trackable_category,
                zoneViolations: 0,
                emergencyCalls: 0,
                uncertifiedOps: 0,
                zoneViolationsDuration: 0,
                emergencyCallsDuration: 0,
                uncertifiedOpsDuration: 0,
            };
        }
        return handleAlarmByType(result, alarm);
    }, { trackables: {}, zoneViolations: 0, emergencyCalls: 0, uncertifiedOps: 0 });
}

export function formatDashboardAlarms(data) {
    const trackables = Object.values(data.trackables);

    return {
        zoneViolations: data.zoneViolations,
        emergencyCalls: data.emergencyCalls,
        uncertifiedOps: data.uncertifiedOps,
        trackables: trackables.map(trackable => ({
            ...trackable,
            zoneViolationsDuration: durationHumanize(trackable.zoneViolationsDuration),
            emergencyCallsDuration: durationHumanize(trackable.emergencyCallsDuration),
            uncertifiedOpsDuration: durationHumanize(trackable.uncertifiedOpsDuration),
        })),
    };
}
