import { openAuditDownloadModal } from 'stores/actions/modalActions/commonModalActions';
import { getLocalStorageValue } from 'utils/browserStorage';
import { CUSTOM_LOCAL_STORE_KEYS, ROUTES, ADMIN_TABS_ROUTES } from 'common/constants';
import {NAME_OF_GEAR_BUTTONS, NAMES_OF_TABS} from 'common/ui-labels';
import { ADMIN_PAGES, REPORT_PAGES, SYSTEM_PAGES, WIDGETS, LOGGER_PAGE_TABS, NAV_BUTTONS, USER_MENU_BUTTONS, USER_SUBMENU_BUTTONS } from 'common/pages';
import { USER_ROLES } from 'common/user-roles';
import { USER_SCOPE_KEYS, getCurrentUserScope } from 'common/scopes';
import { stringToBoolean, userHasPrivileges, userHasRoleCompanyAdmin } from 'utils/utils';
import { addModulesPageForUser, addModulesNavForUser } from 'utils/scopeAddons';
const { modules_list } = require('../../../features/featuresList');

export const getDashboardWidgets = (access) => {
    const widgets = [WIDGETS.CURRENT_SHIFT_WIDGET, WIDGETS.PERSON_ACTIVITY_WIDGET, WIDGETS.CURRENT_ALARMS_WIDGET];
    
    if (userHasPrivileges(access.currentRole, USER_ROLES.PROJECT_MAINTAINER)) {
        widgets.push(WIDGETS.WIN_STATUS_WIDGET);
    }
    return widgets;
};

const getSubPagesForRoute = (pages, route) => pages.find(page => page.path === route)
    ?.tabs
    ?.map(page => ({ label: page.name, dataCy: page.dataCy, to: page.path, iconClass: page.iconClass }));


/**
 * @function
 * @returns {Array<{
 *     path: String,
 *     tabs: Array<Object>
 * }>} - list of pages
 * */
function getPagesForSystemScope() {
    return [
        {
            path: ROUTES.ADMIN_ROUTE,
            tabs: [ADMIN_PAGES.COMPANIES, ADMIN_PAGES.SUPER_ADMIN_USERS],
        }
    ]
}

/**
 * @function
 * @returns {Array<Object>} - list of buttons
 * */
function getNavButtonsForSystemScope() {
    return [
            {
                label: NAMES_OF_TABS.COMPANIES,
                title: NAMES_OF_TABS.COMPANIES_TITLE,
                to: ADMIN_TABS_ROUTES.COMPANIES,
                dataCy: 'nav_menu_company',
                iconClass: 'fas fa-building',
            },
            {
                label: NAMES_OF_TABS.SUPER_ADMIN_USERS,
                title: NAMES_OF_TABS.SUPER_ADMIN_USERS_TITLE,
                to: ADMIN_TABS_ROUTES.SUPER_ADMIN_USERS,
                dataCy: 'nav_menu_super_admin',
                iconClass: 'fas fa-users',
            },
            {
                label: NAMES_OF_TABS.AUDIT_DOWNLOAD,
                title: NAMES_OF_TABS.AUDIT_DOWNLOAD_TITLE,
                dispatchAction: openAuditDownloadModal,
                dataCy: 'nav_menu_audit_download',
                iconClass: 'fas fa-download',
            },
    ]
}

/**
 * @function
 * @returns {Array<{
 *     path: String,
 *     tabs: Array<Object>
 * }>} - list of pages
 * */
function getPagesForCompanyScope() {
    return [
        {
            path: ROUTES.ADMIN_ROUTE,
            tabs: [ADMIN_PAGES.PROJECTS, ADMIN_PAGES.NODES],
        }
    ]
}

/**
 * @function
 * @returns {Array<Object>} - list of buttons
 * */
function getNavButtonsForCompanyScope() {
    return [
        {
            label: NAMES_OF_TABS.PROJECTS,
            title: NAMES_OF_TABS.PROJECTS_TITLE,
            to: ADMIN_TABS_ROUTES.PROJECTS,
            dataCy: 'nav_menu_project',
            iconClass: 'fas fa-project-diagram',
        },
        {
            label: NAMES_OF_TABS.NODES,
            title: NAMES_OF_TABS.NODES_TITLE,
            to: ADMIN_TABS_ROUTES.NODES,
            dataCy: 'nav_menu_nodes',
            iconClass: 'fas fa-tags',
        },
        {
            label: NAMES_OF_TABS.AUDIT_DOWNLOAD,
            title: NAMES_OF_TABS.AUDIT_DOWNLOAD_TITLE,
            dispatchAction: openAuditDownloadModal,
            dataCy: 'nav_menu_audit_download',
            iconClass: 'fas fa-download',
        },
    ]
}

/**
 * @function
 * @param {String} userRole - user role
 * @param {Boolean} hasHighChartLicense - flag indicating use gas HighChart license
 * @returns {Array<{
 *     path: String,
 *     tabs: Array<Object>
 * }>} - list of pages
 * */
function getPagesForProjectScope(userRole, hasHighChartLicense) {
    const pages = [];
    switch (userRole) {
        case USER_ROLES.PROJECT_SYSTEM_ADMIN: {
            pages.push({ path: ROUTES.ADMIN_ROUTE, tabs: [ADMIN_PAGES.USERS_PROJECT_SCOPE, ADMIN_PAGES.TRACKABLE_OBJECTS, ADMIN_PAGES.GROUPS, ADMIN_PAGES.ZONES, ADMIN_PAGES.NOTIFICATIONS, ADMIN_PAGES.SHIFTS, ADMIN_PAGES.NODES] });
            pages.push({ path: ROUTES.SYSTEM_ROUTE, tabs: [SYSTEM_PAGES.SERVER, SYSTEM_PAGES.ANCHORS] });
            pages.push({ path: ROUTES.SITE_ROUTE });
            pages.push({ path: ROUTES.DASHBOARD_ROUTE });

            if (hasHighChartLicense) {
                pages.push({ path: ROUTES.REPORTS_ROUTE, tabs: Object.values(REPORT_PAGES) });
            }
            return pages;
        }
        case USER_ROLES.PROJECT_OPERATIONS_ADMIN: {
            pages.push({ path: ROUTES.ADMIN_ROUTE, tabs: [ADMIN_PAGES.USERS_PROJECT_SCOPE, ADMIN_PAGES.TRACKABLE_OBJECTS, ADMIN_PAGES.GROUPS, ADMIN_PAGES.ZONES, ADMIN_PAGES.NOTIFICATIONS, ADMIN_PAGES.SHIFTS] });
            pages.push({ path: ROUTES.SYSTEM_ROUTE, tabs: [SYSTEM_PAGES.ANCHORS] });
            pages.push({ path: ROUTES.SITE_ROUTE });
            pages.push({ path: ROUTES.DASHBOARD_ROUTE });

            if (hasHighChartLicense) {
                pages.push({ path: ROUTES.REPORTS_ROUTE, tabs: Object.values(REPORT_PAGES) });
            }
            return pages;
        }
        case USER_ROLES.PROJECT_MAINTAINER: {
            pages.push({ path: ROUTES.ADMIN_ROUTE, tabs: [ADMIN_PAGES.USERS_PROJECT_SCOPE, ADMIN_PAGES.TRACKABLE_OBJECTS] });
            pages.push({ path: ROUTES.SYSTEM_ROUTE, tabs: [SYSTEM_PAGES.ANCHORS] });
            pages.push({ path: ROUTES.SITE_ROUTE });
            pages.push({ path: ROUTES.DASHBOARD_ROUTE });

            if (hasHighChartLicense) {
                pages.push({ path: ROUTES.REPORTS_ROUTE, tabs: Object.values(REPORT_PAGES) });
            }
            return pages;
        }
        case USER_ROLES.PROJECT_USER: {
            pages.push({ path: ROUTES.SITE_ROUTE }, { path: ROUTES.DASHBOARD_ROUTE });

            if (hasHighChartLicense) {
                pages.push({ path: ROUTES.REPORTS_ROUTE, tabs: Object.values(REPORT_PAGES) });
            }
            return pages;
        }
        default:
    }
    return pages;
}

/**
 * @function
 * @param {String} currentRole
 * @param {Array<Object>} navPages
 * @param {Boolean} hasHighChartLicense
 * @returns {Array<Object>}
* */
function getNavButtonsForProjectScope(currentRole, navPages, hasHighChartLicense) {
    const systemSubmenuPages = getSubPagesForRoute(navPages, ROUTES.SYSTEM_ROUTE) || [];
    const adminMenuPages = getSubPagesForRoute(navPages, ROUTES.ADMIN_ROUTE) || [];
    const reportsMenuPages = getSubPagesForRoute(navPages, ROUTES.REPORTS_ROUTE) || [];

    const navButtons = [NAV_BUTTONS.SITE, NAV_BUTTONS.DASHBOARD];
    switch (currentRole) {
        case USER_ROLES.PROJECT_SYSTEM_ADMIN:
            if (hasHighChartLicense) navButtons.push({ ...NAV_BUTTONS.REPORTS, submenu: reportsMenuPages });
            navButtons.push({ ...NAV_BUTTONS.ADMIN, submenu: adminMenuPages });
            navButtons.push({ ...NAV_BUTTONS.SYSTEM, submenu: [ ...systemSubmenuPages, NAV_BUTTONS.SYSTEM_SITE_MONITOR ] });
            return navButtons;
        case USER_ROLES.PROJECT_OPERATIONS_ADMIN:
        case USER_ROLES.PROJECT_MAINTAINER:
            if (hasHighChartLicense) navButtons.push({ ...NAV_BUTTONS.REPORTS, submenu: reportsMenuPages });
            navButtons.push({ ...NAV_BUTTONS.ADMIN, submenu: adminMenuPages });
            navButtons.push({ ...NAV_BUTTONS.SYSTEM, submenu: [ ...systemSubmenuPages ] });
            return navButtons;
        case USER_ROLES.PROJECT_USER:
        default:
            if (hasHighChartLicense) navButtons.push({ ...NAV_BUTTONS.REPORTS, submenu: reportsMenuPages });
            return navButtons;
    }
}

/**
 *
 * @param access
 * @returns Array{{
 *     path {string} - '/admin'
 *     tabs: {Array}
 *     tabs.name {string} - intl("PROJECTS")
 *     tabs.systemName {string} - 'PROJECTS'
 *     tabs.path {string} - '/admin/nodes'
 * }}
 */
export const getPagesForScope = (access) => {
    const pages = [];
    const { currentRole } = access;
    const currentScope = getCurrentUserScope(currentRole);

    switch (currentScope) {
        case USER_SCOPE_KEYS.SYSTEM_SCOPE:
            pages.push(...getPagesForSystemScope());
            break;
        case USER_SCOPE_KEYS.COMPANY_SCOPE:
            pages.push(...getPagesForCompanyScope());
            break;
        case USER_SCOPE_KEYS.PROJECT_SCOPE:
        default:
            pages.push(...getPagesForProjectScope(currentRole, access.isHighChartsLicensed));
    }
    
    if (stringToBoolean(getLocalStorageValue(CUSTOM_LOCAL_STORE_KEYS.SYSTEM_LOGGER))) {
        pages.push({
            path: ROUTES.LOGGER_ROUTE,
            tabs: [LOGGER_PAGE_TABS.MESSAGE_PROCESSOR, LOGGER_PAGE_TABS.API, LOGGER_PAGE_TABS.LEVELS, LOGGER_PAGE_TABS.LOGS, LOGGER_PAGE_TABS.ACTIVITIES, LOGGER_PAGE_TABS.DEBUG],
        });
    }
    // This function modify pages;
    addModulesPageForUser(access.currentRole || access, pages, modules_list);
    
    return pages;
};

/**
 * @param access
 * @returns Array{{
 *     label {string} intl string
 *     to {string?}
 *     iconClass {string}
 * }}
 */
export const getNavButtonsForScope = (access) => {
    const { currentRole } = access;
    const navButtons = [];
    const currentScope = getCurrentUserScope(currentRole);

    switch (currentScope) {
        case USER_SCOPE_KEYS.SYSTEM_SCOPE:
            navButtons.push(...getNavButtonsForSystemScope());
            break;
        case USER_SCOPE_KEYS.COMPANY_SCOPE:
            navButtons.push(...getNavButtonsForCompanyScope());
            break;
        case USER_SCOPE_KEYS.PROJECT_SCOPE:
        default:
            const navPages = getPagesForScope(access);
            navButtons.push(...getNavButtonsForProjectScope(currentRole, navPages, access.isHighChartsLicensed));
    }
    if (stringToBoolean(getLocalStorageValue(CUSTOM_LOCAL_STORE_KEYS.SYSTEM_LOGGER))) {
        navButtons.push(NAV_BUTTONS.LOGGER);
    }
    // This function modify navButtons;
    addModulesNavForUser(access.currentRole || access, navButtons, modules_list);
    return navButtons;
};

/**
 * @param userAccess - current user access object
 * @param getState
 * @returns {Array<Object>}
 */
export function getUserMenuItemsForScope({ userAccess, isCompanyContext, onCompanyEditClick, onCompanyReturnClick, onUserEditClick, onUserSignOutClick, onUserGuideClick, currentUserData }) {
    const userMenuItems = [];
    const userFullName = `${currentUserData?.first_name || ''} ${currentUserData?.last_name || ''}` || NAME_OF_GEAR_BUTTONS.USER_PROFILE;
    const EDIT_COMPANY_BTN = { ...USER_SUBMENU_BUTTONS.EDIT_COMPANY, onClick: onCompanyEditClick };
    const RETURN_COMPANY_BTN = { ...USER_SUBMENU_BUTTONS.RETURN_TO_COMPANY_PAGE, onClick: onCompanyReturnClick };
    const EDIT_PROFILE_SUBMENU = { ...USER_SUBMENU_BUTTONS.EDIT_PROFILE, onClick: onUserEditClick };
    const SIGN_OUT_SUBMENU = { ...USER_SUBMENU_BUTTONS.SIGN_OUT, onClick: onUserSignOutClick };
    const USER_GUIDE_SUBMENU = { ...USER_SUBMENU_BUTTONS.USER_GUIDE, onClick: onUserGuideClick };
    const USER_BTN = { ...USER_MENU_BUTTONS.USER, label: userFullName, title: userFullName, submenu: [EDIT_PROFILE_SUBMENU, SIGN_OUT_SUBMENU] };
    const HELP_BTN = { ...USER_MENU_BUTTONS.HELP, submenu: [USER_GUIDE_SUBMENU] };
    const COMPANY_BTN = { ...USER_MENU_BUTTONS.COMPANY, submenu: [] };

    if (isCompanyContext && userHasRoleCompanyAdmin(userAccess)) {
        COMPANY_BTN.submenu.push(EDIT_COMPANY_BTN);

        if (userAccess.currentRole !== USER_ROLES.COMPANY_ADMIN) {
            COMPANY_BTN.submenu.push(RETURN_COMPANY_BTN);
        }
        userMenuItems.push(COMPANY_BTN);
    }
    userMenuItems.push(USER_BTN);
    userMenuItems.push(HELP_BTN);

    return userMenuItems;
}
