import axios from 'axios';


export function getActiveAlarms() {
    return axios.get('/api/v2/alarms/active/').then(({ data }) => data.alarms || data);
}

export async function updateAlarm(uid, alarm) {
    let { data } = await axios.put(`/api/v2/alarms/${uid}`, alarm);
    data = data.alarms || data;
    return data.length > 0 ? data[0] : undefined;
}

export async function getAlarmsCSV(from, to, site_uid) {
    const typesQuery = 'alarm_type_name[]=zone_violation&alarm_type_name[]=buffer_violation&alarm_type_name[]=emergency_button&alarm_type_name[]=uncertified_operation';
    return axios.get(`/api/v2/alarms?from=${new Date(from).getTime()}&to=${new Date(to).getTime()}&location_uid=${site_uid}&format=csv&${typesQuery}&report=1`);
}

export async function getAlarmsForPeriod(from, to, area_uid) {
    const typesQuery = 'alarm_type_name[]=zone_violation&alarm_type_name[]=buffer_violation&alarm_type_name[]=emergency_button&alarm_type_name[]=uncertified_operation';
    return axios.get(`/api/v2/alarms?from=${from}&to=${to}&sublocation_uid=${area_uid}&format=json&${typesQuery}&report=1`)
        .then(({ data }) => data.alarms || data);
}

export async function getZoneEvents(from, to, area_uids) {
    let query = '';
    if (Array.isArray(area_uids)) {
        query += area_uids.map(uid => `&area_uid[]=${uid}`).join('');
    }
    
    return axios.get(`/api/v2/data/zone_events?from=${from}&to=${to}&type=information&format=csv${query}`);
}

export async function getAlarmsByUrl(url) {
    return axios.get(url);
}
