import axios from 'axios';
import { authDataAdapter, companyAccessAdapter } from '../adapters';

export function auth(data) {
    return axios.post('/api/v2/auth/log_in.json', data)
        .then((res) => authDataAdapter(res.data.data));
}

export const getCompanyAccess = async (company_uid) => {
    const result = await axios.get(`/api/v2/auth/access_company/${company_uid}/`);
    return companyAccessAdapter(result.data.data);
};

/**
 * returns websocket url
 * @param hostName http:\\dev7.rpplabs.com or https:\\dev7.rpplabs.com
 * @returns {axios.Promise}
 */
export const getWsHost = (hostName) => axios.get('/api/v2/wshost/')
    .then((res) => ((hostName.split(':')[0]).toLowerCase() === 'https' ? 'wss://' : 'ws://') + res.data.wsHost); // server host

export const getVersion = () => axios.get('/version')
    .then((res) => res.data);

export const getBeta = () => axios.get('/api/v2/beta/version')
    .then((res) => res.data);

export const validateToken = (data) => (
    axios.post('/api/v2/auth/validate_token/', data)
        .then((res) => ({
            status: true,
            needUpdatePassword: res.data.data.needUpdatePassword,
        }))
        .catch(() => ({
            status: false,
        }))
);

export const logout = (data) => axios.post('/api/v2/auth/log_out/', data)
    .then((res) => res.data)
    .catch((err) => {
        console.error('logout: ', err);
    });
