import axios from 'axios';

export function loadTrackObjects() {
    return axios.get('/api/v2/trackable_objects').then(({ data }) => data.trackableObjects || data);
}

export function loadAllTrackables() { // with deleted
    return axios.get('/api/v2/trackable_objects/all?include_removed=true').then(({ data }) => data.trackableObjects || data);
}

export function loadAllTrackablesForPeriod(sl_uid, from, to) { // with deleted
    return axios.get(`/api/v2/trackable_objects/active_for_period?sublocation_uid=${sl_uid}&from=${from}&to=${to}`).then(({ data }) => data.trackableObjects || data);
}

export function loadTrackablesExistedInPeriod(from, to) { // with deleted
    return axios.get(`/api/v2/trackable_objects/existed_for_period?from=${from}&to=${to}`).then(({ data }) => data.trackableObjects || data);
}

export function loadCompanyTrackObjects() {
    return axios.get('/api/v2/trackable_objects/all').then(({ data }) => data.trackableObjects || data);
}

export function loadTrackObjectsByUid(uid) {
    return axios.get(`/api/v2/trackable_objects/${uid}`).then(({ data }) => {
        const [trackable] = data.trackableObjects || data;

        return trackable;
    });
}

export function createTrackable(params) {
    return axios.post('/api/v2/trackable_objects', params).then(({ data }) => data.trackableObjects || data);
}

export function updateTrackable(params, uid) {
    return axios.put(`/api/v2/trackable_objects/${uid || params.uid}`, params).then(({ data }) => data.trackableObjects || data);
}

export function getTrackablePosition(trackableUid) {
    return axios.get(`/api/v2/trackable_objects/position_from_state/${trackableUid}`)
        .then(({ data }) => data.trackablePositionFromState);
}

export function deleteTrackable(params) {
    return axios.delete(`/api/v2/trackable_objects/${params.uid}`).then(() => {});
}

/**
 * @return {Promise<Array<TrackableTemplates>>}
 */
export function loadTrackableTemplates() {
    return axios.get('/api/v2/trackable_objects/templates')
        .then(({ data }) => (data.trackable_templates));
}
