import axios from 'axios';
import { userAccessControlResAdapter, userAccessControlReqAdapter } from '../adapters';

export function getUsers() {
    return axios.get('/api/v2/users/?withProjects=true').then(res => res.data.users);
}

export function getHelperLink() {
    return axios.get('/api/v2/info/helper').then(res => res.data);
}

export function getSiteMonitorLink() {
    return axios.get('/api/v2/info/site_monitor').then(res => res.data);
}

export function updateUserAccess(projectUid, user) {
    const params = {
        projectUsersAccess: [{
            user_uid: user.uid,
            user_role: user.role,
            project_uid: projectUid,
        }],
    };
    return axios.post('/api/v2/projects/access/', params)
        .then((res) => {
            /**
             * @type {Array<{
             *      email: String;
             *      project_uid: String;
             *      user_role: String;
             *      user_uid : String;
             *  }>}
             */
            return res.data.projectUsersAccess[0];
        });
}

/**
 * @function
 * @param {Object} data
 * @property {String} data.role
 * @property {Number} data.userSessionTimeout
 * @property {Number} data.accountExpirationTimeout
 * @property {String} data.companyUid
 * @return {Promise<Object>}
 * */
export async function updateUserAccessControl(data) {
    const companyUid = axios.defaults.headers.common['X-User-Subcontractor'];
    return axios.put('/api/v2/users/access_control/', userAccessControlReqAdapter({ ...data, companyUid }))
        .then(res => userAccessControlResAdapter(res.data.access_control))
        .then((data) => data[0]);
}

export async function getUserAccessControl() {
    const companyUid = axios.defaults.headers.common['X-User-Subcontractor'];
    const uacList = await axios.get('/api/v2/users/access_control/').then(res => userAccessControlResAdapter(res.data.access_control));
    return uacList.filter(item => item.companyUid === companyUid);
}

export function deleteUser(uid) {
    return axios.delete(`/api/v2/users/${uid}/`).then(res => res.data);
}

export function createUser(params) {
    return axios.post('/api/v2/users', params).then(res => res.data.user || res.data);
}

export function updateUser(params, uid) {
    return axios.put(`/api/v2/users/${uid}/`, params).then(res => res.data.user || res.data);
}

export function validateUser(params) {
    return axios.post('/api/v2/users/validation', params).then(res => res.data);
}

export function restorePassword(email) {
    return axios.put('/api/v2/users/restorePassword/', { email }).then(res => res.data.result);
}

export async function changePassword({ uid, oldPassword, newPassword }) { // uid, oldPassword, newPassword
    return axios.put('/api/v2/users/changePassword', { uid, oldPassword, newPassword }).then(res => res);
}
