import axios from 'axios';

export * from './api';

export const setParamsToHeader = ({ hostName, token, email, project, company }, companyUid) => {
    if (hostName) {
        axios.defaults.baseURL = hostName;
    }
    
    if (token) {
        axios.defaults.headers.common['X-User-Token'] = token;
    }
    if (email) {
        axios.defaults.headers.common['X-User-Email'] = email;
    }
    
    if (project) {
        axios.defaults.headers.common['X-User-Project'] = project.uid;
    } else if (axios.defaults.headers.common['X-User-Project']) {
        delete axios.defaults.headers.common['X-User-Project'];
    }
    
    if (company) {
        axios.defaults.headers.common['X-User-Subcontractor'] = company ? company.uid : companyUid;
    }
};

let tokenRefreshing = false;
let failedRequestsQueue = [];

const processQueue = (error, token = null) => {
    failedRequestsQueue.forEach((prom) => {
        if (error) {
            prom.reject(error);
        } else {
            prom.resolve(token);
        }
    });
    
    failedRequestsQueue = [];
    tokenRefreshing = false;
};

axios.interceptors.response.use((response) => response, (error) => {
    const originalRequest = error.config;
    const isRefreshTokenRequest = originalRequest.url.includes('/refresh_token');
    if (error.response && error.response.status === 401 && !isRefreshTokenRequest && !originalRequest._retry) {
        if (tokenRefreshing) {
            return new Promise((resolve, reject) => {
                failedRequestsQueue.push({ resolve, reject });
            }).then((token) => {
                originalRequest.headers['X-User-Token'] = token;
                return axios(originalRequest);
            }).catch((err) => Promise.reject(err));
        }
        
        originalRequest._retry = true;
        tokenRefreshing = true;
        const email = axios.defaults.headers.common['X-User-Email'];
        const token = axios.defaults.headers.common['X-User-Token'];
        return new Promise((resolve, reject) => {
            axios.post('/api/v2/auth/refresh_token/', { email, token })
                .then(({ data }) => {
                    axios.defaults.headers.common['X-User-Token'] = data.data.token;
                    originalRequest.headers['X-User-Token'] = data.data.token;
                    processQueue(null, data.data.token);
                    if (originalRequest.url.includes('/auth/validate_token')) {
                        originalRequest.data = JSON.stringify({ ...JSON.parse(originalRequest.data), token: data.data.token });
                    }
                    resolve(axios(originalRequest));
                })
                .catch((err) => {
                    processQueue(err, null);
                    reject(err);
                });
        });
    }
    return Promise.reject(error);
});
