import SpaghettiNotifyMethods from './SpaghettiNotifyMethods';
import { HTTP_STATUS } from '../../js/common/constants';
import SpaghettiError from '../../js/stores/classes/SpaghettiError';

export default class SpaghettiHttpMethods extends SpaghettiNotifyMethods {
    requestServerData = (params, spaghettiId) => {
        const { token, email, project_uid, hostname, queryParams } = params;
        const spaghettiParams = {
            from: params.spaghettiFrom,
            to: params.spaghettiTo,
            trackable_uids: params.trackables.map((trackable) => trackable.uid),
            sublocation_uid: params.sublocation.uid,
        };
        
        const req = new XMLHttpRequest();
        const queryServer = queryParams.target_server ? `?target_server=${queryParams.target_server}` : '';

        req.open('POST', `${hostname}/api/v2/spaghetti${queryServer}`, true);
        req.setRequestHeader('X-User-Token', token);
        req.setRequestHeader('X-User-Email', email);
        req.setRequestHeader('X-User-Project', project_uid);
        req.setRequestHeader('Content-Type', 'application/json');
        req.send(JSON.stringify(spaghettiParams));
        
        req.onprogress = () => { };
        
        req.onloadend = (data) => {
            if (data.target && data.target.status === HTTP_STATUS.OK) {
                const _positions = data.target.responseText.split('/');
                const positions = _positions.reduce((memo, _position, index) => {
                    if (index > 0) {
                        const [uid, x, y, ts] = _position.split(',');
                        if (x && y && ts) {
                            memo.push({
                                uid, x, y, ts: Number(ts),
                            });
                        }
                    }
                    return memo;
                }, []).sort((a, b) => a.ts - b.ts);
                this.handleSpaghettiPositions(positions, spaghettiId, params.displayTo);
                this.getSpaghettiForTimeFrame(params.spaghettiFrom, params.spaghettiTo, spaghettiId);
                console.log('History load ended');
            } else {
                this.notifyClientAboutError(new SpaghettiError());
            }
        };
    };    
}
