import { getDistanceBetweenPointsInMm, getDistanceWithFloatingPointPrevention } from 'worker/utils';
import { distanceBetween, formatIdlePosition, formatPosition, formatRawPos } from './common/formatters';
import SpaghettiHttpMethods from './SpaghettiHttpMethods';


export default class SpaghettiPositionMethods extends SpaghettiHttpMethods {
    trackableMoved = (lastPosition, currentPosition) => distanceBetween(lastPosition, currentPosition) > this.minimalFilteredDistance;
    
    breakDownSpaghetti = (curPos, prevPos) => {
        const timeGap = curPos.ts - prevPos.ts;
        const distanceGap = distanceBetween(curPos, prevPos);
        return timeGap > this.break_down_time && distanceGap > this.break_down_ditance;
    };
    
    handlePosition = (lastPositions, curPos, prevPos, trackableInSpaghetti, uid, sublocation) => {
        const lastPos = lastPositions[uid];
        if (trackableInSpaghetti.positions[0].length === 0) {
            lastPositions[uid] = { ...curPos, distance: 0, deltaDistance: 0 };
            trackableInSpaghetti.addPos(formatPosition(lastPositions[uid], sublocation));
        } else if (this.trackableMoved(lastPos, curPos)) {
            const deltaDistance = getDistanceBetweenPointsInMm(lastPos, curPos);
            const distance = getDistanceWithFloatingPointPrevention(lastPos.distance, deltaDistance);
            lastPositions[uid] = { ...curPos, distance, deltaDistance };
            if (this.breakDownSpaghetti(curPos, prevPos)) {
                trackableInSpaghetti.breakDown();
            }
            trackableInSpaghetti.addPos(formatPosition(lastPositions[uid], sublocation));
        } else {
            trackableInSpaghetti.setLastPositionTs(curPos.ts);
        }
    };
    
    addIdlePos = (trackable, idlePositions, uid, sublocation) => {
        const index = trackable.idlePosIndex(idlePositions[uid].ts);
        if (index !== -1) {
            trackable.replaceIdlePos(formatIdlePosition(idlePositions[uid], sublocation), index);
        } else {
            trackable.addIdlePos(formatIdlePosition(idlePositions[uid], sublocation));
        }
    }
    
    handleIdlePosition = (idlePositions, curPos, trackableInSpaghetti, uid, sublocation, spaghettiFrom) => {
        const idlePos = idlePositions[uid];
        const firstPosition = !idlePos;
        
        if (firstPosition) {
            idlePositions[uid] = { ...curPos, ts: spaghettiFrom, idle: curPos.ts - spaghettiFrom };
            if (idlePositions[uid].idle > this.indle_time) {
                trackableInSpaghetti.addIdlePos(formatIdlePosition(idlePositions[uid], sublocation));
            }
        } else if (idlePos && curPos.ts - idlePos.ts > this.indle_time && !this.trackableMoved(curPos, idlePos)) {
            idlePositions[uid].idle = curPos.ts - idlePos.ts;
            this.addIdlePos(trackableInSpaghetti, idlePositions, uid, sublocation);
        } else if (this.trackableMoved(curPos, idlePos)) {
            idlePositions[uid] = { ...curPos, idle: 0 };
        }
    };
    
    checkIdleForLastPosition = (idlePositions, spaghettiId, spaghettiTo, sublocation) => {
        for (const uid in idlePositions) {
            const trackable = this.spaghetti[spaghettiId].trackables[uid];
            if (spaghettiTo - idlePositions[uid].ts > this.indle_time) {
                idlePositions[uid].idle = spaghettiTo - idlePositions[uid].ts;
                this.addIdlePos(trackable, idlePositions, uid, sublocation);
            }
        }
    };
    
    handleSpaghettiPositions = (positions, spaghettiId, spaghettiTo) => {
        const lastPositions = {};
        const prevPositions = {};
        const idlePositions = {};
        if (this.spaghetti[spaghettiId]) {
            const { sublocation, spaghettiFrom, trackables } = this.spaghetti[spaghettiId];
            
            positions.forEach((pos) => {
                const trackableInSpaghetti = trackables[pos.uid];
                if (trackableInSpaghetti) {
                    const curPos = formatRawPos(pos);
                    const prevPos = prevPositions[pos.uid] ? formatRawPos(prevPositions[pos.uid]) : curPos;
                    this.handlePosition(lastPositions, curPos, prevPos, trackableInSpaghetti, pos.uid, sublocation);
                    this.handleIdlePosition(idlePositions, curPos, trackableInSpaghetti, pos.uid, sublocation, spaghettiFrom);
                    prevPositions[pos.uid] = pos;
                }
            });
            this.checkIdleForLastPosition(idlePositions, spaghettiId, spaghettiTo, sublocation);
        }
    };
}
