import { getDistanceWithFloatingPointPrevention } from 'worker/utils';


export class SpaghettiTrackable {
    constructor(trackable, color) {
        this.positions = [[]];
        this.idle_positions = [];
        this.posListIndex = 0;
        this.totalDistance = 0;
        this.uid = trackable.uid;
        this.name = trackable.name;
        this.color = color;
    }
    
    breakDown() {
        this.posListIndex += 1;
        this.positions.push([]);
    }
    
    addPos(pos) {
        this.positions[this.posListIndex].push(pos);
        this.totalDistance = pos.distance;
    }

    addIdlePos(idlePos) {
        this.idle_positions.push(idlePos);
    }
    
    idlePosIndex(ts) {
        return this.idle_positions.findIndex(pos => pos.ts === ts);
    }

    replaceIdlePos(idlePos, index) {
        this.idle_positions[index] = idlePos;
    }
    
    setLastPositionTs(ts) {
        const listIdx = this.positions.length - 1;
        const lastPosIndex = this.positions[listIdx].length - 1;
        this.positions[listIdx][lastPosIndex].ts = ts;
    }
    
    get totalIdleTime() {
        return this.idle_positions.reduce((acc, el) => acc + el.idle, 0);
    }
}

export class DisplayedTrackable {
    constructor(trackable, timeframe) {
        this.trackable = trackable;
        this.displayFrom = timeframe.displayFrom;
        this.displayTo = timeframe.displayTo;
    }
    
    get displayIdlePos() {
        return this.trackable.idle_positions.reduce((memo, idlePos) => {
            const idleStartBeforeFrom = idlePos.ts < this.displayFrom;
            const idleEndAfterFrom = idlePos.ts + idlePos.idle > this.displayFrom;
            const isIdleStartBetweenFromTo = idlePos.ts >= this.displayFrom && idlePos.ts <= this.displayTo;
            
            if ((idleStartBeforeFrom && idleEndAfterFrom) || isIdleStartBetweenFromTo) {
                memo.push(idlePos);
            }
            return memo;
        }, []);
    }
    
    get displayPos() {
        return this.trackable.positions.map(positions => positions.reduce((memo, pos) => {
            if (pos.ts >= this.displayFrom && pos.ts <= this.displayTo) {
                if (memo.length === 0) {
                    memo.push({ ...pos, distance: 0, deltaDistance: 0 });
                } else {
                    const distance = getDistanceWithFloatingPointPrevention(memo[memo.length - 1].distance, pos.deltaDistance);
                    memo.push({ ...pos, distance });
                }
            }
            return memo;
        }, [])).filter(positions => positions.length > 0);
    }
    
    get data() {
        return {
            name: this.trackable.name,
            uid: this.trackable.uid,
            color: this.trackable.color,
            positions: this.displayPos,
            idle_positions: this.displayIdlePos,
            totalDistance: this.trackable.totalDistance,
            totalIdleTime: this.trackable.totalIdleTime,
        };
    }
}
