import { WS_ACTIONS } from '../common/constants';
import WSNotifyHandlers from './NotifyHandlers';


class WebSocketHandler extends WSNotifyHandlers {
    init = () => {
        if (this.openedChannels && this.openedChannels.length > 0) {
            this.unsubscribe(this.openedChannels);
            this.ws.close();
        }

        this.ws = new WebSocket(this.wsHost);
        this.ws.onopen = this.onOpen;
        this.ws.onmessage = this.onMessage;
        this.ws.onclose = this.onClose;
        this.ws.onerror = this.onError;
    };
    reconnect = () => {
        this.reconnectTimerId = setInterval(() => {
            this.init();
        }, 5000);
    };
    onOpen = () => {
        console.info('[WebSocketHandler] WebSocket open');

        if (this.reconnectTimerId) {
            clearInterval(this.reconnectTimerId);
            this.reconnectTimerId = null;
        }

        self.postMessage({
            type: WS_ACTIONS.WORKER_WEB_SOCKET_TURN_ON,
            params: null,
        });
        // turn on life mode by default, when opened ws
        this.startUpdateInterval();

        // this.subscribe(['notify']);
        this.subscribe(['notify', 'alarm']); // default channels
    };
    onClose = () => {
        console.info('[WebSocketHandler] WebSocket close');

        // wait, until reconnect work without success
        if (this.reconnectTimerId) return;

        this.reconnect();

        self.postMessage({
            type: WS_ACTIONS.WORKER_WEB_SOCKET_TURN_OFF,
            params: null,
        });
        this.stopUpdateInterval();

        this.unsubscribe(this.openedChannels);
    };
    onError = (error) => {
        console.error('[WebSocketHandler] WebScoket error', error);
    };
    onMessage = (message) => {
        // console.log('WebSocket message', message);

        try {
            message = JSON.parse(message.data);
        } catch (e) {
            console.error('[WebSocketHandler] Wrong message by ws ', e);
        }

        if (message.method === 'notify') {
            this.handleNotifyMessage(message.params);
        } else {
            console.warn('[WebSocketHandler] Message not notify from ws ', message);
        }
    };

    constructor(initialData) {
        super();

        // console.info('[WebSocketHandler] webSocket init', initialData);

        this.userEmail = initialData.userEmail;
        this.userToken = initialData.userToken;
        this.companyUid = initialData.companyUid;
        this.projectUid = initialData.projectUid;
        this.wsHost = initialData.wsHost;

        this.init();

        // class variables
        this.openedChannels = [];
        this.reconnectTimerId = null;
    }
}

export default WebSocketHandler;
